package androidx.constraintlayout.motion.widget;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.RectF;
import android.util.AttributeSet;
import android.util.Log;
import android.util.SparseIntArray;
import android.view.View;
import android.view.ViewGroup;
import androidx.base.b2;
import androidx.constraintlayout.widget.R;
import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.HashSet;

public class KeyTrigger extends Key {
    public static final int KEY_TYPE = 5;
    public static final String NAME = "KeyTrigger";
    private static final String TAG = "KeyTrigger";
    public RectF mCollisionRect;
    private String mCross = null;
    private int mCurveFit = -1;
    private Method mFireCross;
    private boolean mFireCrossReset;
    private float mFireLastPos;
    private Method mFireNegativeCross;
    private boolean mFireNegativeReset;
    private Method mFirePositiveCross;
    private boolean mFirePositiveReset;
    private float mFireThreshold;
    private String mNegativeCross;
    private String mPositiveCross;
    private boolean mPostLayout;
    public RectF mTargetRect;
    private int mTriggerCollisionId;
    private View mTriggerCollisionView;
    private int mTriggerID;
    private int mTriggerReceiver;
    public float mTriggerSlack;

    public static class Loader {
        private static final int COLLISION = 9;
        private static final int CROSS = 4;
        private static final int FRAME_POS = 8;
        private static final int NEGATIVE_CROSS = 1;
        private static final int POSITIVE_CROSS = 2;
        private static final int POST_LAYOUT = 10;
        private static final int TARGET_ID = 7;
        private static final int TRIGGER_ID = 6;
        private static final int TRIGGER_RECEIVER = 11;
        private static final int TRIGGER_SLACK = 5;
        private static SparseIntArray mAttrMap;

        static {
            SparseIntArray sparseIntArray = new SparseIntArray();
            mAttrMap = sparseIntArray;
            sparseIntArray.append(R.styleable.KeyTrigger_framePosition, 8);
            mAttrMap.append(R.styleable.KeyTrigger_onCross, 4);
            mAttrMap.append(R.styleable.KeyTrigger_onNegativeCross, 1);
            mAttrMap.append(R.styleable.KeyTrigger_onPositiveCross, 2);
            mAttrMap.append(R.styleable.KeyTrigger_motionTarget, 7);
            mAttrMap.append(R.styleable.KeyTrigger_triggerId, 6);
            mAttrMap.append(R.styleable.KeyTrigger_triggerSlack, 5);
            mAttrMap.append(R.styleable.KeyTrigger_motion_triggerOnCollision, 9);
            mAttrMap.append(R.styleable.KeyTrigger_motion_postLayoutCollision, 10);
            mAttrMap.append(R.styleable.KeyTrigger_triggerReceiver, 11);
        }

        private Loader() {
        }

        public static void read(KeyTrigger keyTrigger, TypedArray typedArray, Context context) {
            int indexCount = typedArray.getIndexCount();
            for (int i = 0; i < indexCount; i++) {
                int index = typedArray.getIndex(i);
                switch (mAttrMap.get(index)) {
                    case 1:
                        keyTrigger.mNegativeCross = typedArray.getString(index);
                        continue;
                    case 2:
                        keyTrigger.mPositiveCross = typedArray.getString(index);
                        continue;
                    case 4:
                        keyTrigger.mCross = typedArray.getString(index);
                        continue;
                    case 5:
                        keyTrigger.mTriggerSlack = typedArray.getFloat(index, keyTrigger.mTriggerSlack);
                        continue;
                    case 6:
                        keyTrigger.mTriggerID = typedArray.getResourceId(index, keyTrigger.mTriggerID);
                        continue;
                    case 7:
                        if (MotionLayout.IS_IN_EDIT_MODE) {
                            int resourceId = typedArray.getResourceId(index, keyTrigger.mTargetId);
                            keyTrigger.mTargetId = resourceId;
                            if (resourceId == -1) {
                                keyTrigger.mTargetString = typedArray.getString(index);
                            } else {
                                continue;
                            }
                        } else if (typedArray.peekValue(index).type == 3) {
                            keyTrigger.mTargetString = typedArray.getString(index);
                        } else {
                            keyTrigger.mTargetId = typedArray.getResourceId(index, keyTrigger.mTargetId);
                        }
                    case 8:
                        int integer = typedArray.getInteger(index, keyTrigger.mFramePosition);
                        keyTrigger.mFramePosition = integer;
                        keyTrigger.mFireThreshold = (((float) integer) + 0.5f) / 100.0f;
                        continue;
                    case 9:
                        keyTrigger.mTriggerCollisionId = typedArray.getResourceId(index, keyTrigger.mTriggerCollisionId);
                        continue;
                    case 10:
                        keyTrigger.mPostLayout = typedArray.getBoolean(index, keyTrigger.mPostLayout);
                        continue;
                    case 11:
                        keyTrigger.mTriggerReceiver = typedArray.getResourceId(index, keyTrigger.mTriggerReceiver);
                        break;
                }
                StringBuilder j = b2.j("unused attribute 0x");
                j.append(Integer.toHexString(index));
                j.append("   ");
                j.append(mAttrMap.get(index));
                Log.e("KeyTrigger", j.toString());
            }
        }
    }

    public KeyTrigger() {
        int i = Key.UNSET;
        this.mTriggerReceiver = i;
        this.mNegativeCross = null;
        this.mPositiveCross = null;
        this.mTriggerID = i;
        this.mTriggerCollisionId = i;
        this.mTriggerCollisionView = null;
        this.mTriggerSlack = 0.1f;
        this.mFireCrossReset = true;
        this.mFireNegativeReset = true;
        this.mFirePositiveReset = true;
        this.mFireThreshold = Float.NaN;
        this.mPostLayout = false;
        this.mCollisionRect = new RectF();
        this.mTargetRect = new RectF();
        this.mType = 5;
        this.mCustomConstraints = new HashMap<>();
    }

    private void setUpRect(RectF rectF, View view, boolean z) {
        rectF.top = (float) view.getTop();
        rectF.bottom = (float) view.getBottom();
        rectF.left = (float) view.getLeft();
        rectF.right = (float) view.getRight();
        if (z) {
            view.getMatrix().mapRect(rectF);
        }
    }

    @Override // androidx.constraintlayout.motion.widget.Key
    public void addValues(HashMap<String, SplineSet> hashMap) {
    }

    /* JADX WARNING: Removed duplicated region for block: B:108:? A[ADDED_TO_REGION, RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:36:0x008d  */
    /* JADX WARNING: Removed duplicated region for block: B:41:0x00a2  */
    /* JADX WARNING: Removed duplicated region for block: B:47:0x00b7  */
    /* JADX WARNING: Removed duplicated region for block: B:54:0x00cf  */
    /* JADX WARNING: Removed duplicated region for block: B:66:0x00fb  */
    /* JADX WARNING: Removed duplicated region for block: B:73:0x011b A[SYNTHETIC, Splitter:B:73:0x011b] */
    /* JADX WARNING: Removed duplicated region for block: B:86:0x018c A[SYNTHETIC, Splitter:B:86:0x018c] */
    /* JADX WARNING: Removed duplicated region for block: B:95:0x01f5  */
    public void conditionallyFire(float f, View view) {
        boolean z;
        boolean z2;
        boolean z3;
        boolean z4;
        boolean z5;
        boolean z6 = true;
        if (this.mTriggerCollisionId != Key.UNSET) {
            if (this.mTriggerCollisionView == null) {
                this.mTriggerCollisionView = ((ViewGroup) view.getParent()).findViewById(this.mTriggerCollisionId);
            }
            setUpRect(this.mCollisionRect, this.mTriggerCollisionView, this.mPostLayout);
            setUpRect(this.mTargetRect, view, this.mPostLayout);
            if (this.mCollisionRect.intersect(this.mTargetRect)) {
                if (this.mFireCrossReset) {
                    this.mFireCrossReset = false;
                    z3 = true;
                } else {
                    z3 = false;
                }
                if (this.mFirePositiveReset) {
                    this.mFirePositiveReset = false;
                    z2 = true;
                } else {
                    z2 = false;
                }
                this.mFireNegativeReset = true;
                z = false;
                this.mFireLastPos = f;
                if (z || z3 || z2) {
                    ((MotionLayout) view.getParent()).fireTrigger(this.mTriggerID, z2, f);
                }
                if (this.mTriggerReceiver != Key.UNSET) {
                    view = ((MotionLayout) view.getParent()).findViewById(this.mTriggerReceiver);
                }
                if (z && this.mNegativeCross != null) {
                    if (this.mFireNegativeCross == null) {
                        try {
                            this.mFireNegativeCross = view.getClass().getMethod(this.mNegativeCross, new Class[0]);
                        } catch (NoSuchMethodException unused) {
                            StringBuilder j = b2.j("Could not find method \"");
                            j.append(this.mNegativeCross);
                            j.append("\"on class ");
                            j.append(view.getClass().getSimpleName());
                            j.append(" ");
                            j.append(Debug.getName(view));
                            Log.e("KeyTrigger", j.toString());
                        }
                    }
                    this.mFireNegativeCross.invoke(view, new Object[0]);
                }
                if (z2 && this.mPositiveCross != null) {
                    if (this.mFirePositiveCross == null) {
                        try {
                            this.mFirePositiveCross = view.getClass().getMethod(this.mPositiveCross, new Class[0]);
                        } catch (NoSuchMethodException unused2) {
                            StringBuilder j2 = b2.j("Could not find method \"");
                            j2.append(this.mPositiveCross);
                            j2.append("\"on class ");
                            j2.append(view.getClass().getSimpleName());
                            j2.append(" ");
                            j2.append(Debug.getName(view));
                            Log.e("KeyTrigger", j2.toString());
                        }
                    }
                    this.mFirePositiveCross.invoke(view, new Object[0]);
                }
                if (!z3 && this.mCross != null) {
                    if (this.mFireCross == null) {
                        try {
                            this.mFireCross = view.getClass().getMethod(this.mCross, new Class[0]);
                        } catch (NoSuchMethodException unused3) {
                            StringBuilder j3 = b2.j("Could not find method \"");
                            j3.append(this.mCross);
                            j3.append("\"on class ");
                            j3.append(view.getClass().getSimpleName());
                            j3.append(" ");
                            j3.append(Debug.getName(view));
                            Log.e("KeyTrigger", j3.toString());
                        }
                    }
                    try {
                        this.mFireCross.invoke(view, new Object[0]);
                        return;
                    } catch (Exception unused4) {
                        StringBuilder j4 = b2.j("Exception in call \"");
                        j4.append(this.mCross);
                        j4.append("\"on class ");
                        j4.append(view.getClass().getSimpleName());
                        j4.append(" ");
                        j4.append(Debug.getName(view));
                        Log.e("KeyTrigger", j4.toString());
                        return;
                    }
                } else {
                    return;
                }
            } else {
                if (!this.mFireCrossReset) {
                    this.mFireCrossReset = true;
                    z3 = true;
                } else {
                    z3 = false;
                }
                if (this.mFireNegativeReset) {
                    this.mFireNegativeReset = false;
                    z5 = true;
                } else {
                    z5 = false;
                }
                this.mFirePositiveReset = true;
                z = z5;
            }
        } else {
            if (this.mFireCrossReset) {
                float f2 = this.mFireThreshold;
                if ((this.mFireLastPos - f2) * (f - f2) < 0.0f) {
                    this.mFireCrossReset = false;
                    z3 = true;
                    if (!this.mFireNegativeReset) {
                        float f3 = this.mFireThreshold;
                        float f4 = f - f3;
                        if ((this.mFireLastPos - f3) * f4 < 0.0f && f4 < 0.0f) {
                            this.mFireNegativeReset = false;
                            z4 = true;
                            if (this.mFirePositiveReset) {
                                float f5 = this.mFireThreshold;
                                float f6 = f - f5;
                                if ((this.mFireLastPos - f5) * f6 >= 0.0f || f6 <= 0.0f) {
                                    z6 = false;
                                } else {
                                    this.mFirePositiveReset = false;
                                }
                                z2 = z6;
                                z = z4;
                                this.mFireLastPos = f;
                                ((MotionLayout) view.getParent()).fireTrigger(this.mTriggerID, z2, f);
                                if (this.mTriggerReceiver != Key.UNSET) {
                                }
                                if (this.mFireNegativeCross == null) {
                                }
                                this.mFireNegativeCross.invoke(view, new Object[0]);
                                if (this.mFirePositiveCross == null) {
                                }
                                this.mFirePositiveCross.invoke(view, new Object[0]);
                                if (!z3) {
                                    return;
                                }
                                return;
                            }
                            if (Math.abs(f - this.mFireThreshold) > this.mTriggerSlack) {
                                this.mFirePositiveReset = true;
                            }
                            z = z4;
                        }
                    } else if (Math.abs(f - this.mFireThreshold) > this.mTriggerSlack) {
                        this.mFireNegativeReset = true;
                    }
                    z4 = false;
                    if (this.mFirePositiveReset) {
                    }
                }
            } else if (Math.abs(f - this.mFireThreshold) > this.mTriggerSlack) {
                this.mFireCrossReset = true;
            }
            z3 = false;
            if (!this.mFireNegativeReset) {
            }
            z4 = false;
            if (this.mFirePositiveReset) {
            }
        }
        z2 = false;
        this.mFireLastPos = f;
        ((MotionLayout) view.getParent()).fireTrigger(this.mTriggerID, z2, f);
        if (this.mTriggerReceiver != Key.UNSET) {
        }
        if (this.mFireNegativeCross == null) {
        }
        try {
            this.mFireNegativeCross.invoke(view, new Object[0]);
        } catch (Exception unused5) {
            StringBuilder j5 = b2.j("Exception in call \"");
            j5.append(this.mNegativeCross);
            j5.append("\"on class ");
            j5.append(view.getClass().getSimpleName());
            j5.append(" ");
            j5.append(Debug.getName(view));
            Log.e("KeyTrigger", j5.toString());
        }
        if (this.mFirePositiveCross == null) {
        }
        try {
            this.mFirePositiveCross.invoke(view, new Object[0]);
        } catch (Exception unused6) {
            StringBuilder j6 = b2.j("Exception in call \"");
            j6.append(this.mPositiveCross);
            j6.append("\"on class ");
            j6.append(view.getClass().getSimpleName());
            j6.append(" ");
            j6.append(Debug.getName(view));
            Log.e("KeyTrigger", j6.toString());
        }
        if (!z3) {
        }
    }

    @Override // androidx.constraintlayout.motion.widget.Key
    public void getAttributeNames(HashSet<String> hashSet) {
    }

    public int getCurveFit() {
        return this.mCurveFit;
    }

    @Override // androidx.constraintlayout.motion.widget.Key
    public void load(Context context, AttributeSet attributeSet) {
        Loader.read(this, context.obtainStyledAttributes(attributeSet, R.styleable.KeyTrigger), context);
    }

    @Override // androidx.constraintlayout.motion.widget.Key
    public void setValue(String str, Object obj) {
    }
}
