package androidx.room;

import android.content.Context;
import androidx.annotation.NonNull;
import androidx.base.b2;
import androidx.room.RoomDatabase;

public class Room {
    private static final String CURSOR_CONV_SUFFIX = "_CursorConverter";
    public static final String LOG_TAG = "ROOM";
    public static final String MASTER_TABLE_NAME = "room_master_table";

    @NonNull
    public static <T extends RoomDatabase> RoomDatabase.Builder<T> databaseBuilder(@NonNull Context context, @NonNull Class<T> cls, @NonNull String str) {
        if (str != null && str.trim().length() != 0) {
            return new RoomDatabase.Builder<>(context, cls, str);
        }
        throw new IllegalArgumentException("Cannot build a database with null or empty name. If you are trying to create an in memory database, use Room.inMemoryDatabaseBuilder");
    }

    @NonNull
    public static <T, C> T getGeneratedImplementation(Class<C> cls, String str) {
        String str2;
        String name = cls.getPackage().getName();
        String canonicalName = cls.getCanonicalName();
        if (!name.isEmpty()) {
            canonicalName = canonicalName.substring(name.length() + 1);
        }
        String str3 = canonicalName.replace('.', '_') + str;
        try {
            if (name.isEmpty()) {
                str2 = str3;
            } else {
                str2 = name + "." + str3;
            }
            return (T) Class.forName(str2, true, cls.getClassLoader()).newInstance();
        } catch (ClassNotFoundException unused) {
            StringBuilder j = b2.j("cannot find implementation for ");
            j.append(cls.getCanonicalName());
            j.append(". ");
            j.append(str3);
            j.append(" does not exist");
            throw new RuntimeException(j.toString());
        } catch (IllegalAccessException unused2) {
            StringBuilder j2 = b2.j("Cannot access the constructor");
            j2.append(cls.getCanonicalName());
            throw new RuntimeException(j2.toString());
        } catch (InstantiationException unused3) {
            StringBuilder j3 = b2.j("Failed to create an instance of ");
            j3.append(cls.getCanonicalName());
            throw new RuntimeException(j3.toString());
        }
    }

    @NonNull
    public static <T extends RoomDatabase> RoomDatabase.Builder<T> inMemoryDatabaseBuilder(@NonNull Context context, @NonNull Class<T> cls) {
        return new RoomDatabase.Builder<>(context, cls, null);
    }
}
