package com.github.tvbox.quickjs;

import androidx.base.ue;
import java.lang.reflect.Method;

public class JSObject {
    private final QuickJSContext context;
    private boolean isReleased;
    private final long pointer;

    public JSObject(QuickJSContext quickJSContext, long j) {
        this.context = quickJSContext;
        this.pointer = j;
    }

    public final void checkReleased() {
        if (this.isReleased) {
            throw new NullPointerException("This JSObject was Released, Can not call this!");
        }
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || getClass() != obj.getClass()) {
            return false;
        }
        JSObject jSObject = (JSObject) obj;
        if (this.pointer == jSObject.pointer && this.isReleased == jSObject.isReleased && this.context == jSObject.context) {
            return true;
        }
        return false;
    }

    public Boolean getBoolean(String str) {
        Object property = getProperty(str);
        if (property instanceof Boolean) {
            return (Boolean) property;
        }
        return null;
    }

    @Deprecated
    public Boolean getBooleanProperty(String str) {
        Object property = getProperty(str);
        if (property instanceof Boolean) {
            return (Boolean) property;
        }
        return null;
    }

    public QuickJSContext getContext() {
        return this.context;
    }

    public Double getDouble(String str) {
        Object property = getProperty(str);
        if (property instanceof Double) {
            return (Double) property;
        }
        return null;
    }

    @Deprecated
    public Double getDoubleProperty(String str) {
        Object property = getProperty(str);
        if (property instanceof Double) {
            return (Double) property;
        }
        return null;
    }

    @Deprecated
    public Integer getIntProperty(String str) {
        Object property = getProperty(str);
        if (property instanceof Integer) {
            return (Integer) property;
        }
        return null;
    }

    public Integer getInteger(String str) {
        Object property = getProperty(str);
        if (property instanceof Integer) {
            return (Integer) property;
        }
        return null;
    }

    public JSArray getJSArray(String str) {
        Object property = getProperty(str);
        if (property instanceof JSArray) {
            return (JSArray) property;
        }
        return null;
    }

    @Deprecated
    public JSArray getJSArrayProperty(String str) {
        Object property = getProperty(str);
        if (property instanceof JSArray) {
            return (JSArray) property;
        }
        return null;
    }

    public JSFunction getJSFunction(String str) {
        Object property = getProperty(str);
        if (property instanceof JSFunction) {
            return (JSFunction) property;
        }
        return null;
    }

    @Deprecated
    public JSFunction getJSFunctionProperty(String str) {
        Object property = getProperty(str);
        if (property instanceof JSFunction) {
            return (JSFunction) property;
        }
        return null;
    }

    public JSObject getJSObject(String str) {
        Object property = getProperty(str);
        if (property instanceof JSObject) {
            return (JSObject) property;
        }
        return null;
    }

    @Deprecated
    public JSObject getJSObjectProperty(String str) {
        Object property = getProperty(str);
        if (property instanceof JSObject) {
            return (JSObject) property;
        }
        return null;
    }

    public JSArray getNames() {
        return (JSArray) ((JSFunction) this.context.evaluate("Object.getOwnPropertyNames")).call(this);
    }

    @Deprecated
    public JSArray getOwnPropertyNames() {
        return (JSArray) ((JSFunction) this.context.evaluate("Object.getOwnPropertyNames")).call(this);
    }

    public long getPointer() {
        return this.pointer;
    }

    public Object getProperty(String str) {
        checkReleased();
        return this.context.getProperty(this, str);
    }

    public String getString(String str) {
        Object property = getProperty(str);
        if (property instanceof String) {
            return (String) property;
        }
        return null;
    }

    @Deprecated
    public String getStringProperty(String str) {
        Object property = getProperty(str);
        if (property instanceof String) {
            return (String) property;
        }
        return null;
    }

    public void hold() {
        this.context.hold(this);
    }

    public boolean isAlive() {
        return this.context.isLiveObject(this);
    }

    public void release() {
        checkReleased();
        this.context.freeValue(this);
        this.isReleased = true;
    }

    public void setProperty(String str, String str2) {
        this.context.setProperty(this, str, str2);
    }

    public String stringify() {
        return this.context.stringify(this);
    }

    public String toString() {
        checkReleased();
        Object evaluate = this.context.evaluate("__format_string;");
        if (!(evaluate instanceof JSFunction)) {
            return super.toString();
        }
        return (String) ((JSFunction) evaluate).call(this);
    }

    public void setProperty(String str, int i) {
        this.context.setProperty(this, str, Integer.valueOf(i));
    }

    public void setProperty(String str, JSObject jSObject) {
        this.context.setProperty(this, str, jSObject);
    }

    public void setProperty(String str, boolean z) {
        this.context.setProperty(this, str, Boolean.valueOf(z));
    }

    public void setProperty(String str, double d) {
        this.context.setProperty(this, str, Double.valueOf(d));
    }

    public void setProperty(String str, JSCallFunction jSCallFunction) {
        this.context.setProperty(this, str, jSCallFunction);
    }

    /* JADX WARNING: Removed duplicated region for block: B:16:0x003c  */
    /* JADX WARNING: Removed duplicated region for block: B:8:0x0011  */
    public void setProperty(String str, Class cls) {
        Object obj;
        try {
            obj = cls.newInstance();
        } catch (IllegalAccessException e) {
            e.printStackTrace();
        } catch (InstantiationException e2) {
            e2.printStackTrace();
        }
        if (obj == null) {
            JSObject createNewJSObject = this.context.createNewJSObject();
            Method[] methods = cls.getMethods();
            for (Method method : methods) {
                if (method.isAnnotationPresent(JSMethod.class)) {
                    createNewJSObject.setProperty(method.getName(), new ue(method, obj));
                }
            }
            setProperty(str, createNewJSObject);
            return;
        }
        throw new NullPointerException("The JavaObj cannot be null. An error occurred in newInstance!");
        obj = null;
        if (obj == null) {
        }
    }
}
