package com.github.tvbox.quickjs;

import okhttp3.HttpUrl;

public class QuickJSContext {
    private static final String UNKNOWN_FILE = "unknown.js";
    private final long context;
    private final long currentThreadId;
    private final NativeCleaner<JSObject> nativeCleaner = new NativeCleaner<JSObject>() {
        /* class com.github.tvbox.quickjs.QuickJSContext.AnonymousClass1 */

        @Override // com.github.tvbox.quickjs.NativeCleaner
        public void onRemove(long j) {
            QuickJSContext quickJSContext = QuickJSContext.this;
            quickJSContext.freeDupValue(quickJSContext.context, j);
        }
    };

    private QuickJSContext() {
        try {
            this.context = createContext();
            this.currentThreadId = Thread.currentThread().getId();
        } catch (UnsatisfiedLinkError unused) {
            throw new QuickJSException("The so library must be initialized before createContext!");
        }
    }

    private native Object call(long j, long j2, long j3, Object[] objArr);

    private void checkSameThread() {
        if (!(this.currentThreadId == Thread.currentThread().getId())) {
            throw new QuickJSException("Must be call same thread in QuickJSContext.create!");
        }
    }

    private native byte[] compile(long j, String str, String str2);

    public static QuickJSContext create() {
        return new QuickJSContext();
    }

    private native long createContext();

    private native void destroyContext(long j);

    private native void dupValue(long j, long j2);

    private void dupValue(JSObject jSObject) {
        checkSameThread();
        dupValue(this.context, jSObject.getPointer());
    }

    private native Object evaluate(long j, String str, String str2);

    private native Object evaluateModule(long j, String str, String str2);

    private native Object execute(long j, byte[] bArr);

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native void freeDupValue(long j, long j2);

    private void freeDupValue(JSObject jSObject) {
        checkSameThread();
        freeDupValue(this.context, jSObject.getPointer());
    }

    private native void freeValue(long j, long j2);

    private native Object get(long j, long j2, int i);

    private native JSObject getGlobalObject(long j);

    private native Object getProperty(long j, long j2, String str);

    private native boolean isLiveObject(long j, long j2);

    private native int length(long j, long j2);

    private native JSObject parseJSON(long j, String str);

    private native void runGC(long j);

    private native void set(long j, long j2, Object obj, int i);

    private native void setMaxStackSize(long j, int i);

    private native void setProperty(long j, long j2, String str, Object obj);

    private native String stringify(long j, long j2);

    public Object call(JSObject jSObject, long j, Object... objArr) {
        checkSameThread();
        return call(this.context, jSObject.getPointer(), j, objArr);
    }

    public byte[] compile(String str) {
        checkSameThread();
        return compile(this.context, str, UNKNOWN_FILE);
    }

    public JSArray createNewJSArray() {
        return (JSArray) parseJSON(HttpUrl.PATH_SEGMENT_ENCODE_SET_URI);
    }

    public JSObject createNewJSObject() {
        return parseJSON("{}");
    }

    public void destroyContext() {
        checkSameThread();
        this.nativeCleaner.forceClean();
        destroyContext(this.context);
    }

    public Object evaluate(String str) {
        return evaluate(str, UNKNOWN_FILE);
    }

    public Object evaluateModule(String str, String str2) {
        return evaluateModule(this.context, str, str2);
    }

    public Object execute(byte[] bArr) {
        checkSameThread();
        return execute(this.context, bArr);
    }

    public void freeValue(JSObject jSObject) {
        checkSameThread();
        freeValue(this.context, jSObject.getPointer());
    }

    public Object get(JSArray jSArray, int i) {
        checkSameThread();
        return get(this.context, jSArray.getPointer(), i);
    }

    public JSObject getGlobalObject() {
        checkSameThread();
        return getGlobalObject(this.context);
    }

    public Object getProperty(JSObject jSObject, String str) {
        checkSameThread();
        return getProperty(this.context, jSObject.getPointer(), str);
    }

    public void hold(JSObject jSObject) {
        checkSameThread();
        dupValue(jSObject);
        this.nativeCleaner.register(jSObject, jSObject.getPointer());
    }

    public boolean isLiveObject(JSObject jSObject) {
        return isLiveObject(this.context, jSObject.getPointer());
    }

    public int length(JSArray jSArray) {
        checkSameThread();
        return length(this.context, jSArray.getPointer());
    }

    public JSObject parseJSON(String str) {
        checkSameThread();
        return parseJSON(this.context, str);
    }

    public void runGC() {
        runGC(this.context);
    }

    public void set(JSArray jSArray, Object obj, int i) {
        checkSameThread();
        set(this.context, jSArray.getPointer(), obj, i);
    }

    public void setMaxStackSize(int i) {
        checkSameThread();
        setMaxStackSize(this.context, i);
    }

    public void setProperty(JSObject jSObject, String str, Object obj) {
        checkSameThread();
        setProperty(this.context, jSObject.getPointer(), str, obj);
    }

    public String stringify(JSObject jSObject) {
        checkSameThread();
        return stringify(this.context, jSObject.getPointer());
    }

    public void throwJSException(String str) {
        checkSameThread();
        evaluate("throw \"" + str + "\";");
    }

    public static QuickJSContext create(int i) {
        QuickJSContext create = create();
        create.setMaxStackSize(i);
        return create;
    }

    public Object evaluate(String str, String str2) {
        checkSameThread();
        return evaluate(this.context, str, str2);
    }

    public Object evaluateModule(String str) {
        checkSameThread();
        return evaluateModule(str, UNKNOWN_FILE);
    }

    public byte[] compile(String str, String str2) {
        checkSameThread();
        return compile(this.context, str, str2);
    }
}
