package com.google.android.exoplayer2.ext.rtmp;

import android.net.Uri;
import androidx.annotation.Nullable;
import com.google.android.exoplayer2.ExoPlayerLibraryInfo;
import com.google.android.exoplayer2.upstream.BaseDataSource;
import com.google.android.exoplayer2.upstream.DataSpec;
import com.google.android.exoplayer2.util.Util;
import net.butterflytv.rtmp_client.RtmpClient;

public final class RtmpDataSource extends BaseDataSource {
    @Nullable
    private RtmpClient rtmpClient;
    @Nullable
    private Uri uri;

    static {
        ExoPlayerLibraryInfo.registerModule("goog.exo.rtmp");
    }

    public RtmpDataSource() {
        super(true);
    }

    @Override // com.google.android.exoplayer2.upstream.DataSource
    public void close() {
        if (this.uri != null) {
            this.uri = null;
            transferEnded();
        }
        RtmpClient rtmpClient2 = this.rtmpClient;
        if (rtmpClient2 != null) {
            rtmpClient2.nativeClose(rtmpClient2.a);
            rtmpClient2.a = 0;
            this.rtmpClient = null;
        }
    }

    @Override // com.google.android.exoplayer2.upstream.DataSource
    @Nullable
    public Uri getUri() {
        return this.uri;
    }

    @Override // com.google.android.exoplayer2.upstream.DataSource
    public long open(DataSpec dataSpec) {
        transferInitializing(dataSpec);
        RtmpClient rtmpClient2 = new RtmpClient();
        this.rtmpClient = rtmpClient2;
        String uri2 = dataSpec.uri.toString();
        long nativeAlloc = rtmpClient2.nativeAlloc();
        rtmpClient2.a = nativeAlloc;
        if (nativeAlloc != 0) {
            int nativeOpen = rtmpClient2.nativeOpen(uri2, false, nativeAlloc, 10000, 10000);
            if (nativeOpen == 0) {
                this.uri = dataSpec.uri;
                transferStarted(dataSpec);
                return -1;
            }
            rtmpClient2.a = 0;
            throw new RtmpClient.a(nativeOpen);
        }
        throw new RtmpClient.a(-2);
    }

    @Override // com.google.android.exoplayer2.upstream.DataReader
    public int read(byte[] bArr, int i, int i2) {
        RtmpClient rtmpClient2 = (RtmpClient) Util.castNonNull(this.rtmpClient);
        int nativeRead = rtmpClient2.nativeRead(bArr, i, i2, rtmpClient2.a);
        if (nativeRead < 0 && nativeRead != -1) {
            throw new RtmpClient.a(nativeRead);
        } else if (nativeRead == -1) {
            return -1;
        } else {
            bytesTransferred(nativeRead);
            return nativeRead;
        }
    }
}
