package com.google.android.exoplayer2.source.rtsp;

import android.net.Uri;
import androidx.annotation.Nullable;
import androidx.base.b2;
import androidx.base.bs;
import androidx.base.ds;
import com.google.android.exoplayer2.util.Util;
import java.util.HashMap;

public final class SessionDescription {
    public static final String ATTR_CONTROL = "control";
    public static final String ATTR_FMTP = "fmtp";
    public static final String ATTR_LENGTH = "length";
    public static final String ATTR_RANGE = "range";
    public static final String ATTR_RTPMAP = "rtpmap";
    public static final String ATTR_TOOL = "tool";
    public static final String ATTR_TYPE = "type";
    public static final String SUPPORTED_SDP_VERSION = "0";
    public final ds<String, String> attributes;
    public final int bitrate;
    @Nullable
    public final String connection;
    @Nullable
    public final String emailAddress;
    @Nullable
    public final String key;
    public final bs<MediaDescription> mediaDescriptionList;
    public final String origin;
    @Nullable
    public final String phoneNumber;
    @Nullable
    public final String sessionInfo;
    public final String sessionName;
    public final String timing;
    @Nullable
    public final Uri uri;

    public static final class Builder {
        private final HashMap<String, String> attributes = new HashMap<>();
        private int bitrate = -1;
        @Nullable
        private String connection;
        @Nullable
        private String emailAddress;
        @Nullable
        private String key;
        private final bs.a<MediaDescription> mediaDescriptionListBuilder = new bs.a<>();
        @Nullable
        private String origin;
        @Nullable
        private String phoneNumber;
        @Nullable
        private String sessionInfo;
        @Nullable
        private String sessionName;
        @Nullable
        private String timing;
        @Nullable
        private Uri uri;

        public Builder addAttribute(String str, String str2) {
            this.attributes.put(str, str2);
            return this;
        }

        public Builder addMediaDescription(MediaDescription mediaDescription) {
            this.mediaDescriptionListBuilder.b(mediaDescription);
            return this;
        }

        public SessionDescription build() {
            if (this.sessionName != null && this.origin != null && this.timing != null) {
                return new SessionDescription(this);
            }
            throw new IllegalStateException("One of more mandatory SDP fields are not set.");
        }

        public Builder setBitrate(int i) {
            this.bitrate = i;
            return this;
        }

        public Builder setConnection(String str) {
            this.connection = str;
            return this;
        }

        public Builder setEmailAddress(String str) {
            this.emailAddress = str;
            return this;
        }

        public Builder setKey(String str) {
            this.key = str;
            return this;
        }

        public Builder setOrigin(String str) {
            this.origin = str;
            return this;
        }

        public Builder setPhoneNumber(String str) {
            this.phoneNumber = str;
            return this;
        }

        public Builder setSessionInfo(String str) {
            this.sessionInfo = str;
            return this;
        }

        public Builder setSessionName(String str) {
            this.sessionName = str;
            return this;
        }

        public Builder setTiming(String str) {
            this.timing = str;
            return this;
        }

        public Builder setUri(Uri uri2) {
            this.uri = uri2;
            return this;
        }
    }

    public boolean equals(@Nullable Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || SessionDescription.class != obj.getClass()) {
            return false;
        }
        SessionDescription sessionDescription = (SessionDescription) obj;
        if (this.bitrate != sessionDescription.bitrate || !this.attributes.equals(sessionDescription.attributes) || !this.mediaDescriptionList.equals(sessionDescription.mediaDescriptionList) || !this.origin.equals(sessionDescription.origin) || !this.sessionName.equals(sessionDescription.sessionName) || !this.timing.equals(sessionDescription.timing) || !Util.areEqual(this.sessionInfo, sessionDescription.sessionInfo) || !Util.areEqual(this.uri, sessionDescription.uri) || !Util.areEqual(this.emailAddress, sessionDescription.emailAddress) || !Util.areEqual(this.phoneNumber, sessionDescription.phoneNumber) || !Util.areEqual(this.connection, sessionDescription.connection) || !Util.areEqual(this.key, sessionDescription.key)) {
            return false;
        }
        return true;
    }

    public int hashCode() {
        int b = (b2.b(this.timing, b2.b(this.sessionName, b2.b(this.origin, (this.mediaDescriptionList.hashCode() + ((this.attributes.hashCode() + 217) * 31)) * 31, 31), 31), 31) + this.bitrate) * 31;
        String str = this.sessionInfo;
        int i = 0;
        int hashCode = (b + (str == null ? 0 : str.hashCode())) * 31;
        Uri uri2 = this.uri;
        int hashCode2 = (hashCode + (uri2 == null ? 0 : uri2.hashCode())) * 31;
        String str2 = this.emailAddress;
        int hashCode3 = (hashCode2 + (str2 == null ? 0 : str2.hashCode())) * 31;
        String str3 = this.phoneNumber;
        int hashCode4 = (hashCode3 + (str3 == null ? 0 : str3.hashCode())) * 31;
        String str4 = this.connection;
        int hashCode5 = (hashCode4 + (str4 == null ? 0 : str4.hashCode())) * 31;
        String str5 = this.key;
        if (str5 != null) {
            i = str5.hashCode();
        }
        return hashCode5 + i;
    }

    private SessionDescription(Builder builder) {
        this.attributes = ds.copyOf(builder.attributes);
        this.mediaDescriptionList = builder.mediaDescriptionListBuilder.e();
        this.sessionName = (String) Util.castNonNull(builder.sessionName);
        this.origin = (String) Util.castNonNull(builder.origin);
        this.timing = (String) Util.castNonNull(builder.timing);
        this.uri = builder.uri;
        this.connection = builder.connection;
        this.bitrate = builder.bitrate;
        this.key = builder.key;
        this.emailAddress = builder.emailAddress;
        this.phoneNumber = builder.phoneNumber;
        this.sessionInfo = builder.sessionInfo;
    }
}
