package com.google.android.exoplayer2.upstream;

import android.content.Context;
import android.os.Handler;
import android.support.v4.media.session.PlaybackStateCompat;
import androidx.annotation.Nullable;
import androidx.base.b;
import androidx.base.bs;
import androidx.base.cs;
import androidx.base.dp;
import androidx.base.ds;
import androidx.base.gp;
import com.google.android.exoplayer2.SimpleExoPlayer;
import com.google.android.exoplayer2.upstream.BandwidthMeter;
import com.google.android.exoplayer2.util.Assertions;
import com.google.android.exoplayer2.util.Clock;
import com.google.android.exoplayer2.util.NetworkTypeObserver;
import com.google.android.exoplayer2.util.SlidingPercentile;
import com.google.android.exoplayer2.util.Util;
import java.util.HashMap;
import java.util.Map;

public final class DefaultBandwidthMeter implements BandwidthMeter, TransferListener {
    private static final int BYTES_TRANSFERRED_FOR_ESTIMATE = 524288;
    private static final int COUNTRY_GROUP_INDEX_2G = 1;
    private static final int COUNTRY_GROUP_INDEX_3G = 2;
    private static final int COUNTRY_GROUP_INDEX_4G = 3;
    private static final int COUNTRY_GROUP_INDEX_5G_NSA = 4;
    private static final int COUNTRY_GROUP_INDEX_5G_SA = 5;
    private static final int COUNTRY_GROUP_INDEX_WIFI = 0;
    public static final cs<String, Integer> DEFAULT_INITIAL_BITRATE_COUNTRY_GROUPS = createInitialBitrateCountryGroupAssignment();
    public static final long DEFAULT_INITIAL_BITRATE_ESTIMATE = 1000000;
    public static final bs<Long> DEFAULT_INITIAL_BITRATE_ESTIMATES_2G = bs.of(248000L, 160000L, 142000L, 127000L, 113000L);
    public static final bs<Long> DEFAULT_INITIAL_BITRATE_ESTIMATES_3G = bs.of(2200000L, 1300000L, 950000L, 760000L, 520000L);
    public static final bs<Long> DEFAULT_INITIAL_BITRATE_ESTIMATES_4G = bs.of(4400000L, 2300000L, 1500000L, 1100000L, 640000L);
    public static final bs<Long> DEFAULT_INITIAL_BITRATE_ESTIMATES_5G_NSA = bs.of(10000000L, 7200000L, 5000000L, 2700000L, 1600000L);
    public static final bs<Long> DEFAULT_INITIAL_BITRATE_ESTIMATES_5G_SA = bs.of(2600000L, 2200000L, 2000000L, 1500000L, 470000L);
    public static final bs<Long> DEFAULT_INITIAL_BITRATE_ESTIMATES_WIFI = bs.of(6200000L, 3900000L, 2300000L, 1300000L, 620000L);
    public static final int DEFAULT_SLIDING_WINDOW_MAX_WEIGHT = 2000;
    private static final int ELAPSED_MILLIS_FOR_ESTIMATE = 2000;
    @Nullable
    private static DefaultBandwidthMeter singletonInstance;
    private long bitrateEstimate;
    private final Clock clock;
    private final BandwidthMeter.EventListener.EventDispatcher eventDispatcher;
    private final ds<Integer, Long> initialBitrateEstimates;
    private long lastReportedBitrateEstimate;
    private int networkType;
    private int networkTypeOverride;
    private boolean networkTypeOverrideSet;
    private final boolean resetOnNetworkTypeChange;
    private long sampleBytesTransferred;
    private long sampleStartTimeMs;
    private final SlidingPercentile slidingPercentile;
    private int streamCount;
    private long totalBytesTransferred;
    private long totalElapsedTimeMs;

    private static cs<String, Integer> createInitialBitrateCountryGroupAssignment() {
        cs.a builder = cs.builder();
        builder.h("AD", 1, 2, 0, 0, 2, 2);
        builder.h("AE", 1, 4, 4, 4, 2, 2);
        builder.h("AF", 4, 4, 3, 4, 2, 2);
        builder.h("AG", 4, 2, 1, 4, 2, 2);
        builder.h("AI", 1, 2, 2, 2, 2, 2);
        builder.h("AL", 1, 1, 1, 1, 2, 2);
        builder.h("AM", 2, 2, 1, 3, 2, 2);
        builder.h("AO", 3, 4, 3, 1, 2, 2);
        builder.h("AR", 2, 4, 2, 1, 2, 2);
        builder.h("AS", 2, 2, 3, 3, 2, 2);
        builder.h("AT", 0, 1, 0, 0, 0, 2);
        builder.h("AU", 0, 2, 0, 1, 1, 2);
        builder.h("AW", 1, 2, 0, 4, 2, 2);
        builder.h("AX", 0, 2, 2, 2, 2, 2);
        builder.h("AZ", 3, 3, 3, 4, 4, 2);
        builder.h("BA", 1, 1, 0, 1, 2, 2);
        builder.h("BB", 0, 2, 0, 0, 2, 2);
        builder.h("BD", 2, 0, 3, 3, 2, 2);
        builder.h("BE", 0, 0, 2, 3, 2, 2);
        builder.h("BF", 4, 4, 4, 2, 2, 2);
        builder.h("BG", 0, 1, 0, 0, 2, 2);
        builder.h("BH", 1, 0, 2, 4, 2, 2);
        builder.h("BI", 4, 4, 4, 4, 2, 2);
        builder.h("BJ", 4, 4, 4, 4, 2, 2);
        builder.h("BL", 1, 2, 2, 2, 2, 2);
        builder.h("BM", 0, 2, 0, 0, 2, 2);
        builder.h("BN", 3, 2, 1, 0, 2, 2);
        builder.h("BO", 1, 2, 4, 2, 2, 2);
        builder.h("BQ", 1, 2, 1, 2, 2, 2);
        builder.h("BR", 2, 4, 3, 2, 2, 2);
        builder.h("BS", 2, 2, 1, 3, 2, 2);
        builder.h("BT", 3, 0, 3, 2, 2, 2);
        builder.h("BW", 3, 4, 1, 1, 2, 2);
        builder.h("BY", 1, 1, 1, 2, 2, 2);
        builder.h("BZ", 2, 2, 2, 2, 2, 2);
        builder.h("CA", 0, 3, 1, 2, 4, 2);
        builder.h("CD", 4, 2, 2, 1, 2, 2);
        builder.h("CF", 4, 2, 3, 2, 2, 2);
        builder.h("CG", 3, 4, 2, 2, 2, 2);
        builder.h("CH", 0, 0, 0, 0, 1, 2);
        builder.h("CI", 3, 3, 3, 3, 2, 2);
        builder.h("CK", 2, 2, 3, 0, 2, 2);
        builder.h("CL", 1, 1, 2, 2, 2, 2);
        builder.h("CM", 3, 4, 3, 2, 2, 2);
        builder.h("CN", 2, 2, 2, 1, 3, 2);
        builder.h("CO", 2, 3, 4, 2, 2, 2);
        builder.h("CR", 2, 3, 4, 4, 2, 2);
        builder.h("CU", 4, 4, 2, 2, 2, 2);
        builder.h("CV", 2, 3, 1, 0, 2, 2);
        builder.h("CW", 1, 2, 0, 0, 2, 2);
        builder.h("CY", 1, 1, 0, 0, 2, 2);
        builder.h("CZ", 0, 1, 0, 0, 1, 2);
        builder.h("DE", 0, 0, 1, 1, 0, 2);
        builder.h("DJ", 4, 0, 4, 4, 2, 2);
        builder.h("DK", 0, 0, 1, 0, 0, 2);
        builder.h("DM", 1, 2, 2, 2, 2, 2);
        builder.h("DO", 3, 4, 4, 4, 2, 2);
        builder.h("DZ", 3, 3, 4, 4, 2, 4);
        builder.h("EC", 2, 4, 3, 1, 2, 2);
        builder.h("EE", 0, 1, 0, 0, 2, 2);
        builder.h("EG", 3, 4, 3, 3, 2, 2);
        builder.h("EH", 2, 2, 2, 2, 2, 2);
        builder.h("ER", 4, 2, 2, 2, 2, 2);
        builder.h("ES", 0, 1, 1, 1, 2, 2);
        builder.h("ET", 4, 4, 4, 1, 2, 2);
        builder.h("FI", 0, 0, 0, 0, 0, 2);
        builder.h("FJ", 3, 0, 2, 3, 2, 2);
        builder.h("FK", 4, 2, 2, 2, 2, 2);
        builder.h("FM", 3, 2, 4, 4, 2, 2);
        builder.h("FO", 1, 2, 0, 1, 2, 2);
        builder.h("FR", 1, 1, 2, 0, 1, 2);
        builder.h("GA", 3, 4, 1, 1, 2, 2);
        builder.h("GB", 0, 0, 1, 1, 1, 2);
        builder.h("GD", 1, 2, 2, 2, 2, 2);
        builder.h("GE", 1, 1, 1, 2, 2, 2);
        builder.h("GF", 2, 2, 2, 3, 2, 2);
        builder.h("GG", 1, 2, 0, 0, 2, 2);
        builder.h("GH", 3, 1, 3, 2, 2, 2);
        builder.h("GI", 0, 2, 0, 0, 2, 2);
        builder.h("GL", 1, 2, 0, 0, 2, 2);
        builder.h("GM", 4, 3, 2, 4, 2, 2);
        builder.h("GN", 4, 3, 4, 2, 2, 2);
        builder.h("GP", 2, 1, 2, 3, 2, 2);
        builder.h("GQ", 4, 2, 2, 4, 2, 2);
        builder.h("GR", 1, 2, 0, 0, 2, 2);
        builder.h("GT", 3, 2, 3, 1, 2, 2);
        builder.h("GU", 1, 2, 3, 4, 2, 2);
        builder.h("GW", 4, 4, 4, 4, 2, 2);
        builder.h("GY", 3, 3, 3, 4, 2, 2);
        builder.h("HK", 0, 1, 2, 3, 2, 0);
        builder.h("HN", 3, 1, 3, 3, 2, 2);
        builder.h("HR", 1, 1, 0, 0, 3, 2);
        builder.h("HT", 4, 4, 4, 4, 2, 2);
        builder.h("HU", 0, 0, 0, 0, 0, 2);
        builder.h("ID", 3, 2, 3, 3, 2, 2);
        builder.h("IE", 0, 0, 1, 1, 3, 2);
        builder.h("IL", 1, 0, 2, 3, 4, 2);
        builder.h("IM", 0, 2, 0, 1, 2, 2);
        builder.h("IN", 2, 1, 3, 3, 2, 2);
        builder.h("IO", 4, 2, 2, 4, 2, 2);
        builder.h("IQ", 3, 3, 4, 4, 2, 2);
        builder.h("IR", 3, 2, 3, 2, 2, 2);
        builder.h("IS", 0, 2, 0, 0, 2, 2);
        builder.h("IT", 0, 4, 0, 1, 2, 2);
        builder.h("JE", 2, 2, 1, 2, 2, 2);
        builder.h("JM", 3, 3, 4, 4, 2, 2);
        builder.h("JO", 2, 2, 1, 1, 2, 2);
        builder.h("JP", 0, 0, 0, 0, 2, 1);
        builder.h("KE", 3, 4, 2, 2, 2, 2);
        builder.h("KG", 2, 0, 1, 1, 2, 2);
        builder.h("KH", 1, 0, 4, 3, 2, 2);
        builder.h("KI", 4, 2, 4, 3, 2, 2);
        builder.h("KM", 4, 3, 2, 3, 2, 2);
        builder.h("KN", 1, 2, 2, 2, 2, 2);
        builder.h("KP", 4, 2, 2, 2, 2, 2);
        builder.h("KR", 0, 0, 1, 3, 1, 2);
        builder.h("KW", 1, 3, 1, 1, 1, 2);
        builder.h("KY", 1, 2, 0, 2, 2, 2);
        builder.h("KZ", 2, 2, 2, 3, 2, 2);
        builder.h("LA", 1, 2, 1, 1, 2, 2);
        builder.h("LB", 3, 2, 0, 0, 2, 2);
        builder.h("LC", 1, 2, 0, 0, 2, 2);
        builder.h("LI", 0, 2, 2, 2, 2, 2);
        builder.h("LK", 2, 0, 2, 3, 2, 2);
        builder.h("LR", 3, 4, 4, 3, 2, 2);
        builder.h("LS", 3, 3, 2, 3, 2, 2);
        builder.h("LT", 0, 0, 0, 0, 2, 2);
        builder.h("LU", 1, 0, 1, 1, 2, 2);
        builder.h("LV", 0, 0, 0, 0, 2, 2);
        builder.h("LY", 4, 2, 4, 3, 2, 2);
        builder.h("MA", 3, 2, 2, 1, 2, 2);
        builder.h("MC", 0, 2, 0, 0, 2, 2);
        builder.h("MD", 1, 2, 0, 0, 2, 2);
        builder.h("ME", 1, 2, 0, 1, 2, 2);
        builder.h("MF", 2, 2, 1, 1, 2, 2);
        builder.h("MG", 3, 4, 2, 2, 2, 2);
        builder.h("MH", 4, 2, 2, 4, 2, 2);
        builder.h("MK", 1, 1, 0, 0, 2, 2);
        builder.h("ML", 4, 4, 2, 2, 2, 2);
        builder.h("MM", 2, 3, 3, 3, 2, 2);
        builder.h("MN", 2, 4, 2, 2, 2, 2);
        builder.h("MO", 0, 2, 4, 4, 2, 2);
        builder.h("MP", 0, 2, 2, 2, 2, 2);
        builder.h("MQ", 2, 2, 2, 3, 2, 2);
        builder.h("MR", 3, 0, 4, 3, 2, 2);
        builder.h("MS", 1, 2, 2, 2, 2, 2);
        builder.h("MT", 0, 2, 0, 0, 2, 2);
        builder.h("MU", 2, 1, 1, 2, 2, 2);
        builder.h("MV", 4, 3, 2, 4, 2, 2);
        builder.h("MW", 4, 2, 1, 0, 2, 2);
        builder.h("MX", 2, 4, 4, 4, 4, 2);
        builder.h("MY", 1, 0, 3, 2, 2, 2);
        builder.h("MZ", 3, 3, 2, 1, 2, 2);
        builder.h("NA", 4, 3, 3, 2, 2, 2);
        builder.h("NC", 3, 0, 4, 4, 2, 2);
        builder.h("NE", 4, 4, 4, 4, 2, 2);
        builder.h("NF", 2, 2, 2, 2, 2, 2);
        builder.h("NG", 3, 3, 2, 3, 2, 2);
        builder.h("NI", 2, 1, 4, 4, 2, 2);
        builder.h("NL", 0, 2, 3, 2, 0, 2);
        builder.h("NO", 0, 1, 2, 0, 0, 2);
        builder.h("NP", 2, 0, 4, 2, 2, 2);
        builder.h("NR", 3, 2, 3, 1, 2, 2);
        builder.h("NU", 4, 2, 2, 2, 2, 2);
        builder.h("NZ", 0, 2, 1, 2, 4, 2);
        builder.h("OM", 2, 2, 1, 3, 3, 2);
        builder.h("PA", 1, 3, 3, 3, 2, 2);
        builder.h("PE", 2, 3, 4, 4, 2, 2);
        builder.h("PF", 2, 2, 2, 1, 2, 2);
        builder.h("PG", 4, 4, 3, 2, 2, 2);
        builder.h("PH", 2, 1, 3, 3, 3, 2);
        builder.h("PK", 3, 2, 3, 3, 2, 2);
        builder.h("PL", 1, 0, 1, 2, 3, 2);
        builder.h("PM", 0, 2, 2, 2, 2, 2);
        builder.h("PR", 2, 1, 2, 2, 4, 3);
        builder.h("PS", 3, 3, 2, 2, 2, 2);
        builder.h("PT", 0, 1, 1, 0, 2, 2);
        builder.h("PW", 1, 2, 4, 1, 2, 2);
        builder.h("PY", 2, 0, 3, 2, 2, 2);
        builder.h("QA", 2, 3, 1, 2, 3, 2);
        builder.h("RE", 1, 0, 2, 2, 2, 2);
        builder.h("RO", 0, 1, 0, 1, 0, 2);
        builder.h("RS", 1, 2, 0, 0, 2, 2);
        builder.h("RU", 0, 1, 0, 1, 4, 2);
        builder.h("RW", 3, 3, 3, 1, 2, 2);
        builder.h("SA", 2, 2, 2, 1, 1, 2);
        builder.h("SB", 4, 2, 3, 2, 2, 2);
        builder.h("SC", 4, 2, 1, 3, 2, 2);
        builder.h("SD", 4, 4, 4, 4, 2, 2);
        builder.h("SE", 0, 0, 0, 0, 0, 2);
        builder.h("SG", 1, 0, 1, 2, 3, 2);
        builder.h("SH", 4, 2, 2, 2, 2, 2);
        builder.h("SI", 0, 0, 0, 0, 2, 2);
        builder.h("SJ", 2, 2, 2, 2, 2, 2);
        builder.h("SK", 0, 1, 0, 0, 2, 2);
        builder.h("SL", 4, 3, 4, 0, 2, 2);
        builder.h("SM", 0, 2, 2, 2, 2, 2);
        builder.h("SN", 4, 4, 4, 4, 2, 2);
        builder.h("SO", 3, 3, 3, 4, 2, 2);
        builder.h("SR", 3, 2, 2, 2, 2, 2);
        builder.h("SS", 4, 4, 3, 3, 2, 2);
        builder.h("ST", 2, 2, 1, 2, 2, 2);
        builder.h("SV", 2, 1, 4, 3, 2, 2);
        builder.h("SX", 2, 2, 1, 0, 2, 2);
        builder.h("SY", 4, 3, 3, 2, 2, 2);
        builder.h("SZ", 3, 3, 2, 4, 2, 2);
        builder.h("TC", 2, 2, 2, 0, 2, 2);
        builder.h("TD", 4, 3, 4, 4, 2, 2);
        builder.h("TG", 3, 2, 2, 4, 2, 2);
        builder.h("TH", 0, 3, 2, 3, 2, 2);
        builder.h("TJ", 4, 4, 4, 4, 2, 2);
        builder.h("TL", 4, 0, 4, 4, 2, 2);
        builder.h("TM", 4, 2, 4, 3, 2, 2);
        builder.h("TN", 2, 1, 1, 2, 2, 2);
        builder.h("TO", 3, 3, 4, 3, 2, 2);
        builder.h("TR", 1, 2, 1, 1, 2, 2);
        builder.h("TT", 1, 4, 0, 1, 2, 2);
        builder.h("TV", 3, 2, 2, 4, 2, 2);
        builder.h("TW", 0, 0, 0, 0, 1, 0);
        builder.h("TZ", 3, 3, 3, 2, 2, 2);
        builder.h("UA", 0, 3, 1, 1, 2, 2);
        builder.h("UG", 3, 2, 3, 3, 2, 2);
        builder.h("US", 1, 1, 2, 2, 4, 2);
        builder.h("UY", 2, 2, 1, 1, 2, 2);
        builder.h("UZ", 2, 1, 3, 4, 2, 2);
        builder.h("VC", 1, 2, 2, 2, 2, 2);
        builder.h("VE", 4, 4, 4, 4, 2, 2);
        builder.h("VG", 2, 2, 1, 1, 2, 2);
        builder.h("VI", 1, 2, 1, 2, 2, 2);
        builder.h("VN", 0, 1, 3, 4, 2, 2);
        builder.h("VU", 4, 0, 3, 1, 2, 2);
        builder.h("WF", 4, 2, 2, 4, 2, 2);
        builder.h("WS", 3, 1, 3, 1, 2, 2);
        builder.h("XK", 0, 1, 1, 0, 2, 2);
        builder.h("YE", 4, 4, 4, 3, 2, 2);
        builder.h("YT", 4, 2, 2, 3, 2, 2);
        builder.h("ZA", 3, 3, 2, 1, 2, 2);
        builder.h("ZM", 3, 2, 3, 3, 2, 2);
        builder.h("ZW", 3, 2, 4, 3, 2, 2);
        return builder.f();
    }

    private long getInitialBitrateEstimateForNetworkType(int i) {
        Long l = this.initialBitrateEstimates.get(Integer.valueOf(i));
        if (l == null) {
            l = this.initialBitrateEstimates.get(0);
        }
        if (l == null) {
            l = 1000000L;
        }
        return l.longValue();
    }

    public static synchronized DefaultBandwidthMeter getSingletonInstance(Context context) {
        DefaultBandwidthMeter defaultBandwidthMeter;
        synchronized (DefaultBandwidthMeter.class) {
            if (singletonInstance == null) {
                singletonInstance = new Builder(context).build();
            }
            defaultBandwidthMeter = singletonInstance;
        }
        return defaultBandwidthMeter;
    }

    private static boolean isTransferAtFullNetworkSpeed(DataSpec dataSpec, boolean z) {
        return z && !dataSpec.isFlagSet(8);
    }

    private void maybeNotifyBandwidthSample(int i, long j, long j2) {
        if (i != 0 || j != 0 || j2 != this.lastReportedBitrateEstimate) {
            this.lastReportedBitrateEstimate = j2;
            this.eventDispatcher.bandwidthSample(i, j, j2);
        }
    }

    /* access modifiers changed from: private */
    public synchronized void onNetworkTypeChanged(int i) {
        int i2 = this.networkType;
        if (i2 == 0 || this.resetOnNetworkTypeChange) {
            if (this.networkTypeOverrideSet) {
                i = this.networkTypeOverride;
            }
            if (i2 != i) {
                this.networkType = i;
                if (i != 1 && i != 0 && i != 8) {
                    this.bitrateEstimate = getInitialBitrateEstimateForNetworkType(i);
                    long elapsedRealtime = this.clock.elapsedRealtime();
                    maybeNotifyBandwidthSample(this.streamCount > 0 ? (int) (elapsedRealtime - this.sampleStartTimeMs) : 0, this.sampleBytesTransferred, this.bitrateEstimate);
                    this.sampleStartTimeMs = elapsedRealtime;
                    this.sampleBytesTransferred = 0;
                    this.totalBytesTransferred = 0;
                    this.totalElapsedTimeMs = 0;
                    this.slidingPercentile.reset();
                }
            }
        }
    }

    @Override // com.google.android.exoplayer2.upstream.BandwidthMeter
    public void addEventListener(Handler handler, BandwidthMeter.EventListener eventListener) {
        Assertions.checkNotNull(handler);
        Assertions.checkNotNull(eventListener);
        this.eventDispatcher.addListener(handler, eventListener);
    }

    @Override // com.google.android.exoplayer2.upstream.BandwidthMeter
    public synchronized long getBitrateEstimate() {
        return this.bitrateEstimate;
    }

    @Override // com.google.android.exoplayer2.upstream.BandwidthMeter
    public /* synthetic */ long getTimeToFirstByteEstimateUs() {
        return gp.a(this);
    }

    @Override // com.google.android.exoplayer2.upstream.BandwidthMeter
    public TransferListener getTransferListener() {
        return this;
    }

    @Override // com.google.android.exoplayer2.upstream.TransferListener
    public synchronized void onBytesTransferred(DataSource dataSource, DataSpec dataSpec, boolean z, int i) {
        if (isTransferAtFullNetworkSpeed(dataSpec, z)) {
            this.sampleBytesTransferred += (long) i;
        }
    }

    @Override // com.google.android.exoplayer2.upstream.TransferListener
    public synchronized void onTransferEnd(DataSource dataSource, DataSpec dataSpec, boolean z) {
        if (isTransferAtFullNetworkSpeed(dataSpec, z)) {
            Assertions.checkState(this.streamCount > 0);
            long elapsedRealtime = this.clock.elapsedRealtime();
            int i = (int) (elapsedRealtime - this.sampleStartTimeMs);
            this.totalElapsedTimeMs += (long) i;
            long j = this.totalBytesTransferred;
            long j2 = this.sampleBytesTransferred;
            this.totalBytesTransferred = j + j2;
            if (i > 0) {
                this.slidingPercentile.addSample((int) Math.sqrt((double) j2), (((float) j2) * 8000.0f) / ((float) i));
                if (this.totalElapsedTimeMs >= SimpleExoPlayer.DEFAULT_DETACH_SURFACE_TIMEOUT_MS || this.totalBytesTransferred >= PlaybackStateCompat.ACTION_SET_SHUFFLE_MODE_ENABLED) {
                    this.bitrateEstimate = (long) this.slidingPercentile.getPercentile(0.5f);
                }
                maybeNotifyBandwidthSample(i, this.sampleBytesTransferred, this.bitrateEstimate);
                this.sampleStartTimeMs = elapsedRealtime;
                this.sampleBytesTransferred = 0;
            }
            this.streamCount--;
        }
    }

    @Override // com.google.android.exoplayer2.upstream.TransferListener
    public void onTransferInitializing(DataSource dataSource, DataSpec dataSpec, boolean z) {
    }

    @Override // com.google.android.exoplayer2.upstream.TransferListener
    public synchronized void onTransferStart(DataSource dataSource, DataSpec dataSpec, boolean z) {
        if (isTransferAtFullNetworkSpeed(dataSpec, z)) {
            if (this.streamCount == 0) {
                this.sampleStartTimeMs = this.clock.elapsedRealtime();
            }
            this.streamCount++;
        }
    }

    @Override // com.google.android.exoplayer2.upstream.BandwidthMeter
    public void removeEventListener(BandwidthMeter.EventListener eventListener) {
        this.eventDispatcher.removeListener(eventListener);
    }

    public synchronized void setNetworkTypeOverride(int i) {
        this.networkTypeOverride = i;
        this.networkTypeOverrideSet = true;
        onNetworkTypeChanged(i);
    }

    public static final class Builder {
        private Clock clock;
        @Nullable
        private final Context context;
        private Map<Integer, Long> initialBitrateEstimates;
        private boolean resetOnNetworkTypeChange;
        private int slidingWindowMaxWeight;

        public Builder(Context context2) {
            Context context3;
            if (context2 == null) {
                context3 = null;
            } else {
                context3 = context2.getApplicationContext();
            }
            this.context = context3;
            this.initialBitrateEstimates = getInitialBitrateEstimatesForCountry(Util.getCountryCode(context2));
            this.slidingWindowMaxWeight = 2000;
            this.clock = Clock.DEFAULT;
            this.resetOnNetworkTypeChange = true;
        }

        private static bs<Integer> getCountryGroupIndices(String str) {
            bs<Integer> bsVar = DefaultBandwidthMeter.DEFAULT_INITIAL_BITRATE_COUNTRY_GROUPS.get(str);
            return bsVar.isEmpty() ? bs.of(2, 2, 2, 2, 2, 2) : bsVar;
        }

        private static Map<Integer, Long> getInitialBitrateEstimatesForCountry(String str) {
            bs<Integer> countryGroupIndices = getCountryGroupIndices(str);
            HashMap hashMap = new HashMap(8);
            hashMap.put(0, 1000000L);
            bs<Long> bsVar = DefaultBandwidthMeter.DEFAULT_INITIAL_BITRATE_ESTIMATES_WIFI;
            hashMap.put(2, bsVar.get(countryGroupIndices.get(0).intValue()));
            hashMap.put(3, DefaultBandwidthMeter.DEFAULT_INITIAL_BITRATE_ESTIMATES_2G.get(countryGroupIndices.get(1).intValue()));
            hashMap.put(4, DefaultBandwidthMeter.DEFAULT_INITIAL_BITRATE_ESTIMATES_3G.get(countryGroupIndices.get(2).intValue()));
            hashMap.put(5, DefaultBandwidthMeter.DEFAULT_INITIAL_BITRATE_ESTIMATES_4G.get(countryGroupIndices.get(3).intValue()));
            hashMap.put(10, DefaultBandwidthMeter.DEFAULT_INITIAL_BITRATE_ESTIMATES_5G_NSA.get(countryGroupIndices.get(4).intValue()));
            hashMap.put(9, DefaultBandwidthMeter.DEFAULT_INITIAL_BITRATE_ESTIMATES_5G_SA.get(countryGroupIndices.get(5).intValue()));
            hashMap.put(7, bsVar.get(countryGroupIndices.get(0).intValue()));
            return hashMap;
        }

        public DefaultBandwidthMeter build() {
            return new DefaultBandwidthMeter(this.context, this.initialBitrateEstimates, this.slidingWindowMaxWeight, this.clock, this.resetOnNetworkTypeChange);
        }

        public Builder setClock(Clock clock2) {
            this.clock = clock2;
            return this;
        }

        public Builder setInitialBitrateEstimate(long j) {
            for (Integer num : this.initialBitrateEstimates.keySet()) {
                setInitialBitrateEstimate(num.intValue(), j);
            }
            return this;
        }

        public Builder setResetOnNetworkTypeChange(boolean z) {
            this.resetOnNetworkTypeChange = z;
            return this;
        }

        public Builder setSlidingWindowMaxWeight(int i) {
            this.slidingWindowMaxWeight = i;
            return this;
        }

        public Builder setInitialBitrateEstimate(int i, long j) {
            this.initialBitrateEstimates.put(Integer.valueOf(i), Long.valueOf(j));
            return this;
        }

        public Builder setInitialBitrateEstimate(String str) {
            this.initialBitrateEstimates = getInitialBitrateEstimatesForCountry(b.q0(str));
            return this;
        }
    }

    @Deprecated
    public DefaultBandwidthMeter() {
        this(null, ds.of(), 2000, Clock.DEFAULT, false);
    }

    private DefaultBandwidthMeter(@Nullable Context context, Map<Integer, Long> map, int i, Clock clock2, boolean z) {
        this.initialBitrateEstimates = ds.copyOf(map);
        this.eventDispatcher = new BandwidthMeter.EventListener.EventDispatcher();
        this.slidingPercentile = new SlidingPercentile(i);
        this.clock = clock2;
        this.resetOnNetworkTypeChange = z;
        if (context != null) {
            NetworkTypeObserver instance = NetworkTypeObserver.getInstance(context);
            int networkType2 = instance.getNetworkType();
            this.networkType = networkType2;
            this.bitrateEstimate = getInitialBitrateEstimateForNetworkType(networkType2);
            instance.register(new dp(this));
            return;
        }
        this.networkType = 0;
        this.bitrateEstimate = getInitialBitrateEstimateForNetworkType(0);
    }
}
