package com.kingja.loadsir.core;

import android.content.Context;
import android.os.Handler;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import com.kingja.loadsir.callback.Callback;
import com.kingja.loadsir.callback.SuccessCallback;
import com.kingja.loadsir.core.LoadSir;
import java.util.List;

public class LoadService<T> {
    private final String TAG = getClass().getSimpleName();
    private Convertor<T> convertor;
    private LoadLayout loadLayout;

    public LoadService(Convertor<T> convertor2, LoadLayout loadLayout2, LoadSir.Builder builder) {
        this.convertor = convertor2;
        this.loadLayout = loadLayout2;
        initCallback(builder);
    }

    private void initCallback(LoadSir.Builder builder) {
        List<Callback> callbacks = builder.getCallbacks();
        final Class<? extends Callback> defaultCallback = builder.getDefaultCallback();
        if (callbacks != null && callbacks.size() > 0) {
            for (Callback callback : callbacks) {
                this.loadLayout.setupCallback(callback);
            }
        }
        new Handler().post(new Runnable() {
            /* class com.kingja.loadsir.core.LoadService.AnonymousClass1 */

            public void run() {
                if (defaultCallback != null) {
                    LoadService.this.loadLayout.showCallback(defaultCallback);
                }
            }
        });
    }

    public Class<? extends Callback> getCurrentCallback() {
        return this.loadLayout.getCurrentCallback();
    }

    public LoadLayout getLoadLayout() {
        return this.loadLayout;
    }

    public LinearLayout getTitleLoadLayout(Context context, ViewGroup viewGroup, View view) {
        LinearLayout linearLayout = new LinearLayout(context);
        linearLayout.setOrientation(1);
        LinearLayout.LayoutParams layoutParams = new LinearLayout.LayoutParams(-1, -1);
        linearLayout.setLayoutParams(layoutParams);
        viewGroup.removeView(view);
        linearLayout.addView(view);
        linearLayout.addView(this.loadLayout, layoutParams);
        return linearLayout;
    }

    public LoadService<T> setCallBack(Class<? extends Callback> cls, Transport transport) {
        this.loadLayout.setCallBack(cls, transport);
        return this;
    }

    public void showCallback(Class<? extends Callback> cls) {
        this.loadLayout.showCallback(cls);
    }

    public void showSuccess() {
        this.loadLayout.showCallback(SuccessCallback.class);
    }

    public void showWithConvertor(T t) {
        Convertor<T> convertor2 = this.convertor;
        if (convertor2 != null) {
            this.loadLayout.showCallback(convertor2.map(t));
            return;
        }
        throw new IllegalArgumentException("You haven't set the Convertor.");
    }
}
