package com.kingja.loadsir.core;

import androidx.annotation.NonNull;
import com.kingja.loadsir.LoadSirUtil;
import com.kingja.loadsir.callback.Callback;
import com.kingja.loadsir.target.ActivityTarget;
import com.kingja.loadsir.target.ITarget;
import com.kingja.loadsir.target.ViewTarget;
import java.util.ArrayList;
import java.util.List;

public class LoadSir {
    private static volatile LoadSir loadSir;
    private Builder builder;

    public static class Builder {
        private List<Callback> callbacks = new ArrayList();
        private Class<? extends Callback> defaultCallback;
        private List<ITarget> targetContextList;

        public Builder() {
            ArrayList arrayList = new ArrayList();
            this.targetContextList = arrayList;
            arrayList.add(new ActivityTarget());
            this.targetContextList.add(new ViewTarget());
        }

        public Builder addCallback(@NonNull Callback callback) {
            this.callbacks.add(callback);
            return this;
        }

        public Builder addTargetContext(ITarget iTarget) {
            this.targetContextList.add(iTarget);
            return this;
        }

        public LoadSir build() {
            return new LoadSir(this);
        }

        public void commit() {
            LoadSir.getDefault().setBuilder(this);
        }

        public List<Callback> getCallbacks() {
            return this.callbacks;
        }

        public Class<? extends Callback> getDefaultCallback() {
            return this.defaultCallback;
        }

        public List<ITarget> getTargetContextList() {
            return this.targetContextList;
        }

        public Builder setDefaultCallback(@NonNull Class<? extends Callback> cls) {
            this.defaultCallback = cls;
            return this;
        }
    }

    public static Builder beginBuilder() {
        return new Builder();
    }

    public static LoadSir getDefault() {
        if (loadSir == null) {
            synchronized (LoadSir.class) {
                if (loadSir == null) {
                    loadSir = new LoadSir();
                }
            }
        }
        return loadSir;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setBuilder(@NonNull Builder builder2) {
        this.builder = builder2;
    }

    public LoadService register(@NonNull Object obj) {
        return register(obj, null, null);
    }

    private LoadSir() {
        this.builder = new Builder();
    }

    public LoadService register(Object obj, Callback.OnReloadListener onReloadListener) {
        return register(obj, onReloadListener, null);
    }

    public <T> LoadService register(Object obj, Callback.OnReloadListener onReloadListener, Convertor<T> convertor) {
        return new LoadService(convertor, LoadSirUtil.getTargetContext(obj, this.builder.getTargetContextList()).replaceView(obj, onReloadListener), this.builder);
    }

    private LoadSir(Builder builder2) {
        this.builder = builder2;
    }
}
