package com.orhanobut.hawk;

import android.content.Context;
import com.google.gson.Gson;

public class HawkBuilder {
    private static final String STORAGE_TAG_DO_NOT_CHANGE = "Hawk2";
    private Context context;
    private Converter converter;
    private Storage cryptoStorage;
    private Encryption encryption;
    private LogInterceptor logInterceptor;
    private Parser parser;
    private Serializer serializer;

    public HawkBuilder(Context context2) {
        HawkUtils.checkNull("Context", context2);
        this.context = context2.getApplicationContext();
    }

    public void build() {
        Hawk.build(this);
    }

    public Converter getConverter() {
        if (this.converter == null) {
            this.converter = new HawkConverter(getParser());
        }
        return this.converter;
    }

    public Encryption getEncryption() {
        if (this.encryption == null) {
            ConcealEncryption concealEncryption = new ConcealEncryption(this.context);
            this.encryption = concealEncryption;
            if (!concealEncryption.init()) {
                this.encryption = new NoEncryption();
            }
        }
        return this.encryption;
    }

    public LogInterceptor getLogInterceptor() {
        if (this.logInterceptor == null) {
            this.logInterceptor = new LogInterceptor() {
                /* class com.orhanobut.hawk.HawkBuilder.AnonymousClass1 */

                @Override // com.orhanobut.hawk.LogInterceptor
                public void onLog(String str) {
                }
            };
        }
        return this.logInterceptor;
    }

    public Parser getParser() {
        if (this.parser == null) {
            this.parser = new GsonParser(new Gson());
        }
        return this.parser;
    }

    public Serializer getSerializer() {
        if (this.serializer == null) {
            this.serializer = new HawkSerializer(getLogInterceptor());
        }
        return this.serializer;
    }

    public Storage getStorage() {
        if (this.cryptoStorage == null) {
            this.cryptoStorage = new SharedPreferencesStorage(this.context, STORAGE_TAG_DO_NOT_CHANGE);
        }
        return this.cryptoStorage;
    }

    public HawkBuilder setConverter(Converter converter2) {
        this.converter = converter2;
        return this;
    }

    public HawkBuilder setEncryption(Encryption encryption2) {
        this.encryption = encryption2;
        return this;
    }

    public HawkBuilder setLogInterceptor(LogInterceptor logInterceptor2) {
        this.logInterceptor = logInterceptor2;
        return this;
    }

    public HawkBuilder setParser(Parser parser2) {
        this.parser = parser2;
        return this;
    }

    public HawkBuilder setSerializer(Serializer serializer2) {
        this.serializer = serializer2;
        return this;
    }

    public HawkBuilder setStorage(Storage storage) {
        this.cryptoStorage = storage;
        return this;
    }
}
