package com.orhanobut.hawk;

import androidx.base.b2;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;

public class HawkSerializer implements Serializer {
    private static final char DELIMITER = '@';
    private static final String INFO_DELIMITER = "#";
    private static final char NEW_VERSION = 'V';
    private final LogInterceptor logInterceptor;

    public HawkSerializer(LogInterceptor logInterceptor2) {
        this.logInterceptor = logInterceptor2;
    }

    private String getCipherText(String str) {
        int indexOf = str.indexOf(64);
        if (indexOf != -1) {
            return str.substring(indexOf + 1);
        }
        throw new IllegalArgumentException("Text should contain delimiter");
    }

    @Override // com.orhanobut.hawk.Serializer
    public DataInfo deserialize(String str) {
        Class<?> cls;
        String str2;
        String[] split = str.split(INFO_DELIMITER);
        char charAt = split[2].charAt(0);
        String str3 = split[0];
        Class<?> cls2 = null;
        if (!(str3 == null || str3.length() == 0)) {
            try {
                cls = Class.forName(str3);
            } catch (ClassNotFoundException e) {
                LogInterceptor logInterceptor2 = this.logInterceptor;
                StringBuilder j = b2.j("HawkSerializer -> ");
                j.append(e.getMessage());
                logInterceptor2.onLog(j.toString());
            }
            str2 = split[1];
            if (!(str2 == null || str2.length() == 0)) {
                cls2 = Class.forName(str2);
            }
            return new DataInfo(charAt, getCipherText(split[split.length - 1]), cls, cls2);
        }
        cls = null;
        str2 = split[1];
        try {
            cls2 = Class.forName(str2);
        } catch (ClassNotFoundException e2) {
            LogInterceptor logInterceptor3 = this.logInterceptor;
            StringBuilder j2 = b2.j("HawkSerializer -> ");
            j2.append(e2.getMessage());
            logInterceptor3.onLog(j2.toString());
        }
        return new DataInfo(charAt, getCipherText(split[split.length - 1]), cls, cls2);
    }

    @Override // com.orhanobut.hawk.Serializer
    public <T> String serialize(String str, T t) {
        String str2;
        char c;
        String str3;
        HawkUtils.checkNullOrEmpty("Cipher text", str);
        HawkUtils.checkNull("Value", t);
        String str4 = "";
        if (List.class.isAssignableFrom(t.getClass())) {
            T t2 = t;
            str2 = !t2.isEmpty() ? t2.get(0).getClass().getName() : str4;
            c = DataInfo.TYPE_LIST;
        } else if (Map.class.isAssignableFrom(t.getClass())) {
            c = DataInfo.TYPE_MAP;
            T t3 = t;
            if (!t3.isEmpty()) {
                Iterator it = t3.entrySet().iterator();
                if (it.hasNext()) {
                    Map.Entry entry = (Map.Entry) it.next();
                    str4 = entry.getKey().getClass().getName();
                    str3 = entry.getValue().getClass().getName();
                    str4 = str3;
                    str2 = str4;
                }
            }
            str3 = str4;
            str4 = str3;
            str2 = str4;
        } else if (Set.class.isAssignableFrom(t.getClass())) {
            T t4 = t;
            if (!t4.isEmpty()) {
                Iterator it2 = t4.iterator();
                if (it2.hasNext()) {
                    str2 = it2.next().getClass().getName();
                    c = DataInfo.TYPE_SET;
                }
            }
            str2 = str4;
            c = DataInfo.TYPE_SET;
        } else {
            c = DataInfo.TYPE_OBJECT;
            str2 = t.getClass().getName();
        }
        return str2 + INFO_DELIMITER + str4 + INFO_DELIMITER + c + NEW_VERSION + DELIMITER + str;
    }
}
