package com.thoughtworks.xstream.converters.collections;

import com.thoughtworks.xstream.converters.UnmarshallingContext;
import com.thoughtworks.xstream.io.HierarchicalStreamReader;
import com.thoughtworks.xstream.mapper.Mapper;
import java.util.Collections;

public class SingletonCollectionConverter extends CollectionConverter {
    private static final Class LIST;
    private static final Class SET;

    static {
        Boolean bool = Boolean.TRUE;
        LIST = Collections.singletonList(bool).getClass();
        SET = Collections.singleton(bool).getClass();
    }

    public SingletonCollectionConverter(Mapper mapper) {
        super(mapper);
    }

    @Override // com.thoughtworks.xstream.converters.collections.AbstractCollectionConverter, com.thoughtworks.xstream.converters.ConverterMatcher, com.thoughtworks.xstream.converters.collections.CollectionConverter
    public boolean canConvert(Class cls) {
        return LIST == cls || SET == cls;
    }

    @Override // com.thoughtworks.xstream.converters.collections.AbstractCollectionConverter, com.thoughtworks.xstream.converters.Converter, com.thoughtworks.xstream.converters.collections.CollectionConverter
    public Object unmarshal(HierarchicalStreamReader hierarchicalStreamReader, UnmarshallingContext unmarshallingContext) {
        Object readCompleteItem = readCompleteItem(hierarchicalStreamReader, unmarshallingContext, null);
        if (unmarshallingContext.getRequiredType() == LIST) {
            return Collections.singletonList(readCompleteItem);
        }
        return Collections.singleton(readCompleteItem);
    }
}
