package com.thoughtworks.xstream.converters.enums;

import com.thoughtworks.xstream.converters.ConversionException;
import com.thoughtworks.xstream.converters.MarshallingContext;
import com.thoughtworks.xstream.converters.UnmarshallingContext;
import com.thoughtworks.xstream.converters.collections.MapConverter;
import com.thoughtworks.xstream.core.util.Fields;
import com.thoughtworks.xstream.io.HierarchicalStreamReader;
import com.thoughtworks.xstream.io.HierarchicalStreamWriter;
import com.thoughtworks.xstream.mapper.Mapper;
import java.lang.reflect.Field;
import java.util.EnumMap;

public class EnumMapConverter extends MapConverter {

    public static class Reflections {
        private static final Field typeField = Fields.locate(EnumMap.class, Class.class, false);

        private Reflections() {
        }
    }

    public EnumMapConverter(Mapper mapper) {
        super(mapper);
    }

    @Override // com.thoughtworks.xstream.converters.collections.AbstractCollectionConverter, com.thoughtworks.xstream.converters.ConverterMatcher, com.thoughtworks.xstream.converters.collections.MapConverter
    public boolean canConvert(Class cls) {
        return cls == EnumMap.class && Reflections.typeField != null;
    }

    @Override // com.thoughtworks.xstream.converters.collections.AbstractCollectionConverter, com.thoughtworks.xstream.converters.Converter, com.thoughtworks.xstream.converters.collections.MapConverter
    public void marshal(Object obj, HierarchicalStreamWriter hierarchicalStreamWriter, MarshallingContext marshallingContext) {
        Class cls = (Class) Fields.read(Reflections.typeField, obj);
        String aliasForSystemAttribute = mapper().aliasForSystemAttribute("enum-type");
        if (aliasForSystemAttribute != null) {
            hierarchicalStreamWriter.addAttribute(aliasForSystemAttribute, mapper().serializedClass(cls));
        }
        super.marshal(obj, hierarchicalStreamWriter, marshallingContext);
    }

    @Override // com.thoughtworks.xstream.converters.collections.AbstractCollectionConverter, com.thoughtworks.xstream.converters.Converter, com.thoughtworks.xstream.converters.collections.MapConverter
    public Object unmarshal(HierarchicalStreamReader hierarchicalStreamReader, UnmarshallingContext unmarshallingContext) {
        String aliasForSystemAttribute = mapper().aliasForSystemAttribute("enum-type");
        if (aliasForSystemAttribute != null) {
            EnumMap enumMap = new EnumMap(mapper().realClass(hierarchicalStreamReader.getAttribute(aliasForSystemAttribute)));
            populateMap(hierarchicalStreamReader, unmarshallingContext, enumMap);
            return enumMap;
        }
        throw new ConversionException("No EnumType specified for EnumMap");
    }
}
