package com.thoughtworks.xstream.converters.enums;

import com.thoughtworks.xstream.converters.basic.AbstractSingleValueConverter;

public class EnumSingleValueConverter extends AbstractSingleValueConverter {
    private final Class<? extends Enum> enumType;

    public EnumSingleValueConverter(Class<? extends Enum> cls) {
        if (Enum.class.isAssignableFrom(cls) || cls == Enum.class) {
            this.enumType = cls;
            return;
        }
        throw new IllegalArgumentException("Converter can only handle defined enums");
    }

    @Override // com.thoughtworks.xstream.converters.ConverterMatcher, com.thoughtworks.xstream.converters.basic.AbstractSingleValueConverter
    public boolean canConvert(Class cls) {
        return cls != null && this.enumType.isAssignableFrom(cls);
    }

    @Override // com.thoughtworks.xstream.converters.basic.AbstractSingleValueConverter, com.thoughtworks.xstream.converters.SingleValueConverter
    public Object fromString(String str) {
        return Enum.valueOf(this.enumType, str);
    }

    @Override // com.thoughtworks.xstream.converters.basic.AbstractSingleValueConverter, com.thoughtworks.xstream.converters.SingleValueConverter
    public String toString(Object obj) {
        return ((Enum) Enum.class.cast(obj)).name();
    }
}
