package com.thoughtworks.xstream.converters.extended;

import androidx.base.b2;
import com.orhanobut.hawk.DataInfo;
import com.thoughtworks.xstream.converters.ConversionException;
import com.thoughtworks.xstream.converters.basic.AbstractSingleValueConverter;
import com.thoughtworks.xstream.core.util.ThreadSafeSimpleDateFormat;
import java.sql.Timestamp;
import java.text.ParseException;
import java.util.TimeZone;

public class SqlTimestampConverter extends AbstractSingleValueConverter {
    public static /* synthetic */ Class class$java$sql$Timestamp;
    private final ThreadSafeSimpleDateFormat format;

    public SqlTimestampConverter() {
        this(TimeZone.getTimeZone("UTC"));
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e) {
            throw b2.n(e);
        }
    }

    @Override // com.thoughtworks.xstream.converters.ConverterMatcher, com.thoughtworks.xstream.converters.basic.AbstractSingleValueConverter
    public boolean canConvert(Class cls) {
        Class cls2 = class$java$sql$Timestamp;
        if (cls2 == null) {
            cls2 = class$("java.sql.Timestamp");
            class$java$sql$Timestamp = cls2;
        }
        return cls == cls2;
    }

    @Override // com.thoughtworks.xstream.converters.basic.AbstractSingleValueConverter, com.thoughtworks.xstream.converters.SingleValueConverter
    public Object fromString(String str) {
        int lastIndexOf = str.lastIndexOf(46);
        if (lastIndexOf <= 0 || (str.length() - lastIndexOf >= 2 && str.length() - lastIndexOf <= 10)) {
            try {
                Timestamp timestamp = new Timestamp(this.format.parse(lastIndexOf < 0 ? str : str.substring(0, lastIndexOf)).getTime());
                if (lastIndexOf > 0) {
                    StringBuffer stringBuffer = new StringBuffer(str.substring(lastIndexOf + 1));
                    while (stringBuffer.length() != 9) {
                        stringBuffer.append(DataInfo.TYPE_OBJECT);
                    }
                    timestamp.setNanos(Integer.parseInt(stringBuffer.toString()));
                }
                return timestamp;
            } catch (NumberFormatException e) {
                throw new ConversionException("Timestamp format must be yyyy-mm-dd hh:mm:ss[.fffffffff]", e);
            } catch (ParseException e2) {
                throw new ConversionException("Timestamp format must be yyyy-mm-dd hh:mm:ss[.fffffffff]", e2);
            }
        } else {
            throw new ConversionException("Timestamp format must be yyyy-mm-dd hh:mm:ss[.fffffffff]");
        }
    }

    @Override // com.thoughtworks.xstream.converters.basic.AbstractSingleValueConverter, com.thoughtworks.xstream.converters.SingleValueConverter
    public String toString(Object obj) {
        Timestamp timestamp = (Timestamp) obj;
        StringBuffer stringBuffer = new StringBuffer(this.format.format(timestamp));
        if (timestamp.getNanos() != 0) {
            stringBuffer.append('.');
            String valueOf = String.valueOf(timestamp.getNanos() + 1000000000);
            int i = 10;
            while (i > 2 && valueOf.charAt(i - 1) == '0') {
                i--;
            }
            stringBuffer.append(valueOf.subSequence(1, i));
        }
        return stringBuffer.toString();
    }

    public SqlTimestampConverter(TimeZone timeZone) {
        this.format = new ThreadSafeSimpleDateFormat("yyyy-MM-dd HH:mm:ss", timeZone, 0, 5, false);
    }
}
