package com.thoughtworks.xstream.converters.extended;

import com.thoughtworks.xstream.converters.ConversionException;
import com.thoughtworks.xstream.converters.Converter;
import com.thoughtworks.xstream.converters.ConverterLookup;
import com.thoughtworks.xstream.converters.ConverterMatcher;
import com.thoughtworks.xstream.converters.MarshallingContext;
import com.thoughtworks.xstream.converters.SingleValueConverter;
import com.thoughtworks.xstream.converters.UnmarshallingContext;
import com.thoughtworks.xstream.converters.reflection.AbstractReflectionConverter;
import com.thoughtworks.xstream.converters.reflection.ReflectionProvider;
import com.thoughtworks.xstream.core.JVM;
import com.thoughtworks.xstream.core.util.FastField;
import com.thoughtworks.xstream.core.util.HierarchicalStreams;
import com.thoughtworks.xstream.core.util.Primitives;
import com.thoughtworks.xstream.io.HierarchicalStreamReader;
import com.thoughtworks.xstream.io.HierarchicalStreamWriter;
import com.thoughtworks.xstream.mapper.Mapper;
import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;

public class ToAttributedValueConverter implements Converter {
    private static final String STRUCTURE_MARKER = "";
    private final Mapper enumMapper;
    private final ConverterLookup lookup;
    private final Mapper mapper;
    private final ReflectionProvider reflectionProvider;
    private final Class type;
    private final Field valueField;

    public ToAttributedValueConverter(Class cls, Mapper mapper2, ReflectionProvider reflectionProvider2, ConverterLookup converterLookup) {
        this(cls, mapper2, reflectionProvider2, converterLookup, null, null);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean fieldIsEqual(FastField fastField) {
        return this.valueField.getName().equals(fastField.getName()) && this.valueField.getDeclaringClass().getName().equals(fastField.getDeclaringClass());
    }

    @Override // com.thoughtworks.xstream.converters.ConverterMatcher
    public boolean canConvert(Class cls) {
        return this.type == cls;
    }

    @Override // com.thoughtworks.xstream.converters.Converter
    public void marshal(Object obj, final HierarchicalStreamWriter hierarchicalStreamWriter, MarshallingContext marshallingContext) {
        String aliasForSystemAttribute;
        final Class<?> cls = obj.getClass();
        final HashMap hashMap = new HashMap();
        final String[] strArr = new String[1];
        final Object[] objArr = new Object[1];
        final Class[] clsArr = new Class[1];
        final Class[] clsArr2 = new Class[1];
        this.reflectionProvider.visitSerializableFields(obj, new ReflectionProvider.Visitor() {
            /* class com.thoughtworks.xstream.converters.extended.ToAttributedValueConverter.AnonymousClass1 */

            @Override // com.thoughtworks.xstream.converters.reflection.ReflectionProvider.Visitor
            public void visit(String str, Class cls, Class cls2, Object obj) {
                ConverterMatcher converterMatcher;
                if (ToAttributedValueConverter.this.mapper.shouldSerializeMember(cls2, str)) {
                    FastField fastField = new FastField(cls2, str);
                    String serializedMember = ToAttributedValueConverter.this.mapper.serializedMember(cls2, str);
                    if (!hashMap.containsKey(serializedMember)) {
                        hashMap.put(serializedMember, ToAttributedValueConverter.this.reflectionProvider.getField(cls, str));
                    } else if (!ToAttributedValueConverter.this.fieldIsEqual(fastField)) {
                        ConversionException conversionException = new ConversionException("Cannot write attribute twice for object");
                        conversionException.add("alias", serializedMember);
                        conversionException.add("type", cls.getName());
                        throw conversionException;
                    }
                    if (UseAttributeForEnumMapper.isEnum(cls)) {
                        converterMatcher = ToAttributedValueConverter.this.enumMapper.getConverterFromItemType(null, cls, null);
                    } else {
                        converterMatcher = ToAttributedValueConverter.this.mapper.getLocalConverter(cls2, str);
                    }
                    if (converterMatcher == null) {
                        converterMatcher = ToAttributedValueConverter.this.lookup.lookupConverterForType(cls);
                    }
                    if (obj != null) {
                        boolean z = ToAttributedValueConverter.this.valueField != null && ToAttributedValueConverter.this.fieldIsEqual(fastField);
                        if (z) {
                            clsArr2[0] = cls2;
                            clsArr[0] = cls;
                            objArr[0] = obj;
                            strArr[0] = "";
                        }
                        if (converterMatcher instanceof SingleValueConverter) {
                            String singleValueConverter = ((SingleValueConverter) converterMatcher).toString(obj);
                            if (z) {
                                strArr[0] = singleValueConverter;
                            } else if (singleValueConverter != null) {
                                hierarchicalStreamWriter.addAttribute(serializedMember, singleValueConverter);
                            }
                        } else if (!z) {
                            ConversionException conversionException2 = new ConversionException("Cannot write element as attribute");
                            conversionException2.add("alias", serializedMember);
                            conversionException2.add("type", cls.getName());
                            throw conversionException2;
                        }
                    }
                }
            }
        });
        if (strArr[0] != null) {
            Class<?> cls2 = objArr[0].getClass();
            Class defaultImplementationOf = this.mapper.defaultImplementationOf(clsArr[0]);
            if (!cls2.equals(defaultImplementationOf)) {
                String serializedClass = this.mapper.serializedClass(cls2);
                if (!serializedClass.equals(this.mapper.serializedClass(defaultImplementationOf)) && (aliasForSystemAttribute = this.mapper.aliasForSystemAttribute("class")) != null) {
                    hierarchicalStreamWriter.addAttribute(aliasForSystemAttribute, serializedClass);
                }
            }
            if (strArr[0] == "") {
                marshallingContext.convertAnother(objArr[0]);
            } else {
                hierarchicalStreamWriter.setValue(strArr[0]);
            }
        }
    }

    @Override // com.thoughtworks.xstream.converters.Converter
    public Object unmarshal(HierarchicalStreamReader hierarchicalStreamReader, UnmarshallingContext unmarshallingContext) {
        Field field;
        Class cls;
        Class<?> cls2;
        HashSet hashSet;
        Iterator it;
        ConverterMatcher converterMatcher;
        Object newInstance = this.reflectionProvider.newInstance(unmarshallingContext.getRequiredType());
        Class<?> cls3 = newInstance.getClass();
        HashSet hashSet2 = new HashSet();
        Iterator attributeNames = hierarchicalStreamReader.getAttributeNames();
        HashSet hashSet3 = new HashSet();
        hashSet3.add(this.mapper.aliasForSystemAttribute("class"));
        while (attributeNames.hasNext()) {
            String str = (String) attributeNames.next();
            if (!hashSet3.contains(str)) {
                String realMember = this.mapper.realMember(cls3, str);
                Field fieldOrNull = this.reflectionProvider.getFieldOrNull(cls3, realMember);
                if (fieldOrNull == null) {
                    cls2 = cls3;
                    it = attributeNames;
                    hashSet = hashSet3;
                } else if (Modifier.isTransient(fieldOrNull.getModifiers())) {
                    continue;
                } else {
                    it = attributeNames;
                    Class<?> type2 = fieldOrNull.getType();
                    Class<?> declaringClass = fieldOrNull.getDeclaringClass();
                    if (UseAttributeForEnumMapper.isEnum(type2)) {
                        hashSet = hashSet3;
                        cls2 = cls3;
                        converterMatcher = this.enumMapper.getConverterFromItemType(null, type2, null);
                    } else {
                        cls2 = cls3;
                        hashSet = hashSet3;
                        converterMatcher = this.mapper.getLocalConverter(declaringClass, realMember);
                    }
                    if (converterMatcher == null) {
                        converterMatcher = this.lookup.lookupConverterForType(type2);
                    }
                    if (!(converterMatcher instanceof SingleValueConverter)) {
                        ConversionException conversionException = new ConversionException("Cannot read field as a single value for object");
                        conversionException.add("field", realMember);
                        conversionException.add("type", cls2.getName());
                        throw conversionException;
                    } else if (converterMatcher != null) {
                        Object fromString = ((SingleValueConverter) converterMatcher).fromString(hierarchicalStreamReader.getAttribute(str));
                        if (type2.isPrimitive()) {
                            type2 = Primitives.box(type2);
                        }
                        if (fromString == null || type2.isAssignableFrom(fromString.getClass())) {
                            this.reflectionProvider.writeField(newInstance, realMember, fromString, declaringClass);
                            if (!hashSet2.add(new FastField(declaringClass, realMember))) {
                                StringBuffer stringBuffer = new StringBuffer();
                                stringBuffer.append(realMember);
                                stringBuffer.append(" [");
                                stringBuffer.append(declaringClass.getName());
                                stringBuffer.append("]");
                                throw new AbstractReflectionConverter.DuplicateFieldException(stringBuffer.toString());
                            }
                        } else {
                            ConversionException conversionException2 = new ConversionException("Cannot assign object to type");
                            conversionException2.add("object type", fromString.getClass().getName());
                            conversionException2.add("target type", type2.getName());
                            throw conversionException2;
                        }
                    }
                }
                attributeNames = it;
                hashSet3 = hashSet;
                cls3 = cls2;
            }
        }
        Field field2 = this.valueField;
        if (field2 != null) {
            Class<?> declaringClass2 = field2.getDeclaringClass();
            String name = this.valueField.getName();
            if (name == null) {
                field = null;
            } else {
                field = this.reflectionProvider.getField(declaringClass2, name);
            }
            if (name == null || field == null) {
                ConversionException conversionException3 = new ConversionException("Cannot assign value to field of type");
                conversionException3.add("element", hierarchicalStreamReader.getNodeName());
                conversionException3.add("field", name);
                conversionException3.add("target type", unmarshallingContext.getRequiredType().getName());
                throw conversionException3;
            }
            String readClassAttribute = HierarchicalStreams.readClassAttribute(hierarchicalStreamReader, this.mapper);
            if (readClassAttribute != null) {
                cls = this.mapper.realClass(readClassAttribute);
            } else {
                cls = this.mapper.defaultImplementationOf(this.reflectionProvider.getFieldType(newInstance, name, declaringClass2));
            }
            Object convertAnother = unmarshallingContext.convertAnother(newInstance, cls, this.mapper.getLocalConverter(field.getDeclaringClass(), field.getName()));
            Class fieldType = this.reflectionProvider.getFieldType(newInstance, name, declaringClass2);
            if (!fieldType.isPrimitive()) {
                cls = fieldType;
            }
            if (convertAnother == null || cls.isAssignableFrom(convertAnother.getClass())) {
                this.reflectionProvider.writeField(newInstance, name, convertAnother, declaringClass2);
                if (!hashSet2.add(new FastField(declaringClass2, name))) {
                    StringBuffer stringBuffer2 = new StringBuffer();
                    stringBuffer2.append(name);
                    stringBuffer2.append(" [");
                    stringBuffer2.append(declaringClass2.getName());
                    stringBuffer2.append("]");
                    throw new AbstractReflectionConverter.DuplicateFieldException(stringBuffer2.toString());
                }
            } else {
                ConversionException conversionException4 = new ConversionException("Cannot assign object to type");
                conversionException4.add("object type", convertAnother.getClass().getName());
                conversionException4.add("target type", cls.getName());
                throw conversionException4;
            }
        }
        return newInstance;
    }

    public ToAttributedValueConverter(Class cls, Mapper mapper2, ReflectionProvider reflectionProvider2, ConverterLookup converterLookup, String str) {
        this(cls, mapper2, reflectionProvider2, converterLookup, str, null);
    }

    public ToAttributedValueConverter(Class cls, Mapper mapper2, ReflectionProvider reflectionProvider2, ConverterLookup converterLookup, String str, Class cls2) {
        this.type = cls;
        this.mapper = mapper2;
        this.reflectionProvider = reflectionProvider2;
        this.lookup = converterLookup;
        Mapper mapper3 = null;
        if (str == null) {
            this.valueField = null;
        } else {
            try {
                Field declaredField = (cls2 != null ? cls2 : cls).getDeclaredField(str);
                if (!declaredField.isAccessible()) {
                    declaredField.setAccessible(true);
                }
                this.valueField = declaredField;
            } catch (NoSuchFieldException e) {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(e.getMessage());
                stringBuffer.append(": ");
                stringBuffer.append(str);
                throw new IllegalArgumentException(stringBuffer.toString());
            }
        }
        this.enumMapper = JVM.isVersion(5) ? UseAttributeForEnumMapper.createEnumMapper(mapper2) : mapper3;
    }
}
