package com.thoughtworks.xstream.converters.javabean;

import androidx.base.b2;
import com.thoughtworks.xstream.converters.ConversionException;
import com.thoughtworks.xstream.converters.ErrorWritingException;
import com.thoughtworks.xstream.converters.javabean.JavaBeanProvider;
import com.thoughtworks.xstream.converters.reflection.ObjectAccessException;
import java.beans.PropertyDescriptor;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.Iterator;

public class BeanProvider implements JavaBeanProvider {
    public static final Object[] NO_PARAMS = new Object[0];
    public static /* synthetic */ Class class$java$lang$Void;
    public PropertyDictionary propertyDictionary;

    public interface Visitor extends JavaBeanProvider.Visitor {
    }

    public BeanProvider() {
        this(new PropertyDictionary(new NativePropertySorter()));
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e) {
            throw b2.n(e);
        }
    }

    @Override // com.thoughtworks.xstream.converters.javabean.JavaBeanProvider
    public boolean canInstantiate(Class cls) {
        if (cls == null) {
            return false;
        }
        try {
            return newInstance(cls) != null;
        } catch (ErrorWritingException unused) {
            return false;
        }
    }

    public boolean canStreamProperty(PropertyDescriptor propertyDescriptor) {
        return (propertyDescriptor.getReadMethod() == null || propertyDescriptor.getWriteMethod() == null) ? false : true;
    }

    public Constructor getDefaultConstrutor(Class cls) {
        Constructor<?>[] constructors = cls.getConstructors();
        for (Constructor<?> constructor : constructors) {
            if (constructor.getParameterTypes().length == 0 && Modifier.isPublic(constructor.getModifiers())) {
                return constructor;
            }
        }
        return null;
    }

    public PropertyDescriptor getProperty(String str, Class cls) {
        return this.propertyDictionary.propertyDescriptor(cls, str);
    }

    @Override // com.thoughtworks.xstream.converters.javabean.JavaBeanProvider
    public Class getPropertyType(Object obj, String str) {
        return getProperty(str, obj.getClass()).getPropertyType();
    }

    public PropertyDescriptor[] getSerializableProperties(Object obj) {
        ArrayList arrayList = new ArrayList();
        Iterator propertiesFor = this.propertyDictionary.propertiesFor(obj.getClass());
        while (propertiesFor.hasNext()) {
            PropertyDescriptor propertyDescriptor = (PropertyDescriptor) propertiesFor.next();
            if (canStreamProperty(propertyDescriptor)) {
                arrayList.add(propertyDescriptor);
            }
        }
        return (PropertyDescriptor[]) arrayList.toArray(new PropertyDescriptor[arrayList.size()]);
    }

    @Override // com.thoughtworks.xstream.converters.javabean.JavaBeanProvider
    public Object newInstance(Class cls) {
        ErrorWritingException errorWritingException;
        if (cls != Void.TYPE) {
            Class cls2 = class$java$lang$Void;
            if (cls2 == null) {
                cls2 = class$("java.lang.Void");
                class$java$lang$Void = cls2;
            }
            if (cls != cls2) {
                try {
                    return cls.newInstance();
                } catch (InstantiationException e) {
                    errorWritingException = new ConversionException("Cannot construct type", e);
                } catch (IllegalAccessException e2) {
                    errorWritingException = new ObjectAccessException("Cannot construct type", e2);
                } catch (SecurityException e3) {
                    errorWritingException = new ObjectAccessException("Cannot construct type", e3);
                } catch (ExceptionInInitializerError e4) {
                    errorWritingException = new ConversionException("Cannot construct type", e4);
                }
            }
        }
        errorWritingException = new ConversionException("Security alert: Marshalling rejected");
        errorWritingException.add("construction-type", cls.getName());
        throw errorWritingException;
    }

    @Override // com.thoughtworks.xstream.converters.javabean.JavaBeanProvider
    public boolean propertyDefinedInClass(String str, Class cls) {
        return this.propertyDictionary.propertyDescriptorOrNull(cls, str) != null;
    }

    public boolean propertyWriteable(String str, Class cls) {
        return getProperty(str, cls).getWriteMethod() != null;
    }

    /* JADX WARNING: Removed duplicated region for block: B:16:0x004b A[LOOP:0: B:1:0x0008->B:16:0x004b, LOOP_END] */
    /* JADX WARNING: Removed duplicated region for block: B:20:0x004e A[SYNTHETIC] */
    @Override // com.thoughtworks.xstream.converters.javabean.JavaBeanProvider
    public void visitSerializableProperties(Object obj, JavaBeanProvider.Visitor visitor) {
        ErrorWritingException errorWritingException;
        PropertyDescriptor[] serializableProperties = getSerializableProperties(obj);
        for (PropertyDescriptor propertyDescriptor : serializableProperties) {
            ErrorWritingException errorWritingException2 = null;
            try {
                Method readMethod = propertyDescriptor.getReadMethod();
                String name = propertyDescriptor.getName();
                Class<?> declaringClass = readMethod.getDeclaringClass();
                if (visitor.shouldVisit(name, declaringClass)) {
                    visitor.visit(name, propertyDescriptor.getPropertyType(), declaringClass, readMethod.invoke(obj, new Object[0]));
                }
            } catch (IllegalArgumentException e) {
                errorWritingException = new ConversionException("Cannot get property", e);
                errorWritingException2 = errorWritingException;
                if (errorWritingException2 == null) {
                }
            } catch (IllegalAccessException e2) {
                errorWritingException = new ObjectAccessException("Cannot access property", e2);
                errorWritingException2 = errorWritingException;
                if (errorWritingException2 == null) {
                }
            } catch (InvocationTargetException e3) {
                errorWritingException = new ConversionException("Cannot get property", e3.getTargetException());
                errorWritingException2 = errorWritingException;
                if (errorWritingException2 == null) {
                }
            }
            if (errorWritingException2 == null) {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(obj.getClass());
                stringBuffer.append(".");
                stringBuffer.append(propertyDescriptor.getName());
                errorWritingException2.add("property", stringBuffer.toString());
                throw errorWritingException2;
            }
        }
    }

    @Override // com.thoughtworks.xstream.converters.javabean.JavaBeanProvider
    public void writeProperty(Object obj, String str, Object obj2) {
        ObjectAccessException objectAccessException;
        ConversionException conversionException;
        PropertyDescriptor property = getProperty(str, obj.getClass());
        try {
            property.getWriteMethod().invoke(obj, obj2);
            objectAccessException = null;
        } catch (IllegalArgumentException e) {
            conversionException = new ConversionException("Cannot set property", e);
            objectAccessException = conversionException;
        } catch (IllegalAccessException e2) {
            objectAccessException = new ObjectAccessException("Cannot access property", e2);
        } catch (InvocationTargetException e3) {
            conversionException = new ConversionException("Cannot set property", e3.getTargetException());
            objectAccessException = conversionException;
        }
        if (objectAccessException != null) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(obj.getClass());
            stringBuffer.append(".");
            stringBuffer.append(property.getName());
            objectAccessException.add("property", stringBuffer.toString());
            throw objectAccessException;
        }
    }

    public BeanProvider(Comparator comparator) {
        this(new PropertyDictionary(new ComparingPropertySorter(comparator)));
    }

    public BeanProvider(PropertyDictionary propertyDictionary2) {
        this.propertyDictionary = propertyDictionary2;
    }
}
