package com.thoughtworks.xstream.converters.reflection;

import androidx.base.b2;
import com.thoughtworks.xstream.converters.ConversionException;
import com.thoughtworks.xstream.converters.MarshallingContext;
import com.thoughtworks.xstream.converters.UnmarshallingContext;
import com.thoughtworks.xstream.converters.reflection.ReflectionProvider;
import com.thoughtworks.xstream.core.ClassLoaderReference;
import com.thoughtworks.xstream.io.ExtendedHierarchicalStreamWriterHelper;
import com.thoughtworks.xstream.io.HierarchicalStreamReader;
import com.thoughtworks.xstream.io.HierarchicalStreamWriter;
import com.thoughtworks.xstream.mapper.Mapper;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationHandler;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.lang.reflect.Proxy;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import net.sf.cglib.proxy.Callback;
import net.sf.cglib.proxy.CallbackFilter;
import net.sf.cglib.proxy.Enhancer;
import net.sf.cglib.proxy.Factory;
import net.sf.cglib.proxy.NoOp;

public class CGLIBEnhancedConverter extends SerializableConverter {
    private static String CALLBACK_MARKER = "CGLIB$CALLBACK_";
    private static String DEFAULT_NAMING_MARKER = "$$EnhancerByCGLIB$$";
    public static /* synthetic */ Class class$com$thoughtworks$xstream$converters$reflection$CGLIBEnhancedConverter;
    public static /* synthetic */ Class class$com$thoughtworks$xstream$mapper$CGLIBMapper$Marker;
    public static /* synthetic */ Class class$java$lang$Class;
    public static /* synthetic */ Class class$java$lang$String;
    public static /* synthetic */ Class class$java$util$HashMap;
    public static /* synthetic */ Class class$net$sf$cglib$proxy$Callback;
    public static /* synthetic */ Class class$net$sf$cglib$proxy$Factory;
    public static /* synthetic */ Class class$net$sf$cglib$proxy$MethodInterceptor;
    public static /* synthetic */ Class class$net$sf$cglib$proxy$NoOp;
    private transient Map fieldCache;

    public static class CGLIBFilteringReflectionProvider extends ReflectionProviderWrapper {
        public CGLIBFilteringReflectionProvider(ReflectionProvider reflectionProvider) {
            super(reflectionProvider);
        }

        @Override // com.thoughtworks.xstream.converters.reflection.ReflectionProviderWrapper, com.thoughtworks.xstream.converters.reflection.ReflectionProvider
        public void visitSerializableFields(Object obj, final ReflectionProvider.Visitor visitor) {
            this.wrapped.visitSerializableFields(obj, new ReflectionProvider.Visitor() {
                /* class com.thoughtworks.xstream.converters.reflection.CGLIBEnhancedConverter.CGLIBFilteringReflectionProvider.AnonymousClass1 */

                @Override // com.thoughtworks.xstream.converters.reflection.ReflectionProvider.Visitor
                public void visit(String str, Class cls, Class cls2, Object obj) {
                    if (!str.startsWith("CGLIB$")) {
                        visitor.visit(str, cls, cls2, obj);
                    }
                }
            });
        }
    }

    public static class ReverseEngineeredCallbackFilter implements CallbackFilter {
        private final Map callbackIndexMap;

        public ReverseEngineeredCallbackFilter(Map map) {
            this.callbackIndexMap = map;
        }

        public int accept(Method method) {
            if (this.callbackIndexMap.containsKey(method)) {
                return ((Integer) this.callbackIndexMap.get(method)).intValue();
            }
            ConversionException conversionException = new ConversionException("CGLIB callback not detected in reverse engineering");
            conversionException.add("CGLIB-callback", method.toString());
            throw conversionException;
        }
    }

    public static final class ReverseEngineeringInvocationHandler implements InvocationHandler {
        private final Integer index;
        private final Map indexMap;

        public ReverseEngineeringInvocationHandler(int i, Map map) {
            this.indexMap = map;
            this.index = new Integer(i);
        }

        @Override // java.lang.reflect.InvocationHandler
        public Object invoke(Object obj, Method method, Object[] objArr) {
            Map map = this.indexMap;
            map.put(map.get(null), this.index);
            return null;
        }
    }

    public CGLIBEnhancedConverter(Mapper mapper, ReflectionProvider reflectionProvider, ClassLoaderReference classLoaderReference) {
        super(mapper, new CGLIBFilteringReflectionProvider(reflectionProvider), classLoaderReference);
        this.fieldCache = new HashMap();
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e) {
            throw b2.n(e);
        }
    }

    private Object create(Enhancer enhancer, List list, boolean z) {
        Object create = enhancer.create();
        if (z) {
            ((Factory) create).setCallbacks((Callback[]) list.toArray(new Callback[list.size()]));
        }
        return create;
    }

    /* JADX INFO: finally extract failed */
    /* JADX WARNING: Code restructure failed: missing block: B:48:0x00fa, code lost:
        r2 = e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:49:0x00fb, code lost:
        r8 = r10;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:50:0x00fd, code lost:
        r2 = new com.thoughtworks.xstream.converters.ConversionException("CGLIB enhanced proxies wit abstract nethod that has not been implemented");
        r2.add("proxy-superclass", r6.getSuperclass().getName());
        r2.add("method", r8.toString());
     */
    /* JADX WARNING: Code restructure failed: missing block: B:52:0x0118, code lost:
        throw r2;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Removed duplicated region for block: B:51:? A[ExcHandler: NoSuchMethodException (unused java.lang.NoSuchMethodException), SYNTHETIC, Splitter:B:37:0x00d1] */
    /* JADX WARNING: Removed duplicated region for block: B:54:? A[ExcHandler: InvocationTargetException (unused java.lang.reflect.InvocationTargetException), SYNTHETIC, Splitter:B:37:0x00d1] */
    private Map createCallbackIndexMap(Factory factory) {
        Callback[] callbacks = factory.getCallbacks();
        Callback[] callbackArr = new Callback[callbacks.length];
        HashMap hashMap = new HashMap();
        int i = -1;
        for (int i2 = 0; i2 < callbacks.length; i2++) {
            Callback callback = callbacks[i2];
            if (callback == null) {
                callbackArr[i2] = null;
            } else {
                Class cls = class$net$sf$cglib$proxy$NoOp;
                if (cls == null) {
                    cls = class$("net.sf.cglib.proxy.NoOp");
                    class$net$sf$cglib$proxy$NoOp = cls;
                }
                if (cls.isAssignableFrom(callback.getClass())) {
                    callbackArr[i2] = NoOp.INSTANCE;
                    i = i2;
                } else {
                    callbackArr[i2] = createReverseEngineeredCallbackOfProperType(callback, i2, hashMap);
                }
            }
        }
        try {
            factory.setCallbacks(callbackArr);
            HashSet hashSet = new HashSet();
            HashSet hashSet2 = new HashSet();
            Class<?> cls2 = factory.getClass();
            do {
                hashSet2.addAll(Arrays.asList(cls2.getDeclaredMethods()));
                hashSet2.addAll(Arrays.asList(cls2.getMethods()));
                hashSet.addAll(Arrays.asList(cls2.getInterfaces()));
                cls2 = cls2.getSuperclass();
            } while (cls2 != null);
            Iterator it = hashSet.iterator();
            while (it.hasNext()) {
                cls2 = (Class) it.next();
                hashSet2.addAll(Arrays.asList(cls2.getDeclaredMethods()));
            }
            Iterator it2 = hashSet2.iterator();
            while (it2.hasNext()) {
                Method method = (Method) it2.next();
                if (!method.isAccessible()) {
                    method.setAccessible(true);
                }
                Class cls3 = class$net$sf$cglib$proxy$Factory;
                if (cls3 == null) {
                    cls3 = class$("net.sf.cglib.proxy.Factory");
                    class$net$sf$cglib$proxy$Factory = cls3;
                }
                if (!cls3.isAssignableFrom(method.getDeclaringClass())) {
                    if ((method.getModifiers() & 24) <= 0) {
                        Class[] parameterTypes = method.getParameterTypes();
                        try {
                            Method method2 = (method.getModifiers() & 1024) > 0 ? factory.getClass().getMethod(method.getName(), method.getParameterTypes()) : method;
                            hashMap.put(null, method);
                            method2.invoke(factory, parameterTypes == null ? null : createNullArguments(parameterTypes));
                        } catch (IllegalAccessException e) {
                            IllegalAccessException e2 = e;
                            ObjectAccessException objectAccessException = new ObjectAccessException("Cannot access method", e2);
                            objectAccessException.add("method", method.toString());
                            throw objectAccessException;
                        } catch (InvocationTargetException unused) {
                        } catch (NoSuchMethodException unused2) {
                        }
                        if (hashMap.containsKey(method)) {
                            it2.remove();
                        }
                    }
                }
                it2.remove();
            }
            if (i >= 0) {
                Integer num = new Integer(i);
                Iterator it3 = hashSet2.iterator();
                while (it3.hasNext()) {
                    hashMap.put(it3.next(), num);
                }
            }
            factory.setCallbacks(callbacks);
            hashMap.remove(null);
            return hashMap;
        } catch (Throwable th) {
            factory.setCallbacks(callbacks);
            throw th;
        }
    }

    private Object[] createNullArguments(Class[] clsArr) {
        int length = clsArr.length;
        Object[] objArr = new Object[length];
        for (int i = 0; i < length; i++) {
            Class cls = clsArr[i];
            if (cls.isPrimitive()) {
                if (cls == Byte.TYPE) {
                    objArr[i] = new Byte((byte) 0);
                } else if (cls == Short.TYPE) {
                    objArr[i] = new Short((short) 0);
                } else if (cls == Integer.TYPE) {
                    objArr[i] = new Integer(0);
                } else if (cls == Long.TYPE) {
                    objArr[i] = new Long(0);
                } else if (cls == Float.TYPE) {
                    objArr[i] = new Float(0.0f);
                } else if (cls == Double.TYPE) {
                    objArr[i] = new Double(0.0d);
                } else if (cls == Character.TYPE) {
                    objArr[i] = new Character(0);
                } else {
                    objArr[i] = Boolean.FALSE;
                }
            }
        }
        return objArr;
    }

    private Callback createReverseEngineeredCallbackOfProperType(Callback callback, int i, Map map) {
        Class<?>[] interfaces = callback.getClass().getInterfaces();
        Class<?> cls = null;
        int i2 = 0;
        while (i2 < interfaces.length) {
            Class cls2 = class$net$sf$cglib$proxy$Callback;
            if (cls2 == null) {
                cls2 = class$("net.sf.cglib.proxy.Callback");
                class$net$sf$cglib$proxy$Callback = cls2;
            }
            if (cls2.isAssignableFrom(interfaces[i2])) {
                cls = interfaces[i2];
                Class<?> cls3 = class$net$sf$cglib$proxy$Callback;
                if (cls3 == null) {
                    cls3 = class$("net.sf.cglib.proxy.Callback");
                    class$net$sf$cglib$proxy$Callback = cls3;
                }
                if (cls != cls3) {
                    interfaces = cls.getInterfaces();
                    List asList = Arrays.asList(interfaces);
                    Class cls4 = class$net$sf$cglib$proxy$Callback;
                    if (cls4 == null) {
                        cls4 = class$("net.sf.cglib.proxy.Callback");
                        class$net$sf$cglib$proxy$Callback = cls4;
                    }
                    if (asList.contains(cls4)) {
                        break;
                    }
                    i2 = -1;
                } else {
                    ConversionException conversionException = new ConversionException("Cannot handle CGLIB callback");
                    conversionException.add("CGLIB-callback-type", callback.getClass().getName());
                    throw conversionException;
                }
            }
            i2++;
        }
        return (Callback) Proxy.newProxyInstance(cls.getClassLoader(), new Class[]{cls}, new ReverseEngineeringInvocationHandler(i, map));
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:10:? */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r1v2, types: [java.util.List] */
    /* JADX WARN: Type inference failed for: r1v3, types: [java.util.List] */
    /* JADX WARN: Type inference failed for: r1v5, types: [java.lang.Object, java.util.ArrayList] */
    /* JADX WARNING: Unknown variable types count: 1 */
    private Callback[] getCallbacks(Object obj) {
        Class<?> cls = obj.getClass();
        ?? r1 = (List) this.fieldCache.get(cls.getName());
        if (r1 == 0) {
            r1 = new ArrayList();
            this.fieldCache.put(cls.getName(), r1);
            int i = 0;
            while (true) {
                try {
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append(CALLBACK_MARKER);
                    stringBuffer.append(i);
                    Field declaredField = cls.getDeclaredField(stringBuffer.toString());
                    if (!declaredField.isAccessible()) {
                        declaredField.setAccessible(true);
                    }
                    r1.add(declaredField);
                    i++;
                } catch (NoSuchFieldException unused) {
                }
            }
        }
        ArrayList arrayList = new ArrayList();
        for (int i2 = 0; i2 < r1.size(); i2++) {
            try {
                arrayList.add(((Field) r1.get(i2)).get(obj));
            } catch (IllegalAccessException e) {
                ObjectAccessException objectAccessException = new ObjectAccessException("Cannot access field", e);
                StringBuffer stringBuffer2 = new StringBuffer();
                stringBuffer2.append(cls.getName());
                stringBuffer2.append(".");
                stringBuffer2.append(CALLBACK_MARKER);
                stringBuffer2.append(i2);
                objectAccessException.add("field", stringBuffer2.toString());
                throw objectAccessException;
            }
        }
        return (Callback[]) arrayList.toArray(new Callback[arrayList.size()]);
    }

    private void readCallback(HierarchicalStreamReader hierarchicalStreamReader, UnmarshallingContext unmarshallingContext, List list, List list2) {
        Callback callback = (Callback) unmarshallingContext.convertAnother(null, this.mapper.realClass(hierarchicalStreamReader.getNodeName()));
        list2.add(callback);
        if (callback == null) {
            list.add(NoOp.INSTANCE);
        } else {
            list.add(callback);
        }
    }

    @Override // com.thoughtworks.xstream.converters.ConverterMatcher, com.thoughtworks.xstream.converters.reflection.SerializableConverter
    public boolean canConvert(Class cls) {
        if (cls == null || !Enhancer.isEnhanced(cls) || cls.getName().indexOf(DEFAULT_NAMING_MARKER) <= 0) {
            Class cls2 = class$com$thoughtworks$xstream$mapper$CGLIBMapper$Marker;
            if (cls2 == null) {
                cls2 = class$("com.thoughtworks.xstream.mapper.CGLIBMapper$Marker");
                class$com$thoughtworks$xstream$mapper$CGLIBMapper$Marker = cls2;
            }
            return cls == cls2;
        }
    }

    @Override // com.thoughtworks.xstream.converters.reflection.SerializableConverter
    public List hierarchyFor(Class cls) {
        List hierarchyFor = super.hierarchyFor(cls);
        hierarchyFor.remove(hierarchyFor.size() - 1);
        return hierarchyFor;
    }

    @Override // com.thoughtworks.xstream.converters.Converter, com.thoughtworks.xstream.converters.reflection.AbstractReflectionConverter
    public void marshal(Object obj, HierarchicalStreamWriter hierarchicalStreamWriter, MarshallingContext marshallingContext) {
        Callback[] callbackArr;
        Class<?> cls = obj.getClass();
        Class cls2 = class$net$sf$cglib$proxy$Factory;
        if (cls2 == null) {
            cls2 = class$("net.sf.cglib.proxy.Factory");
            class$net$sf$cglib$proxy$Factory = cls2;
        }
        boolean isAssignableFrom = cls2.isAssignableFrom(cls);
        ExtendedHierarchicalStreamWriterHelper.startNode(hierarchicalStreamWriter, "type", cls);
        marshallingContext.convertAnother(cls.getSuperclass());
        hierarchicalStreamWriter.endNode();
        hierarchicalStreamWriter.startNode("interfaces");
        Class<?>[] interfaces = cls.getInterfaces();
        for (int i = 0; i < interfaces.length; i++) {
            Class<?> cls3 = interfaces[i];
            Class<?> cls4 = class$net$sf$cglib$proxy$Factory;
            if (cls4 == null) {
                cls4 = class$("net.sf.cglib.proxy.Factory");
                class$net$sf$cglib$proxy$Factory = cls4;
            }
            if (cls3 != cls4) {
                ExtendedHierarchicalStreamWriterHelper.startNode(hierarchicalStreamWriter, this.mapper.serializedClass(interfaces[i].getClass()), interfaces[i].getClass());
                marshallingContext.convertAnother(interfaces[i]);
                hierarchicalStreamWriter.endNode();
            }
        }
        hierarchicalStreamWriter.endNode();
        hierarchicalStreamWriter.startNode("hasFactory");
        hierarchicalStreamWriter.setValue(String.valueOf(isAssignableFrom));
        hierarchicalStreamWriter.endNode();
        if (isAssignableFrom) {
            callbackArr = ((Factory) obj).getCallbacks();
        } else {
            callbackArr = getCallbacks(obj);
        }
        if (callbackArr.length > 1) {
            if (isAssignableFrom) {
                Map createCallbackIndexMap = createCallbackIndexMap((Factory) obj);
                hierarchicalStreamWriter.startNode("callbacks");
                hierarchicalStreamWriter.startNode("mapping");
                marshallingContext.convertAnother(createCallbackIndexMap);
                hierarchicalStreamWriter.endNode();
            } else {
                ConversionException conversionException = new ConversionException("Cannot handle CGLIB enhanced proxies without factory that have multiple callbacks");
                conversionException.add("proxy-superclass", cls.getSuperclass().getName());
                conversionException.add("number-of-callbacks", String.valueOf(callbackArr.length));
                throw conversionException;
            }
        }
        boolean z = false;
        for (Callback callback : callbackArr) {
            if (callback == null) {
                hierarchicalStreamWriter.startNode(this.mapper.serializedClass(null));
                hierarchicalStreamWriter.endNode();
            } else {
                if (!z) {
                    Class cls5 = class$net$sf$cglib$proxy$MethodInterceptor;
                    if (cls5 == null) {
                        cls5 = class$("net.sf.cglib.proxy.MethodInterceptor");
                        class$net$sf$cglib$proxy$MethodInterceptor = cls5;
                    }
                    if (!cls5.isAssignableFrom(callback.getClass())) {
                        z = false;
                        ExtendedHierarchicalStreamWriterHelper.startNode(hierarchicalStreamWriter, this.mapper.serializedClass(callback.getClass()), callback.getClass());
                        marshallingContext.convertAnother(callback);
                        hierarchicalStreamWriter.endNode();
                    }
                }
                z = true;
                ExtendedHierarchicalStreamWriterHelper.startNode(hierarchicalStreamWriter, this.mapper.serializedClass(callback.getClass()), callback.getClass());
                marshallingContext.convertAnother(callback);
                hierarchicalStreamWriter.endNode();
            }
        }
        if (callbackArr.length > 1) {
            hierarchicalStreamWriter.endNode();
        }
        try {
            Field declaredField = cls.getDeclaredField("serialVersionUID");
            if (!declaredField.isAccessible()) {
                declaredField.setAccessible(true);
            }
            long j = declaredField.getLong(null);
            Class cls6 = class$java$lang$String;
            if (cls6 == null) {
                cls6 = class$("java.lang.String");
                class$java$lang$String = cls6;
            }
            ExtendedHierarchicalStreamWriterHelper.startNode(hierarchicalStreamWriter, "serialVersionUID", cls6);
            hierarchicalStreamWriter.setValue(String.valueOf(j));
            hierarchicalStreamWriter.endNode();
        } catch (NoSuchFieldException unused) {
        } catch (IllegalAccessException e) {
            ObjectAccessException objectAccessException = new ObjectAccessException("Cannot access field", e);
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(cls.getName());
            stringBuffer.append(".serialVersionUID");
            objectAccessException.add("field", stringBuffer.toString());
            throw objectAccessException;
        }
        if (z) {
            hierarchicalStreamWriter.startNode("instance");
            super.doMarshalConditionally(obj, hierarchicalStreamWriter, marshallingContext);
            hierarchicalStreamWriter.endNode();
        }
    }

    @Override // com.thoughtworks.xstream.converters.reflection.AbstractReflectionConverter
    public Object readResolve() {
        super.readResolve();
        this.fieldCache = new HashMap();
        return this;
    }

    @Override // com.thoughtworks.xstream.converters.Converter, com.thoughtworks.xstream.converters.reflection.AbstractReflectionConverter
    public Object unmarshal(HierarchicalStreamReader hierarchicalStreamReader, UnmarshallingContext unmarshallingContext) {
        Map map;
        Enhancer enhancer = new Enhancer();
        hierarchicalStreamReader.moveDown();
        Class cls = class$java$lang$Class;
        if (cls == null) {
            cls = class$("java.lang.Class");
            class$java$lang$Class = cls;
        }
        Object obj = null;
        enhancer.setSuperclass((Class) unmarshallingContext.convertAnother(null, cls));
        hierarchicalStreamReader.moveUp();
        hierarchicalStreamReader.moveDown();
        ArrayList arrayList = new ArrayList();
        while (hierarchicalStreamReader.hasMoreChildren()) {
            hierarchicalStreamReader.moveDown();
            arrayList.add(unmarshallingContext.convertAnother(null, this.mapper.realClass(hierarchicalStreamReader.getNodeName())));
            hierarchicalStreamReader.moveUp();
        }
        enhancer.setInterfaces((Class[]) arrayList.toArray(new Class[arrayList.size()]));
        hierarchicalStreamReader.moveUp();
        hierarchicalStreamReader.moveDown();
        boolean booleanValue = Boolean.valueOf(hierarchicalStreamReader.getValue()).booleanValue();
        enhancer.setUseFactory(booleanValue);
        hierarchicalStreamReader.moveUp();
        ArrayList arrayList2 = new ArrayList();
        List arrayList3 = new ArrayList();
        hierarchicalStreamReader.moveDown();
        if ("callbacks".equals(hierarchicalStreamReader.getNodeName())) {
            hierarchicalStreamReader.moveDown();
            Class cls2 = class$java$util$HashMap;
            if (cls2 == null) {
                cls2 = class$("java.util.HashMap");
                class$java$util$HashMap = cls2;
            }
            map = (Map) unmarshallingContext.convertAnother(null, cls2);
            hierarchicalStreamReader.moveUp();
            while (hierarchicalStreamReader.hasMoreChildren()) {
                hierarchicalStreamReader.moveDown();
                readCallback(hierarchicalStreamReader, unmarshallingContext, arrayList2, arrayList3);
                hierarchicalStreamReader.moveUp();
            }
        } else {
            readCallback(hierarchicalStreamReader, unmarshallingContext, arrayList2, arrayList3);
            map = null;
        }
        enhancer.setCallbacks((Callback[]) arrayList2.toArray(new Callback[arrayList2.size()]));
        if (map != null) {
            enhancer.setCallbackFilter(new ReverseEngineeredCallbackFilter(map));
        }
        hierarchicalStreamReader.moveUp();
        while (hierarchicalStreamReader.hasMoreChildren()) {
            hierarchicalStreamReader.moveDown();
            if (hierarchicalStreamReader.getNodeName().equals("serialVersionUID")) {
                enhancer.setSerialVersionUID(Long.valueOf(hierarchicalStreamReader.getValue()));
            } else if (hierarchicalStreamReader.getNodeName().equals("instance")) {
                obj = create(enhancer, arrayList3, booleanValue);
                super.doUnmarshalConditionally(obj, hierarchicalStreamReader, unmarshallingContext);
            }
            hierarchicalStreamReader.moveUp();
        }
        if (obj == null) {
            obj = create(enhancer, arrayList3, booleanValue);
        }
        return this.serializationMembers.callReadResolve(obj);
    }

    public CGLIBEnhancedConverter(Mapper mapper, ReflectionProvider reflectionProvider, ClassLoader classLoader) {
        super(mapper, new CGLIBFilteringReflectionProvider(reflectionProvider), classLoader);
        this.fieldCache = new HashMap();
    }

    /* JADX WARNING: Illegal instructions before constructor call */
    public CGLIBEnhancedConverter(Mapper mapper, ReflectionProvider reflectionProvider) {
        this(mapper, r0, r3.getClassLoader());
        CGLIBFilteringReflectionProvider cGLIBFilteringReflectionProvider = new CGLIBFilteringReflectionProvider(reflectionProvider);
        Class cls = class$com$thoughtworks$xstream$converters$reflection$CGLIBEnhancedConverter;
        if (cls == null) {
            cls = class$("com.thoughtworks.xstream.converters.reflection.CGLIBEnhancedConverter");
            class$com$thoughtworks$xstream$converters$reflection$CGLIBEnhancedConverter = cls;
        }
    }
}
