package com.thoughtworks.xstream.converters.reflection;

import androidx.base.b2;
import com.thoughtworks.xstream.converters.ConversionException;
import com.thoughtworks.xstream.converters.Converter;
import com.thoughtworks.xstream.converters.MarshallingContext;
import com.thoughtworks.xstream.converters.UnmarshallingContext;
import com.thoughtworks.xstream.core.ClassLoaderReference;
import com.thoughtworks.xstream.core.JVM;
import com.thoughtworks.xstream.core.ReferencingMarshallingContext;
import com.thoughtworks.xstream.core.util.CustomObjectInputStream;
import com.thoughtworks.xstream.core.util.CustomObjectOutputStream;
import com.thoughtworks.xstream.core.util.HierarchicalStreams;
import com.thoughtworks.xstream.core.util.SerializationMembers;
import com.thoughtworks.xstream.io.ExtendedHierarchicalStreamWriterHelper;
import com.thoughtworks.xstream.io.HierarchicalStreamReader;
import com.thoughtworks.xstream.io.HierarchicalStreamWriter;
import com.thoughtworks.xstream.io.StreamException;
import com.thoughtworks.xstream.mapper.Mapper;
import java.io.Externalizable;
import java.io.IOException;
import java.io.NotActiveException;
import java.io.ObjectInputValidation;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.util.Map;

public class ExternalizableConverter implements Converter {
    public static /* synthetic */ Class class$com$thoughtworks$xstream$converters$reflection$ExternalizableConverter;
    public static /* synthetic */ Class class$java$io$Externalizable;
    private final ClassLoaderReference classLoaderReference;
    private Mapper mapper;
    private transient SerializationMembers serializationMembers;

    public ExternalizableConverter(Mapper mapper2, ClassLoaderReference classLoaderReference2) {
        this.mapper = mapper2;
        this.classLoaderReference = classLoaderReference2;
        this.serializationMembers = new SerializationMembers();
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e) {
            throw b2.n(e);
        }
    }

    private Object readResolve() {
        this.serializationMembers = new SerializationMembers();
        return this;
    }

    @Override // com.thoughtworks.xstream.converters.ConverterMatcher
    public boolean canConvert(Class cls) {
        if (cls != null && JVM.canCreateDerivedObjectOutputStream()) {
            Class cls2 = class$java$io$Externalizable;
            if (cls2 == null) {
                cls2 = class$("java.io.Externalizable");
                class$java$io$Externalizable = cls2;
            }
            if (cls2.isAssignableFrom(cls)) {
                return true;
            }
        }
        return false;
    }

    @Override // com.thoughtworks.xstream.converters.Converter
    public void marshal(Object obj, final HierarchicalStreamWriter hierarchicalStreamWriter, final MarshallingContext marshallingContext) {
        Object callWriteReplace = this.serializationMembers.callWriteReplace(obj);
        if (callWriteReplace != obj && (marshallingContext instanceof ReferencingMarshallingContext)) {
            ((ReferencingMarshallingContext) marshallingContext).replace(obj, callWriteReplace);
        }
        if (callWriteReplace.getClass() != obj.getClass()) {
            String aliasForSystemAttribute = this.mapper.aliasForSystemAttribute("resolves-to");
            if (aliasForSystemAttribute != null) {
                hierarchicalStreamWriter.addAttribute(aliasForSystemAttribute, this.mapper.serializedClass(callWriteReplace.getClass()));
            }
            marshallingContext.convertAnother(callWriteReplace);
            return;
        }
        try {
            CustomObjectOutputStream instance = CustomObjectOutputStream.getInstance(marshallingContext, new CustomObjectOutputStream.StreamCallback() {
                /* class com.thoughtworks.xstream.converters.reflection.ExternalizableConverter.AnonymousClass1 */

                @Override // com.thoughtworks.xstream.core.util.CustomObjectOutputStream.StreamCallback
                public void close() {
                    throw new UnsupportedOperationException("Objects are not allowed to call ObjectOutput.close() from writeExternal()");
                }

                @Override // com.thoughtworks.xstream.core.util.CustomObjectOutputStream.StreamCallback
                public void defaultWriteObject() {
                    throw new UnsupportedOperationException();
                }

                @Override // com.thoughtworks.xstream.core.util.CustomObjectOutputStream.StreamCallback
                public void flush() {
                    hierarchicalStreamWriter.flush();
                }

                @Override // com.thoughtworks.xstream.core.util.CustomObjectOutputStream.StreamCallback
                public void writeFieldsToStream(Map map) {
                    throw new UnsupportedOperationException();
                }

                @Override // com.thoughtworks.xstream.core.util.CustomObjectOutputStream.StreamCallback
                public void writeToStream(Object obj) {
                    if (obj == null) {
                        hierarchicalStreamWriter.startNode("null");
                        hierarchicalStreamWriter.endNode();
                        return;
                    }
                    ExtendedHierarchicalStreamWriterHelper.startNode(hierarchicalStreamWriter, ExternalizableConverter.this.mapper.serializedClass(obj.getClass()), obj.getClass());
                    marshallingContext.convertAnother(obj);
                    hierarchicalStreamWriter.endNode();
                }
            });
            ((Externalizable) callWriteReplace).writeExternal(instance);
            instance.popCallback();
        } catch (IOException e) {
            StringBuffer h = b2.h("Cannot serialize ");
            h.append(callWriteReplace.getClass().getName());
            h.append(" using Externalization");
            throw new StreamException(h.toString(), e);
        }
    }

    @Override // com.thoughtworks.xstream.converters.Converter
    public Object unmarshal(final HierarchicalStreamReader hierarchicalStreamReader, final UnmarshallingContext unmarshallingContext) {
        Class requiredType = unmarshallingContext.getRequiredType();
        try {
            Constructor declaredConstructor = requiredType.getDeclaredConstructor(null);
            if (!declaredConstructor.isAccessible()) {
                declaredConstructor.setAccessible(true);
            }
            final Externalizable externalizable = (Externalizable) declaredConstructor.newInstance(null);
            CustomObjectInputStream instance = CustomObjectInputStream.getInstance(unmarshallingContext, new CustomObjectInputStream.StreamCallback() {
                /* class com.thoughtworks.xstream.converters.reflection.ExternalizableConverter.AnonymousClass2 */

                @Override // com.thoughtworks.xstream.core.util.CustomObjectInputStream.StreamCallback
                public void close() {
                    throw new UnsupportedOperationException("Objects are not allowed to call ObjectInput.close() from readExternal()");
                }

                @Override // com.thoughtworks.xstream.core.util.CustomObjectInputStream.StreamCallback
                public void defaultReadObject() {
                    throw new UnsupportedOperationException();
                }

                @Override // com.thoughtworks.xstream.core.util.CustomObjectInputStream.StreamCallback
                public Map readFieldsFromStream() {
                    throw new UnsupportedOperationException();
                }

                @Override // com.thoughtworks.xstream.core.util.CustomObjectInputStream.StreamCallback
                public Object readFromStream() {
                    hierarchicalStreamReader.moveDown();
                    Object convertAnother = unmarshallingContext.convertAnother(externalizable, HierarchicalStreams.readClassType(hierarchicalStreamReader, ExternalizableConverter.this.mapper));
                    hierarchicalStreamReader.moveUp();
                    return convertAnother;
                }

                @Override // com.thoughtworks.xstream.core.util.CustomObjectInputStream.StreamCallback
                public void registerValidation(ObjectInputValidation objectInputValidation, int i) {
                    throw new NotActiveException("stream inactive");
                }
            }, this.classLoaderReference);
            externalizable.readExternal(instance);
            instance.popCallback();
            return this.serializationMembers.callReadResolve(externalizable);
        } catch (NoSuchMethodException e) {
            throw new ConversionException("Missing default constructor of type", e);
        } catch (InvocationTargetException e2) {
            throw new ConversionException("Cannot construct type", e2);
        } catch (InstantiationException e3) {
            throw new ConversionException("Cannot construct type", e3);
        } catch (IllegalAccessException e4) {
            throw new ObjectAccessException("Cannot construct type", e4);
        } catch (IOException e5) {
            StringBuffer h = b2.h("Cannot externalize ");
            h.append(requiredType.getClass());
            throw new StreamException(h.toString(), e5);
        } catch (ClassNotFoundException e6) {
            throw new ConversionException("Cannot construct type", e6);
        }
    }

    public ExternalizableConverter(Mapper mapper2, ClassLoader classLoader) {
        this(mapper2, new ClassLoaderReference(classLoader));
    }

    /* JADX WARNING: Illegal instructions before constructor call */
    public ExternalizableConverter(Mapper mapper2) {
        this(mapper2, r0.getClassLoader());
        Class cls = class$com$thoughtworks$xstream$converters$reflection$ExternalizableConverter;
        if (cls == null) {
            cls = class$("com.thoughtworks.xstream.converters.reflection.ExternalizableConverter");
            class$com$thoughtworks$xstream$converters$reflection$ExternalizableConverter = cls;
        }
    }
}
