package com.thoughtworks.xstream.converters.reflection;

import androidx.base.b2;

public class FieldKey {
    private final Class declaringClass;
    private final int depth;
    private final String fieldName;
    private final int order;

    public FieldKey(String str, Class cls, int i) {
        if (str == null || cls == null) {
            throw new IllegalArgumentException("fieldName or declaringClass is null");
        }
        this.fieldName = str;
        this.declaringClass = cls;
        this.order = i;
        int i2 = 0;
        while (cls.getSuperclass() != null) {
            i2++;
            cls = cls.getSuperclass();
        }
        this.depth = i2;
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (!(obj instanceof FieldKey)) {
            return false;
        }
        FieldKey fieldKey = (FieldKey) obj;
        return this.declaringClass.equals(fieldKey.declaringClass) && this.fieldName.equals(fieldKey.fieldName);
    }

    public Class getDeclaringClass() {
        return this.declaringClass;
    }

    public int getDepth() {
        return this.depth;
    }

    public String getFieldName() {
        return this.fieldName;
    }

    public int getOrder() {
        return this.order;
    }

    public int hashCode() {
        return this.declaringClass.hashCode() + (this.fieldName.hashCode() * 29);
    }

    public String toString() {
        StringBuffer h = b2.h("FieldKey{order=");
        h.append(this.order);
        h.append(", writer=");
        h.append(this.depth);
        h.append(", declaringClass=");
        h.append(this.declaringClass);
        h.append(", fieldName='");
        h.append(this.fieldName);
        h.append("'}");
        return h.toString();
    }
}
