package com.thoughtworks.xstream.converters.reflection;

import androidx.base.b2;
import com.thoughtworks.xstream.converters.ConversionException;
import com.thoughtworks.xstream.converters.ErrorWritingException;
import com.thoughtworks.xstream.converters.reflection.ReflectionProvider;
import com.thoughtworks.xstream.core.JVM;
import com.thoughtworks.xstream.core.util.Fields;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.DataOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectStreamClass;
import java.lang.reflect.Constructor;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Modifier;
import java.util.Iterator;
import java.util.Map;
import java.util.WeakHashMap;

public class PureJavaReflectionProvider implements ReflectionProvider {
    public static /* synthetic */ Class class$java$io$Serializable;
    public static /* synthetic */ Class class$java$lang$Void;
    public FieldDictionary fieldDictionary;
    private transient Map serializedDataCache;

    public PureJavaReflectionProvider() {
        this(new FieldDictionary(new ImmutableFieldKeySorter()));
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e) {
            throw b2.n(e);
        }
    }

    private Object instantiateUsingSerialization(final Class cls) {
        ObjectAccessException objectAccessException;
        Object readObject;
        try {
            synchronized (this.serializedDataCache) {
                byte[] bArr = (byte[]) this.serializedDataCache.get(cls);
                if (bArr == null) {
                    ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
                    DataOutputStream dataOutputStream = new DataOutputStream(byteArrayOutputStream);
                    dataOutputStream.writeShort(-21267);
                    dataOutputStream.writeShort(5);
                    dataOutputStream.writeByte(115);
                    dataOutputStream.writeByte(114);
                    dataOutputStream.writeUTF(cls.getName());
                    dataOutputStream.writeLong(ObjectStreamClass.lookup(cls).getSerialVersionUID());
                    dataOutputStream.writeByte(2);
                    dataOutputStream.writeShort(0);
                    dataOutputStream.writeByte(120);
                    dataOutputStream.writeByte(112);
                    bArr = byteArrayOutputStream.toByteArray();
                    this.serializedDataCache.put(cls, bArr);
                }
                readObject = new ObjectInputStream(new ByteArrayInputStream(bArr)) {
                    /* class com.thoughtworks.xstream.converters.reflection.PureJavaReflectionProvider.AnonymousClass1 */

                    @Override // java.io.ObjectInputStream
                    public Class resolveClass(ObjectStreamClass objectStreamClass) {
                        return Class.forName(objectStreamClass.getName(), false, cls.getClassLoader());
                    }
                }.readObject();
            }
            return readObject;
        } catch (IOException e) {
            objectAccessException = new ObjectAccessException("Cannot create type by JDK serialization", e);
            objectAccessException.add("construction-type", cls.getName());
            throw objectAccessException;
        } catch (ClassNotFoundException e2) {
            objectAccessException = new ObjectAccessException("Cannot find class", e2);
            objectAccessException.add("construction-type", cls.getName());
            throw objectAccessException;
        }
    }

    private Object readResolve() {
        init();
        return this;
    }

    @Override // com.thoughtworks.xstream.converters.reflection.ReflectionProvider
    public boolean fieldDefinedInClass(String str, Class cls) {
        Field fieldOrNull = this.fieldDictionary.fieldOrNull(cls, str, null);
        return fieldOrNull != null && fieldModifiersSupported(fieldOrNull);
    }

    public boolean fieldModifiersSupported(Field field) {
        int modifiers = field.getModifiers();
        return !Modifier.isStatic(modifiers) && !Modifier.isTransient(modifiers);
    }

    @Override // com.thoughtworks.xstream.converters.reflection.ReflectionProvider
    public Field getField(Class cls, String str) {
        return this.fieldDictionary.field(cls, str, null);
    }

    @Override // com.thoughtworks.xstream.converters.reflection.ReflectionProvider
    public Field getFieldOrNull(Class cls, String str) {
        return this.fieldDictionary.fieldOrNull(cls, str, null);
    }

    @Override // com.thoughtworks.xstream.converters.reflection.ReflectionProvider
    public Class getFieldType(Object obj, String str, Class cls) {
        return this.fieldDictionary.field(obj.getClass(), str, cls).getType();
    }

    public void init() {
        this.serializedDataCache = new WeakHashMap();
    }

    @Override // com.thoughtworks.xstream.converters.reflection.ReflectionProvider
    public Object newInstance(Class cls) {
        ErrorWritingException errorWritingException;
        ObjectAccessException objectAccessException;
        if (cls != Void.TYPE) {
            Class cls2 = class$java$lang$Void;
            if (cls2 == null) {
                cls2 = class$("java.lang.Void");
                class$java$lang$Void = cls2;
            }
            if (cls != cls2) {
                try {
                    Constructor<?>[] declaredConstructors = cls.getDeclaredConstructors();
                    for (Constructor<?> constructor : declaredConstructors) {
                        if (constructor.getParameterTypes().length == 0) {
                            if (!constructor.isAccessible()) {
                                constructor.setAccessible(true);
                            }
                            return constructor.newInstance(new Object[0]);
                        }
                    }
                    Class cls3 = class$java$io$Serializable;
                    if (cls3 == null) {
                        cls3 = class$("java.io.Serializable");
                        class$java$io$Serializable = cls3;
                    }
                    if (cls3.isAssignableFrom(cls)) {
                        return instantiateUsingSerialization(cls);
                    }
                    errorWritingException = new ObjectAccessException("Cannot construct type as it does not have a no-args constructor");
                    errorWritingException.add("construction-type", cls.getName());
                    throw errorWritingException;
                } catch (InstantiationException e) {
                    objectAccessException = new ObjectAccessException("Cannot construct type", e);
                    errorWritingException = objectAccessException;
                } catch (IllegalAccessException e2) {
                    objectAccessException = new ObjectAccessException("Cannot construct type", e2);
                    errorWritingException = objectAccessException;
                } catch (InvocationTargetException e3) {
                    if (e3.getTargetException() instanceof RuntimeException) {
                        throw ((RuntimeException) e3.getTargetException());
                    } else if (e3.getTargetException() instanceof Error) {
                        throw ((Error) e3.getTargetException());
                    } else {
                        errorWritingException = new ObjectAccessException("Constructor for type threw an exception", e3.getTargetException());
                    }
                }
            }
        }
        errorWritingException = new ConversionException("Security alert: Marshalling rejected");
        errorWritingException.add("construction-type", cls.getName());
        throw errorWritingException;
    }

    public void setFieldDictionary(FieldDictionary fieldDictionary2) {
        this.fieldDictionary = fieldDictionary2;
    }

    public void validateFieldAccess(Field field) {
        if (!Modifier.isFinal(field.getModifiers())) {
            return;
        }
        if (!JVM.isVersion(5)) {
            StringBuffer h = b2.h("Invalid final field ");
            h.append(field.getDeclaringClass().getName());
            h.append(".");
            h.append(field.getName());
            throw new ObjectAccessException(h.toString());
        } else if (!field.isAccessible()) {
            field.setAccessible(true);
        }
    }

    @Override // com.thoughtworks.xstream.converters.reflection.ReflectionProvider
    public void visitSerializableFields(Object obj, ReflectionProvider.Visitor visitor) {
        Iterator fieldsFor = this.fieldDictionary.fieldsFor(obj.getClass());
        while (fieldsFor.hasNext()) {
            Field field = (Field) fieldsFor.next();
            if (fieldModifiersSupported(field)) {
                validateFieldAccess(field);
                visitor.visit(field.getName(), field.getType(), field.getDeclaringClass(), Fields.read(field, obj));
            }
        }
    }

    @Override // com.thoughtworks.xstream.converters.reflection.ReflectionProvider
    public void writeField(Object obj, String str, Object obj2, Class cls) {
        Field field = this.fieldDictionary.field(obj.getClass(), str, cls);
        validateFieldAccess(field);
        Fields.write(field, obj, obj2);
    }

    public PureJavaReflectionProvider(FieldDictionary fieldDictionary2) {
        this.fieldDictionary = fieldDictionary2;
        init();
    }
}
