package com.thoughtworks.xstream.converters.reflection;

import androidx.base.b2;
import com.thoughtworks.xstream.converters.ConversionException;
import com.thoughtworks.xstream.converters.MarshallingContext;
import com.thoughtworks.xstream.converters.UnmarshallingContext;
import com.thoughtworks.xstream.converters.reflection.ReflectionProvider;
import com.thoughtworks.xstream.core.ClassLoaderReference;
import com.thoughtworks.xstream.core.JVM;
import com.thoughtworks.xstream.core.util.CustomObjectInputStream;
import com.thoughtworks.xstream.core.util.CustomObjectOutputStream;
import com.thoughtworks.xstream.core.util.Fields;
import com.thoughtworks.xstream.core.util.HierarchicalStreams;
import com.thoughtworks.xstream.io.ExtendedHierarchicalStreamWriterHelper;
import com.thoughtworks.xstream.io.HierarchicalStreamReader;
import com.thoughtworks.xstream.io.HierarchicalStreamWriter;
import com.thoughtworks.xstream.io.StreamException;
import com.thoughtworks.xstream.mapper.Mapper;
import java.io.IOException;
import java.io.InvalidObjectException;
import java.io.ObjectInputValidation;
import java.io.ObjectStreamClass;
import java.io.ObjectStreamField;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class SerializableConverter extends AbstractReflectionConverter {
    private static final String ATTRIBUTE_CLASS = "class";
    private static final String ATTRIBUTE_NAME = "name";
    private static final String ATTRIBUTE_SERIALIZATION = "serialization";
    private static final String ATTRIBUTE_VALUE_CUSTOM = "custom";
    private static final String ELEMENT_DEFAULT = "default";
    private static final String ELEMENT_FIELD = "field";
    private static final String ELEMENT_FIELDS = "fields";
    private static final String ELEMENT_NULL = "null";
    private static final String ELEMENT_UNSERIALIZABLE_PARENTS = "unserializable-parents";
    public static /* synthetic */ Class class$java$io$Serializable;
    public static /* synthetic */ Class class$java$lang$Object;
    private final ClassLoaderReference classLoaderReference;

    public static class UnserializableParentsReflectionProvider extends ReflectionProviderWrapper {
        public UnserializableParentsReflectionProvider(ReflectionProvider reflectionProvider) {
            super(reflectionProvider);
        }

        @Override // com.thoughtworks.xstream.converters.reflection.ReflectionProviderWrapper, com.thoughtworks.xstream.converters.reflection.ReflectionProvider
        public void visitSerializableFields(Object obj, final ReflectionProvider.Visitor visitor) {
            this.wrapped.visitSerializableFields(obj, new ReflectionProvider.Visitor() {
                /* class com.thoughtworks.xstream.converters.reflection.SerializableConverter.UnserializableParentsReflectionProvider.AnonymousClass1 */

                @Override // com.thoughtworks.xstream.converters.reflection.ReflectionProvider.Visitor
                public void visit(String str, Class cls, Class cls2, Object obj) {
                    Class cls3 = SerializableConverter.class$java$io$Serializable;
                    if (cls3 == null) {
                        cls3 = SerializableConverter.class$("java.io.Serializable");
                        SerializableConverter.class$java$io$Serializable = cls3;
                    }
                    if (!cls3.isAssignableFrom(cls2)) {
                        visitor.visit(str, cls, cls2, obj);
                    }
                }
            });
        }
    }

    public SerializableConverter(Mapper mapper, ReflectionProvider reflectionProvider, ClassLoaderReference classLoaderReference2) {
        super(mapper, new UnserializableParentsReflectionProvider(reflectionProvider));
        this.classLoaderReference = classLoaderReference2;
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e) {
            throw b2.n(e);
        }
    }

    private boolean isSerializable(Class cls) {
        if (cls == null) {
            return false;
        }
        Class cls2 = class$java$io$Serializable;
        if (cls2 == null) {
            cls2 = class$("java.io.Serializable");
            class$java$io$Serializable = cls2;
        }
        if (!cls2.isAssignableFrom(cls) || cls.isInterface()) {
            return false;
        }
        if (!(this.serializationMembers.supportsReadObject(cls, true) || this.serializationMembers.supportsWriteObject(cls, true))) {
            return false;
        }
        for (Class<?> cls3 : hierarchyFor(cls)) {
            Class cls4 = class$java$io$Serializable;
            if (cls4 == null) {
                cls4 = class$("java.io.Serializable");
                class$java$io$Serializable = cls4;
            }
            if (!cls4.isAssignableFrom(cls3)) {
                return canAccess(cls);
            }
        }
        return true;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Object readField(ObjectStreamField objectStreamField, Class cls, Object obj) {
        return Fields.read(Fields.find(cls, objectStreamField.getName()), obj);
    }

    @Override // com.thoughtworks.xstream.converters.ConverterMatcher
    public boolean canConvert(Class cls) {
        return JVM.canCreateDerivedObjectOutputStream() && isSerializable(cls);
    }

    @Override // com.thoughtworks.xstream.converters.reflection.AbstractReflectionConverter
    public void doMarshal(final Object obj, final HierarchicalStreamWriter hierarchicalStreamWriter, final MarshallingContext marshallingContext) {
        String aliasForSystemAttribute;
        String aliasForSystemAttribute2;
        String aliasForSystemAttribute3 = this.mapper.aliasForSystemAttribute(ATTRIBUTE_SERIALIZATION);
        if (aliasForSystemAttribute3 != null) {
            hierarchicalStreamWriter.addAttribute(aliasForSystemAttribute3, ATTRIBUTE_VALUE_CUSTOM);
        }
        final Class[] clsArr = new Class[1];
        final boolean[] zArr = {false};
        AnonymousClass1 r11 = new CustomObjectOutputStream.StreamCallback() {
            /* class com.thoughtworks.xstream.converters.reflection.SerializableConverter.AnonymousClass1 */

            @Override // com.thoughtworks.xstream.core.util.CustomObjectOutputStream.StreamCallback
            public void close() {
                throw new UnsupportedOperationException("Objects are not allowed to call ObjectOutputStream.close() from writeObject()");
            }

            @Override // com.thoughtworks.xstream.core.util.CustomObjectOutputStream.StreamCallback
            public void defaultWriteObject() {
                String aliasForSystemAttribute;
                ObjectStreamClass lookup = ObjectStreamClass.lookup(clsArr[0]);
                if (lookup != null) {
                    ObjectStreamField[] fields = lookup.getFields();
                    boolean z = false;
                    for (ObjectStreamField objectStreamField : fields) {
                        Object readField = SerializableConverter.this.readField(objectStreamField, clsArr[0], obj);
                        if (readField != null) {
                            if (!zArr[0]) {
                                hierarchicalStreamWriter.startNode(SerializableConverter.this.mapper.serializedClass(clsArr[0]));
                                zArr[0] = true;
                            }
                            if (!z) {
                                hierarchicalStreamWriter.startNode(SerializableConverter.ELEMENT_DEFAULT);
                                z = true;
                            }
                            if (SerializableConverter.this.mapper.shouldSerializeMember(clsArr[0], objectStreamField.getName())) {
                                Class<?> cls = readField.getClass();
                                ExtendedHierarchicalStreamWriterHelper.startNode(hierarchicalStreamWriter, SerializableConverter.this.mapper.serializedMember(obj.getClass(), objectStreamField.getName()), cls);
                                if (!cls.equals(SerializableConverter.this.mapper.defaultImplementationOf(objectStreamField.getType())) && (aliasForSystemAttribute = SerializableConverter.this.mapper.aliasForSystemAttribute(SerializableConverter.ATTRIBUTE_CLASS)) != null) {
                                    hierarchicalStreamWriter.addAttribute(aliasForSystemAttribute, SerializableConverter.this.mapper.serializedClass(cls));
                                }
                                marshallingContext.convertAnother(readField);
                                hierarchicalStreamWriter.endNode();
                            }
                        }
                    }
                    if (zArr[0] && !z) {
                        hierarchicalStreamWriter.startNode(SerializableConverter.ELEMENT_DEFAULT);
                        hierarchicalStreamWriter.endNode();
                    } else if (z) {
                        hierarchicalStreamWriter.endNode();
                    }
                }
            }

            @Override // com.thoughtworks.xstream.core.util.CustomObjectOutputStream.StreamCallback
            public void flush() {
                hierarchicalStreamWriter.flush();
            }

            @Override // com.thoughtworks.xstream.core.util.CustomObjectOutputStream.StreamCallback
            public void writeFieldsToStream(Map map) {
                String aliasForSystemAttribute;
                ObjectStreamClass lookup = ObjectStreamClass.lookup(clsArr[0]);
                hierarchicalStreamWriter.startNode(SerializableConverter.ELEMENT_DEFAULT);
                for (String str : map.keySet()) {
                    if (SerializableConverter.this.mapper.shouldSerializeMember(clsArr[0], str)) {
                        ObjectStreamField field = lookup.getField(str);
                        Object obj = map.get(str);
                        if (field == null) {
                            throw new MissingFieldException(obj.getClass().getName(), str);
                        } else if (obj != null) {
                            ExtendedHierarchicalStreamWriterHelper.startNode(hierarchicalStreamWriter, SerializableConverter.this.mapper.serializedMember(obj.getClass(), str), obj.getClass());
                            if (!(field.getType() == obj.getClass() || field.getType().isPrimitive() || (aliasForSystemAttribute = SerializableConverter.this.mapper.aliasForSystemAttribute(SerializableConverter.ATTRIBUTE_CLASS)) == null)) {
                                hierarchicalStreamWriter.addAttribute(aliasForSystemAttribute, SerializableConverter.this.mapper.serializedClass(obj.getClass()));
                            }
                            marshallingContext.convertAnother(obj);
                            hierarchicalStreamWriter.endNode();
                        }
                    }
                }
                hierarchicalStreamWriter.endNode();
            }

            @Override // com.thoughtworks.xstream.core.util.CustomObjectOutputStream.StreamCallback
            public void writeToStream(Object obj) {
                if (obj == null) {
                    hierarchicalStreamWriter.startNode(SerializableConverter.ELEMENT_NULL);
                    hierarchicalStreamWriter.endNode();
                    return;
                }
                ExtendedHierarchicalStreamWriterHelper.startNode(hierarchicalStreamWriter, SerializableConverter.this.mapper.serializedClass(obj.getClass()), obj.getClass());
                marshallingContext.convertAnother(obj);
                hierarchicalStreamWriter.endNode();
            }
        };
        try {
            boolean z = false;
            for (Class cls : hierarchyFor(obj.getClass())) {
                clsArr[0] = cls;
                Class cls2 = class$java$io$Serializable;
                if (cls2 == null) {
                    cls2 = class$("java.io.Serializable");
                    class$java$io$Serializable = cls2;
                }
                if (!cls2.isAssignableFrom(clsArr[0])) {
                    z = true;
                } else {
                    if (z) {
                        marshalUnserializableParent(hierarchicalStreamWriter, marshallingContext, obj);
                        z = false;
                    }
                    if (this.serializationMembers.supportsWriteObject(clsArr[0], false)) {
                        zArr[0] = true;
                        hierarchicalStreamWriter.startNode(this.mapper.serializedClass(clsArr[0]));
                        if (!(clsArr[0] == this.mapper.defaultImplementationOf(clsArr[0]) || (aliasForSystemAttribute2 = this.mapper.aliasForSystemAttribute(ATTRIBUTE_CLASS)) == null)) {
                            hierarchicalStreamWriter.addAttribute(aliasForSystemAttribute2, clsArr[0].getName());
                        }
                        CustomObjectOutputStream instance = CustomObjectOutputStream.getInstance(marshallingContext, r11);
                        this.serializationMembers.callWriteObject(clsArr[0], obj, instance);
                        instance.popCallback();
                        hierarchicalStreamWriter.endNode();
                    } else if (this.serializationMembers.supportsReadObject(clsArr[0], false)) {
                        zArr[0] = true;
                        hierarchicalStreamWriter.startNode(this.mapper.serializedClass(clsArr[0]));
                        if (!(clsArr[0] == this.mapper.defaultImplementationOf(clsArr[0]) || (aliasForSystemAttribute = this.mapper.aliasForSystemAttribute(ATTRIBUTE_CLASS)) == null)) {
                            hierarchicalStreamWriter.addAttribute(aliasForSystemAttribute, clsArr[0].getName());
                        }
                        r11.defaultWriteObject();
                        hierarchicalStreamWriter.endNode();
                    } else {
                        zArr[0] = false;
                        r11.defaultWriteObject();
                        if (zArr[0]) {
                            hierarchicalStreamWriter.endNode();
                        }
                    }
                }
            }
        } catch (IOException e) {
            throw new StreamException("Cannot write defaults", e);
        }
    }

    public void doMarshalConditionally(Object obj, HierarchicalStreamWriter hierarchicalStreamWriter, MarshallingContext marshallingContext) {
        if (isSerializable(obj.getClass())) {
            doMarshal(obj, hierarchicalStreamWriter, marshallingContext);
        } else {
            super.doMarshal(obj, hierarchicalStreamWriter, marshallingContext);
        }
    }

    @Override // com.thoughtworks.xstream.converters.reflection.AbstractReflectionConverter
    public Object doUnmarshal(final Object obj, final HierarchicalStreamReader hierarchicalStreamReader, final UnmarshallingContext unmarshallingContext) {
        final Class[] clsArr = new Class[1];
        String aliasForSystemAttribute = this.mapper.aliasForSystemAttribute(ATTRIBUTE_SERIALIZATION);
        if (aliasForSystemAttribute == null || ATTRIBUTE_VALUE_CUSTOM.equals(hierarchicalStreamReader.getAttribute(aliasForSystemAttribute))) {
            AnonymousClass2 r7 = new CustomObjectInputStream.StreamCallback() {
                /* class com.thoughtworks.xstream.converters.reflection.SerializableConverter.AnonymousClass2 */

                @Override // com.thoughtworks.xstream.core.util.CustomObjectInputStream.StreamCallback
                public void close() {
                    throw new UnsupportedOperationException("Objects are not allowed to call ObjectInputStream.close() from readObject()");
                }

                @Override // com.thoughtworks.xstream.core.util.CustomObjectInputStream.StreamCallback
                public void defaultReadObject() {
                    Class cls;
                    if (SerializableConverter.this.serializationMembers.getSerializablePersistentFields(clsArr[0]) != null) {
                        readFieldsFromStream();
                    } else if (hierarchicalStreamReader.hasMoreChildren()) {
                        hierarchicalStreamReader.moveDown();
                        if (hierarchicalStreamReader.getNodeName().equals(SerializableConverter.ELEMENT_DEFAULT)) {
                            while (hierarchicalStreamReader.hasMoreChildren()) {
                                hierarchicalStreamReader.moveDown();
                                String realMember = SerializableConverter.this.mapper.realMember(clsArr[0], hierarchicalStreamReader.getNodeName());
                                if (SerializableConverter.this.mapper.shouldSerializeMember(clsArr[0], realMember)) {
                                    String readClassAttribute = HierarchicalStreams.readClassAttribute(hierarchicalStreamReader, SerializableConverter.this.mapper);
                                    if (readClassAttribute != null) {
                                        cls = SerializableConverter.this.mapper.realClass(readClassAttribute);
                                    } else {
                                        SerializableConverter serializableConverter = SerializableConverter.this;
                                        cls = serializableConverter.mapper.defaultImplementationOf(serializableConverter.reflectionProvider.getFieldType(obj, realMember, clsArr[0]));
                                    }
                                    SerializableConverter.this.reflectionProvider.writeField(obj, realMember, unmarshallingContext.convertAnother(obj, cls), clsArr[0]);
                                }
                                hierarchicalStreamReader.moveUp();
                            }
                            hierarchicalStreamReader.moveUp();
                            return;
                        }
                        throw new ConversionException("Expected <default/> element in readObject() stream");
                    }
                }

                @Override // com.thoughtworks.xstream.core.util.CustomObjectInputStream.StreamCallback
                public Map readFieldsFromStream() {
                    Class cls;
                    HashMap hashMap = new HashMap();
                    hierarchicalStreamReader.moveDown();
                    if (hierarchicalStreamReader.getNodeName().equals(SerializableConverter.ELEMENT_FIELDS)) {
                        while (hierarchicalStreamReader.hasMoreChildren()) {
                            hierarchicalStreamReader.moveDown();
                            if (hierarchicalStreamReader.getNodeName().equals(SerializableConverter.ELEMENT_FIELD)) {
                                hashMap.put(hierarchicalStreamReader.getAttribute(SerializableConverter.ATTRIBUTE_NAME), unmarshallingContext.convertAnother(obj, SerializableConverter.this.mapper.realClass(hierarchicalStreamReader.getAttribute(SerializableConverter.ATTRIBUTE_CLASS))));
                                hierarchicalStreamReader.moveUp();
                            } else {
                                throw new ConversionException("Expected <field/> element inside <field/>");
                            }
                        }
                    } else if (hierarchicalStreamReader.getNodeName().equals(SerializableConverter.ELEMENT_DEFAULT)) {
                        ObjectStreamClass lookup = ObjectStreamClass.lookup(clsArr[0]);
                        while (hierarchicalStreamReader.hasMoreChildren()) {
                            hierarchicalStreamReader.moveDown();
                            String realMember = SerializableConverter.this.mapper.realMember(clsArr[0], hierarchicalStreamReader.getNodeName());
                            if (SerializableConverter.this.mapper.shouldSerializeMember(clsArr[0], realMember)) {
                                String readClassAttribute = HierarchicalStreams.readClassAttribute(hierarchicalStreamReader, SerializableConverter.this.mapper);
                                if (readClassAttribute != null) {
                                    cls = SerializableConverter.this.mapper.realClass(readClassAttribute);
                                } else {
                                    ObjectStreamField field = lookup.getField(realMember);
                                    if (field != null) {
                                        cls = field.getType();
                                    } else {
                                        throw new MissingFieldException(clsArr[0].getName(), realMember);
                                    }
                                }
                                hashMap.put(realMember, unmarshallingContext.convertAnother(obj, cls));
                            }
                            hierarchicalStreamReader.moveUp();
                        }
                    } else {
                        throw new ConversionException("Expected <fields/> or <default/> element when calling ObjectInputStream.readFields()");
                    }
                    hierarchicalStreamReader.moveUp();
                    return hashMap;
                }

                @Override // com.thoughtworks.xstream.core.util.CustomObjectInputStream.StreamCallback
                public Object readFromStream() {
                    hierarchicalStreamReader.moveDown();
                    Object convertAnother = unmarshallingContext.convertAnother(obj, HierarchicalStreams.readClassType(hierarchicalStreamReader, SerializableConverter.this.mapper));
                    hierarchicalStreamReader.moveUp();
                    return convertAnother;
                }

                @Override // com.thoughtworks.xstream.core.util.CustomObjectInputStream.StreamCallback
                public void registerValidation(final ObjectInputValidation objectInputValidation, int i) {
                    unmarshallingContext.addCompletionCallback(new Runnable() {
                        /* class com.thoughtworks.xstream.converters.reflection.SerializableConverter.AnonymousClass2.AnonymousClass1 */

                        public void run() {
                            try {
                                objectInputValidation.validateObject();
                            } catch (InvalidObjectException e) {
                                throw new ObjectAccessException("Cannot validate object", e);
                            }
                        }
                    }, i);
                }
            };
            while (hierarchicalStreamReader.hasMoreChildren()) {
                hierarchicalStreamReader.moveDown();
                String nodeName = hierarchicalStreamReader.getNodeName();
                if (nodeName.equals(ELEMENT_UNSERIALIZABLE_PARENTS)) {
                    super.doUnmarshal(obj, hierarchicalStreamReader, unmarshallingContext);
                } else {
                    String readClassAttribute = HierarchicalStreams.readClassAttribute(hierarchicalStreamReader, this.mapper);
                    if (readClassAttribute == null) {
                        Mapper mapper = this.mapper;
                        clsArr[0] = mapper.defaultImplementationOf(mapper.realClass(nodeName));
                    } else {
                        clsArr[0] = this.mapper.realClass(readClassAttribute);
                    }
                    if (this.serializationMembers.supportsReadObject(clsArr[0], false)) {
                        CustomObjectInputStream instance = CustomObjectInputStream.getInstance(unmarshallingContext, r7, this.classLoaderReference);
                        this.serializationMembers.callReadObject(clsArr[0], obj, instance);
                        instance.popCallback();
                    } else {
                        try {
                            r7.defaultReadObject();
                        } catch (IOException e) {
                            throw new StreamException("Cannot read defaults", e);
                        }
                    }
                }
                hierarchicalStreamReader.moveUp();
            }
            return obj;
        }
        throw new ConversionException("Cannot deserialize object with new readObject()/writeObject() methods");
    }

    public Object doUnmarshalConditionally(Object obj, HierarchicalStreamReader hierarchicalStreamReader, UnmarshallingContext unmarshallingContext) {
        return isSerializable(obj.getClass()) ? doUnmarshal(obj, hierarchicalStreamReader, unmarshallingContext) : super.doUnmarshal(obj, hierarchicalStreamReader, unmarshallingContext);
    }

    public List hierarchyFor(Class cls) {
        ArrayList arrayList = new ArrayList();
        while (true) {
            Class cls2 = class$java$lang$Object;
            if (cls2 == null) {
                cls2 = class$("java.lang.Object");
                class$java$lang$Object = cls2;
            }
            if (cls == cls2 || cls == null) {
                Collections.reverse(arrayList);
            } else {
                arrayList.add(cls);
                cls = cls.getSuperclass();
            }
        }
        Collections.reverse(arrayList);
        return arrayList;
    }

    public void marshalUnserializableParent(HierarchicalStreamWriter hierarchicalStreamWriter, MarshallingContext marshallingContext, Object obj) {
        hierarchicalStreamWriter.startNode(ELEMENT_UNSERIALIZABLE_PARENTS);
        super.doMarshal(obj, hierarchicalStreamWriter, marshallingContext);
        hierarchicalStreamWriter.endNode();
    }

    public SerializableConverter(Mapper mapper, ReflectionProvider reflectionProvider, ClassLoader classLoader) {
        this(mapper, reflectionProvider, new ClassLoaderReference(classLoader));
    }

    public SerializableConverter(Mapper mapper, ReflectionProvider reflectionProvider) {
        this(mapper, new UnserializableParentsReflectionProvider(reflectionProvider), new ClassLoaderReference(null));
    }
}
