package com.thoughtworks.xstream.converters.time;

import androidx.base.b2;
import com.thoughtworks.xstream.converters.ConversionException;
import com.thoughtworks.xstream.converters.basic.AbstractSingleValueConverter;
import java.time.DateTimeException;
import java.time.chrono.ChronoLocalDate;
import java.time.chrono.Chronology;
import java.time.chrono.Era;
import java.util.Set;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public abstract class AbstractChronoLocalDateConverter<E extends Era> extends AbstractSingleValueConverter {
    private static final Pattern CHRONO_DATE_PATTERN = Pattern.compile("^ (\\w+) (\\d+)-(\\d+)-(\\d+)$");

    public abstract ChronoLocalDate chronoLocalDateOf(E e, int i, int i2, int i3);

    public abstract E eraOf(String str);

    public ChronoLocalDate parseChronoLocalDate(String str, String str2, Set<Chronology> set) {
        ConversionException conversionException = null;
        if (str == null) {
            return null;
        }
        for (Chronology chronology : set) {
            String id = chronology.getId();
            if (str.startsWith(id + ' ')) {
                Matcher matcher = CHRONO_DATE_PATTERN.matcher(str.subSequence(id.length(), str.length()));
                if (matcher.matches()) {
                    try {
                        E eraOf = eraOf(matcher.group(1));
                        if (eraOf != null) {
                            try {
                                return chronoLocalDateOf(eraOf, Integer.parseInt(matcher.group(2)), Integer.parseInt(matcher.group(3)), Integer.parseInt(matcher.group(4)));
                            } catch (DateTimeException e) {
                                conversionException = new ConversionException(b2.d("Cannot parse value as ", str2, " date"), e);
                            }
                        }
                    } catch (IllegalArgumentException e2) {
                        conversionException = new ConversionException(b2.d("Cannot parse value as ", str2, " date"), e2);
                    }
                } else {
                    continue;
                }
            }
        }
        if (conversionException == null) {
            conversionException = new ConversionException(b2.d("Cannot parse value as ", str2, " date"));
        }
        conversionException.add("value", str);
        throw conversionException;
    }
}
