package com.thoughtworks.xstream.converters.time;

import com.thoughtworks.xstream.converters.ConversionException;
import com.thoughtworks.xstream.converters.SingleValueConverter;
import java.time.DateTimeException;
import java.time.chrono.Chronology;

public class ChronologyConverter implements SingleValueConverter {
    @Override // com.thoughtworks.xstream.converters.ConverterMatcher
    public boolean canConvert(Class cls) {
        return cls != null && Chronology.class.isAssignableFrom(cls);
    }

    @Override // com.thoughtworks.xstream.converters.SingleValueConverter
    public String toString(Object obj) {
        if (obj == null) {
            return null;
        }
        return ((Chronology) obj).getId();
    }

    @Override // com.thoughtworks.xstream.converters.SingleValueConverter
    public Chronology fromString(String str) {
        if (str == null) {
            return null;
        }
        try {
            return Chronology.of(str);
        } catch (DateTimeException e) {
            ConversionException conversionException = new ConversionException("Cannot parse value as chronology", e);
            conversionException.add("value", str);
            throw conversionException;
        }
    }
}
