package com.thoughtworks.xstream.core;

import com.thoughtworks.xstream.converters.ConversionException;
import com.thoughtworks.xstream.converters.Converter;
import com.thoughtworks.xstream.converters.ConverterLookup;
import com.thoughtworks.xstream.core.util.FastStack;
import com.thoughtworks.xstream.io.HierarchicalStreamReader;
import com.thoughtworks.xstream.mapper.Mapper;
import java.util.HashMap;
import java.util.Map;

public abstract class AbstractReferenceUnmarshaller extends TreeUnmarshaller {
    private static final Object NULL = new Object();
    private FastStack parentStack = new FastStack(16);
    private Map values = new HashMap();

    public AbstractReferenceUnmarshaller(Object obj, HierarchicalStreamReader hierarchicalStreamReader, ConverterLookup converterLookup, Mapper mapper) {
        super(obj, hierarchicalStreamReader, converterLookup, mapper);
    }

    @Override // com.thoughtworks.xstream.core.TreeUnmarshaller
    public Object convert(Object obj, Class cls, Converter converter) {
        String str;
        Object peek;
        if (this.parentStack.size() > 0 && (peek = this.parentStack.peek()) != null && !this.values.containsKey(peek)) {
            this.values.put(peek, obj);
        }
        String aliasForSystemAttribute = getMapper().aliasForSystemAttribute("reference");
        if (aliasForSystemAttribute == null) {
            str = null;
        } else {
            str = this.reader.getAttribute(aliasForSystemAttribute);
        }
        boolean isReferenceable = getMapper().isReferenceable(cls);
        if (str != null) {
            Object obj2 = isReferenceable ? this.values.get(getReferenceKey(str)) : null;
            if (obj2 == null) {
                ConversionException conversionException = new ConversionException("Invalid reference");
                conversionException.add("reference", str);
                conversionException.add("referenced-type", cls.getName());
                conversionException.add("referenceable", Boolean.toString(isReferenceable));
                throw conversionException;
            } else if (obj2 == NULL) {
                return null;
            } else {
                return obj2;
            }
        } else if (!isReferenceable) {
            return super.convert(obj, cls, converter);
        } else {
            Object currentReferenceKey = getCurrentReferenceKey();
            this.parentStack.push(currentReferenceKey);
            try {
                Object convert = super.convert(obj, cls, converter);
                if (currentReferenceKey != null) {
                    this.values.put(currentReferenceKey, convert == null ? NULL : convert);
                }
                this.parentStack.popSilently();
                return convert;
            } catch (Throwable th) {
                if (currentReferenceKey != null) {
                    this.values.put(currentReferenceKey, NULL);
                }
                this.parentStack.popSilently();
                throw th;
            }
        }
    }

    public abstract Object getCurrentReferenceKey();

    public abstract Object getReferenceKey(String str);
}
