package com.thoughtworks.xstream.core.util;

import androidx.base.b2;
import com.thoughtworks.xstream.converters.DataHolder;
import com.thoughtworks.xstream.converters.reflection.ObjectAccessException;
import com.thoughtworks.xstream.core.ClassLoaderReference;
import com.thoughtworks.xstream.io.StreamException;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectInputValidation;
import java.io.ObjectStreamClass;
import java.io.StreamCorruptedException;
import java.util.Map;

public class CustomObjectInputStream extends ObjectInputStream {
    private static final String DATA_HOLDER_KEY;
    public static /* synthetic */ Class class$com$thoughtworks$xstream$core$util$CustomObjectInputStream;
    private FastStack callbacks;
    private final ClassLoaderReference classLoaderReference;

    public class CustomGetField extends ObjectInputStream.GetField {
        private Map fields;

        public CustomGetField(Map map) {
            this.fields = map;
        }

        private Object get(String str) {
            return this.fields.get(str);
        }

        @Override // java.io.ObjectInputStream.GetField
        public boolean defaulted(String str) {
            return !this.fields.containsKey(str);
        }

        public ObjectStreamClass getObjectStreamClass() {
            throw new UnsupportedOperationException();
        }

        @Override // java.io.ObjectInputStream.GetField
        public byte get(String str, byte b) {
            return defaulted(str) ? b : ((Byte) get(str)).byteValue();
        }

        @Override // java.io.ObjectInputStream.GetField
        public char get(String str, char c) {
            return defaulted(str) ? c : ((Character) get(str)).charValue();
        }

        @Override // java.io.ObjectInputStream.GetField
        public double get(String str, double d) {
            return defaulted(str) ? d : ((Double) get(str)).doubleValue();
        }

        @Override // java.io.ObjectInputStream.GetField
        public float get(String str, float f) {
            return defaulted(str) ? f : ((Float) get(str)).floatValue();
        }

        @Override // java.io.ObjectInputStream.GetField
        public int get(String str, int i) {
            return defaulted(str) ? i : ((Integer) get(str)).intValue();
        }

        @Override // java.io.ObjectInputStream.GetField
        public long get(String str, long j) {
            return defaulted(str) ? j : ((Long) get(str)).longValue();
        }

        @Override // java.io.ObjectInputStream.GetField
        public short get(String str, short s) {
            return defaulted(str) ? s : ((Short) get(str)).shortValue();
        }

        @Override // java.io.ObjectInputStream.GetField
        public boolean get(String str, boolean z) {
            return defaulted(str) ? z : ((Boolean) get(str)).booleanValue();
        }

        @Override // java.io.ObjectInputStream.GetField
        public Object get(String str, Object obj) {
            return defaulted(str) ? obj : get(str);
        }
    }

    public interface StreamCallback {
        void close();

        void defaultReadObject();

        Map readFieldsFromStream();

        Object readFromStream();

        void registerValidation(ObjectInputValidation objectInputValidation, int i);
    }

    static {
        Class cls = class$com$thoughtworks$xstream$core$util$CustomObjectInputStream;
        if (cls == null) {
            cls = class$("com.thoughtworks.xstream.core.util.CustomObjectInputStream");
            class$com$thoughtworks$xstream$core$util$CustomObjectInputStream = cls;
        }
        DATA_HOLDER_KEY = cls.getName();
    }

    public CustomObjectInputStream(StreamCallback streamCallback, ClassLoaderReference classLoaderReference2) {
        FastStack fastStack = new FastStack(1);
        this.callbacks = fastStack;
        fastStack.push(streamCallback);
        this.classLoaderReference = classLoaderReference2;
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e) {
            throw b2.n(e);
        }
    }

    public static CustomObjectInputStream getInstance(DataHolder dataHolder, StreamCallback streamCallback) {
        return getInstance(dataHolder, streamCallback, (ClassLoader) null);
    }

    @Override // java.io.ObjectInputStream, java.io.ObjectInput, java.io.InputStream
    public int available() {
        throw new UnsupportedOperationException();
    }

    @Override // java.io.Closeable, java.io.ObjectInputStream, java.io.ObjectInput, java.lang.AutoCloseable, java.io.InputStream
    public void close() {
        peekCallback().close();
    }

    @Override // java.io.ObjectInputStream
    public void defaultReadObject() {
        peekCallback().defaultReadObject();
    }

    public void mark(int i) {
        throw new UnsupportedOperationException();
    }

    public boolean markSupported() {
        return false;
    }

    public StreamCallback peekCallback() {
        return (StreamCallback) this.callbacks.peek();
    }

    public StreamCallback popCallback() {
        return (StreamCallback) this.callbacks.pop();
    }

    public void pushCallback(StreamCallback streamCallback) {
        this.callbacks.push(streamCallback);
    }

    @Override // java.io.ObjectInputStream, java.io.ObjectInput, java.io.InputStream
    public int read() {
        return readUnsignedByte();
    }

    @Override // java.io.ObjectInputStream, java.io.DataInput
    public boolean readBoolean() {
        return ((Boolean) peekCallback().readFromStream()).booleanValue();
    }

    @Override // java.io.ObjectInputStream, java.io.DataInput
    public byte readByte() {
        return ((Byte) peekCallback().readFromStream()).byteValue();
    }

    @Override // java.io.ObjectInputStream, java.io.DataInput
    public char readChar() {
        return ((Character) peekCallback().readFromStream()).charValue();
    }

    @Override // java.io.ObjectInputStream, java.io.DataInput
    public double readDouble() {
        return ((Double) peekCallback().readFromStream()).doubleValue();
    }

    @Override // java.io.ObjectInputStream
    public ObjectInputStream.GetField readFields() {
        return new CustomGetField(peekCallback().readFieldsFromStream());
    }

    @Override // java.io.ObjectInputStream, java.io.DataInput
    public float readFloat() {
        return ((Float) peekCallback().readFromStream()).floatValue();
    }

    @Override // java.io.ObjectInputStream, java.io.DataInput
    public void readFully(byte[] bArr) {
        readFully(bArr, 0, bArr.length);
    }

    @Override // java.io.ObjectInputStream, java.io.DataInput
    public int readInt() {
        return ((Integer) peekCallback().readFromStream()).intValue();
    }

    @Override // java.io.ObjectInputStream, java.io.DataInput
    public String readLine() {
        throw new UnsupportedOperationException();
    }

    @Override // java.io.ObjectInputStream, java.io.DataInput
    public long readLong() {
        return ((Long) peekCallback().readFromStream()).longValue();
    }

    @Override // java.io.ObjectInputStream
    public Object readObjectOverride() {
        return peekCallback().readFromStream();
    }

    @Override // java.io.ObjectInputStream, java.io.DataInput
    public short readShort() {
        return ((Short) peekCallback().readFromStream()).shortValue();
    }

    @Override // java.io.ObjectInputStream, java.io.DataInput
    public String readUTF() {
        return (String) peekCallback().readFromStream();
    }

    @Override // java.io.ObjectInputStream
    public Object readUnshared() {
        return readObject();
    }

    @Override // java.io.ObjectInputStream, java.io.DataInput
    public int readUnsignedByte() {
        return ((Byte) peekCallback().readFromStream()).intValue() & 255;
    }

    @Override // java.io.ObjectInputStream, java.io.DataInput
    public int readUnsignedShort() {
        return ((Short) peekCallback().readFromStream()).intValue() & 65535;
    }

    @Override // java.io.ObjectInputStream
    public void registerValidation(ObjectInputValidation objectInputValidation, int i) {
        peekCallback().registerValidation(objectInputValidation, i);
    }

    @Override // java.io.InputStream
    public void reset() {
        throw new UnsupportedOperationException();
    }

    @Override // java.io.ObjectInputStream
    public Class resolveClass(ObjectStreamClass objectStreamClass) {
        ClassLoader reference = this.classLoaderReference.getReference();
        if (reference == null) {
            return super.resolveClass(objectStreamClass);
        }
        return Class.forName(objectStreamClass.getName(), false, reference);
    }

    @Override // java.io.ObjectInput, java.io.InputStream
    public long skip(long j) {
        throw new UnsupportedOperationException();
    }

    @Override // java.io.ObjectInputStream, java.io.DataInput
    public int skipBytes(int i) {
        throw new UnsupportedOperationException();
    }

    public static synchronized CustomObjectInputStream getInstance(DataHolder dataHolder, StreamCallback streamCallback, ClassLoader classLoader) {
        CustomObjectInputStream instance;
        synchronized (CustomObjectInputStream.class) {
            instance = getInstance(dataHolder, streamCallback, new ClassLoaderReference(classLoader));
        }
        return instance;
    }

    @Override // java.io.ObjectInputStream, java.io.ObjectInput, java.io.InputStream
    public int read(byte[] bArr, int i, int i2) {
        byte[] bArr2 = (byte[]) peekCallback().readFromStream();
        if (bArr2.length == i2) {
            System.arraycopy(bArr2, 0, bArr, i, i2);
            return i2;
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Expected ");
        stringBuffer.append(i2);
        stringBuffer.append(" bytes from stream, got ");
        stringBuffer.append(bArr2.length);
        throw new StreamCorruptedException(stringBuffer.toString());
    }

    @Override // java.io.ObjectInputStream, java.io.DataInput
    public void readFully(byte[] bArr, int i, int i2) {
        System.arraycopy((byte[]) peekCallback().readFromStream(), 0, bArr, i, i2);
    }

    public static synchronized CustomObjectInputStream getInstance(DataHolder dataHolder, StreamCallback streamCallback, ClassLoaderReference classLoaderReference2) {
        CustomObjectInputStream customObjectInputStream;
        synchronized (CustomObjectInputStream.class) {
            try {
                Object obj = DATA_HOLDER_KEY;
                customObjectInputStream = (CustomObjectInputStream) dataHolder.get(obj);
                if (customObjectInputStream == null) {
                    customObjectInputStream = new CustomObjectInputStream(streamCallback, classLoaderReference2);
                    dataHolder.put(obj, customObjectInputStream);
                } else {
                    customObjectInputStream.pushCallback(streamCallback);
                }
            } catch (SecurityException e) {
                throw new ObjectAccessException("Cannot create CustomObjectStream", e);
            } catch (IOException e2) {
                throw new StreamException("Cannot create CustomObjectStream", e2);
            }
        }
        return customObjectInputStream;
    }

    public CustomObjectInputStream(StreamCallback streamCallback, ClassLoader classLoader) {
        this(streamCallback, new ClassLoaderReference(classLoader));
    }

    @Override // java.io.ObjectInput, java.io.InputStream
    public int read(byte[] bArr) {
        return read(bArr, 0, bArr.length);
    }
}
