package com.thoughtworks.xstream.core.util;

import androidx.base.b2;
import com.thoughtworks.xstream.converters.DataHolder;
import com.thoughtworks.xstream.converters.reflection.ObjectAccessException;
import com.thoughtworks.xstream.io.StreamException;
import java.io.IOException;
import java.io.ObjectOutput;
import java.io.ObjectOutputStream;
import java.util.Map;

public class CustomObjectOutputStream extends ObjectOutputStream {
    private static final String DATA_HOLDER_KEY;
    public static /* synthetic */ Class class$com$thoughtworks$xstream$core$util$CustomObjectOutputStream;
    private FastStack callbacks = new FastStack(1);
    private FastStack customFields = new FastStack(1);

    public class CustomPutField extends ObjectOutputStream.PutField {
        private final Map fields;

        private CustomPutField() {
            this.fields = new OrderRetainingMap();
        }

        public Map asMap() {
            return this.fields;
        }

        @Override // java.io.ObjectOutputStream.PutField
        public void put(String str, Object obj) {
            this.fields.put(str, obj);
        }

        @Override // java.io.ObjectOutputStream.PutField
        public void write(ObjectOutput objectOutput) {
            CustomObjectOutputStream.this.peekCallback().writeToStream(asMap());
        }

        @Override // java.io.ObjectOutputStream.PutField
        public void put(String str, byte b) {
            put(str, new Byte(b));
        }

        @Override // java.io.ObjectOutputStream.PutField
        public void put(String str, char c) {
            put(str, new Character(c));
        }

        @Override // java.io.ObjectOutputStream.PutField
        public void put(String str, double d) {
            put(str, new Double(d));
        }

        @Override // java.io.ObjectOutputStream.PutField
        public void put(String str, float f) {
            put(str, new Float(f));
        }

        @Override // java.io.ObjectOutputStream.PutField
        public void put(String str, int i) {
            put(str, new Integer(i));
        }

        @Override // java.io.ObjectOutputStream.PutField
        public void put(String str, long j) {
            put(str, new Long(j));
        }

        @Override // java.io.ObjectOutputStream.PutField
        public void put(String str, short s) {
            put(str, new Short(s));
        }

        @Override // java.io.ObjectOutputStream.PutField
        public void put(String str, boolean z) {
            put(str, z ? Boolean.TRUE : Boolean.FALSE);
        }
    }

    public interface StreamCallback {
        void close();

        void defaultWriteObject();

        void flush();

        void writeFieldsToStream(Map map);

        void writeToStream(Object obj);
    }

    static {
        Class cls = class$com$thoughtworks$xstream$core$util$CustomObjectOutputStream;
        if (cls == null) {
            cls = class$("com.thoughtworks.xstream.core.util.CustomObjectOutputStream");
            class$com$thoughtworks$xstream$core$util$CustomObjectOutputStream = cls;
        }
        DATA_HOLDER_KEY = cls.getName();
    }

    public CustomObjectOutputStream(StreamCallback streamCallback) {
        this.callbacks.push(streamCallback);
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e) {
            throw b2.n(e);
        }
    }

    public static synchronized CustomObjectOutputStream getInstance(DataHolder dataHolder, StreamCallback streamCallback) {
        CustomObjectOutputStream customObjectOutputStream;
        synchronized (CustomObjectOutputStream.class) {
            try {
                Object obj = DATA_HOLDER_KEY;
                customObjectOutputStream = (CustomObjectOutputStream) dataHolder.get(obj);
                if (customObjectOutputStream == null) {
                    customObjectOutputStream = new CustomObjectOutputStream(streamCallback);
                    dataHolder.put(obj, customObjectOutputStream);
                } else {
                    customObjectOutputStream.pushCallback(streamCallback);
                }
            } catch (SecurityException e) {
                throw new ObjectAccessException("Cannot create CustomObjectStream", e);
            } catch (IOException e2) {
                throw new StreamException("Cannot create CustomObjectStream", e2);
            }
        }
        return customObjectOutputStream;
    }

    @Override // java.io.OutputStream, java.io.Closeable, java.io.ObjectOutput, java.io.ObjectOutputStream, java.lang.AutoCloseable
    public void close() {
        peekCallback().close();
    }

    @Override // java.io.ObjectOutputStream
    public void defaultWriteObject() {
        peekCallback().defaultWriteObject();
    }

    @Override // java.io.OutputStream, java.io.ObjectOutput, java.io.ObjectOutputStream, java.io.Flushable
    public void flush() {
        peekCallback().flush();
    }

    public StreamCallback peekCallback() {
        return (StreamCallback) this.callbacks.peek();
    }

    public StreamCallback popCallback() {
        return (StreamCallback) this.callbacks.pop();
    }

    public void pushCallback(StreamCallback streamCallback) {
        this.callbacks.push(streamCallback);
    }

    @Override // java.io.ObjectOutputStream
    public ObjectOutputStream.PutField putFields() {
        CustomPutField customPutField = new CustomPutField();
        this.customFields.push(customPutField);
        return customPutField;
    }

    @Override // java.io.ObjectOutputStream
    public void reset() {
        throw new UnsupportedOperationException();
    }

    @Override // java.io.ObjectOutputStream
    public void useProtocolVersion(int i) {
        throw new UnsupportedOperationException();
    }

    @Override // java.io.OutputStream, java.io.DataOutput, java.io.ObjectOutput, java.io.ObjectOutputStream
    public void write(byte[] bArr) {
        peekCallback().writeToStream(bArr);
    }

    @Override // java.io.DataOutput, java.io.ObjectOutputStream
    public void writeBoolean(boolean z) {
        peekCallback().writeToStream(z ? Boolean.TRUE : Boolean.FALSE);
    }

    @Override // java.io.DataOutput, java.io.ObjectOutputStream
    public void writeByte(int i) {
        peekCallback().writeToStream(new Byte((byte) i));
    }

    @Override // java.io.DataOutput, java.io.ObjectOutputStream
    public void writeBytes(String str) {
        throw new UnsupportedOperationException();
    }

    @Override // java.io.DataOutput, java.io.ObjectOutputStream
    public void writeChar(int i) {
        peekCallback().writeToStream(new Character((char) i));
    }

    @Override // java.io.DataOutput, java.io.ObjectOutputStream
    public void writeChars(String str) {
        peekCallback().writeToStream(str.toCharArray());
    }

    @Override // java.io.DataOutput, java.io.ObjectOutputStream
    public void writeDouble(double d) {
        peekCallback().writeToStream(new Double(d));
    }

    @Override // java.io.ObjectOutputStream
    public void writeFields() {
        peekCallback().writeFieldsToStream(((CustomPutField) this.customFields.pop()).asMap());
    }

    @Override // java.io.DataOutput, java.io.ObjectOutputStream
    public void writeFloat(float f) {
        peekCallback().writeToStream(new Float(f));
    }

    @Override // java.io.DataOutput, java.io.ObjectOutputStream
    public void writeInt(int i) {
        peekCallback().writeToStream(new Integer(i));
    }

    @Override // java.io.DataOutput, java.io.ObjectOutputStream
    public void writeLong(long j) {
        peekCallback().writeToStream(new Long(j));
    }

    @Override // java.io.ObjectOutputStream
    public void writeObjectOverride(Object obj) {
        peekCallback().writeToStream(obj);
    }

    @Override // java.io.DataOutput, java.io.ObjectOutputStream
    public void writeShort(int i) {
        peekCallback().writeToStream(new Short((short) i));
    }

    @Override // java.io.DataOutput, java.io.ObjectOutputStream
    public void writeUTF(String str) {
        peekCallback().writeToStream(str);
    }

    @Override // java.io.ObjectOutputStream
    public void writeUnshared(Object obj) {
        throw new UnsupportedOperationException();
    }

    @Override // java.io.OutputStream, java.io.DataOutput, java.io.ObjectOutput, java.io.ObjectOutputStream
    public void write(int i) {
        peekCallback().writeToStream(new Byte((byte) i));
    }

    @Override // java.io.OutputStream, java.io.DataOutput, java.io.ObjectOutput, java.io.ObjectOutputStream
    public void write(byte[] bArr, int i, int i2) {
        byte[] bArr2 = new byte[i2];
        System.arraycopy(bArr, i, bArr2, 0, i2);
        peekCallback().writeToStream(bArr2);
    }
}
