package com.thoughtworks.xstream.core.util;

public class Pool {
    private final Factory factory;
    private final int initialPoolSize;
    private final int maxPoolSize;
    private transient Object mutex = new Object();
    private transient int nextAvailable;
    private transient Object[] pool;

    public interface Factory {
        Object newInstance();
    }

    public Pool(int i, int i2, Factory factory2) {
        this.initialPoolSize = i;
        this.maxPoolSize = i2;
        this.factory = factory2;
    }

    private Object readResolve() {
        this.mutex = new Object();
        return this;
    }

    public Object fetchFromPool() {
        int i;
        Object obj;
        synchronized (this.mutex) {
            if (this.pool == null) {
                this.pool = new Object[this.maxPoolSize];
                this.nextAvailable = this.initialPoolSize;
                while (this.nextAvailable > 0) {
                    putInPool(this.factory.newInstance());
                }
            }
            while (true) {
                i = this.nextAvailable;
                if (i != this.maxPoolSize) {
                    break;
                }
                try {
                    this.mutex.wait();
                } catch (InterruptedException e) {
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append("Interrupted whilst waiting for a free item in the pool : ");
                    stringBuffer.append(e.getMessage());
                    throw new RuntimeException(stringBuffer.toString());
                }
            }
            Object[] objArr = this.pool;
            this.nextAvailable = i + 1;
            obj = objArr[i];
            if (obj == null) {
                obj = this.factory.newInstance();
                putInPool(obj);
                this.nextAvailable++;
            }
        }
        return obj;
    }

    public void putInPool(Object obj) {
        synchronized (this.mutex) {
            Object[] objArr = this.pool;
            int i = this.nextAvailable - 1;
            this.nextAvailable = i;
            objArr[i] = obj;
            this.mutex.notify();
        }
    }
}
