package com.thoughtworks.xstream.core.util;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Comparator;
import java.util.Iterator;
import java.util.List;
import java.util.SortedSet;

public class PresortedSet implements SortedSet {
    private final Comparator comparator;
    private final List list;

    public PresortedSet() {
        this(null);
    }

    @Override // java.util.Collection, java.util.Set
    public boolean add(Object obj) {
        return this.list.add(obj);
    }

    @Override // java.util.Collection, java.util.Set
    public boolean addAll(Collection collection) {
        return this.list.addAll(collection);
    }

    public void clear() {
        this.list.clear();
    }

    @Override // java.util.SortedSet
    public Comparator comparator() {
        return this.comparator;
    }

    public boolean contains(Object obj) {
        return this.list.contains(obj);
    }

    @Override // java.util.Collection, java.util.Set
    public boolean containsAll(Collection collection) {
        return this.list.containsAll(collection);
    }

    public boolean equals(Object obj) {
        return this.list.equals(obj);
    }

    @Override // java.util.SortedSet
    public Object first() {
        if (this.list.isEmpty()) {
            return null;
        }
        return this.list.get(0);
    }

    public int hashCode() {
        return this.list.hashCode();
    }

    @Override // java.util.SortedSet
    public SortedSet headSet(Object obj) {
        throw new UnsupportedOperationException();
    }

    public boolean isEmpty() {
        return this.list.isEmpty();
    }

    @Override // java.util.Collection, java.util.Set, java.lang.Iterable
    public Iterator iterator() {
        return this.list.iterator();
    }

    @Override // java.util.SortedSet
    public Object last() {
        if (this.list.isEmpty()) {
            return null;
        }
        List list2 = this.list;
        return list2.get(list2.size() - 1);
    }

    public boolean remove(Object obj) {
        return this.list.remove(obj);
    }

    @Override // java.util.Collection, java.util.Set
    public boolean removeAll(Collection collection) {
        return this.list.removeAll(collection);
    }

    @Override // java.util.Collection, java.util.Set
    public boolean retainAll(Collection collection) {
        return this.list.retainAll(collection);
    }

    public int size() {
        return this.list.size();
    }

    public List subList(int i, int i2) {
        return this.list.subList(i, i2);
    }

    @Override // java.util.SortedSet
    public SortedSet subSet(Object obj, Object obj2) {
        throw new UnsupportedOperationException();
    }

    @Override // java.util.SortedSet
    public SortedSet tailSet(Object obj) {
        throw new UnsupportedOperationException();
    }

    public Object[] toArray() {
        return this.list.toArray();
    }

    public PresortedSet(Comparator comparator2) {
        this(comparator2, null);
    }

    @Override // java.util.Collection, java.util.Set
    public Object[] toArray(Object[] objArr) {
        return this.list.toArray(objArr);
    }

    public PresortedSet(Comparator comparator2, Collection collection) {
        this.list = new ArrayList();
        this.comparator = comparator2;
        if (collection != null) {
            addAll(collection);
        }
    }
}
