package com.thoughtworks.xstream.core.util;

import java.util.Iterator;
import java.util.Set;
import java.util.TreeSet;

public class PrioritizedList {
    private int lastId = 0;
    private int lowestPriority = Integer.MAX_VALUE;
    private final Set set = new TreeSet();

    public static class PrioritizedItem implements Comparable {
        public final int id;
        public final int priority;
        public final Object value;

        public PrioritizedItem(Object obj, int i, int i2) {
            this.value = obj;
            this.priority = i;
            this.id = i2;
        }

        @Override // java.lang.Comparable
        public int compareTo(Object obj) {
            PrioritizedItem prioritizedItem = (PrioritizedItem) obj;
            int i = this.priority;
            int i2 = prioritizedItem.priority;
            if (i != i2) {
                return i2 - i;
            }
            return prioritizedItem.id - this.id;
        }

        public boolean equals(Object obj) {
            return this.id == ((PrioritizedItem) obj).id;
        }
    }

    public static class PrioritizedItemIterator implements Iterator {
        private Iterator iterator;

        public PrioritizedItemIterator(Iterator it) {
            this.iterator = it;
        }

        public boolean hasNext() {
            return this.iterator.hasNext();
        }

        @Override // java.util.Iterator
        public Object next() {
            return ((PrioritizedItem) this.iterator.next()).value;
        }

        public void remove() {
            throw new UnsupportedOperationException();
        }
    }

    public void add(Object obj, int i) {
        if (this.lowestPriority > i) {
            this.lowestPriority = i;
        }
        Set set2 = this.set;
        int i2 = this.lastId + 1;
        this.lastId = i2;
        set2.add(new PrioritizedItem(obj, i, i2));
    }

    public Iterator iterator() {
        return new PrioritizedItemIterator(this.set.iterator());
    }
}
