package com.thoughtworks.xstream.core.util;

import androidx.base.b2;
import com.thoughtworks.xstream.converters.ConversionException;
import com.thoughtworks.xstream.converters.ErrorWritingException;
import com.thoughtworks.xstream.converters.reflection.ObjectAccessException;
import com.thoughtworks.xstream.core.Caching;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.ObjectStreamField;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;

public class SerializationMembers implements Caching {
    private static final Object[] EMPTY_ARGS = new Object[0];
    private static final Class[] EMPTY_CLASSES = new Class[0];
    private static final Map NO_FIELDS = Collections.EMPTY_MAP;
    private static final Method NO_METHOD = AnonymousClass1.class.getDeclaredMethods()[0];
    private static final FastField[] OBJECT_TYPE_FIELDS;
    private static final int PERSISTENT_FIELDS_MODIFIER = 26;
    public static /* synthetic */ Class class$java$io$ObjectInputStream;
    public static /* synthetic */ Class class$java$io$ObjectOutputStream;
    public static /* synthetic */ Class class$java$lang$Object;
    private Map declaredCache = Collections.synchronizedMap(new HashMap());
    private final Map fieldCache = Collections.synchronizedMap(new HashMap());
    private Map resRepCache = Collections.synchronizedMap(new HashMap());

    static {
        new Object() {
            /* class com.thoughtworks.xstream.core.util.SerializationMembers.AnonymousClass1 */

            private void noMethod() {
            }
        };
        FastField[] fastFieldArr = new FastField[4];
        Class cls = class$java$lang$Object;
        if (cls == null) {
            cls = class$("java.lang.Object");
            class$java$lang$Object = cls;
        }
        fastFieldArr[0] = new FastField(cls, "readResolve");
        Class cls2 = class$java$lang$Object;
        if (cls2 == null) {
            cls2 = class$("java.lang.Object");
            class$java$lang$Object = cls2;
        }
        fastFieldArr[1] = new FastField(cls2, "writeReplace");
        Class cls3 = class$java$lang$Object;
        if (cls3 == null) {
            cls3 = class$("java.lang.Object");
            class$java$lang$Object = cls3;
        }
        fastFieldArr[2] = new FastField(cls3, "readObject");
        Class cls4 = class$java$lang$Object;
        if (cls4 == null) {
            cls4 = class$("java.lang.Object");
            class$java$lang$Object = cls4;
        }
        fastFieldArr[3] = new FastField(cls4, "writeObject");
        OBJECT_TYPE_FIELDS = fastFieldArr;
    }

    public SerializationMembers() {
        int i = 0;
        while (true) {
            FastField[] fastFieldArr = OBJECT_TYPE_FIELDS;
            if (i >= fastFieldArr.length) {
                break;
            }
            this.declaredCache.put(fastFieldArr[i], NO_METHOD);
            i++;
        }
        for (int i2 = 0; i2 < 2; i2++) {
            this.resRepCache.put(OBJECT_TYPE_FIELDS[i2], NO_METHOD);
        }
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e) {
            throw b2.n(e);
        }
    }

    private Method getMethod(Class cls, String str, Class[] clsArr, boolean z) {
        Method method = getMethod(cls, str, clsArr);
        if (method == NO_METHOD || (!z && !method.getDeclaringClass().equals(cls))) {
            return null;
        }
        return method;
    }

    private Method getRRMethod(Class cls, String str) {
        Method method;
        FastField fastField = new FastField(cls, str);
        Method method2 = (Method) this.resRepCache.get(fastField);
        if (method2 == null) {
            Method method3 = getMethod(cls, str, EMPTY_CLASSES, true);
            if (method3 == null || method3.getDeclaringClass() == cls) {
                if (method3 == null) {
                    method = NO_METHOD;
                }
                method2 = method3;
                this.resRepCache.put(fastField, method2);
            } else {
                if ((method3.getModifiers() & 5) == 0 && ((method3.getModifiers() & 2) > 0 || cls.getPackage() != method3.getDeclaringClass().getPackage())) {
                    method = NO_METHOD;
                }
                method2 = method3;
                this.resRepCache.put(fastField, method2);
            }
            method2 = method;
            this.resRepCache.put(fastField, method2);
        }
        if (method2 == NO_METHOD) {
            return null;
        }
        return method2;
    }

    /* JADX WARNING: Removed duplicated region for block: B:13:0x0039 A[RETURN] */
    /* JADX WARNING: Removed duplicated region for block: B:14:0x003a  */
    public void callReadObject(Class cls, Object obj, ObjectInputStream objectInputStream) {
        ErrorWritingException errorWritingException;
        ErrorWritingException errorWritingException2;
        try {
            Class[] clsArr = new Class[1];
            Class cls2 = class$java$io$ObjectInputStream;
            if (cls2 == null) {
                cls2 = class$("java.io.ObjectInputStream");
                class$java$io$ObjectInputStream = cls2;
            }
            clsArr[0] = cls2;
            getMethod(cls, "readObject", clsArr, false).invoke(obj, objectInputStream);
            errorWritingException = null;
        } catch (IllegalAccessException e) {
            errorWritingException2 = new ObjectAccessException("Cannot access method", e);
            errorWritingException = errorWritingException2;
            if (errorWritingException != null) {
            }
        } catch (InvocationTargetException e2) {
            errorWritingException2 = new ConversionException("Failed calling method", e2.getTargetException());
            errorWritingException = errorWritingException2;
            if (errorWritingException != null) {
            }
        }
        if (errorWritingException != null) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(obj.getClass().getName());
            stringBuffer.append(".readObject()");
            errorWritingException.add("method", stringBuffer.toString());
            throw errorWritingException;
        }
    }

    public Object callReadResolve(Object obj) {
        ErrorWritingException errorWritingException;
        if (obj == null) {
            return null;
        }
        Class<?> cls = obj.getClass();
        Method rRMethod = getRRMethod(cls, "readResolve");
        if (rRMethod == null) {
            return obj;
        }
        try {
            return rRMethod.invoke(obj, EMPTY_ARGS);
        } catch (IllegalAccessException e) {
            errorWritingException = new ObjectAccessException("Cannot access method", e);
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(cls.getName());
            stringBuffer.append(".readResolve()");
            errorWritingException.add("method", stringBuffer.toString());
            throw errorWritingException;
        } catch (InvocationTargetException e2) {
            errorWritingException = new ConversionException("Failed calling method", e2.getTargetException());
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(cls.getName());
            stringBuffer2.append(".readResolve()");
            errorWritingException.add("method", stringBuffer2.toString());
            throw errorWritingException;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:13:0x003a A[RETURN] */
    /* JADX WARNING: Removed duplicated region for block: B:14:0x003b  */
    public void callWriteObject(Class cls, Object obj, ObjectOutputStream objectOutputStream) {
        ErrorWritingException errorWritingException;
        ErrorWritingException errorWritingException2;
        try {
            Class[] clsArr = new Class[1];
            Class cls2 = class$java$io$ObjectOutputStream;
            if (cls2 == null) {
                cls2 = class$("java.io.ObjectOutputStream");
                class$java$io$ObjectOutputStream = cls2;
            }
            clsArr[0] = cls2;
            getMethod(cls, "writeObject", clsArr, false).invoke(obj, objectOutputStream);
            errorWritingException = null;
        } catch (IllegalAccessException e) {
            errorWritingException2 = new ObjectAccessException("Cannot access method", e);
            errorWritingException = errorWritingException2;
            if (errorWritingException != null) {
            }
        } catch (InvocationTargetException e2) {
            errorWritingException2 = new ConversionException("Failed calling method", e2.getTargetException());
            errorWritingException = errorWritingException2;
            if (errorWritingException != null) {
            }
        }
        if (errorWritingException != null) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(obj.getClass().getName());
            stringBuffer.append(".writeObject()");
            errorWritingException.add("method", stringBuffer.toString());
            throw errorWritingException;
        }
    }

    public Object callWriteReplace(Object obj) {
        ErrorWritingException e;
        ErrorWritingException errorWritingException;
        if (obj == null) {
            return null;
        }
        Class<?> cls = obj.getClass();
        Method rRMethod = getRRMethod(cls, "writeReplace");
        if (rRMethod == null) {
            return obj;
        }
        try {
            Object invoke = rRMethod.invoke(obj, EMPTY_ARGS);
            return (invoke == null || obj.getClass().equals(invoke.getClass())) ? invoke : callWriteReplace(invoke);
        } catch (IllegalAccessException e2) {
            errorWritingException = new ObjectAccessException("Cannot access method", e2);
            e = errorWritingException;
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(cls.getName());
            stringBuffer.append(".writeReplace()");
            e.add("method", stringBuffer.toString());
            throw e;
        } catch (InvocationTargetException e3) {
            errorWritingException = new ConversionException("Failed calling method", e3.getTargetException());
            e = errorWritingException;
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(cls.getName());
            stringBuffer2.append(".writeReplace()");
            e.add("method", stringBuffer2.toString());
            throw e;
        } catch (ErrorWritingException e4) {
            e = e4;
            StringBuffer stringBuffer22 = new StringBuffer();
            stringBuffer22.append(cls.getName());
            stringBuffer22.append(".writeReplace()");
            e.add("method", stringBuffer22.toString());
            throw e;
        }
    }

    @Override // com.thoughtworks.xstream.core.Caching
    public void flushCache() {
        Set keySet = this.declaredCache.keySet();
        FastField[] fastFieldArr = OBJECT_TYPE_FIELDS;
        keySet.retainAll(Arrays.asList(fastFieldArr));
        this.resRepCache.keySet().retainAll(Arrays.asList(fastFieldArr));
    }

    /* JADX WARNING: Removed duplicated region for block: B:32:0x0064  */
    /* JADX WARNING: Removed duplicated region for block: B:35:0x0072  */
    public Map getSerializablePersistentFields(Class cls) {
        ErrorWritingException errorWritingException;
        Map map;
        HashMap hashMap;
        IllegalAccessException e;
        HashMap hashMap2;
        ClassCastException e2;
        if (cls == null) {
            return null;
        }
        Map map2 = (Map) this.fieldCache.get(cls.getName());
        if (map2 == null) {
            try {
                Field declaredField = cls.getDeclaredField("serialPersistentFields");
                if ((declaredField.getModifiers() & 26) == 26) {
                    declaredField.setAccessible(true);
                    ObjectStreamField[] objectStreamFieldArr = (ObjectStreamField[]) declaredField.get(null);
                    if (objectStreamFieldArr != null) {
                        HashMap hashMap3 = new HashMap();
                        for (int i = 0; i < objectStreamFieldArr.length; i++) {
                            try {
                                hashMap3.put(objectStreamFieldArr[i].getName(), objectStreamFieldArr[i]);
                            } catch (NoSuchFieldException unused) {
                            } catch (IllegalAccessException e3) {
                                e = e3;
                                hashMap = hashMap3;
                                errorWritingException = new ObjectAccessException("Cannot get field", e);
                                map = hashMap;
                                map2 = map;
                                if (errorWritingException == null) {
                                }
                            } catch (ClassCastException e4) {
                                e2 = e4;
                                hashMap2 = hashMap3;
                                errorWritingException = new ConversionException("Incompatible field type", e2);
                                map = hashMap2;
                                map2 = map;
                                if (errorWritingException == null) {
                                }
                            }
                        }
                        map2 = hashMap3;
                    }
                }
            } catch (NoSuchFieldException unused2) {
            } catch (IllegalAccessException e5) {
                hashMap = map2;
                e = e5;
                errorWritingException = new ObjectAccessException("Cannot get field", e);
                map = hashMap;
                map2 = map;
                if (errorWritingException == null) {
                }
            } catch (ClassCastException e6) {
                hashMap2 = map2;
                e2 = e6;
                errorWritingException = new ConversionException("Incompatible field type", e2);
                map = hashMap2;
                map2 = map;
                if (errorWritingException == null) {
                }
            }
            errorWritingException = null;
            if (errorWritingException == null) {
                if (map2 == null) {
                    map2 = NO_FIELDS;
                }
                this.fieldCache.put(cls.getName(), map2);
            } else {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(cls.getName());
                stringBuffer.append(".serialPersistentFields");
                errorWritingException.add("field", stringBuffer.toString());
                throw errorWritingException;
            }
        }
        if (map2 == NO_FIELDS) {
            return null;
        }
        return map2;
    }

    public boolean supportsReadObject(Class cls, boolean z) {
        Class[] clsArr = new Class[1];
        Class cls2 = class$java$io$ObjectInputStream;
        if (cls2 == null) {
            cls2 = class$("java.io.ObjectInputStream");
            class$java$io$ObjectInputStream = cls2;
        }
        clsArr[0] = cls2;
        if (getMethod(cls, "readObject", clsArr, z) != null) {
            return true;
        }
        return false;
    }

    public boolean supportsWriteObject(Class cls, boolean z) {
        Class[] clsArr = new Class[1];
        Class cls2 = class$java$io$ObjectOutputStream;
        if (cls2 == null) {
            cls2 = class$("java.io.ObjectOutputStream");
            class$java$io$ObjectOutputStream = cls2;
        }
        clsArr[0] = cls2;
        if (getMethod(cls, "writeObject", clsArr, z) != null) {
            return true;
        }
        return false;
    }

    private Method getMethod(Class cls, String str, Class[] clsArr) {
        if (cls == null) {
            return null;
        }
        FastField fastField = new FastField(cls, str);
        Method method = (Method) this.declaredCache.get(fastField);
        if (method == null) {
            try {
                method = cls.getDeclaredMethod(str, clsArr);
                if (!method.isAccessible()) {
                    method.setAccessible(true);
                }
            } catch (NoSuchMethodException unused) {
                method = getMethod(cls.getSuperclass(), str, clsArr);
            }
            this.declaredCache.put(fastField, method);
        }
        return method;
    }
}
