package com.thoughtworks.xstream.core.util;

import com.google.android.exoplayer2.C;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.PushbackInputStream;
import java.io.Reader;
import java.util.HashMap;
import java.util.Map;

public final class XmlHeaderAwareReader extends Reader {
    private static final String KEY_ENCODING = "encoding";
    private static final String KEY_VERSION = "version";
    private static final int STATE_ATTR_NAME = 3;
    private static final int STATE_ATTR_VALUE = 4;
    private static final int STATE_AWAIT_XML_HEADER = 2;
    private static final int STATE_BOM = 0;
    private static final int STATE_START = 1;
    private static final String XML_TOKEN = "?xml";
    private final InputStreamReader reader;
    private final double version;

    public XmlHeaderAwareReader(InputStream inputStream) {
        PushbackInputStream[] pushbackInputStreamArr = new PushbackInputStream[1];
        pushbackInputStreamArr[0] = inputStream instanceof PushbackInputStream ? (PushbackInputStream) inputStream : new PushbackInputStream(inputStream, 64);
        Map header = getHeader(pushbackInputStreamArr);
        this.version = Double.parseDouble((String) header.get(KEY_VERSION));
        this.reader = new InputStreamReader(pushbackInputStreamArr[0], (String) header.get(KEY_ENCODING));
    }

    private Map getHeader(PushbackInputStream[] pushbackInputStreamArr) {
        HashMap hashMap = new HashMap();
        hashMap.put(KEY_ENCODING, C.UTF8_NAME);
        hashMap.put(KEY_VERSION, "1.0");
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream(64);
        StringBuffer stringBuffer = new StringBuffer();
        StringBuffer stringBuffer2 = new StringBuffer();
        int i = 0;
        char c = 0;
        char c2 = 0;
        loop0:
        while (true) {
            boolean z = false;
            while (i != -1 && (i = pushbackInputStreamArr[0].read()) != -1) {
                byteArrayOutputStream.write(i);
                char c3 = (char) i;
                if (c != 0) {
                    if (c != 1) {
                        if (c != 2) {
                            if (c != 3) {
                                if (c != 4) {
                                    continue;
                                } else if (c2 == 0) {
                                    if (c3 == '\"' || c3 == '\'') {
                                        c2 = c3;
                                    }
                                    i = -1;
                                } else if (c3 == '\\' && !z) {
                                    z = true;
                                } else if (c3 == c2 && !z) {
                                    hashMap.put(stringBuffer.toString(), stringBuffer2.toString());
                                    stringBuffer.setLength(0);
                                    stringBuffer2.setLength(0);
                                    c = 3;
                                    c2 = 0;
                                } else if (c3 != '\n') {
                                    stringBuffer2.append(c3);
                                } else {
                                    i = -1;
                                }
                            } else if (Character.isWhitespace(c3)) {
                                if (stringBuffer.length() <= 0) {
                                }
                                i = -1;
                            } else if (c3 == '=') {
                                c = 4;
                            } else {
                                char lowerCase = Character.toLowerCase(c3);
                                if (Character.isLetter(lowerCase)) {
                                    stringBuffer.append(lowerCase);
                                }
                                i = -1;
                            }
                        } else if (!Character.isWhitespace(c3)) {
                            stringBuffer.append(Character.toLowerCase(c3));
                            if (XML_TOKEN.startsWith(stringBuffer.substring(0))) {
                            }
                            i = -1;
                        } else {
                            if (stringBuffer.toString().equals(XML_TOKEN)) {
                                stringBuffer.setLength(0);
                                c = 3;
                            }
                            i = -1;
                        }
                    }
                } else if ((c3 != 239 || byteArrayOutputStream.size() != 1) && ((c3 != 187 || byteArrayOutputStream.size() != 2) && (c3 != 191 || byteArrayOutputStream.size() != 3))) {
                    if (byteArrayOutputStream.size() <= 1) {
                        c = 1;
                    }
                    i = -1;
                } else if (c3 == 191) {
                    byteArrayOutputStream.reset();
                    c = 1;
                }
                if (!Character.isWhitespace(c3)) {
                    if (c3 == '<') {
                        c = 2;
                    }
                    i = -1;
                }
            }
        }
        byte[] byteArray = byteArrayOutputStream.toByteArray();
        int length = byteArray.length;
        while (true) {
            int i2 = length - 1;
            if (length <= 0) {
                return hashMap;
            }
            try {
                pushbackInputStreamArr[0].unread(byteArray[i2]);
            } catch (IOException unused) {
                i2++;
                pushbackInputStreamArr[0] = new PushbackInputStream(pushbackInputStreamArr[0], i2);
            }
            length = i2;
        }
    }

    @Override // java.io.Closeable, java.io.Reader, java.lang.AutoCloseable
    public void close() {
        this.reader.close();
    }

    public boolean equals(Object obj) {
        return this.reader.equals(obj);
    }

    public String getEncoding() {
        return this.reader.getEncoding();
    }

    public double getVersion() {
        return this.version;
    }

    public int hashCode() {
        return this.reader.hashCode();
    }

    @Override // java.io.Reader
    public void mark(int i) {
        this.reader.mark(i);
    }

    public boolean markSupported() {
        return this.reader.markSupported();
    }

    @Override // java.io.Reader
    public int read() {
        return this.reader.read();
    }

    @Override // java.io.Reader
    public boolean ready() {
        return this.reader.ready();
    }

    @Override // java.io.Reader
    public void reset() {
        this.reader.reset();
    }

    @Override // java.io.Reader
    public long skip(long j) {
        return this.reader.skip(j);
    }

    public String toString() {
        return this.reader.toString();
    }

    @Override // java.io.Reader
    public int read(char[] cArr, int i, int i2) {
        return this.reader.read(cArr, i, i2);
    }

    @Override // java.io.Reader
    public int read(char[] cArr) {
        return this.reader.read(cArr);
    }
}
