package com.thoughtworks.xstream.io.xml;

import com.thoughtworks.xstream.converters.ErrorWriter;
import com.thoughtworks.xstream.core.util.FastStack;
import com.thoughtworks.xstream.io.AttributeNameIterator;
import com.thoughtworks.xstream.io.naming.NameCoder;
import java.util.Iterator;

public abstract class AbstractDocumentReader extends AbstractXmlReader implements DocumentReader {
    private Object current;
    private FastStack pointers;

    public static class Pointer {
        public int v;

        private Pointer() {
        }
    }

    public AbstractDocumentReader(Object obj) {
        this(obj, new XmlFriendlyNameCoder());
    }

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamReader, com.thoughtworks.xstream.converters.ErrorReporter
    public void appendErrors(ErrorWriter errorWriter) {
    }

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamReader
    public void close() {
    }

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamReader
    public Iterator getAttributeNames() {
        return new AttributeNameIterator(this);
    }

    public abstract Object getChild(int i);

    public abstract int getChildCount();

    @Override // com.thoughtworks.xstream.io.xml.DocumentReader
    public Object getCurrent() {
        return this.current;
    }

    public abstract Object getParent();

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamReader
    public boolean hasMoreChildren() {
        return ((Pointer) this.pointers.peek()).v < getChildCount();
    }

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamReader
    public void moveDown() {
        Pointer pointer = (Pointer) this.pointers.peek();
        this.pointers.push(new Pointer());
        Object child = getChild(pointer.v);
        this.current = child;
        pointer.v++;
        reassignCurrentElement(child);
    }

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamReader
    public void moveUp() {
        this.current = getParent();
        this.pointers.popSilently();
        reassignCurrentElement(this.current);
    }

    public abstract void reassignCurrentElement(Object obj);

    public AbstractDocumentReader(Object obj, NameCoder nameCoder) {
        super(nameCoder);
        FastStack fastStack = new FastStack(16);
        this.pointers = fastStack;
        this.current = obj;
        fastStack.push(new Pointer());
        reassignCurrentElement(this.current);
    }

    public AbstractDocumentReader(Object obj, XmlFriendlyReplacer xmlFriendlyReplacer) {
        this(obj, (NameCoder) xmlFriendlyReplacer);
    }
}
