package com.thoughtworks.xstream.io.xml;

import com.thoughtworks.xstream.io.HierarchicalStreamReader;
import com.thoughtworks.xstream.io.HierarchicalStreamWriter;
import com.thoughtworks.xstream.io.StreamException;
import com.thoughtworks.xstream.io.naming.NameCoder;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.Reader;
import java.io.Writer;
import java.net.URL;
import nu.xom.Builder;
import nu.xom.ParsingException;
import nu.xom.ValidityException;

public class XomDriver extends AbstractXmlDriver {
    private final Builder builder;

    public XomDriver() {
        this(new XmlFriendlyNameCoder());
    }

    public Builder createBuilder() {
        Builder builder2 = getBuilder();
        return builder2 != null ? builder2 : new Builder();
    }

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamDriver
    public HierarchicalStreamReader createReader(Reader reader) {
        try {
            return new XomReader(createBuilder().build(reader), getNameCoder());
        } catch (ValidityException e) {
            throw new StreamException((Throwable) e);
        } catch (ParsingException e2) {
            throw new StreamException((Throwable) e2);
        } catch (IOException e3) {
            throw new StreamException(e3);
        }
    }

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamDriver
    public HierarchicalStreamWriter createWriter(Writer writer) {
        return new PrettyPrintWriter(writer, getNameCoder());
    }

    public Builder getBuilder() {
        return this.builder;
    }

    public XomDriver(Builder builder2) {
        this(builder2, new XmlFriendlyNameCoder());
    }

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamDriver
    public HierarchicalStreamWriter createWriter(OutputStream outputStream) {
        return new PrettyPrintWriter(new OutputStreamWriter(outputStream), getNameCoder());
    }

    public XomDriver(NameCoder nameCoder) {
        super(nameCoder);
        this.builder = null;
    }

    public XomDriver(Builder builder2, NameCoder nameCoder) {
        super(nameCoder);
        this.builder = builder2;
    }

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamDriver
    public HierarchicalStreamReader createReader(InputStream inputStream) {
        try {
            return new XomReader(createBuilder().build(inputStream), getNameCoder());
        } catch (ValidityException e) {
            throw new StreamException((Throwable) e);
        } catch (ParsingException e2) {
            throw new StreamException((Throwable) e2);
        } catch (IOException e3) {
            throw new StreamException(e3);
        }
    }

    public XomDriver(XmlFriendlyReplacer xmlFriendlyReplacer) {
        this((NameCoder) xmlFriendlyReplacer);
    }

    public XomDriver(Builder builder2, XmlFriendlyReplacer xmlFriendlyReplacer) {
        this(builder2, (NameCoder) xmlFriendlyReplacer);
    }

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamDriver, com.thoughtworks.xstream.io.AbstractDriver
    public HierarchicalStreamReader createReader(URL url) {
        try {
            return new XomReader(createBuilder().build(url.toExternalForm()), getNameCoder());
        } catch (ValidityException e) {
            throw new StreamException((Throwable) e);
        } catch (ParsingException e2) {
            throw new StreamException((Throwable) e2);
        } catch (IOException e3) {
            throw new StreamException(e3);
        }
    }

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamDriver, com.thoughtworks.xstream.io.AbstractDriver
    public HierarchicalStreamReader createReader(File file) {
        try {
            return new XomReader(createBuilder().build(file), getNameCoder());
        } catch (ValidityException e) {
            throw new StreamException((Throwable) e);
        } catch (ParsingException e2) {
            throw new StreamException((Throwable) e2);
        } catch (IOException e3) {
            throw new StreamException(e3);
        }
    }
}
