package com.thoughtworks.xstream.mapper;

import com.thoughtworks.xstream.XStreamException;
import com.thoughtworks.xstream.core.Caching;
import com.thoughtworks.xstream.security.ForbiddenClassException;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

public class CachingMapper extends MapperWrapper implements Caching {
    private transient Map realClassCache;

    public CachingMapper(Mapper mapper) {
        super(mapper);
        readResolve();
    }

    private Object readResolve() {
        this.realClassCache = Collections.synchronizedMap(new HashMap(128));
        return this;
    }

    @Override // com.thoughtworks.xstream.core.Caching
    public void flushCache() {
        this.realClassCache.clear();
    }

    @Override // com.thoughtworks.xstream.mapper.MapperWrapper, com.thoughtworks.xstream.mapper.Mapper
    public Class realClass(String str) {
        Object obj = this.realClassCache.get(str);
        if (obj == null) {
            try {
                Class realClass = super.realClass(str);
                this.realClassCache.put(str, realClass);
                return realClass;
            } catch (ForbiddenClassException e) {
                this.realClassCache.put(str, e);
                throw e;
            } catch (CannotResolveClassException e2) {
                this.realClassCache.put(str, e2);
                throw e2;
            }
        } else if (obj instanceof Class) {
            return (Class) obj;
        } else {
            throw ((XStreamException) obj);
        }
    }
}
