package com.thoughtworks.xstream.mapper;

import androidx.base.b2;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;
import java.util.Comparator;
import java.util.HashMap;
import java.util.Map;
import java.util.TreeMap;

public class PackageAliasingMapper extends MapperWrapper implements Serializable {
    private static final Comparator REVERSE = new Comparator() {
        /* class com.thoughtworks.xstream.mapper.PackageAliasingMapper.AnonymousClass1 */

        @Override // java.util.Comparator
        public int compare(Object obj, Object obj2) {
            return ((String) obj2).compareTo((String) obj);
        }
    };
    public transient Map nameToPackage = new HashMap();
    private Map packageToName = new TreeMap(REVERSE);

    public PackageAliasingMapper(Mapper mapper) {
        super(mapper);
    }

    private void readObject(ObjectInputStream objectInputStream) {
        TreeMap treeMap = new TreeMap(REVERSE);
        this.packageToName = treeMap;
        treeMap.putAll((Map) objectInputStream.readObject());
        this.nameToPackage = new HashMap();
        for (Object obj : this.packageToName.keySet()) {
            this.nameToPackage.put(this.packageToName.get(obj), obj);
        }
    }

    private void writeObject(ObjectOutputStream objectOutputStream) {
        objectOutputStream.writeObject(new HashMap(this.packageToName));
    }

    public void addPackageAlias(String str, String str2) {
        if (str.length() > 0 && str.charAt(str.length() - 1) != '.') {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append(str);
            stringBuffer.append('.');
            str = stringBuffer.toString();
        }
        if (str2.length() > 0 && str2.charAt(str2.length() - 1) != '.') {
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(str2);
            stringBuffer2.append('.');
            str2 = stringBuffer2.toString();
        }
        this.nameToPackage.put(str, str2);
        this.packageToName.put(str2, str);
    }

    @Override // com.thoughtworks.xstream.mapper.MapperWrapper, com.thoughtworks.xstream.mapper.Mapper
    public Class realClass(String str) {
        String str2;
        int length = str.length();
        while (true) {
            int lastIndexOf = str.lastIndexOf(46, length);
            if (lastIndexOf < 0) {
                str2 = "";
            } else {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(str.substring(0, lastIndexOf));
                stringBuffer.append('.');
                str2 = stringBuffer.toString();
            }
            String str3 = (String) this.nameToPackage.get(str2);
            if (str3 != null) {
                StringBuffer h = b2.h(str3);
                if (lastIndexOf >= 0) {
                    str = str.substring(lastIndexOf + 1);
                }
                h.append(str);
                str = h.toString();
            } else {
                int i = lastIndexOf - 1;
                if (lastIndexOf < 0) {
                    break;
                }
                length = i;
            }
        }
        return super.realClass(str);
    }

    @Override // com.thoughtworks.xstream.mapper.MapperWrapper, com.thoughtworks.xstream.mapper.Mapper
    public String serializedClass(Class cls) {
        String str;
        String name = cls.getName();
        int length = name.length();
        while (true) {
            int lastIndexOf = name.lastIndexOf(46, length);
            if (lastIndexOf < 0) {
                str = "";
            } else {
                str = name.substring(0, lastIndexOf + 1);
            }
            String str2 = (String) this.packageToName.get(str);
            if (str2 != null) {
                StringBuffer h = b2.h(str2);
                if (lastIndexOf >= 0) {
                    name = name.substring(lastIndexOf + 1);
                }
                h.append(name);
                return h.toString();
            }
            int i = lastIndexOf - 1;
            if (lastIndexOf < 0) {
                return super.serializedClass(cls);
            }
            length = i;
        }
    }
}
