package com.xunlei.downloadlib.android;

import android.os.Environment;
import android.os.Handler;
import android.os.HandlerThread;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.text.SimpleDateFormat;
import java.util.Date;

public final class XLLogInternal {
    private static final SimpleDateFormat DATEFORMAT = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss.SSS");
    private File mFile;
    private final Handler mHandler;
    private final LogConfig mLogConfig;
    private int mNext;
    private int mRun;

    public XLLogInternal(LogConfig logConfig) {
        this.mLogConfig = logConfig;
        HandlerThread handlerThread = new HandlerThread("DownloadLib-XLLog");
        handlerThread.start();
        this.mHandler = new Handler(handlerThread.getLooper());
    }

    private static String appendHeader(LogLevel logLevel, String str, String str2) {
        StringBuilder sb = new StringBuilder();
        sb.append(DATEFORMAT.format(new Date()) + ": " + logLevel.toString());
        sb.append("/" + str + "(" + Thread.currentThread().getId() + "):\t");
        sb.append(str2);
        sb.append("\r\n");
        return sb.toString();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private File getLogFile() {
        if ("mounted".equalsIgnoreCase(Environment.getExternalStorageState())) {
            File file = new File(Environment.getExternalStorageDirectory().getPath() + File.separator + this.mLogConfig.mLogDir);
            if (!file.exists()) {
                file.mkdirs();
            }
            while (this.mFile == null) {
                File file2 = new File(file.getPath() + File.separator + new SimpleDateFormat("yyyyMMdd").format(new Date()) + ".R" + this.mRun + ".0." + this.mLogConfig.mFileName);
                this.mFile = file2;
                if (!file2.exists()) {
                    break;
                }
                this.mRun++;
                this.mFile = null;
            }
            if (getLogFileSize() >= this.mLogConfig.mLogSize) {
                this.mNext++;
                File file3 = new File(file.getPath() + File.separator + new SimpleDateFormat("yyyyMMdd").format(new Date()) + ".R" + this.mRun + "." + this.mNext + "." + this.mLogConfig.mFileName);
                this.mFile = file3;
                file3.delete();
            }
        }
        return this.mFile;
    }

    private long getLogFileSize() {
        long j = -1;
        if (this.mFile == null) {
            return -1;
        }
        try {
            FileInputStream fileInputStream = new FileInputStream(this.mFile);
            j = (long) fileInputStream.available();
            fileInputStream.close();
            return j;
        } catch (Exception unused) {
            return j;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void logfile(LogLevel logLevel, String str, String str2) {
        try {
            FileWriter fileWriter = new FileWriter(getLogFile(), true);
            BufferedWriter bufferedWriter = new BufferedWriter(fileWriter);
            bufferedWriter.write(str2);
            bufferedWriter.newLine();
            bufferedWriter.close();
            fileWriter.close();
        } catch (Exception unused) {
        }
    }

    public final void log(final LogLevel logLevel, final String str, String str2) {
        final String appendHeader = appendHeader(logLevel, str, str2);
        if (logLevel.getValue() >= this.mLogConfig.mLevel.getValue() && this.mLogConfig.canLogToFile()) {
            this.mHandler.post(new Runnable() {
                /* class com.xunlei.downloadlib.android.XLLogInternal.AnonymousClass1 */

                public void run() {
                    XLLogInternal.this.logfile(logLevel, str, appendHeader);
                }
            });
        }
    }

    public final void printStackTrace(final Throwable th) {
        this.mHandler.post(new Runnable() {
            /* class com.xunlei.downloadlib.android.XLLogInternal.AnonymousClass2 */

            public void run() {
                try {
                    FileWriter fileWriter = new FileWriter(XLLogInternal.this.getLogFile(), true);
                    BufferedWriter bufferedWriter = new BufferedWriter(fileWriter);
                    th.printStackTrace(new PrintWriter(bufferedWriter));
                    bufferedWriter.write("\n");
                    bufferedWriter.close();
                    fileWriter.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        });
    }
}
