package okio;

import androidx.base.f00;
import androidx.base.g00;
import androidx.base.zz;
import java.io.IOException;
import java.io.InterruptedIOException;
import java.util.concurrent.TimeUnit;

public class AsyncTimeout extends Timeout {
    public static final Companion Companion = new Companion(null);
    private static final long IDLE_TIMEOUT_MILLIS;
    private static final long IDLE_TIMEOUT_NANOS;
    private static final int TIMEOUT_WRITE_SIZE = 65536;
    private static AsyncTimeout head;
    private boolean inQueue;
    private AsyncTimeout next;
    private long timeoutAt;

    public static final class Companion {
        private Companion() {
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private final boolean cancelScheduledTimeout(AsyncTimeout asyncTimeout) {
            synchronized (AsyncTimeout.class) {
                for (AsyncTimeout asyncTimeout2 = AsyncTimeout.head; asyncTimeout2 != null; asyncTimeout2 = asyncTimeout2.next) {
                    if (asyncTimeout2.next == asyncTimeout) {
                        asyncTimeout2.next = asyncTimeout.next;
                        asyncTimeout.next = null;
                        return false;
                    }
                }
                return true;
            }
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private final void scheduleTimeout(AsyncTimeout asyncTimeout, long j, boolean z) {
            synchronized (AsyncTimeout.class) {
                if (AsyncTimeout.head == null) {
                    AsyncTimeout.head = new AsyncTimeout();
                    new Watchdog().start();
                }
                long nanoTime = System.nanoTime();
                if (j != 0 && z) {
                    asyncTimeout.timeoutAt = Math.min(j, asyncTimeout.deadlineNanoTime() - nanoTime) + nanoTime;
                } else if (j != 0) {
                    asyncTimeout.timeoutAt = j + nanoTime;
                } else if (z) {
                    asyncTimeout.timeoutAt = asyncTimeout.deadlineNanoTime();
                } else {
                    throw new AssertionError();
                }
                long remainingNanos = asyncTimeout.remainingNanos(nanoTime);
                AsyncTimeout asyncTimeout2 = AsyncTimeout.head;
                if (asyncTimeout2 != null) {
                    while (true) {
                        if (asyncTimeout2.next == null) {
                            break;
                        }
                        AsyncTimeout asyncTimeout3 = asyncTimeout2.next;
                        if (asyncTimeout3 == null) {
                            g00.e();
                            throw null;
                        } else if (remainingNanos < asyncTimeout3.remainingNanos(nanoTime)) {
                            break;
                        } else {
                            asyncTimeout2 = asyncTimeout2.next;
                            if (asyncTimeout2 == null) {
                                g00.e();
                                throw null;
                            }
                        }
                    }
                    asyncTimeout.next = asyncTimeout2.next;
                    asyncTimeout2.next = asyncTimeout;
                    if (asyncTimeout2 == AsyncTimeout.head) {
                        AsyncTimeout.class.notify();
                    }
                } else {
                    g00.e();
                    throw null;
                }
            }
        }

        public final AsyncTimeout awaitTimeout$okio() {
            AsyncTimeout asyncTimeout = AsyncTimeout.head;
            if (asyncTimeout != null) {
                AsyncTimeout asyncTimeout2 = asyncTimeout.next;
                if (asyncTimeout2 == null) {
                    long nanoTime = System.nanoTime();
                    AsyncTimeout.class.wait(AsyncTimeout.IDLE_TIMEOUT_MILLIS);
                    AsyncTimeout asyncTimeout3 = AsyncTimeout.head;
                    if (asyncTimeout3 == null) {
                        g00.e();
                        throw null;
                    } else if (asyncTimeout3.next != null || System.nanoTime() - nanoTime < AsyncTimeout.IDLE_TIMEOUT_NANOS) {
                        return null;
                    } else {
                        return AsyncTimeout.head;
                    }
                } else {
                    long remainingNanos = asyncTimeout2.remainingNanos(System.nanoTime());
                    if (remainingNanos > 0) {
                        long j = remainingNanos / 1000000;
                        AsyncTimeout.class.wait(j, (int) (remainingNanos - (1000000 * j)));
                        return null;
                    }
                    AsyncTimeout asyncTimeout4 = AsyncTimeout.head;
                    if (asyncTimeout4 != null) {
                        asyncTimeout4.next = asyncTimeout2.next;
                        asyncTimeout2.next = null;
                        return asyncTimeout2;
                    }
                    g00.e();
                    throw null;
                }
            } else {
                g00.e();
                throw null;
            }
        }

        public /* synthetic */ Companion(f00 f00) {
            this();
        }
    }

    public static final class Watchdog extends Thread {
        public Watchdog() {
            super("Okio Watchdog");
            setDaemon(true);
        }

        /* JADX WARNING: Code restructure failed: missing block: B:11:0x0016, code lost:
            if (r1 == null) goto L_0x0000;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:12:0x0018, code lost:
            r1.timedOut();
         */
        public void run() {
            while (true) {
                try {
                    synchronized (AsyncTimeout.class) {
                        AsyncTimeout awaitTimeout$okio = AsyncTimeout.Companion.awaitTimeout$okio();
                        if (awaitTimeout$okio == AsyncTimeout.head) {
                            AsyncTimeout.head = null;
                            return;
                        }
                    }
                } catch (InterruptedException unused) {
                }
            }
        }
    }

    static {
        long millis = TimeUnit.SECONDS.toMillis(60);
        IDLE_TIMEOUT_MILLIS = millis;
        IDLE_TIMEOUT_NANOS = TimeUnit.MILLISECONDS.toNanos(millis);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private final long remainingNanos(long j) {
        return this.timeoutAt - j;
    }

    public final IOException access$newTimeoutException(IOException iOException) {
        return newTimeoutException(iOException);
    }

    public final void enter() {
        if (!this.inQueue) {
            long timeoutNanos = timeoutNanos();
            boolean hasDeadline = hasDeadline();
            if (timeoutNanos != 0 || hasDeadline) {
                this.inQueue = true;
                Companion.scheduleTimeout(this, timeoutNanos, hasDeadline);
                return;
            }
            return;
        }
        throw new IllegalStateException("Unbalanced enter/exit".toString());
    }

    public final boolean exit() {
        if (!this.inQueue) {
            return false;
        }
        this.inQueue = false;
        return Companion.cancelScheduledTimeout(this);
    }

    public IOException newTimeoutException(IOException iOException) {
        InterruptedIOException interruptedIOException = new InterruptedIOException("timeout");
        if (iOException != null) {
            interruptedIOException.initCause(iOException);
        }
        return interruptedIOException;
    }

    public final Sink sink(Sink sink) {
        if (sink != null) {
            return new AsyncTimeout$sink$1(this, sink);
        }
        g00.f("sink");
        throw null;
    }

    public final Source source(Source source) {
        if (source != null) {
            return new AsyncTimeout$source$1(this, source);
        }
        g00.f("source");
        throw null;
    }

    public void timedOut() {
    }

    public final <T> T withTimeout(zz<? extends T> zzVar) {
        if (zzVar != null) {
            enter();
            try {
                T t = (T) zzVar.a();
                if (!exit()) {
                    return t;
                }
                throw access$newTimeoutException(null);
            } catch (IOException e) {
                if (!exit()) {
                    throw e;
                }
                throw access$newTimeoutException(e);
            } finally {
                exit();
            }
        } else {
            g00.f("block");
            throw null;
        }
    }
}
