package okio;

import androidx.base.b2;
import androidx.base.ew;
import androidx.base.g00;
import androidx.base.p00;
import androidx.base.xz;
import androidx.exifinterface.media.ExifInterface;
import com.google.android.exoplayer2.extractor.mp3.IndexSeeker;
import com.google.android.exoplayer2.extractor.ts.PsExtractor;
import java.io.Closeable;
import java.io.EOFException;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.ByteBuffer;
import java.nio.channels.ByteChannel;
import java.nio.charset.Charset;
import java.security.InvalidKeyException;
import java.security.MessageDigest;
import java.util.Arrays;
import javax.crypto.Mac;
import javax.crypto.spec.SecretKeySpec;
import okio.internal.BufferKt;
import org.xwalk.core.XWalkAppVersion;

public final class Buffer implements BufferedSource, BufferedSink, Cloneable, ByteChannel {
    public Segment head;
    private long size;

    public static final class UnsafeCursor implements Closeable {
        public Buffer buffer;
        public byte[] data;
        public int end = -1;
        public long offset = -1;
        public boolean readWrite;
        private Segment segment;
        public int start = -1;

        @Override // java.io.Closeable, java.lang.AutoCloseable
        public void close() {
            if (this.buffer != null) {
                this.buffer = null;
                this.segment = null;
                this.offset = -1;
                this.data = null;
                this.start = -1;
                this.end = -1;
                return;
            }
            throw new IllegalStateException("not attached to a buffer".toString());
        }

        public final long expandBuffer(int i) {
            boolean z = true;
            if (i > 0) {
                if (i > 8192) {
                    z = false;
                }
                if (z) {
                    Buffer buffer2 = this.buffer;
                    if (buffer2 == null) {
                        throw new IllegalStateException("not attached to a buffer".toString());
                    } else if (this.readWrite) {
                        long size = buffer2.size();
                        Segment writableSegment$okio = buffer2.writableSegment$okio(i);
                        int i2 = 8192 - writableSegment$okio.limit;
                        writableSegment$okio.limit = 8192;
                        long j = (long) i2;
                        buffer2.setSize$okio(size + j);
                        this.segment = writableSegment$okio;
                        this.offset = size;
                        this.data = writableSegment$okio.data;
                        this.start = 8192 - i2;
                        this.end = 8192;
                        return j;
                    } else {
                        throw new IllegalStateException("expandBuffer() only permitted for read/write buffers".toString());
                    }
                } else {
                    throw new IllegalArgumentException(b2.t("minByteCount > Segment.SIZE: ", i).toString());
                }
            } else {
                throw new IllegalArgumentException(b2.t("minByteCount <= 0: ", i).toString());
            }
        }

        public final int next() {
            long j = this.offset;
            Buffer buffer2 = this.buffer;
            if (buffer2 != null) {
                if (j != buffer2.size()) {
                    long j2 = this.offset;
                    return seek(j2 == -1 ? 0 : j2 + ((long) (this.end - this.start)));
                }
                throw new IllegalStateException("no more bytes".toString());
            }
            g00.e();
            throw null;
        }

        public final long resizeBuffer(long j) {
            Buffer buffer2 = this.buffer;
            if (buffer2 == null) {
                throw new IllegalStateException("not attached to a buffer".toString());
            } else if (this.readWrite) {
                long size = buffer2.size();
                int i = 1;
                if (j <= size) {
                    if (j >= 0) {
                        long j2 = size - j;
                        while (true) {
                            if (j2 <= 0) {
                                break;
                            }
                            Segment segment2 = buffer2.head;
                            if (segment2 != null) {
                                Segment segment3 = segment2.prev;
                                if (segment3 != null) {
                                    int i2 = segment3.limit;
                                    long j3 = (long) (i2 - segment3.pos);
                                    if (j3 > j2) {
                                        segment3.limit = i2 - ((int) j2);
                                        break;
                                    }
                                    buffer2.head = segment3.pop();
                                    SegmentPool.INSTANCE.recycle(segment3);
                                    j2 -= j3;
                                } else {
                                    g00.e();
                                    throw null;
                                }
                            } else {
                                g00.e();
                                throw null;
                            }
                        }
                        this.segment = null;
                        this.offset = j;
                        this.data = null;
                        this.start = -1;
                        this.end = -1;
                    } else {
                        throw new IllegalArgumentException(b2.v("newSize < 0: ", j).toString());
                    }
                } else if (j > size) {
                    long j4 = j - size;
                    boolean z = true;
                    while (j4 > 0) {
                        Segment writableSegment$okio = buffer2.writableSegment$okio(i);
                        int min = (int) Math.min(j4, (long) (8192 - writableSegment$okio.limit));
                        int i3 = writableSegment$okio.limit + min;
                        writableSegment$okio.limit = i3;
                        j4 -= (long) min;
                        if (z) {
                            this.segment = writableSegment$okio;
                            this.offset = size;
                            this.data = writableSegment$okio.data;
                            this.start = i3 - min;
                            this.end = i3;
                            z = false;
                        }
                        i = 1;
                    }
                }
                buffer2.setSize$okio(j);
                return size;
            } else {
                throw new IllegalStateException("resizeBuffer() only permitted for read/write buffers".toString());
            }
        }

        public final int seek(long j) {
            Buffer buffer2 = this.buffer;
            if (buffer2 == null) {
                throw new IllegalStateException("not attached to a buffer".toString());
            } else if (j < ((long) -1) || j > buffer2.size()) {
                String format = String.format("offset=%s > size=%s", Arrays.copyOf(new Object[]{Long.valueOf(j), Long.valueOf(buffer2.size())}, 2));
                g00.b(format, "java.lang.String.format(format, *args)");
                throw new ArrayIndexOutOfBoundsException(format);
            } else if (j == -1 || j == buffer2.size()) {
                this.segment = null;
                this.offset = j;
                this.data = null;
                this.start = -1;
                this.end = -1;
                return -1;
            } else {
                long j2 = 0;
                long size = buffer2.size();
                Segment segment2 = buffer2.head;
                Segment segment3 = this.segment;
                if (segment3 != null) {
                    long j3 = this.offset;
                    int i = this.start;
                    if (segment3 != null) {
                        long j4 = j3 - ((long) (i - segment3.pos));
                        if (j4 > j) {
                            size = j4;
                            segment3 = segment2;
                            segment2 = segment3;
                        } else {
                            j2 = j4;
                        }
                    } else {
                        g00.e();
                        throw null;
                    }
                } else {
                    segment3 = segment2;
                }
                if (size - j > j - j2) {
                    while (segment3 != null) {
                        int i2 = segment3.limit;
                        int i3 = segment3.pos;
                        if (j >= ((long) (i2 - i3)) + j2) {
                            j2 += (long) (i2 - i3);
                            segment3 = segment3.next;
                        }
                    }
                    g00.e();
                    throw null;
                }
                while (size > j) {
                    if (segment2 != null) {
                        segment2 = segment2.prev;
                        if (segment2 != null) {
                            size -= (long) (segment2.limit - segment2.pos);
                        } else {
                            g00.e();
                            throw null;
                        }
                    } else {
                        g00.e();
                        throw null;
                    }
                }
                segment3 = segment2;
                j2 = size;
                if (this.readWrite) {
                    if (segment3 == null) {
                        g00.e();
                        throw null;
                    } else if (segment3.shared) {
                        Segment unsharedCopy = segment3.unsharedCopy();
                        if (buffer2.head == segment3) {
                            buffer2.head = unsharedCopy;
                        }
                        segment3 = segment3.push(unsharedCopy);
                        Segment segment4 = segment3.prev;
                        if (segment4 != null) {
                            segment4.pop();
                        } else {
                            g00.e();
                            throw null;
                        }
                    }
                }
                this.segment = segment3;
                this.offset = j;
                if (segment3 != null) {
                    this.data = segment3.data;
                    int i4 = segment3.pos + ((int) (j - j2));
                    this.start = i4;
                    int i5 = segment3.limit;
                    this.end = i5;
                    return i5 - i4;
                }
                g00.e();
                throw null;
            }
        }
    }

    public static /* synthetic */ Buffer copyTo$default(Buffer buffer, OutputStream outputStream, long j, long j2, int i, Object obj) {
        if ((i & 2) != 0) {
            j = 0;
        }
        if ((i & 4) != 0) {
            j2 = buffer.size - j;
        }
        return buffer.copyTo(outputStream, j, j2);
    }

    public static /* synthetic */ Buffer copyTo$default(Buffer buffer, Buffer buffer2, long j, int i, Object obj) {
        if ((i & 2) != 0) {
            j = 0;
        }
        return buffer.copyTo(buffer2, j);
    }

    public static /* synthetic */ Buffer copyTo$default(Buffer buffer, Buffer buffer2, long j, long j2, int i, Object obj) {
        if ((i & 2) != 0) {
            j = 0;
        }
        return buffer.copyTo(buffer2, j, j2);
    }

    private final ByteString digest(String str) {
        MessageDigest instance = MessageDigest.getInstance(str);
        Segment segment = this.head;
        if (segment != null) {
            byte[] bArr = segment.data;
            int i = segment.pos;
            instance.update(bArr, i, segment.limit - i);
            Segment segment2 = segment.next;
            if (segment2 != null) {
                while (segment2 != segment) {
                    byte[] bArr2 = segment2.data;
                    int i2 = segment2.pos;
                    instance.update(bArr2, i2, segment2.limit - i2);
                    segment2 = segment2.next;
                    if (segment2 == null) {
                        g00.e();
                        throw null;
                    }
                }
            } else {
                g00.e();
                throw null;
            }
        }
        byte[] digest = instance.digest();
        g00.b(digest, "messageDigest.digest()");
        return new ByteString(digest);
    }

    private final ByteString hmac(String str, ByteString byteString) {
        try {
            Mac instance = Mac.getInstance(str);
            instance.init(new SecretKeySpec(byteString.internalArray$okio(), str));
            Segment segment = this.head;
            if (segment != null) {
                byte[] bArr = segment.data;
                int i = segment.pos;
                instance.update(bArr, i, segment.limit - i);
                Segment segment2 = segment.next;
                if (segment2 != null) {
                    while (segment2 != segment) {
                        byte[] bArr2 = segment2.data;
                        int i2 = segment2.pos;
                        instance.update(bArr2, i2, segment2.limit - i2);
                        segment2 = segment2.next;
                        if (segment2 == null) {
                            g00.e();
                            throw null;
                        }
                    }
                } else {
                    g00.e();
                    throw null;
                }
            }
            byte[] doFinal = instance.doFinal();
            g00.b(doFinal, "mac.doFinal()");
            return new ByteString(doFinal);
        } catch (InvalidKeyException e) {
            throw new IllegalArgumentException(e);
        }
    }

    public static /* synthetic */ UnsafeCursor readAndWriteUnsafe$default(Buffer buffer, UnsafeCursor unsafeCursor, int i, Object obj) {
        if ((i & 1) != 0) {
            unsafeCursor = new UnsafeCursor();
        }
        return buffer.readAndWriteUnsafe(unsafeCursor);
    }

    public static /* synthetic */ UnsafeCursor readUnsafe$default(Buffer buffer, UnsafeCursor unsafeCursor, int i, Object obj) {
        if ((i & 1) != 0) {
            unsafeCursor = new UnsafeCursor();
        }
        return buffer.readUnsafe(unsafeCursor);
    }

    public static /* synthetic */ Buffer writeTo$default(Buffer buffer, OutputStream outputStream, long j, int i, Object obj) {
        if ((i & 2) != 0) {
            j = buffer.size;
        }
        return buffer.writeTo(outputStream, j);
    }

    /* renamed from: -deprecated_getByte  reason: not valid java name */
    public final byte m1deprecated_getByte(long j) {
        return getByte(j);
    }

    /* renamed from: -deprecated_size  reason: not valid java name */
    public final long m2deprecated_size() {
        return this.size;
    }

    @Override // okio.BufferedSource, okio.BufferedSink
    public Buffer buffer() {
        return this;
    }

    public final void clear() {
        skip(size());
    }

    @Override // okio.Source, java.lang.AutoCloseable, okio.Sink, java.io.Closeable, java.nio.channels.Channel
    public void close() {
    }

    public final long completeSegmentByteCount() {
        long size2 = size();
        if (size2 == 0) {
            return 0;
        }
        Segment segment = this.head;
        if (segment != null) {
            Segment segment2 = segment.prev;
            if (segment2 != null) {
                int i = segment2.limit;
                if (i < 8192 && segment2.owner) {
                    size2 -= (long) (i - segment2.pos);
                }
                return size2;
            }
            g00.e();
            throw null;
        }
        g00.e();
        throw null;
    }

    public final Buffer copy() {
        Buffer buffer = new Buffer();
        if (size() != 0) {
            Segment segment = this.head;
            if (segment != null) {
                Segment sharedCopy = segment.sharedCopy();
                buffer.head = sharedCopy;
                sharedCopy.prev = sharedCopy;
                sharedCopy.next = sharedCopy;
                for (Segment segment2 = segment.next; segment2 != segment; segment2 = segment2.next) {
                    Segment segment3 = sharedCopy.prev;
                    if (segment3 == null) {
                        g00.e();
                        throw null;
                    } else if (segment2 != null) {
                        segment3.push(segment2.sharedCopy());
                    } else {
                        g00.e();
                        throw null;
                    }
                }
                buffer.setSize$okio(size());
            } else {
                g00.e();
                throw null;
            }
        }
        return buffer;
    }

    public final Buffer copyTo(OutputStream outputStream) {
        return copyTo$default(this, outputStream, 0, 0, 6, (Object) null);
    }

    public final Buffer copyTo(OutputStream outputStream, long j) {
        return copyTo$default(this, outputStream, j, 0, 4, (Object) null);
    }

    public final Buffer copyTo(OutputStream outputStream, long j, long j2) {
        if (outputStream != null) {
            Util.checkOffsetAndCount(this.size, j, j2);
            if (j2 == 0) {
                return this;
            }
            Segment segment = this.head;
            while (segment != null) {
                int i = segment.limit;
                int i2 = segment.pos;
                if (j >= ((long) (i - i2))) {
                    j -= (long) (i - i2);
                    segment = segment.next;
                } else {
                    while (j2 > 0) {
                        if (segment != null) {
                            int i3 = (int) (((long) segment.pos) + j);
                            int min = (int) Math.min((long) (segment.limit - i3), j2);
                            outputStream.write(segment.data, i3, min);
                            j2 -= (long) min;
                            segment = segment.next;
                            j = 0;
                        } else {
                            g00.e();
                            throw null;
                        }
                    }
                    return this;
                }
            }
            g00.e();
            throw null;
        }
        g00.f("out");
        throw null;
    }

    @Override // okio.BufferedSink
    public Buffer emit() {
        return this;
    }

    @Override // okio.BufferedSink
    public Buffer emitCompleteSegments() {
        return this;
    }

    public boolean equals(Object obj) {
        if (this != obj) {
            if (obj instanceof Buffer) {
                Buffer buffer = (Buffer) obj;
                if (size() == buffer.size()) {
                    if (size() != 0) {
                        Segment segment = this.head;
                        if (segment != null) {
                            Segment segment2 = buffer.head;
                            if (segment2 != null) {
                                int i = segment.pos;
                                int i2 = segment2.pos;
                                long j = 0;
                                while (j < size()) {
                                    long min = (long) Math.min(segment.limit - i, segment2.limit - i2);
                                    long j2 = 0;
                                    while (j2 < min) {
                                        int i3 = i + 1;
                                        int i4 = i2 + 1;
                                        if (segment.data[i] == segment2.data[i2]) {
                                            j2++;
                                            i = i3;
                                            i2 = i4;
                                        }
                                    }
                                    if (i == segment.limit) {
                                        Segment segment3 = segment.next;
                                        if (segment3 != null) {
                                            i = segment3.pos;
                                            segment = segment3;
                                        } else {
                                            g00.e();
                                            throw null;
                                        }
                                    }
                                    if (i2 == segment2.limit) {
                                        segment2 = segment2.next;
                                        if (segment2 != null) {
                                            i2 = segment2.pos;
                                        } else {
                                            g00.e();
                                            throw null;
                                        }
                                    }
                                    j += min;
                                }
                            } else {
                                g00.e();
                                throw null;
                            }
                        } else {
                            g00.e();
                            throw null;
                        }
                    }
                }
            }
            return false;
        }
        return true;
    }

    @Override // okio.BufferedSource
    public boolean exhausted() {
        return this.size == 0;
    }

    @Override // okio.Sink, okio.BufferedSink, java.io.Flushable
    public void flush() {
    }

    @Override // okio.BufferedSource, okio.BufferedSink
    public Buffer getBuffer() {
        return this;
    }

    public final byte getByte(long j) {
        Util.checkOffsetAndCount(size(), j, 1);
        Segment segment = this.head;
        if (segment == null) {
            g00.e();
            throw null;
        } else if (size() - j < j) {
            long size2 = size();
            while (size2 > j) {
                segment = segment.prev;
                if (segment != null) {
                    size2 -= (long) (segment.limit - segment.pos);
                } else {
                    g00.e();
                    throw null;
                }
            }
            return segment.data[(int) ((((long) segment.pos) + j) - size2)];
        } else {
            long j2 = 0;
            while (true) {
                int i = segment.limit;
                int i2 = segment.pos;
                long j3 = ((long) (i - i2)) + j2;
                if (j3 > j) {
                    return segment.data[(int) ((((long) i2) + j) - j2)];
                }
                segment = segment.next;
                if (segment != null) {
                    j2 = j3;
                } else {
                    g00.e();
                    throw null;
                }
            }
        }
    }

    public int hashCode() {
        Segment segment = this.head;
        if (segment == null) {
            return 0;
        }
        int i = 1;
        do {
            int i2 = segment.limit;
            for (int i3 = segment.pos; i3 < i2; i3++) {
                i = (i * 31) + segment.data[i3];
            }
            segment = segment.next;
            if (segment == null) {
                g00.e();
                throw null;
            }
        } while (segment != this.head);
        return i;
    }

    public final ByteString hmacSha1(ByteString byteString) {
        if (byteString != null) {
            return hmac("HmacSHA1", byteString);
        }
        g00.f(ew.KEY);
        throw null;
    }

    public final ByteString hmacSha256(ByteString byteString) {
        if (byteString != null) {
            return hmac("HmacSHA256", byteString);
        }
        g00.f(ew.KEY);
        throw null;
    }

    public final ByteString hmacSha512(ByteString byteString) {
        if (byteString != null) {
            return hmac("HmacSHA512", byteString);
        }
        g00.f(ew.KEY);
        throw null;
    }

    @Override // okio.BufferedSource
    public long indexOf(byte b) {
        return indexOf(b, 0, Long.MAX_VALUE);
    }

    @Override // okio.BufferedSource
    public long indexOfElement(ByteString byteString) {
        if (byteString != null) {
            return indexOfElement(byteString, 0);
        }
        g00.f("targetBytes");
        throw null;
    }

    @Override // okio.BufferedSource
    public InputStream inputStream() {
        return new Buffer$inputStream$1(this);
    }

    public boolean isOpen() {
        return true;
    }

    public final ByteString md5() {
        return digest("MD5");
    }

    @Override // okio.BufferedSink
    public OutputStream outputStream() {
        return new Buffer$outputStream$1(this);
    }

    @Override // okio.BufferedSource
    public BufferedSource peek() {
        return Okio.buffer(new PeekSource(this));
    }

    @Override // okio.BufferedSource
    public boolean rangeEquals(long j, ByteString byteString) {
        if (byteString != null) {
            return rangeEquals(j, byteString, 0, byteString.size());
        }
        g00.f("bytes");
        throw null;
    }

    @Override // java.nio.channels.ReadableByteChannel
    public int read(ByteBuffer byteBuffer) {
        if (byteBuffer != null) {
            Segment segment = this.head;
            if (segment == null) {
                return -1;
            }
            int min = Math.min(byteBuffer.remaining(), segment.limit - segment.pos);
            byteBuffer.put(segment.data, segment.pos, min);
            int i = segment.pos + min;
            segment.pos = i;
            this.size -= (long) min;
            if (i == segment.limit) {
                this.head = segment.pop();
                SegmentPool.INSTANCE.recycle(segment);
            }
            return min;
        }
        g00.f("sink");
        throw null;
    }

    @Override // okio.BufferedSource
    public long readAll(Sink sink) {
        if (sink != null) {
            long size2 = size();
            if (size2 > 0) {
                sink.write(this, size2);
            }
            return size2;
        }
        g00.f("sink");
        throw null;
    }

    public final UnsafeCursor readAndWriteUnsafe() {
        return readAndWriteUnsafe$default(this, null, 1, null);
    }

    public final UnsafeCursor readAndWriteUnsafe(UnsafeCursor unsafeCursor) {
        if (unsafeCursor != null) {
            if (unsafeCursor.buffer == null) {
                unsafeCursor.buffer = this;
                unsafeCursor.readWrite = true;
                return unsafeCursor;
            }
            throw new IllegalStateException("already attached to a buffer".toString());
        }
        g00.f("unsafeCursor");
        throw null;
    }

    @Override // okio.BufferedSource
    public byte readByte() {
        if (size() != 0) {
            Segment segment = this.head;
            if (segment != null) {
                int i = segment.pos;
                int i2 = segment.limit;
                int i3 = i + 1;
                byte b = segment.data[i];
                setSize$okio(size() - 1);
                if (i3 == i2) {
                    this.head = segment.pop();
                    SegmentPool.INSTANCE.recycle(segment);
                } else {
                    segment.pos = i3;
                }
                return b;
            }
            g00.e();
            throw null;
        }
        throw new EOFException();
    }

    @Override // okio.BufferedSource
    public byte[] readByteArray() {
        return readByteArray(size());
    }

    @Override // okio.BufferedSource
    public ByteString readByteString() {
        return readByteString(size());
    }

    /* JADX WARNING: Code restructure failed: missing block: B:19:0x0051, code lost:
        if (r6 != false) goto L_0x0056;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x0053, code lost:
        r1.readByte();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x0056, code lost:
        r3 = androidx.base.b2.j("Number too large: ");
        r3.append(r1.readUtf8());
     */
    /* JADX WARNING: Code restructure failed: missing block: B:22:0x006c, code lost:
        throw new java.lang.NumberFormatException(r3.toString());
     */
    @Override // okio.BufferedSource
    public long readDecimalLong() {
        long j = 0;
        if (size() != 0) {
            long j2 = -7;
            int i = 0;
            boolean z = false;
            boolean z2 = false;
            loop0:
            do {
                Segment segment = this.head;
                if (segment != null) {
                    byte[] bArr = segment.data;
                    int i2 = segment.pos;
                    int i3 = segment.limit;
                    while (true) {
                        if (i2 >= i3) {
                            break;
                        }
                        byte b = bArr[i2];
                        byte b2 = (byte) 48;
                        if (b >= b2 && b <= ((byte) 57)) {
                            int i4 = b2 - b;
                            if (j < BufferKt.OVERFLOW_ZONE || (j == BufferKt.OVERFLOW_ZONE && ((long) i4) < j2)) {
                                Buffer writeByte = new Buffer().writeDecimalLong(j).writeByte((int) b);
                            } else {
                                j = (j * 10) + ((long) i4);
                            }
                        } else if (b == ((byte) 45) && i == 0) {
                            j2--;
                            z = true;
                        } else if (i != 0) {
                            z2 = true;
                        } else {
                            StringBuilder j3 = b2.j("Expected leading [0-9] or '-' character but was 0x");
                            j3.append(Util.toHexString(b));
                            throw new NumberFormatException(j3.toString());
                        }
                        i2++;
                        i++;
                    }
                    if (i2 == i3) {
                        this.head = segment.pop();
                        SegmentPool.INSTANCE.recycle(segment);
                    } else {
                        segment.pos = i2;
                    }
                    if (z2) {
                        break;
                    }
                } else {
                    g00.e();
                    throw null;
                }
            } while (this.head != null);
            setSize$okio(size() - ((long) i));
            return z ? j : -j;
        }
        throw new EOFException();
    }

    public final Buffer readFrom(InputStream inputStream) {
        if (inputStream != null) {
            readFrom(inputStream, Long.MAX_VALUE, true);
            return this;
        }
        g00.f("input");
        throw null;
    }

    @Override // okio.BufferedSource
    public void readFully(Buffer buffer, long j) {
        if (buffer == null) {
            g00.f("sink");
            throw null;
        } else if (size() >= j) {
            buffer.write(this, j);
        } else {
            buffer.write(this, size());
            throw new EOFException();
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:30:0x0090, code lost:
        if (r8 != r9) goto L_0x009e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:31:0x0092, code lost:
        r15.head = r6.pop();
        okio.SegmentPool.INSTANCE.recycle(r6);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:32:0x009e, code lost:
        r6.pos = r8;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:33:0x00a0, code lost:
        if (r1 != false) goto L_0x00a6;
     */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x0077  */
    /* JADX WARNING: Removed duplicated region for block: B:46:0x0079 A[SYNTHETIC] */
    @Override // okio.BufferedSource
    public long readHexadecimalUnsignedLong() {
        int i;
        if (size() != 0) {
            int i2 = 0;
            boolean z = false;
            long j = 0;
            do {
                Segment segment = this.head;
                if (segment != null) {
                    byte[] bArr = segment.data;
                    int i3 = segment.pos;
                    int i4 = segment.limit;
                    while (true) {
                        if (i3 >= i4) {
                            break;
                        }
                        byte b = bArr[i3];
                        byte b2 = (byte) 48;
                        if (b < b2 || b > ((byte) 57)) {
                            byte b3 = (byte) 97;
                            if ((b >= b3 && b <= ((byte) 102)) || (b >= (b3 = (byte) 65) && b <= ((byte) 70))) {
                                i = (b - b3) + 10;
                            } else if (i2 == 0) {
                                z = true;
                            } else {
                                StringBuilder j2 = b2.j("Expected leading [0-9a-fA-F] character but was 0x");
                                j2.append(Util.toHexString(b));
                                throw new NumberFormatException(j2.toString());
                            }
                        } else {
                            i = b - b2;
                        }
                        if ((-1152921504606846976L & j) == 0) {
                            j = (j << 4) | ((long) i);
                            i3++;
                            i2++;
                        } else {
                            Buffer writeByte = new Buffer().writeHexadecimalUnsignedLong(j).writeByte((int) b);
                            StringBuilder j3 = b2.j("Number too large: ");
                            j3.append(writeByte.readUtf8());
                            throw new NumberFormatException(j3.toString());
                        }
                    }
                    if (i2 == 0) {
                    }
                } else {
                    g00.e();
                    throw null;
                }
            } while (this.head != null);
            setSize$okio(size() - ((long) i2));
            return j;
        }
        throw new EOFException();
    }

    @Override // okio.BufferedSource
    public int readInt() {
        if (size() >= 4) {
            Segment segment = this.head;
            if (segment != null) {
                int i = segment.pos;
                int i2 = segment.limit;
                if (((long) (i2 - i)) < 4) {
                    return ((readByte() & ExifInterface.MARKER) << 24) | ((readByte() & ExifInterface.MARKER) << 16) | ((readByte() & ExifInterface.MARKER) << 8) | (readByte() & ExifInterface.MARKER);
                }
                byte[] bArr = segment.data;
                int i3 = i + 1;
                int i4 = i3 + 1;
                int i5 = ((bArr[i] & ExifInterface.MARKER) << 24) | ((bArr[i3] & ExifInterface.MARKER) << 16);
                int i6 = i4 + 1;
                int i7 = i5 | ((bArr[i4] & ExifInterface.MARKER) << 8);
                int i8 = i6 + 1;
                int i9 = i7 | (bArr[i6] & ExifInterface.MARKER);
                setSize$okio(size() - 4);
                if (i8 == i2) {
                    this.head = segment.pop();
                    SegmentPool.INSTANCE.recycle(segment);
                } else {
                    segment.pos = i8;
                }
                return i9;
            }
            g00.e();
            throw null;
        }
        throw new EOFException();
    }

    @Override // okio.BufferedSource
    public int readIntLe() {
        return Util.reverseBytes(readInt());
    }

    @Override // okio.BufferedSource
    public long readLong() {
        if (size() >= 8) {
            Segment segment = this.head;
            if (segment != null) {
                int i = segment.pos;
                int i2 = segment.limit;
                if (((long) (i2 - i)) < 8) {
                    return ((((long) readInt()) & 4294967295L) << 32) | (4294967295L & ((long) readInt()));
                }
                byte[] bArr = segment.data;
                int i3 = i + 1;
                int i4 = i3 + 1;
                int i5 = i4 + 1;
                long j = ((((long) bArr[i]) & 255) << 56) | ((((long) bArr[i3]) & 255) << 48) | ((((long) bArr[i4]) & 255) << 40);
                int i6 = i5 + 1;
                long j2 = ((((long) bArr[i5]) & 255) << 32) | j;
                int i7 = i6 + 1;
                int i8 = i7 + 1;
                long j3 = j2 | ((((long) bArr[i6]) & 255) << 24) | ((((long) bArr[i7]) & 255) << 16);
                int i9 = i8 + 1;
                int i10 = i9 + 1;
                long j4 = j3 | ((((long) bArr[i8]) & 255) << 8) | (((long) bArr[i9]) & 255);
                setSize$okio(size() - 8);
                if (i10 == i2) {
                    this.head = segment.pop();
                    SegmentPool.INSTANCE.recycle(segment);
                } else {
                    segment.pos = i10;
                }
                return j4;
            }
            g00.e();
            throw null;
        }
        throw new EOFException();
    }

    @Override // okio.BufferedSource
    public long readLongLe() {
        return Util.reverseBytes(readLong());
    }

    @Override // okio.BufferedSource
    public short readShort() {
        if (size() >= 2) {
            Segment segment = this.head;
            if (segment != null) {
                int i = segment.pos;
                int i2 = segment.limit;
                if (i2 - i < 2) {
                    return (short) (((readByte() & ExifInterface.MARKER) << 8) | (readByte() & ExifInterface.MARKER));
                }
                byte[] bArr = segment.data;
                int i3 = i + 1;
                int i4 = i3 + 1;
                int i5 = ((bArr[i] & ExifInterface.MARKER) << 8) | (bArr[i3] & ExifInterface.MARKER);
                setSize$okio(size() - 2);
                if (i4 == i2) {
                    this.head = segment.pop();
                    SegmentPool.INSTANCE.recycle(segment);
                } else {
                    segment.pos = i4;
                }
                return (short) i5;
            }
            g00.e();
            throw null;
        }
        throw new EOFException();
    }

    @Override // okio.BufferedSource
    public short readShortLe() {
        return Util.reverseBytes(readShort());
    }

    @Override // okio.BufferedSource
    public String readString(Charset charset) {
        if (charset != null) {
            return readString(this.size, charset);
        }
        g00.f("charset");
        throw null;
    }

    public final UnsafeCursor readUnsafe() {
        return readUnsafe$default(this, null, 1, null);
    }

    public final UnsafeCursor readUnsafe(UnsafeCursor unsafeCursor) {
        if (unsafeCursor != null) {
            if (unsafeCursor.buffer == null) {
                unsafeCursor.buffer = this;
                unsafeCursor.readWrite = false;
                return unsafeCursor;
            }
            throw new IllegalStateException("already attached to a buffer".toString());
        }
        g00.f("unsafeCursor");
        throw null;
    }

    @Override // okio.BufferedSource
    public String readUtf8() {
        return readString(this.size, p00.a);
    }

    @Override // okio.BufferedSource
    public int readUtf8CodePoint() {
        int i;
        int i2;
        int i3;
        if (size() != 0) {
            byte b = getByte(0);
            if ((b & 128) == 0) {
                i3 = b & Byte.MAX_VALUE;
                i2 = 1;
                i = 0;
            } else if ((b & 224) == 192) {
                i3 = b & 31;
                i2 = 2;
                i = 128;
            } else if ((b & 240) == 224) {
                i3 = b & 15;
                i2 = 3;
                i = 2048;
            } else if ((b & 248) == 240) {
                i3 = b & 7;
                i2 = 4;
                i = 65536;
            } else {
                skip(1);
                return Utf8.REPLACEMENT_CODE_POINT;
            }
            long j = (long) i2;
            if (size() >= j) {
                for (int i4 = 1; i4 < i2; i4++) {
                    long j2 = (long) i4;
                    byte b2 = getByte(j2);
                    if ((b2 & 192) == 128) {
                        i3 = (i3 << 6) | (b2 & Utf8.REPLACEMENT_BYTE);
                    } else {
                        skip(j2);
                        return Utf8.REPLACEMENT_CODE_POINT;
                    }
                }
                skip(j);
                if (i3 > 1114111) {
                    return Utf8.REPLACEMENT_CODE_POINT;
                }
                if ((55296 <= i3 && 57343 >= i3) || i3 < i) {
                    return Utf8.REPLACEMENT_CODE_POINT;
                }
                return i3;
            }
            StringBuilder k = b2.k("size < ", i2, ": ");
            k.append(size());
            k.append(" (to read code point prefixed 0x");
            k.append(Util.toHexString(b));
            k.append(')');
            throw new EOFException(k.toString());
        }
        throw new EOFException();
    }

    @Override // okio.BufferedSource
    public String readUtf8Line() {
        long indexOf = indexOf((byte) 10);
        if (indexOf != -1) {
            return BufferKt.readUtf8Line(this, indexOf);
        }
        if (size() != 0) {
            return readUtf8(size());
        }
        return null;
    }

    @Override // okio.BufferedSource
    public String readUtf8LineStrict() {
        return readUtf8LineStrict(Long.MAX_VALUE);
    }

    @Override // okio.BufferedSource
    public boolean request(long j) {
        return this.size >= j;
    }

    @Override // okio.BufferedSource
    public void require(long j) {
        if (this.size < j) {
            throw new EOFException();
        }
    }

    @Override // okio.BufferedSource
    public int select(Options options) {
        if (options != null) {
            int selectPrefix$default = BufferKt.selectPrefix$default(this, options, false, 2, null);
            if (selectPrefix$default == -1) {
                return -1;
            }
            skip((long) options.getByteStrings$okio()[selectPrefix$default].size());
            return selectPrefix$default;
        }
        g00.f("options");
        throw null;
    }

    public final void setSize$okio(long j) {
        this.size = j;
    }

    public final ByteString sha1() {
        return digest("SHA-1");
    }

    public final ByteString sha256() {
        return digest(XWalkAppVersion.XWALK_APK_HASH_ALGORITHM);
    }

    public final ByteString sha512() {
        return digest("SHA-512");
    }

    public final long size() {
        return this.size;
    }

    @Override // okio.BufferedSource
    public void skip(long j) {
        while (j > 0) {
            Segment segment = this.head;
            if (segment != null) {
                int min = (int) Math.min(j, (long) (segment.limit - segment.pos));
                long j2 = (long) min;
                setSize$okio(size() - j2);
                j -= j2;
                int i = segment.pos + min;
                segment.pos = i;
                if (i == segment.limit) {
                    this.head = segment.pop();
                    SegmentPool.INSTANCE.recycle(segment);
                }
            } else {
                throw new EOFException();
            }
        }
    }

    public final ByteString snapshot() {
        if (size() <= ((long) Integer.MAX_VALUE)) {
            return snapshot((int) size());
        }
        StringBuilder j = b2.j("size > Int.MAX_VALUE: ");
        j.append(size());
        throw new IllegalStateException(j.toString().toString());
    }

    @Override // okio.Source, okio.Sink
    public Timeout timeout() {
        return Timeout.NONE;
    }

    public String toString() {
        return snapshot().toString();
    }

    public final Segment writableSegment$okio(int i) {
        boolean z = true;
        if (i < 1 || i > 8192) {
            z = false;
        }
        if (z) {
            Segment segment = this.head;
            if (segment == null) {
                Segment take = SegmentPool.INSTANCE.take();
                this.head = take;
                take.prev = take;
                take.next = take;
                return take;
            } else if (segment != null) {
                Segment segment2 = segment.prev;
                if (segment2 != null) {
                    return (segment2.limit + i > 8192 || !segment2.owner) ? segment2.push(SegmentPool.INSTANCE.take()) : segment2;
                }
                g00.e();
                throw null;
            } else {
                g00.e();
                throw null;
            }
        } else {
            throw new IllegalArgumentException("unexpected capacity".toString());
        }
    }

    @Override // okio.BufferedSink
    public long writeAll(Source source) {
        if (source != null) {
            long j = 0;
            while (true) {
                long read = source.read(this, (long) 8192);
                if (read == -1) {
                    return j;
                }
                j += read;
            }
        } else {
            g00.f("source");
            throw null;
        }
    }

    public final Buffer writeTo(OutputStream outputStream) {
        return writeTo$default(this, outputStream, 0, 2, null);
    }

    public final Buffer writeTo(OutputStream outputStream, long j) {
        if (outputStream != null) {
            Util.checkOffsetAndCount(this.size, 0, j);
            Segment segment = this.head;
            while (j > 0) {
                if (segment != null) {
                    int min = (int) Math.min(j, (long) (segment.limit - segment.pos));
                    outputStream.write(segment.data, segment.pos, min);
                    int i = segment.pos + min;
                    segment.pos = i;
                    long j2 = (long) min;
                    this.size -= j2;
                    j -= j2;
                    if (i == segment.limit) {
                        Segment pop = segment.pop();
                        this.head = pop;
                        SegmentPool.INSTANCE.recycle(segment);
                        segment = pop;
                    }
                } else {
                    g00.e();
                    throw null;
                }
            }
            return this;
        }
        g00.f("out");
        throw null;
    }

    @Override // java.lang.Object
    public Buffer clone() {
        return copy();
    }

    @Override // okio.BufferedSource
    public long indexOf(byte b, long j) {
        return indexOf(b, j, Long.MAX_VALUE);
    }

    @Override // okio.BufferedSource
    public byte[] readByteArray(long j) {
        if (!(j >= 0 && j <= ((long) Integer.MAX_VALUE))) {
            throw new IllegalArgumentException(b2.v("byteCount: ", j).toString());
        } else if (size() >= j) {
            byte[] bArr = new byte[((int) j)];
            readFully(bArr);
            return bArr;
        } else {
            throw new EOFException();
        }
    }

    @Override // okio.BufferedSource
    public ByteString readByteString(long j) {
        if (!(j >= 0 && j <= ((long) Integer.MAX_VALUE))) {
            throw new IllegalArgumentException(b2.v("byteCount: ", j).toString());
        } else if (size() < j) {
            throw new EOFException();
        } else if (j < ((long) 4096)) {
            return new ByteString(readByteArray(j));
        } else {
            ByteString snapshot = snapshot((int) j);
            skip(j);
            return snapshot;
        }
    }

    @Override // okio.BufferedSource
    public String readUtf8(long j) {
        return readString(j, p00.a);
    }

    @Override // okio.BufferedSource
    public String readUtf8LineStrict(long j) {
        if (j >= 0) {
            long j2 = Long.MAX_VALUE;
            if (j != Long.MAX_VALUE) {
                j2 = j + 1;
            }
            byte b = (byte) 10;
            long indexOf = indexOf(b, 0, j2);
            if (indexOf != -1) {
                return BufferKt.readUtf8Line(this, indexOf);
            }
            if (j2 < size() && getByte(j2 - 1) == ((byte) 13) && getByte(j2) == b) {
                return BufferKt.readUtf8Line(this, j2);
            }
            Buffer buffer = new Buffer();
            copyTo(buffer, 0, Math.min((long) 32, size()));
            throw new EOFException("\\n not found: limit=" + Math.min(size(), j) + " content=" + buffer.readByteString().hex() + (char) 8230);
        }
        throw new IllegalArgumentException(b2.v("limit < 0: ", j).toString());
    }

    @Override // okio.BufferedSink
    public Buffer writeByte(int i) {
        Segment writableSegment$okio = writableSegment$okio(1);
        byte[] bArr = writableSegment$okio.data;
        int i2 = writableSegment$okio.limit;
        writableSegment$okio.limit = i2 + 1;
        bArr[i2] = (byte) i;
        setSize$okio(size() + 1);
        return this;
    }

    @Override // okio.BufferedSink
    public Buffer writeDecimalLong(long j) {
        if (j == 0) {
            return writeByte(48);
        }
        boolean z = false;
        int i = 1;
        if (j < 0) {
            j = -j;
            if (j < 0) {
                return writeUtf8("-9223372036854775808");
            }
            z = true;
        }
        if (j >= 100000000) {
            i = j < 1000000000000L ? j < 10000000000L ? j < 1000000000 ? 9 : 10 : j < 100000000000L ? 11 : 12 : j < 1000000000000000L ? j < 10000000000000L ? 13 : j < 100000000000000L ? 14 : 15 : j < 100000000000000000L ? j < 10000000000000000L ? 16 : 17 : j < 1000000000000000000L ? 18 : 19;
        } else if (j >= 10000) {
            i = j < 1000000 ? j < IndexSeeker.MIN_TIME_BETWEEN_POINTS_US ? 5 : 6 : j < 10000000 ? 7 : 8;
        } else if (j >= 100) {
            i = j < 1000 ? 3 : 4;
        } else if (j >= 10) {
            i = 2;
        }
        if (z) {
            i++;
        }
        Segment writableSegment$okio = writableSegment$okio(i);
        byte[] bArr = writableSegment$okio.data;
        int i2 = writableSegment$okio.limit + i;
        while (j != 0) {
            long j2 = (long) 10;
            i2--;
            bArr[i2] = BufferKt.getHEX_DIGIT_BYTES()[(int) (j % j2)];
            j /= j2;
        }
        if (z) {
            bArr[i2 - 1] = (byte) 45;
        }
        writableSegment$okio.limit += i;
        setSize$okio(size() + ((long) i));
        return this;
    }

    @Override // okio.BufferedSink
    public Buffer writeHexadecimalUnsignedLong(long j) {
        if (j == 0) {
            return writeByte(48);
        }
        long j2 = (j >>> 1) | j;
        long j3 = j2 | (j2 >>> 2);
        long j4 = j3 | (j3 >>> 4);
        long j5 = j4 | (j4 >>> 8);
        long j6 = j5 | (j5 >>> 16);
        long j7 = j6 | (j6 >>> 32);
        long j8 = j7 - ((j7 >>> 1) & 6148914691236517205L);
        long j9 = ((j8 >>> 2) & 3689348814741910323L) + (j8 & 3689348814741910323L);
        long j10 = ((j9 >>> 4) + j9) & 1085102592571150095L;
        long j11 = j10 + (j10 >>> 8);
        long j12 = j11 + (j11 >>> 16);
        int i = (int) ((((j12 & 63) + ((j12 >>> 32) & 63)) + ((long) 3)) / ((long) 4));
        Segment writableSegment$okio = writableSegment$okio(i);
        byte[] bArr = writableSegment$okio.data;
        int i2 = writableSegment$okio.limit;
        for (int i3 = (i2 + i) - 1; i3 >= i2; i3--) {
            bArr[i3] = BufferKt.getHEX_DIGIT_BYTES()[(int) (15 & j)];
            j >>>= 4;
        }
        writableSegment$okio.limit += i;
        setSize$okio(size() + ((long) i));
        return this;
    }

    @Override // okio.BufferedSink
    public Buffer writeInt(int i) {
        Segment writableSegment$okio = writableSegment$okio(4);
        byte[] bArr = writableSegment$okio.data;
        int i2 = writableSegment$okio.limit;
        int i3 = i2 + 1;
        bArr[i2] = (byte) ((i >>> 24) & 255);
        int i4 = i3 + 1;
        bArr[i3] = (byte) ((i >>> 16) & 255);
        int i5 = i4 + 1;
        bArr[i4] = (byte) ((i >>> 8) & 255);
        bArr[i5] = (byte) (i & 255);
        writableSegment$okio.limit = i5 + 1;
        setSize$okio(size() + 4);
        return this;
    }

    @Override // okio.BufferedSink
    public Buffer writeIntLe(int i) {
        return writeInt(Util.reverseBytes(i));
    }

    @Override // okio.BufferedSink
    public Buffer writeLong(long j) {
        Segment writableSegment$okio = writableSegment$okio(8);
        byte[] bArr = writableSegment$okio.data;
        int i = writableSegment$okio.limit;
        int i2 = i + 1;
        bArr[i] = (byte) ((int) ((j >>> 56) & 255));
        int i3 = i2 + 1;
        bArr[i2] = (byte) ((int) ((j >>> 48) & 255));
        int i4 = i3 + 1;
        bArr[i3] = (byte) ((int) ((j >>> 40) & 255));
        int i5 = i4 + 1;
        bArr[i4] = (byte) ((int) ((j >>> 32) & 255));
        int i6 = i5 + 1;
        bArr[i5] = (byte) ((int) ((j >>> 24) & 255));
        int i7 = i6 + 1;
        bArr[i6] = (byte) ((int) ((j >>> 16) & 255));
        int i8 = i7 + 1;
        bArr[i7] = (byte) ((int) ((j >>> 8) & 255));
        bArr[i8] = (byte) ((int) (j & 255));
        writableSegment$okio.limit = i8 + 1;
        setSize$okio(size() + 8);
        return this;
    }

    @Override // okio.BufferedSink
    public Buffer writeLongLe(long j) {
        return writeLong(Util.reverseBytes(j));
    }

    @Override // okio.BufferedSink
    public Buffer writeShort(int i) {
        Segment writableSegment$okio = writableSegment$okio(2);
        byte[] bArr = writableSegment$okio.data;
        int i2 = writableSegment$okio.limit;
        int i3 = i2 + 1;
        bArr[i2] = (byte) ((i >>> 8) & 255);
        bArr[i3] = (byte) (i & 255);
        writableSegment$okio.limit = i3 + 1;
        setSize$okio(size() + 2);
        return this;
    }

    @Override // okio.BufferedSink
    public Buffer writeShortLe(int i) {
        return writeShort((int) Util.reverseBytes((short) i));
    }

    @Override // okio.BufferedSink
    public Buffer writeUtf8CodePoint(int i) {
        if (i < 128) {
            writeByte(i);
        } else if (i < 2048) {
            Segment writableSegment$okio = writableSegment$okio(2);
            byte[] bArr = writableSegment$okio.data;
            int i2 = writableSegment$okio.limit;
            bArr[i2] = (byte) ((i >> 6) | PsExtractor.AUDIO_STREAM);
            bArr[i2 + 1] = (byte) ((i & 63) | 128);
            writableSegment$okio.limit = i2 + 2;
            setSize$okio(size() + 2);
        } else if (55296 <= i && 57343 >= i) {
            writeByte(63);
        } else if (i < 65536) {
            Segment writableSegment$okio2 = writableSegment$okio(3);
            byte[] bArr2 = writableSegment$okio2.data;
            int i3 = writableSegment$okio2.limit;
            bArr2[i3] = (byte) ((i >> 12) | 224);
            bArr2[i3 + 1] = (byte) (((i >> 6) & 63) | 128);
            bArr2[i3 + 2] = (byte) ((i & 63) | 128);
            writableSegment$okio2.limit = i3 + 3;
            setSize$okio(size() + 3);
        } else if (i <= 1114111) {
            Segment writableSegment$okio3 = writableSegment$okio(4);
            byte[] bArr3 = writableSegment$okio3.data;
            int i4 = writableSegment$okio3.limit;
            bArr3[i4] = (byte) ((i >> 18) | PsExtractor.VIDEO_STREAM_MASK);
            bArr3[i4 + 1] = (byte) (((i >> 12) & 63) | 128);
            bArr3[i4 + 2] = (byte) (((i >> 6) & 63) | 128);
            bArr3[i4 + 3] = (byte) ((i & 63) | 128);
            writableSegment$okio3.limit = i4 + 4;
            setSize$okio(size() + 4);
        } else {
            StringBuilder j = b2.j("Unexpected code point: 0x");
            j.append(Util.toHexString(i));
            throw new IllegalArgumentException(j.toString());
        }
        return this;
    }

    @Override // okio.BufferedSource
    public long indexOf(ByteString byteString) {
        if (byteString != null) {
            return indexOf(byteString, 0);
        }
        g00.f("bytes");
        throw null;
    }

    @Override // okio.BufferedSource
    public long indexOfElement(ByteString byteString, long j) {
        int i;
        int i2;
        if (byteString != null) {
            long j2 = 0;
            if (j >= 0) {
                Segment segment = this.head;
                if (segment == null) {
                    return -1;
                }
                if (size() - j < j) {
                    j2 = size();
                    while (j2 > j) {
                        segment = segment.prev;
                        if (segment != null) {
                            j2 -= (long) (segment.limit - segment.pos);
                        } else {
                            g00.e();
                            throw null;
                        }
                    }
                    if (byteString.size() == 2) {
                        byte b = byteString.getByte(0);
                        byte b2 = byteString.getByte(1);
                        while (j2 < size()) {
                            byte[] bArr = segment.data;
                            i = (int) ((((long) segment.pos) + j) - j2);
                            int i3 = segment.limit;
                            while (i < i3) {
                                byte b3 = bArr[i];
                                if (!(b3 == b || b3 == b2)) {
                                    i++;
                                }
                            }
                            j2 += (long) (segment.limit - segment.pos);
                            segment = segment.next;
                            if (segment != null) {
                                j = j2;
                            } else {
                                g00.e();
                                throw null;
                            }
                        }
                        return -1;
                    }
                    byte[] internalArray$okio = byteString.internalArray$okio();
                    while (j2 < size()) {
                        byte[] bArr2 = segment.data;
                        i = (int) ((((long) segment.pos) + j) - j2);
                        int i4 = segment.limit;
                        while (i < i4) {
                            byte b4 = bArr2[i];
                            for (byte b5 : internalArray$okio) {
                                if (b4 == b5) {
                                    i2 = segment.pos;
                                    return ((long) (i - i2)) + j2;
                                }
                            }
                            i++;
                        }
                        j2 += (long) (segment.limit - segment.pos);
                        segment = segment.next;
                        if (segment != null) {
                            j = j2;
                        } else {
                            g00.e();
                            throw null;
                        }
                    }
                    return -1;
                }
                while (true) {
                    long j3 = ((long) (segment.limit - segment.pos)) + j2;
                    if (j3 <= j) {
                        segment = segment.next;
                        if (segment != null) {
                            j2 = j3;
                        } else {
                            g00.e();
                            throw null;
                        }
                    } else if (byteString.size() == 2) {
                        byte b6 = byteString.getByte(0);
                        byte b7 = byteString.getByte(1);
                        while (j2 < size()) {
                            byte[] bArr3 = segment.data;
                            i = (int) ((((long) segment.pos) + j) - j2);
                            int i5 = segment.limit;
                            while (i < i5) {
                                byte b8 = bArr3[i];
                                if (!(b8 == b6 || b8 == b7)) {
                                    i++;
                                }
                            }
                            j2 += (long) (segment.limit - segment.pos);
                            segment = segment.next;
                            if (segment != null) {
                                j = j2;
                            } else {
                                g00.e();
                                throw null;
                            }
                        }
                        return -1;
                    } else {
                        byte[] internalArray$okio2 = byteString.internalArray$okio();
                        while (j2 < size()) {
                            byte[] bArr4 = segment.data;
                            i = (int) ((((long) segment.pos) + j) - j2);
                            int i6 = segment.limit;
                            while (i < i6) {
                                byte b9 = bArr4[i];
                                for (byte b10 : internalArray$okio2) {
                                    if (b9 != b10) {
                                    }
                                }
                                i++;
                            }
                            j2 += (long) (segment.limit - segment.pos);
                            segment = segment.next;
                            if (segment != null) {
                                j = j2;
                            } else {
                                g00.e();
                                throw null;
                            }
                        }
                        return -1;
                    }
                }
                i2 = segment.pos;
                return ((long) (i - i2)) + j2;
                i2 = segment.pos;
                return ((long) (i - i2)) + j2;
            }
            throw new IllegalArgumentException(b2.v("fromIndex < 0: ", j).toString());
        }
        g00.f("targetBytes");
        throw null;
    }

    @Override // okio.BufferedSource
    public boolean rangeEquals(long j, ByteString byteString, int i, int i2) {
        if (byteString == null) {
            g00.f("bytes");
            throw null;
        } else if (j < 0 || i < 0 || i2 < 0 || size() - j < ((long) i2) || byteString.size() - i < i2) {
            return false;
        } else {
            for (int i3 = 0; i3 < i2; i3++) {
                if (getByte(((long) i3) + j) != byteString.getByte(i + i3)) {
                    return false;
                }
            }
            return true;
        }
    }

    public final Buffer readFrom(InputStream inputStream, long j) {
        if (inputStream != null) {
            if (j >= 0) {
                readFrom(inputStream, j, false);
                return this;
            }
            throw new IllegalArgumentException(b2.v("byteCount < 0: ", j).toString());
        }
        g00.f("input");
        throw null;
    }

    @Override // okio.BufferedSource
    public String readString(long j, Charset charset) {
        if (charset != null) {
            if (!(j >= 0 && j <= ((long) Integer.MAX_VALUE))) {
                throw new IllegalArgumentException(b2.v("byteCount: ", j).toString());
            } else if (this.size < j) {
                throw new EOFException();
            } else if (j == 0) {
                return "";
            } else {
                Segment segment = this.head;
                if (segment != null) {
                    int i = segment.pos;
                    if (((long) i) + j > ((long) segment.limit)) {
                        return new String(readByteArray(j), charset);
                    }
                    int i2 = (int) j;
                    String str = new String(segment.data, i, i2, charset);
                    int i3 = segment.pos + i2;
                    segment.pos = i3;
                    this.size -= j;
                    if (i3 == segment.limit) {
                        this.head = segment.pop();
                        SegmentPool.INSTANCE.recycle(segment);
                    }
                    return str;
                }
                g00.e();
                throw null;
            }
        } else {
            g00.f("charset");
            throw null;
        }
    }

    @Override // okio.BufferedSink
    public Buffer writeString(String str, Charset charset) {
        if (str == null) {
            g00.f("string");
            throw null;
        } else if (charset != null) {
            return writeString(str, 0, str.length(), charset);
        } else {
            g00.f("charset");
            throw null;
        }
    }

    @Override // okio.BufferedSink
    public Buffer writeUtf8(String str) {
        if (str != null) {
            return writeUtf8(str, 0, str.length());
        }
        g00.f("string");
        throw null;
    }

    public final ByteString snapshot(int i) {
        if (i == 0) {
            return ByteString.EMPTY;
        }
        Util.checkOffsetAndCount(size(), 0, (long) i);
        Segment segment = this.head;
        int i2 = 0;
        int i3 = 0;
        int i4 = 0;
        while (i3 < i) {
            if (segment != null) {
                int i5 = segment.limit;
                int i6 = segment.pos;
                if (i5 != i6) {
                    i3 += i5 - i6;
                    i4++;
                    segment = segment.next;
                } else {
                    throw new AssertionError("s.limit == s.pos");
                }
            } else {
                g00.e();
                throw null;
            }
        }
        byte[][] bArr = new byte[i4][];
        int[] iArr = new int[(i4 * 2)];
        Segment segment2 = this.head;
        int i7 = 0;
        while (i2 < i) {
            if (segment2 != null) {
                bArr[i7] = segment2.data;
                i2 += segment2.limit - segment2.pos;
                iArr[i7] = Math.min(i2, i);
                iArr[i7 + i4] = segment2.pos;
                segment2.shared = true;
                i7++;
                segment2 = segment2.next;
            } else {
                g00.e();
                throw null;
            }
        }
        return new SegmentedByteString(bArr, iArr);
    }

    @Override // okio.BufferedSource
    public long indexOf(byte b, long j, long j2) {
        Segment segment;
        int i;
        long j3 = 0;
        if (0 <= j && j2 >= j) {
            if (j2 > size()) {
                j2 = size();
            }
            if (!(j == j2 || (segment = this.head) == null)) {
                if (size() - j < j) {
                    j3 = size();
                    while (j3 > j) {
                        segment = segment.prev;
                        if (segment != null) {
                            j3 -= (long) (segment.limit - segment.pos);
                        } else {
                            g00.e();
                            throw null;
                        }
                    }
                    while (j3 < j2) {
                        byte[] bArr = segment.data;
                        int min = (int) Math.min((long) segment.limit, (((long) segment.pos) + j2) - j3);
                        i = (int) ((((long) segment.pos) + j) - j3);
                        while (i < min) {
                            if (bArr[i] != b) {
                                i++;
                            }
                        }
                        j3 += (long) (segment.limit - segment.pos);
                        segment = segment.next;
                        if (segment != null) {
                            j = j3;
                        } else {
                            g00.e();
                            throw null;
                        }
                    }
                } else {
                    while (true) {
                        long j4 = ((long) (segment.limit - segment.pos)) + j3;
                        if (j4 > j) {
                            while (j3 < j2) {
                                byte[] bArr2 = segment.data;
                                int min2 = (int) Math.min((long) segment.limit, (((long) segment.pos) + j2) - j3);
                                i = (int) ((((long) segment.pos) + j) - j3);
                                while (i < min2) {
                                    if (bArr2[i] != b) {
                                        i++;
                                    }
                                }
                                j3 += (long) (segment.limit - segment.pos);
                                segment = segment.next;
                                if (segment != null) {
                                    j = j3;
                                } else {
                                    g00.e();
                                    throw null;
                                }
                            }
                        } else {
                            segment = segment.next;
                            if (segment != null) {
                                j3 = j4;
                            } else {
                                g00.e();
                                throw null;
                            }
                        }
                    }
                }
                return ((long) (i - segment.pos)) + j3;
            }
            return -1;
        }
        StringBuilder j5 = b2.j("size=");
        j5.append(size());
        j5.append(" fromIndex=");
        j5.append(j);
        j5.append(" toIndex=");
        j5.append(j2);
        throw new IllegalArgumentException(j5.toString().toString());
    }

    @Override // okio.BufferedSink
    public Buffer writeString(String str, int i, int i2, Charset charset) {
        if (str == null) {
            g00.f("string");
            throw null;
        } else if (charset != null) {
            boolean z = true;
            if (i >= 0) {
                if (i2 >= i) {
                    if (i2 > str.length()) {
                        z = false;
                    }
                    if (!z) {
                        StringBuilder k = b2.k("endIndex > string.length: ", i2, " > ");
                        k.append(str.length());
                        throw new IllegalArgumentException(k.toString().toString());
                    } else if (g00.a(charset, p00.a)) {
                        return writeUtf8(str, i, i2);
                    } else {
                        String substring = str.substring(i, i2);
                        g00.b(substring, "(this as java.lang.Strin…ing(startIndex, endIndex)");
                        byte[] bytes = substring.getBytes(charset);
                        g00.b(bytes, "(this as java.lang.String).getBytes(charset)");
                        return write(bytes, 0, bytes.length);
                    }
                } else {
                    throw new IllegalArgumentException(("endIndex < beginIndex: " + i2 + " < " + i).toString());
                }
            } else {
                throw new IllegalArgumentException(b2.t("beginIndex < 0: ", i).toString());
            }
        } else {
            g00.f("charset");
            throw null;
        }
    }

    @Override // okio.BufferedSink
    public Buffer writeUtf8(String str, int i, int i2) {
        char charAt;
        if (str != null) {
            if (i >= 0) {
                if (i2 >= i) {
                    if (i2 <= str.length()) {
                        while (i < i2) {
                            char charAt2 = str.charAt(i);
                            if (charAt2 < 128) {
                                Segment writableSegment$okio = writableSegment$okio(1);
                                byte[] bArr = writableSegment$okio.data;
                                int i3 = writableSegment$okio.limit - i;
                                int min = Math.min(i2, 8192 - i3);
                                int i4 = i + 1;
                                bArr[i + i3] = (byte) charAt2;
                                while (true) {
                                    i = i4;
                                    if (i >= min || (charAt = str.charAt(i)) >= 128) {
                                        int i5 = writableSegment$okio.limit;
                                        int i6 = (i3 + i) - i5;
                                        writableSegment$okio.limit = i5 + i6;
                                        setSize$okio(size() + ((long) i6));
                                    } else {
                                        i4 = i + 1;
                                        bArr[i + i3] = (byte) charAt;
                                    }
                                }
                                int i52 = writableSegment$okio.limit;
                                int i62 = (i3 + i) - i52;
                                writableSegment$okio.limit = i52 + i62;
                                setSize$okio(size() + ((long) i62));
                            } else {
                                if (charAt2 < 2048) {
                                    Segment writableSegment$okio2 = writableSegment$okio(2);
                                    byte[] bArr2 = writableSegment$okio2.data;
                                    int i7 = writableSegment$okio2.limit;
                                    bArr2[i7] = (byte) ((charAt2 >> 6) | PsExtractor.AUDIO_STREAM);
                                    bArr2[i7 + 1] = (byte) ((charAt2 & '?') | 128);
                                    writableSegment$okio2.limit = i7 + 2;
                                    setSize$okio(size() + 2);
                                } else if (charAt2 < 55296 || charAt2 > 57343) {
                                    Segment writableSegment$okio3 = writableSegment$okio(3);
                                    byte[] bArr3 = writableSegment$okio3.data;
                                    int i8 = writableSegment$okio3.limit;
                                    bArr3[i8] = (byte) ((charAt2 >> '\f') | 224);
                                    bArr3[i8 + 1] = (byte) ((63 & (charAt2 >> 6)) | 128);
                                    bArr3[i8 + 2] = (byte) ((charAt2 & '?') | 128);
                                    writableSegment$okio3.limit = i8 + 3;
                                    setSize$okio(size() + 3);
                                } else {
                                    int i9 = i + 1;
                                    char charAt3 = i9 < i2 ? str.charAt(i9) : 0;
                                    if (charAt2 > 56319 || 56320 > charAt3 || 57343 < charAt3) {
                                        writeByte(63);
                                        i = i9;
                                    } else {
                                        int i10 = (((charAt2 & 1023) << 10) | (charAt3 & 1023)) + 65536;
                                        Segment writableSegment$okio4 = writableSegment$okio(4);
                                        byte[] bArr4 = writableSegment$okio4.data;
                                        int i11 = writableSegment$okio4.limit;
                                        bArr4[i11] = (byte) ((i10 >> 18) | PsExtractor.VIDEO_STREAM_MASK);
                                        bArr4[i11 + 1] = (byte) (((i10 >> 12) & 63) | 128);
                                        bArr4[i11 + 2] = (byte) (((i10 >> 6) & 63) | 128);
                                        bArr4[i11 + 3] = (byte) ((i10 & 63) | 128);
                                        writableSegment$okio4.limit = i11 + 4;
                                        setSize$okio(size() + 4);
                                        i += 2;
                                    }
                                }
                                i++;
                            }
                        }
                        return this;
                    }
                    StringBuilder k = b2.k("endIndex > string.length: ", i2, " > ");
                    k.append(str.length());
                    throw new IllegalArgumentException(k.toString().toString());
                }
                throw new IllegalArgumentException(("endIndex < beginIndex: " + i2 + " < " + i).toString());
            }
            throw new IllegalArgumentException(b2.t("beginIndex < 0: ", i).toString());
        }
        g00.f("string");
        throw null;
    }

    private final void readFrom(InputStream inputStream, long j, boolean z) {
        while (true) {
            if (j > 0 || z) {
                Segment writableSegment$okio = writableSegment$okio(1);
                int read = inputStream.read(writableSegment$okio.data, writableSegment$okio.limit, (int) Math.min(j, (long) (8192 - writableSegment$okio.limit)));
                if (read == -1) {
                    if (writableSegment$okio.pos == writableSegment$okio.limit) {
                        this.head = writableSegment$okio.pop();
                        SegmentPool.INSTANCE.recycle(writableSegment$okio);
                    }
                    if (!z) {
                        throw new EOFException();
                    }
                    return;
                }
                writableSegment$okio.limit += read;
                long j2 = (long) read;
                this.size += j2;
                j -= j2;
            } else {
                return;
            }
        }
    }

    @Override // okio.BufferedSource
    public void readFully(byte[] bArr) {
        if (bArr != null) {
            int i = 0;
            while (i < bArr.length) {
                int read = read(bArr, i, bArr.length - i);
                if (read != -1) {
                    i += read;
                } else {
                    throw new EOFException();
                }
            }
            return;
        }
        g00.f("sink");
        throw null;
    }

    @Override // java.nio.channels.WritableByteChannel
    public int write(ByteBuffer byteBuffer) {
        if (byteBuffer != null) {
            int remaining = byteBuffer.remaining();
            int i = remaining;
            while (i > 0) {
                Segment writableSegment$okio = writableSegment$okio(1);
                int min = Math.min(i, 8192 - writableSegment$okio.limit);
                byteBuffer.get(writableSegment$okio.data, writableSegment$okio.limit, min);
                i -= min;
                writableSegment$okio.limit += min;
            }
            this.size += (long) remaining;
            return remaining;
        }
        g00.f("source");
        throw null;
    }

    @Override // okio.BufferedSource
    public int read(byte[] bArr) {
        if (bArr != null) {
            return read(bArr, 0, bArr.length);
        }
        g00.f("sink");
        throw null;
    }

    @Override // okio.BufferedSource
    public int read(byte[] bArr, int i, int i2) {
        if (bArr != null) {
            Util.checkOffsetAndCount((long) bArr.length, (long) i, (long) i2);
            Segment segment = this.head;
            if (segment == null) {
                return -1;
            }
            int min = Math.min(i2, segment.limit - segment.pos);
            byte[] bArr2 = segment.data;
            int i3 = segment.pos;
            xz.a(bArr2, bArr, i, i3, i3 + min);
            segment.pos += min;
            setSize$okio(size() - ((long) min));
            if (segment.pos != segment.limit) {
                return min;
            }
            this.head = segment.pop();
            SegmentPool.INSTANCE.recycle(segment);
            return min;
        }
        g00.f("sink");
        throw null;
    }

    public final Buffer copyTo(Buffer buffer, long j) {
        if (buffer != null) {
            return copyTo(buffer, j, this.size - j);
        }
        g00.f("out");
        throw null;
    }

    @Override // okio.BufferedSink
    public Buffer write(ByteString byteString) {
        if (byteString != null) {
            byteString.write$okio(this, 0, byteString.size());
            return this;
        }
        g00.f("byteString");
        throw null;
    }

    public final Buffer copyTo(Buffer buffer, long j, long j2) {
        if (buffer != null) {
            Util.checkOffsetAndCount(size(), j, j2);
            if (j2 != 0) {
                buffer.setSize$okio(buffer.size() + j2);
                Segment segment = this.head;
                while (segment != null) {
                    int i = segment.limit;
                    int i2 = segment.pos;
                    if (j >= ((long) (i - i2))) {
                        j -= (long) (i - i2);
                        segment = segment.next;
                    } else {
                        while (j2 > 0) {
                            if (segment != null) {
                                Segment sharedCopy = segment.sharedCopy();
                                int i3 = sharedCopy.pos + ((int) j);
                                sharedCopy.pos = i3;
                                sharedCopy.limit = Math.min(i3 + ((int) j2), sharedCopy.limit);
                                Segment segment2 = buffer.head;
                                if (segment2 == null) {
                                    sharedCopy.prev = sharedCopy;
                                    sharedCopy.next = sharedCopy;
                                    buffer.head = sharedCopy;
                                } else if (segment2 != null) {
                                    Segment segment3 = segment2.prev;
                                    if (segment3 != null) {
                                        segment3.push(sharedCopy);
                                    } else {
                                        g00.e();
                                        throw null;
                                    }
                                } else {
                                    g00.e();
                                    throw null;
                                }
                                j2 -= (long) (sharedCopy.limit - sharedCopy.pos);
                                segment = segment.next;
                                j = 0;
                            } else {
                                g00.e();
                                throw null;
                            }
                        }
                    }
                }
                g00.e();
                throw null;
            }
            return this;
        }
        g00.f("out");
        throw null;
    }

    @Override // okio.BufferedSink
    public Buffer write(ByteString byteString, int i, int i2) {
        if (byteString != null) {
            byteString.write$okio(this, i, i2);
            return this;
        }
        g00.f("byteString");
        throw null;
    }

    @Override // okio.BufferedSink
    public Buffer write(byte[] bArr) {
        if (bArr != null) {
            return write(bArr, 0, bArr.length);
        }
        g00.f("source");
        throw null;
    }

    @Override // okio.BufferedSink
    public Buffer write(byte[] bArr, int i, int i2) {
        if (bArr != null) {
            long j = (long) i2;
            Util.checkOffsetAndCount((long) bArr.length, (long) i, j);
            int i3 = i2 + i;
            while (i < i3) {
                Segment writableSegment$okio = writableSegment$okio(1);
                int min = Math.min(i3 - i, 8192 - writableSegment$okio.limit);
                int i4 = i + min;
                xz.a(bArr, writableSegment$okio.data, writableSegment$okio.limit, i, i4);
                writableSegment$okio.limit += min;
                i = i4;
            }
            setSize$okio(size() + j);
            return this;
        }
        g00.f("source");
        throw null;
    }

    @Override // okio.Source
    public long read(Buffer buffer, long j) {
        if (buffer != null) {
            if (!(j >= 0)) {
                throw new IllegalArgumentException(b2.v("byteCount < 0: ", j).toString());
            } else if (size() == 0) {
                return -1;
            } else {
                if (j > size()) {
                    j = size();
                }
                buffer.write(this, j);
                return j;
            }
        } else {
            g00.f("sink");
            throw null;
        }
    }

    @Override // okio.BufferedSource
    public long indexOf(ByteString byteString, long j) {
        int i;
        long j2 = j;
        if (byteString != null) {
            if (byteString.size() > 0) {
                long j3 = 0;
                if (j2 >= 0) {
                    Segment segment = this.head;
                    if (segment != null) {
                        if (size() - j2 < j2) {
                            long size2 = size();
                            while (size2 > j2) {
                                segment = segment.prev;
                                if (segment != null) {
                                    size2 -= (long) (segment.limit - segment.pos);
                                } else {
                                    g00.e();
                                    throw null;
                                }
                            }
                            byte[] internalArray$okio = byteString.internalArray$okio();
                            byte b = internalArray$okio[0];
                            int size3 = byteString.size();
                            j3 = size2;
                            for (long size4 = (size() - ((long) size3)) + 1; j3 < size4; size4 = size4) {
                                byte[] bArr = segment.data;
                                int min = (int) Math.min((long) segment.limit, (((long) segment.pos) + size4) - j3);
                                i = (int) ((((long) segment.pos) + j2) - j3);
                                while (i < min) {
                                    if (bArr[i] == b) {
                                        if (BufferKt.rangeEquals(segment, i + 1, internalArray$okio, 1, size3)) {
                                        }
                                    }
                                    i++;
                                }
                                j3 += (long) (segment.limit - segment.pos);
                                segment = segment.next;
                                if (segment != null) {
                                    j2 = j3;
                                } else {
                                    g00.e();
                                    throw null;
                                }
                            }
                        } else {
                            while (true) {
                                long j4 = ((long) (segment.limit - segment.pos)) + j3;
                                if (j4 > j2) {
                                    byte[] internalArray$okio2 = byteString.internalArray$okio();
                                    byte b2 = internalArray$okio2[0];
                                    int size5 = byteString.size();
                                    for (long size6 = (size() - ((long) size5)) + 1; j3 < size6; size6 = size6) {
                                        byte[] bArr2 = segment.data;
                                        int min2 = (int) Math.min((long) segment.limit, (((long) segment.pos) + size6) - j3);
                                        i = (int) ((((long) segment.pos) + j2) - j3);
                                        while (i < min2) {
                                            if (bArr2[i] != b2 || !BufferKt.rangeEquals(segment, i + 1, internalArray$okio2, 1, size5)) {
                                                i++;
                                            }
                                        }
                                        j3 += (long) (segment.limit - segment.pos);
                                        segment = segment.next;
                                        if (segment != null) {
                                            j2 = j3;
                                        } else {
                                            g00.e();
                                            throw null;
                                        }
                                    }
                                } else {
                                    segment = segment.next;
                                    if (segment != null) {
                                        j3 = j4;
                                    } else {
                                        g00.e();
                                        throw null;
                                    }
                                }
                            }
                        }
                        return ((long) (i - segment.pos)) + j3;
                    }
                    return -1;
                }
                throw new IllegalArgumentException(b2.v("fromIndex < 0: ", j2).toString());
            }
            throw new IllegalArgumentException("bytes is empty".toString());
        }
        g00.f("bytes");
        throw null;
    }

    @Override // okio.BufferedSink
    public Buffer write(Source source, long j) {
        if (source != null) {
            while (j > 0) {
                long read = source.read(this, j);
                if (read != -1) {
                    j -= read;
                } else {
                    throw new EOFException();
                }
            }
            return this;
        }
        g00.f("source");
        throw null;
    }

    @Override // okio.Sink
    public void write(Buffer buffer, long j) {
        Segment segment;
        if (buffer != null) {
            if (buffer != this) {
                Util.checkOffsetAndCount(buffer.size(), 0, j);
                while (j > 0) {
                    Segment segment2 = buffer.head;
                    if (segment2 != null) {
                        int i = segment2.limit;
                        if (segment2 != null) {
                            if (j < ((long) (i - segment2.pos))) {
                                Segment segment3 = this.head;
                                if (segment3 == null) {
                                    segment = null;
                                } else if (segment3 != null) {
                                    segment = segment3.prev;
                                } else {
                                    g00.e();
                                    throw null;
                                }
                                if (segment != null && segment.owner) {
                                    if ((((long) segment.limit) + j) - ((long) (segment.shared ? 0 : segment.pos)) <= ((long) 8192)) {
                                        if (segment2 != null) {
                                            segment2.writeTo(segment, (int) j);
                                            buffer.setSize$okio(buffer.size() - j);
                                            setSize$okio(size() + j);
                                            return;
                                        }
                                        g00.e();
                                        throw null;
                                    }
                                }
                                if (segment2 != null) {
                                    buffer.head = segment2.split((int) j);
                                } else {
                                    g00.e();
                                    throw null;
                                }
                            }
                            Segment segment4 = buffer.head;
                            if (segment4 != null) {
                                long j2 = (long) (segment4.limit - segment4.pos);
                                buffer.head = segment4.pop();
                                Segment segment5 = this.head;
                                if (segment5 == null) {
                                    this.head = segment4;
                                    segment4.prev = segment4;
                                    segment4.next = segment4;
                                } else if (segment5 != null) {
                                    Segment segment6 = segment5.prev;
                                    if (segment6 != null) {
                                        segment6.push(segment4).compact();
                                    } else {
                                        g00.e();
                                        throw null;
                                    }
                                } else {
                                    g00.e();
                                    throw null;
                                }
                                buffer.setSize$okio(buffer.size() - j2);
                                setSize$okio(size() + j2);
                                j -= j2;
                            } else {
                                g00.e();
                                throw null;
                            }
                        } else {
                            g00.e();
                            throw null;
                        }
                    } else {
                        g00.e();
                        throw null;
                    }
                }
                return;
            }
            throw new IllegalArgumentException("source == this".toString());
        }
        g00.f("source");
        throw null;
    }
}
