package okio;

import androidx.base.b2;
import androidx.base.g00;
import java.io.EOFException;
import java.io.IOException;
import java.util.zip.DataFormatException;
import java.util.zip.Inflater;

public final class InflaterSource implements Source {
    private int bufferBytesHeldByInflater;
    private boolean closed;
    private final Inflater inflater;
    private final BufferedSource source;

    public InflaterSource(BufferedSource bufferedSource, Inflater inflater2) {
        if (bufferedSource == null) {
            g00.f("source");
            throw null;
        } else if (inflater2 != null) {
            this.source = bufferedSource;
            this.inflater = inflater2;
        } else {
            g00.f("inflater");
            throw null;
        }
    }

    private final void releaseBytesAfterInflate() {
        int i = this.bufferBytesHeldByInflater;
        if (i != 0) {
            int remaining = i - this.inflater.getRemaining();
            this.bufferBytesHeldByInflater -= remaining;
            this.source.skip((long) remaining);
        }
    }

    @Override // okio.Source, java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        if (!this.closed) {
            this.inflater.end();
            this.closed = true;
            this.source.close();
        }
    }

    @Override // okio.Source
    public long read(Buffer buffer, long j) {
        if (buffer != null) {
            do {
                long readOrInflate = readOrInflate(buffer, j);
                if (readOrInflate > 0) {
                    return readOrInflate;
                }
                if (this.inflater.finished() || this.inflater.needsDictionary()) {
                    return -1;
                }
            } while (!this.source.exhausted());
            throw new EOFException("source exhausted prematurely");
        }
        g00.f("sink");
        throw null;
    }

    public final long readOrInflate(Buffer buffer, long j) {
        if (buffer != null) {
            if (!(j >= 0)) {
                throw new IllegalArgumentException(b2.v("byteCount < 0: ", j).toString());
            } else if (!(!this.closed)) {
                throw new IllegalStateException("closed".toString());
            } else if (j == 0) {
                return 0;
            } else {
                try {
                    Segment writableSegment$okio = buffer.writableSegment$okio(1);
                    int min = (int) Math.min(j, (long) (8192 - writableSegment$okio.limit));
                    refill();
                    int inflate = this.inflater.inflate(writableSegment$okio.data, writableSegment$okio.limit, min);
                    releaseBytesAfterInflate();
                    if (inflate > 0) {
                        writableSegment$okio.limit += inflate;
                        long j2 = (long) inflate;
                        buffer.setSize$okio(buffer.size() + j2);
                        return j2;
                    }
                    if (writableSegment$okio.pos == writableSegment$okio.limit) {
                        buffer.head = writableSegment$okio.pop();
                        SegmentPool.INSTANCE.recycle(writableSegment$okio);
                    }
                    return 0;
                } catch (DataFormatException e) {
                    throw new IOException(e);
                }
            }
        } else {
            g00.f("sink");
            throw null;
        }
    }

    public final boolean refill() {
        if (!this.inflater.needsInput()) {
            return false;
        }
        if (this.source.exhausted()) {
            return true;
        }
        Segment segment = this.source.getBuffer().head;
        if (segment != null) {
            int i = segment.limit;
            int i2 = segment.pos;
            int i3 = i - i2;
            this.bufferBytesHeldByInflater = i3;
            this.inflater.setInput(segment.data, i2, i3);
            return false;
        }
        g00.e();
        throw null;
    }

    @Override // okio.Source
    public Timeout timeout() {
        return this.source.timeout();
    }

    /* JADX INFO: this call moved to the top of the method (can break code semantics) */
    public InflaterSource(Source source2, Inflater inflater2) {
        this(Okio.buffer(source2), inflater2);
        if (source2 == null) {
            g00.f("source");
            throw null;
        } else if (inflater2 != null) {
        } else {
            g00.f("inflater");
            throw null;
        }
    }
}
