package okio;

import androidx.base.b2;
import androidx.base.g00;
import java.io.IOException;
import java.io.InputStream;

public final class InputStreamSource implements Source {
    private final InputStream input;
    private final Timeout timeout;

    public InputStreamSource(InputStream inputStream, Timeout timeout2) {
        if (inputStream == null) {
            g00.f("input");
            throw null;
        } else if (timeout2 != null) {
            this.input = inputStream;
            this.timeout = timeout2;
        } else {
            g00.f("timeout");
            throw null;
        }
    }

    @Override // okio.Source, java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        this.input.close();
    }

    @Override // okio.Source
    public long read(Buffer buffer, long j) {
        if (buffer == null) {
            g00.f("sink");
            throw null;
        } else if (j == 0) {
            return 0;
        } else {
            if (j >= 0) {
                try {
                    this.timeout.throwIfReached();
                    Segment writableSegment$okio = buffer.writableSegment$okio(1);
                    int read = this.input.read(writableSegment$okio.data, writableSegment$okio.limit, (int) Math.min(j, (long) (8192 - writableSegment$okio.limit)));
                    if (read != -1) {
                        writableSegment$okio.limit += read;
                        long j2 = (long) read;
                        buffer.setSize$okio(buffer.size() + j2);
                        return j2;
                    } else if (writableSegment$okio.pos != writableSegment$okio.limit) {
                        return -1;
                    } else {
                        buffer.head = writableSegment$okio.pop();
                        SegmentPool.INSTANCE.recycle(writableSegment$okio);
                        return -1;
                    }
                } catch (AssertionError e) {
                    if (Okio.isAndroidGetsocknameError(e)) {
                        throw new IOException(e);
                    }
                    throw e;
                }
            } else {
                throw new IllegalArgumentException(b2.v("byteCount < 0: ", j).toString());
            }
        }
    }

    @Override // okio.Source
    public Timeout timeout() {
        return this.timeout;
    }

    public String toString() {
        StringBuilder j = b2.j("source(");
        j.append(this.input);
        j.append(')');
        return j.toString();
    }
}
