package okio;

import androidx.base.b2;
import androidx.base.g00;
import java.io.OutputStream;

public final class OutputStreamSink implements Sink {
    private final OutputStream out;
    private final Timeout timeout;

    public OutputStreamSink(OutputStream outputStream, Timeout timeout2) {
        if (outputStream == null) {
            g00.f("out");
            throw null;
        } else if (timeout2 != null) {
            this.out = outputStream;
            this.timeout = timeout2;
        } else {
            g00.f("timeout");
            throw null;
        }
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable, okio.Sink
    public void close() {
        this.out.close();
    }

    @Override // okio.Sink, java.io.Flushable
    public void flush() {
        this.out.flush();
    }

    @Override // okio.Sink
    public Timeout timeout() {
        return this.timeout;
    }

    public String toString() {
        StringBuilder j = b2.j("sink(");
        j.append(this.out);
        j.append(')');
        return j.toString();
    }

    @Override // okio.Sink
    public void write(Buffer buffer, long j) {
        if (buffer != null) {
            Util.checkOffsetAndCount(buffer.size(), 0, j);
            while (j > 0) {
                this.timeout.throwIfReached();
                Segment segment = buffer.head;
                if (segment != null) {
                    int min = (int) Math.min(j, (long) (segment.limit - segment.pos));
                    this.out.write(segment.data, segment.pos, min);
                    segment.pos += min;
                    long j2 = (long) min;
                    j -= j2;
                    buffer.setSize$okio(buffer.size() - j2);
                    if (segment.pos == segment.limit) {
                        buffer.head = segment.pop();
                        SegmentPool.INSTANCE.recycle(segment);
                    }
                } else {
                    g00.e();
                    throw null;
                }
            }
            return;
        }
        g00.f("source");
        throw null;
    }
}
