package okio;

import androidx.base.b2;
import androidx.base.g00;
import java.io.EOFException;
import java.io.OutputStream;
import java.nio.ByteBuffer;
import java.nio.charset.Charset;

public final class RealBufferedSink implements BufferedSink {
    public final Buffer bufferField;
    public boolean closed;
    public final Sink sink;

    public RealBufferedSink(Sink sink2) {
        if (sink2 != null) {
            this.sink = sink2;
            this.bufferField = new Buffer();
            return;
        }
        g00.f("sink");
        throw null;
    }

    public static /* synthetic */ void buffer$annotations() {
    }

    @Override // okio.BufferedSink
    public Buffer buffer() {
        return this.bufferField;
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable, okio.Sink, java.nio.channels.Channel
    public void close() {
        if (!this.closed) {
            Throwable th = null;
            try {
                if (this.bufferField.size() > 0) {
                    Sink sink2 = this.sink;
                    Buffer buffer = this.bufferField;
                    sink2.write(buffer, buffer.size());
                }
            } catch (Throwable th2) {
                th = th2;
            }
            try {
                this.sink.close();
            } catch (Throwable th3) {
                if (th == null) {
                    th = th3;
                }
            }
            this.closed = true;
            if (th != null) {
                throw th;
            }
        }
    }

    @Override // okio.BufferedSink
    public BufferedSink emit() {
        if (!this.closed) {
            long size = this.bufferField.size();
            if (size > 0) {
                this.sink.write(this.bufferField, size);
            }
            return this;
        }
        throw new IllegalStateException("closed".toString());
    }

    @Override // okio.BufferedSink
    public BufferedSink emitCompleteSegments() {
        if (!this.closed) {
            long completeSegmentByteCount = this.bufferField.completeSegmentByteCount();
            if (completeSegmentByteCount > 0) {
                this.sink.write(this.bufferField, completeSegmentByteCount);
            }
            return this;
        }
        throw new IllegalStateException("closed".toString());
    }

    @Override // okio.BufferedSink, okio.Sink, java.io.Flushable
    public void flush() {
        if (!this.closed) {
            if (this.bufferField.size() > 0) {
                Sink sink2 = this.sink;
                Buffer buffer = this.bufferField;
                sink2.write(buffer, buffer.size());
            }
            this.sink.flush();
            return;
        }
        throw new IllegalStateException("closed".toString());
    }

    @Override // okio.BufferedSink
    public Buffer getBuffer() {
        return this.bufferField;
    }

    public boolean isOpen() {
        return !this.closed;
    }

    @Override // okio.BufferedSink
    public OutputStream outputStream() {
        return new RealBufferedSink$outputStream$1(this);
    }

    @Override // okio.Sink
    public Timeout timeout() {
        return this.sink.timeout();
    }

    public String toString() {
        StringBuilder j = b2.j("buffer(");
        j.append(this.sink);
        j.append(')');
        return j.toString();
    }

    @Override // java.nio.channels.WritableByteChannel
    public int write(ByteBuffer byteBuffer) {
        if (byteBuffer == null) {
            g00.f("source");
            throw null;
        } else if (!this.closed) {
            int write = this.bufferField.write(byteBuffer);
            emitCompleteSegments();
            return write;
        } else {
            throw new IllegalStateException("closed".toString());
        }
    }

    @Override // okio.BufferedSink
    public long writeAll(Source source) {
        if (source != null) {
            long j = 0;
            while (true) {
                long read = source.read(this.bufferField, (long) 8192);
                if (read == -1) {
                    return j;
                }
                j += read;
                emitCompleteSegments();
            }
        } else {
            g00.f("source");
            throw null;
        }
    }

    @Override // okio.BufferedSink
    public BufferedSink writeByte(int i) {
        if (!this.closed) {
            this.bufferField.writeByte(i);
            return emitCompleteSegments();
        }
        throw new IllegalStateException("closed".toString());
    }

    @Override // okio.BufferedSink
    public BufferedSink writeDecimalLong(long j) {
        if (!this.closed) {
            this.bufferField.writeDecimalLong(j);
            return emitCompleteSegments();
        }
        throw new IllegalStateException("closed".toString());
    }

    @Override // okio.BufferedSink
    public BufferedSink writeHexadecimalUnsignedLong(long j) {
        if (!this.closed) {
            this.bufferField.writeHexadecimalUnsignedLong(j);
            return emitCompleteSegments();
        }
        throw new IllegalStateException("closed".toString());
    }

    @Override // okio.BufferedSink
    public BufferedSink writeInt(int i) {
        if (!this.closed) {
            this.bufferField.writeInt(i);
            return emitCompleteSegments();
        }
        throw new IllegalStateException("closed".toString());
    }

    @Override // okio.BufferedSink
    public BufferedSink writeIntLe(int i) {
        if (!this.closed) {
            this.bufferField.writeIntLe(i);
            return emitCompleteSegments();
        }
        throw new IllegalStateException("closed".toString());
    }

    @Override // okio.BufferedSink
    public BufferedSink writeLong(long j) {
        if (!this.closed) {
            this.bufferField.writeLong(j);
            return emitCompleteSegments();
        }
        throw new IllegalStateException("closed".toString());
    }

    @Override // okio.BufferedSink
    public BufferedSink writeLongLe(long j) {
        if (!this.closed) {
            this.bufferField.writeLongLe(j);
            return emitCompleteSegments();
        }
        throw new IllegalStateException("closed".toString());
    }

    @Override // okio.BufferedSink
    public BufferedSink writeShort(int i) {
        if (!this.closed) {
            this.bufferField.writeShort(i);
            return emitCompleteSegments();
        }
        throw new IllegalStateException("closed".toString());
    }

    @Override // okio.BufferedSink
    public BufferedSink writeShortLe(int i) {
        if (!this.closed) {
            this.bufferField.writeShortLe(i);
            return emitCompleteSegments();
        }
        throw new IllegalStateException("closed".toString());
    }

    @Override // okio.BufferedSink
    public BufferedSink writeString(String str, Charset charset) {
        if (str == null) {
            g00.f("string");
            throw null;
        } else if (charset == null) {
            g00.f("charset");
            throw null;
        } else if (!this.closed) {
            this.bufferField.writeString(str, charset);
            return emitCompleteSegments();
        } else {
            throw new IllegalStateException("closed".toString());
        }
    }

    @Override // okio.BufferedSink
    public BufferedSink writeUtf8(String str) {
        if (str == null) {
            g00.f("string");
            throw null;
        } else if (!this.closed) {
            this.bufferField.writeUtf8(str);
            return emitCompleteSegments();
        } else {
            throw new IllegalStateException("closed".toString());
        }
    }

    @Override // okio.BufferedSink
    public BufferedSink writeUtf8CodePoint(int i) {
        if (!this.closed) {
            this.bufferField.writeUtf8CodePoint(i);
            return emitCompleteSegments();
        }
        throw new IllegalStateException("closed".toString());
    }

    @Override // okio.Sink
    public void write(Buffer buffer, long j) {
        if (buffer == null) {
            g00.f("source");
            throw null;
        } else if (!this.closed) {
            this.bufferField.write(buffer, j);
            emitCompleteSegments();
        } else {
            throw new IllegalStateException("closed".toString());
        }
    }

    @Override // okio.BufferedSink
    public BufferedSink writeString(String str, int i, int i2, Charset charset) {
        if (str == null) {
            g00.f("string");
            throw null;
        } else if (charset == null) {
            g00.f("charset");
            throw null;
        } else if (!this.closed) {
            this.bufferField.writeString(str, i, i2, charset);
            return emitCompleteSegments();
        } else {
            throw new IllegalStateException("closed".toString());
        }
    }

    @Override // okio.BufferedSink
    public BufferedSink writeUtf8(String str, int i, int i2) {
        if (str == null) {
            g00.f("string");
            throw null;
        } else if (!this.closed) {
            this.bufferField.writeUtf8(str, i, i2);
            return emitCompleteSegments();
        } else {
            throw new IllegalStateException("closed".toString());
        }
    }

    @Override // okio.BufferedSink
    public BufferedSink write(ByteString byteString) {
        if (byteString == null) {
            g00.f("byteString");
            throw null;
        } else if (!this.closed) {
            this.bufferField.write(byteString);
            return emitCompleteSegments();
        } else {
            throw new IllegalStateException("closed".toString());
        }
    }

    @Override // okio.BufferedSink
    public BufferedSink write(ByteString byteString, int i, int i2) {
        if (byteString == null) {
            g00.f("byteString");
            throw null;
        } else if (!this.closed) {
            this.bufferField.write(byteString, i, i2);
            return emitCompleteSegments();
        } else {
            throw new IllegalStateException("closed".toString());
        }
    }

    @Override // okio.BufferedSink
    public BufferedSink write(byte[] bArr) {
        if (bArr == null) {
            g00.f("source");
            throw null;
        } else if (!this.closed) {
            this.bufferField.write(bArr);
            return emitCompleteSegments();
        } else {
            throw new IllegalStateException("closed".toString());
        }
    }

    @Override // okio.BufferedSink
    public BufferedSink write(byte[] bArr, int i, int i2) {
        if (bArr == null) {
            g00.f("source");
            throw null;
        } else if (!this.closed) {
            this.bufferField.write(bArr, i, i2);
            return emitCompleteSegments();
        } else {
            throw new IllegalStateException("closed".toString());
        }
    }

    @Override // okio.BufferedSink
    public BufferedSink write(Source source, long j) {
        if (source != null) {
            while (j > 0) {
                long read = source.read(this.bufferField, j);
                if (read != -1) {
                    j -= read;
                    emitCompleteSegments();
                } else {
                    throw new EOFException();
                }
            }
            return this;
        }
        g00.f("source");
        throw null;
    }
}
