package okio;

import androidx.base.b2;
import androidx.base.f00;
import androidx.base.g00;
import androidx.base.zz;
import java.io.InterruptedIOException;
import java.util.concurrent.TimeUnit;

public class Timeout {
    public static final Companion Companion = new Companion(null);
    public static final Timeout NONE = new Timeout$Companion$NONE$1();
    private long deadlineNanoTime;
    private boolean hasDeadline;
    private long timeoutNanos;

    public static final class Companion {
        private Companion() {
        }

        public final long minTimeout(long j, long j2) {
            return (j != 0 && (j2 == 0 || j < j2)) ? j : j2;
        }

        public /* synthetic */ Companion(f00 f00) {
            this();
        }
    }

    public Timeout clearDeadline() {
        this.hasDeadline = false;
        return this;
    }

    public Timeout clearTimeout() {
        this.timeoutNanos = 0;
        return this;
    }

    public final Timeout deadline(long j, TimeUnit timeUnit) {
        if (timeUnit != null) {
            if (j > 0) {
                return deadlineNanoTime(timeUnit.toNanos(j) + System.nanoTime());
            }
            throw new IllegalArgumentException(b2.v("duration <= 0: ", j).toString());
        }
        g00.f("unit");
        throw null;
    }

    public long deadlineNanoTime() {
        if (this.hasDeadline) {
            return this.deadlineNanoTime;
        }
        throw new IllegalStateException("No deadline".toString());
    }

    public boolean hasDeadline() {
        return this.hasDeadline;
    }

    public final void intersectWith(Timeout timeout, zz<?> zzVar) {
        if (timeout == null) {
            g00.f("other");
            throw null;
        } else if (zzVar != null) {
            long timeoutNanos2 = timeoutNanos();
            long minTimeout = Companion.minTimeout(timeout.timeoutNanos(), timeoutNanos());
            TimeUnit timeUnit = TimeUnit.NANOSECONDS;
            timeout(minTimeout, timeUnit);
            if (hasDeadline()) {
                long deadlineNanoTime2 = deadlineNanoTime();
                if (timeout.hasDeadline()) {
                    deadlineNanoTime(Math.min(deadlineNanoTime(), timeout.deadlineNanoTime()));
                }
                try {
                    zzVar.a();
                    timeout(timeoutNanos2, timeUnit);
                    if (timeout.hasDeadline()) {
                        deadlineNanoTime(deadlineNanoTime2);
                    }
                } catch (Throwable th) {
                    timeout(timeoutNanos2, TimeUnit.NANOSECONDS);
                    if (timeout.hasDeadline()) {
                        deadlineNanoTime(deadlineNanoTime2);
                    }
                    throw th;
                }
            } else {
                if (timeout.hasDeadline()) {
                    deadlineNanoTime(timeout.deadlineNanoTime());
                }
                try {
                    zzVar.a();
                    timeout(timeoutNanos2, timeUnit);
                    if (timeout.hasDeadline()) {
                        clearDeadline();
                    }
                } catch (Throwable th2) {
                    timeout(timeoutNanos2, TimeUnit.NANOSECONDS);
                    if (timeout.hasDeadline()) {
                        clearDeadline();
                    }
                    throw th2;
                }
            }
        } else {
            g00.f("block");
            throw null;
        }
    }

    public void throwIfReached() {
        if (Thread.interrupted()) {
            Thread.currentThread().interrupt();
            throw new InterruptedIOException("interrupted");
        } else if (this.hasDeadline && this.deadlineNanoTime - System.nanoTime() <= 0) {
            throw new InterruptedIOException("deadline reached");
        }
    }

    public Timeout timeout(long j, TimeUnit timeUnit) {
        if (timeUnit != null) {
            if (j >= 0) {
                this.timeoutNanos = timeUnit.toNanos(j);
                return this;
            }
            throw new IllegalArgumentException(b2.v("timeout < 0: ", j).toString());
        }
        g00.f("unit");
        throw null;
    }

    public long timeoutNanos() {
        return this.timeoutNanos;
    }

    public final void waitUntilNotified(Object obj) {
        if (obj != null) {
            try {
                boolean hasDeadline2 = hasDeadline();
                long timeoutNanos2 = timeoutNanos();
                long j = 0;
                if (hasDeadline2 || timeoutNanos2 != 0) {
                    long nanoTime = System.nanoTime();
                    if (hasDeadline2 && timeoutNanos2 != 0) {
                        timeoutNanos2 = Math.min(timeoutNanos2, deadlineNanoTime() - nanoTime);
                    } else if (hasDeadline2) {
                        timeoutNanos2 = deadlineNanoTime() - nanoTime;
                    }
                    if (timeoutNanos2 > 0) {
                        long j2 = timeoutNanos2 / 1000000;
                        Long.signum(j2);
                        obj.wait(j2, (int) (timeoutNanos2 - (1000000 * j2)));
                        j = System.nanoTime() - nanoTime;
                    }
                    if (j >= timeoutNanos2) {
                        throw new InterruptedIOException("timeout");
                    }
                    return;
                }
                obj.wait();
            } catch (InterruptedException unused) {
                Thread.currentThread().interrupt();
                throw new InterruptedIOException("interrupted");
            }
        } else {
            g00.f("monitor");
            throw null;
        }
    }

    public Timeout deadlineNanoTime(long j) {
        this.hasDeadline = true;
        this.deadlineNanoTime = j;
        return this;
    }
}
