package okio.internal;

import androidx.base.b00;
import androidx.base.b2;
import androidx.base.g00;
import androidx.base.xz;
import androidx.exifinterface.media.ExifInterface;
import com.google.android.exoplayer2.extractor.mp3.IndexSeeker;
import com.google.android.exoplayer2.extractor.ts.PsExtractor;
import java.io.EOFException;
import okio.Buffer;
import okio.ByteString;
import okio.Options;
import okio.Platform;
import okio.Segment;
import okio.SegmentPool;
import okio.SegmentedByteString;
import okio.Sink;
import okio.Source;
import okio.Utf8;
import okio.Util;

public final class BufferKt {
    private static final byte[] HEX_DIGIT_BYTES = Platform.asUtf8ToByteArray("0123456789abcdef");
    public static final long OVERFLOW_DIGIT_START;
    public static final long OVERFLOW_ZONE;
    public static final int SEGMENTING_THRESHOLD;

    public static final void commonClear(Buffer buffer) {
        if (buffer != null) {
            buffer.skip(buffer.size());
        } else {
            g00.f("$this$commonClear");
            throw null;
        }
    }

    public static final long commonCompleteSegmentByteCount(Buffer buffer) {
        if (buffer != null) {
            long size = buffer.size();
            if (size == 0) {
                return 0;
            }
            Segment segment = buffer.head;
            if (segment != null) {
                Segment segment2 = segment.prev;
                if (segment2 != null) {
                    int i = segment2.limit;
                    return (i >= 8192 || !segment2.owner) ? size : size - ((long) (i - segment2.pos));
                }
                g00.e();
                throw null;
            }
            g00.e();
            throw null;
        }
        g00.f("$this$commonCompleteSegmentByteCount");
        throw null;
    }

    public static final Buffer commonCopy(Buffer buffer) {
        if (buffer != null) {
            Buffer buffer2 = new Buffer();
            if (buffer.size() == 0) {
                return buffer2;
            }
            Segment segment = buffer.head;
            if (segment != null) {
                Segment sharedCopy = segment.sharedCopy();
                buffer2.head = sharedCopy;
                sharedCopy.prev = sharedCopy;
                sharedCopy.next = sharedCopy;
                for (Segment segment2 = segment.next; segment2 != segment; segment2 = segment2.next) {
                    Segment segment3 = sharedCopy.prev;
                    if (segment3 == null) {
                        g00.e();
                        throw null;
                    } else if (segment2 != null) {
                        segment3.push(segment2.sharedCopy());
                    } else {
                        g00.e();
                        throw null;
                    }
                }
                buffer2.setSize$okio(buffer.size());
                return buffer2;
            }
            g00.e();
            throw null;
        }
        g00.f("$this$commonCopy");
        throw null;
    }

    public static final Buffer commonCopyTo(Buffer buffer, Buffer buffer2, long j, long j2) {
        if (buffer == null) {
            g00.f("$this$commonCopyTo");
            throw null;
        } else if (buffer2 != null) {
            Util.checkOffsetAndCount(buffer.size(), j, j2);
            if (j2 == 0) {
                return buffer;
            }
            buffer2.setSize$okio(buffer2.size() + j2);
            Segment segment = buffer.head;
            while (segment != null) {
                int i = segment.limit;
                int i2 = segment.pos;
                if (j >= ((long) (i - i2))) {
                    j -= (long) (i - i2);
                    segment = segment.next;
                } else {
                    while (j2 > 0) {
                        if (segment != null) {
                            Segment sharedCopy = segment.sharedCopy();
                            int i3 = sharedCopy.pos + ((int) j);
                            sharedCopy.pos = i3;
                            sharedCopy.limit = Math.min(i3 + ((int) j2), sharedCopy.limit);
                            Segment segment2 = buffer2.head;
                            if (segment2 == null) {
                                sharedCopy.prev = sharedCopy;
                                sharedCopy.next = sharedCopy;
                                buffer2.head = sharedCopy;
                            } else if (segment2 != null) {
                                Segment segment3 = segment2.prev;
                                if (segment3 != null) {
                                    segment3.push(sharedCopy);
                                } else {
                                    g00.e();
                                    throw null;
                                }
                            } else {
                                g00.e();
                                throw null;
                            }
                            j2 -= (long) (sharedCopy.limit - sharedCopy.pos);
                            segment = segment.next;
                            j = 0;
                        } else {
                            g00.e();
                            throw null;
                        }
                    }
                    return buffer;
                }
            }
            g00.e();
            throw null;
        } else {
            g00.f("out");
            throw null;
        }
    }

    public static final boolean commonEquals(Buffer buffer, Object obj) {
        if (buffer == null) {
            g00.f("$this$commonEquals");
            throw null;
        } else if (buffer == obj) {
            return true;
        } else {
            if (!(obj instanceof Buffer)) {
                return false;
            }
            Buffer buffer2 = (Buffer) obj;
            if (buffer.size() != buffer2.size()) {
                return false;
            }
            long j = 0;
            if (buffer.size() == 0) {
                return true;
            }
            Segment segment = buffer.head;
            if (segment != null) {
                Segment segment2 = buffer2.head;
                if (segment2 != null) {
                    int i = segment.pos;
                    int i2 = segment2.pos;
                    long j2 = 0;
                    while (j2 < buffer.size()) {
                        long min = (long) Math.min(segment.limit - i, segment2.limit - i2);
                        long j3 = j;
                        while (j3 < min) {
                            int i3 = i + 1;
                            int i4 = i2 + 1;
                            if (segment.data[i] != segment2.data[i2]) {
                                return false;
                            }
                            j3++;
                            i = i3;
                            i2 = i4;
                        }
                        if (i == segment.limit) {
                            segment = segment.next;
                            if (segment != null) {
                                i = segment.pos;
                            } else {
                                g00.e();
                                throw null;
                            }
                        }
                        if (i2 == segment2.limit) {
                            segment2 = segment2.next;
                            if (segment2 != null) {
                                i2 = segment2.pos;
                            } else {
                                g00.e();
                                throw null;
                            }
                        }
                        j2 += min;
                        j = 0;
                    }
                    return true;
                }
                g00.e();
                throw null;
            }
            g00.e();
            throw null;
        }
    }

    public static final byte commonGet(Buffer buffer, long j) {
        if (buffer != null) {
            Util.checkOffsetAndCount(buffer.size(), j, 1);
            Segment segment = buffer.head;
            if (segment == null) {
                g00.e();
                throw null;
            } else if (buffer.size() - j < j) {
                long size = buffer.size();
                while (size > j) {
                    segment = segment.prev;
                    if (segment != null) {
                        size -= (long) (segment.limit - segment.pos);
                    } else {
                        g00.e();
                        throw null;
                    }
                }
                return segment.data[(int) ((((long) segment.pos) + j) - size)];
            } else {
                long j2 = 0;
                while (true) {
                    int i = segment.limit;
                    int i2 = segment.pos;
                    long j3 = ((long) (i - i2)) + j2;
                    if (j3 > j) {
                        return segment.data[(int) ((((long) i2) + j) - j2)];
                    }
                    segment = segment.next;
                    if (segment != null) {
                        j2 = j3;
                    } else {
                        g00.e();
                        throw null;
                    }
                }
            }
        } else {
            g00.f("$this$commonGet");
            throw null;
        }
    }

    public static final int commonHashCode(Buffer buffer) {
        if (buffer != null) {
            Segment segment = buffer.head;
            if (segment == null) {
                return 0;
            }
            int i = 1;
            do {
                int i2 = segment.limit;
                for (int i3 = segment.pos; i3 < i2; i3++) {
                    i = (i * 31) + segment.data[i3];
                }
                segment = segment.next;
                if (segment == null) {
                    g00.e();
                    throw null;
                }
            } while (segment != buffer.head);
            return i;
        }
        g00.f("$this$commonHashCode");
        throw null;
    }

    public static final long commonIndexOf(Buffer buffer, byte b, long j, long j2) {
        Segment segment;
        int i;
        if (buffer != null) {
            long j3 = 0;
            if (0 <= j && j2 >= j) {
                if (j2 > buffer.size()) {
                    j2 = buffer.size();
                }
                if (j == j2 || (segment = buffer.head) == null) {
                    return -1;
                }
                if (buffer.size() - j < j) {
                    j3 = buffer.size();
                    while (j3 > j) {
                        segment = segment.prev;
                        if (segment != null) {
                            j3 -= (long) (segment.limit - segment.pos);
                        } else {
                            g00.e();
                            throw null;
                        }
                    }
                    while (j3 < j2) {
                        byte[] bArr = segment.data;
                        int min = (int) Math.min((long) segment.limit, (((long) segment.pos) + j2) - j3);
                        i = (int) ((((long) segment.pos) + j) - j3);
                        while (i < min) {
                            if (bArr[i] != b) {
                                i++;
                            }
                        }
                        j3 += (long) (segment.limit - segment.pos);
                        segment = segment.next;
                        if (segment != null) {
                            j = j3;
                        } else {
                            g00.e();
                            throw null;
                        }
                    }
                    return -1;
                }
                while (true) {
                    long j4 = ((long) (segment.limit - segment.pos)) + j3;
                    if (j4 > j) {
                        while (j3 < j2) {
                            byte[] bArr2 = segment.data;
                            int min2 = (int) Math.min((long) segment.limit, (((long) segment.pos) + j2) - j3);
                            i = (int) ((((long) segment.pos) + j) - j3);
                            while (i < min2) {
                                if (bArr2[i] != b) {
                                    i++;
                                }
                            }
                            j3 += (long) (segment.limit - segment.pos);
                            segment = segment.next;
                            if (segment != null) {
                                j = j3;
                            } else {
                                g00.e();
                                throw null;
                            }
                        }
                        return -1;
                    }
                    segment = segment.next;
                    if (segment != null) {
                        j3 = j4;
                    } else {
                        g00.e();
                        throw null;
                    }
                }
                return ((long) (i - segment.pos)) + j3;
            }
            StringBuilder j5 = b2.j("size=");
            j5.append(buffer.size());
            j5.append(" fromIndex=");
            j5.append(j);
            j5.append(" toIndex=");
            j5.append(j2);
            throw new IllegalArgumentException(j5.toString().toString());
        }
        g00.f("$this$commonIndexOf");
        throw null;
    }

    public static final long commonIndexOfElement(Buffer buffer, ByteString byteString, long j) {
        int i;
        int i2;
        if (buffer == null) {
            g00.f("$this$commonIndexOfElement");
            throw null;
        } else if (byteString != null) {
            long j2 = 0;
            if (j >= 0) {
                Segment segment = buffer.head;
                if (segment == null) {
                    return -1;
                }
                if (buffer.size() - j < j) {
                    j2 = buffer.size();
                    while (j2 > j) {
                        segment = segment.prev;
                        if (segment != null) {
                            j2 -= (long) (segment.limit - segment.pos);
                        } else {
                            g00.e();
                            throw null;
                        }
                    }
                    if (byteString.size() == 2) {
                        byte b = byteString.getByte(0);
                        byte b2 = byteString.getByte(1);
                        while (j2 < buffer.size()) {
                            byte[] bArr = segment.data;
                            i = (int) ((((long) segment.pos) + j) - j2);
                            int i3 = segment.limit;
                            while (i < i3) {
                                byte b3 = bArr[i];
                                if (!(b3 == b || b3 == b2)) {
                                    i++;
                                }
                            }
                            j2 += (long) (segment.limit - segment.pos);
                            segment = segment.next;
                            if (segment != null) {
                                j = j2;
                            } else {
                                g00.e();
                                throw null;
                            }
                        }
                    } else {
                        byte[] internalArray$okio = byteString.internalArray$okio();
                        while (j2 < buffer.size()) {
                            byte[] bArr2 = segment.data;
                            i = (int) ((((long) segment.pos) + j) - j2);
                            int i4 = segment.limit;
                            while (i < i4) {
                                byte b4 = bArr2[i];
                                for (byte b5 : internalArray$okio) {
                                    if (b4 == b5) {
                                        i2 = segment.pos;
                                        return ((long) (i - i2)) + j2;
                                    }
                                }
                                i++;
                            }
                            j2 += (long) (segment.limit - segment.pos);
                            segment = segment.next;
                            if (segment != null) {
                                j = j2;
                            } else {
                                g00.e();
                                throw null;
                            }
                        }
                    }
                    return -1;
                }
                while (true) {
                    long j3 = ((long) (segment.limit - segment.pos)) + j2;
                    if (j3 > j) {
                        if (byteString.size() == 2) {
                            byte b6 = byteString.getByte(0);
                            byte b7 = byteString.getByte(1);
                            while (j2 < buffer.size()) {
                                byte[] bArr3 = segment.data;
                                i = (int) ((((long) segment.pos) + j) - j2);
                                int i5 = segment.limit;
                                while (i < i5) {
                                    byte b8 = bArr3[i];
                                    if (!(b8 == b6 || b8 == b7)) {
                                        i++;
                                    }
                                }
                                j2 += (long) (segment.limit - segment.pos);
                                segment = segment.next;
                                if (segment != null) {
                                    j = j2;
                                } else {
                                    g00.e();
                                    throw null;
                                }
                            }
                        } else {
                            byte[] internalArray$okio2 = byteString.internalArray$okio();
                            while (j2 < buffer.size()) {
                                byte[] bArr4 = segment.data;
                                i = (int) ((((long) segment.pos) + j) - j2);
                                int i6 = segment.limit;
                                while (i < i6) {
                                    byte b9 = bArr4[i];
                                    for (byte b10 : internalArray$okio2) {
                                        if (b9 != b10) {
                                        }
                                    }
                                    i++;
                                }
                                j2 += (long) (segment.limit - segment.pos);
                                segment = segment.next;
                                if (segment != null) {
                                    j = j2;
                                } else {
                                    g00.e();
                                    throw null;
                                }
                            }
                        }
                        return -1;
                    }
                    segment = segment.next;
                    if (segment != null) {
                        j2 = j3;
                    } else {
                        g00.e();
                        throw null;
                    }
                }
                i2 = segment.pos;
                return ((long) (i - i2)) + j2;
                i2 = segment.pos;
                return ((long) (i - i2)) + j2;
            }
            throw new IllegalArgumentException(b2.v("fromIndex < 0: ", j).toString());
        } else {
            g00.f("targetBytes");
            throw null;
        }
    }

    public static final boolean commonRangeEquals(Buffer buffer, long j, ByteString byteString, int i, int i2) {
        if (buffer == null) {
            g00.f("$this$commonRangeEquals");
            throw null;
        } else if (byteString == null) {
            g00.f("bytes");
            throw null;
        } else if (j < 0 || i < 0 || i2 < 0 || buffer.size() - j < ((long) i2) || byteString.size() - i < i2) {
            return false;
        } else {
            for (int i3 = 0; i3 < i2; i3++) {
                if (buffer.getByte(((long) i3) + j) != byteString.getByte(i + i3)) {
                    return false;
                }
            }
            return true;
        }
    }

    public static final int commonRead(Buffer buffer, byte[] bArr) {
        if (buffer == null) {
            g00.f("$this$commonRead");
            throw null;
        } else if (bArr != null) {
            return buffer.read(bArr, 0, bArr.length);
        } else {
            g00.f("sink");
            throw null;
        }
    }

    public static final long commonReadAll(Buffer buffer, Sink sink) {
        if (buffer == null) {
            g00.f("$this$commonReadAll");
            throw null;
        } else if (sink != null) {
            long size = buffer.size();
            if (size > 0) {
                sink.write(buffer, size);
            }
            return size;
        } else {
            g00.f("sink");
            throw null;
        }
    }

    public static final byte commonReadByte(Buffer buffer) {
        if (buffer == null) {
            g00.f("$this$commonReadByte");
            throw null;
        } else if (buffer.size() != 0) {
            Segment segment = buffer.head;
            if (segment != null) {
                int i = segment.pos;
                int i2 = segment.limit;
                int i3 = i + 1;
                byte b = segment.data[i];
                buffer.setSize$okio(buffer.size() - 1);
                if (i3 == i2) {
                    buffer.head = segment.pop();
                    SegmentPool.INSTANCE.recycle(segment);
                } else {
                    segment.pos = i3;
                }
                return b;
            }
            g00.e();
            throw null;
        } else {
            throw new EOFException();
        }
    }

    public static final byte[] commonReadByteArray(Buffer buffer) {
        if (buffer != null) {
            return buffer.readByteArray(buffer.size());
        }
        g00.f("$this$commonReadByteArray");
        throw null;
    }

    public static final ByteString commonReadByteString(Buffer buffer) {
        if (buffer != null) {
            return buffer.readByteString(buffer.size());
        }
        g00.f("$this$commonReadByteString");
        throw null;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:21:0x0053, code lost:
        if (r6 != false) goto L_0x0058;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:22:0x0055, code lost:
        r0.readByte();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:23:0x0058, code lost:
        r2 = androidx.base.b2.j("Number too large: ");
        r2.append(r0.readUtf8());
     */
    /* JADX WARNING: Code restructure failed: missing block: B:24:0x006e, code lost:
        throw new java.lang.NumberFormatException(r2.toString());
     */
    public static final long commonReadDecimalLong(Buffer buffer) {
        if (buffer != null) {
            long j = 0;
            if (buffer.size() != 0) {
                long j2 = -7;
                int i = 0;
                boolean z = false;
                boolean z2 = false;
                loop0:
                do {
                    Segment segment = buffer.head;
                    if (segment != null) {
                        byte[] bArr = segment.data;
                        int i2 = segment.pos;
                        int i3 = segment.limit;
                        while (true) {
                            if (i2 >= i3) {
                                break;
                            }
                            byte b = bArr[i2];
                            byte b2 = (byte) 48;
                            if (b >= b2 && b <= ((byte) 57)) {
                                int i4 = b2 - b;
                                if (j < OVERFLOW_ZONE || (j == OVERFLOW_ZONE && ((long) i4) < j2)) {
                                    Buffer writeByte = new Buffer().writeDecimalLong(j).writeByte((int) b);
                                } else {
                                    j = (j * 10) + ((long) i4);
                                }
                            } else if (b == ((byte) 45) && i == 0) {
                                j2--;
                                z = true;
                            } else if (i != 0) {
                                z2 = true;
                            } else {
                                StringBuilder j3 = b2.j("Expected leading [0-9] or '-' character but was 0x");
                                j3.append(Util.toHexString(b));
                                throw new NumberFormatException(j3.toString());
                            }
                            i2++;
                            i++;
                        }
                        if (i2 == i3) {
                            buffer.head = segment.pop();
                            SegmentPool.INSTANCE.recycle(segment);
                        } else {
                            segment.pos = i2;
                        }
                        if (z2) {
                            break;
                        }
                    } else {
                        g00.e();
                        throw null;
                    }
                } while (buffer.head != null);
                buffer.setSize$okio(buffer.size() - ((long) i));
                return z ? j : -j;
            }
            throw new EOFException();
        }
        g00.f("$this$commonReadDecimalLong");
        throw null;
    }

    public static final void commonReadFully(Buffer buffer, byte[] bArr) {
        if (buffer == null) {
            g00.f("$this$commonReadFully");
            throw null;
        } else if (bArr != null) {
            int i = 0;
            while (i < bArr.length) {
                int read = buffer.read(bArr, i, bArr.length - i);
                if (read != -1) {
                    i += read;
                } else {
                    throw new EOFException();
                }
            }
        } else {
            g00.f("sink");
            throw null;
        }
    }

    public static final long commonReadHexadecimalUnsignedLong(Buffer buffer) {
        int i;
        if (buffer == null) {
            g00.f("$this$commonReadHexadecimalUnsignedLong");
            throw null;
        } else if (buffer.size() != 0) {
            int i2 = 0;
            boolean z = false;
            long j = 0;
            do {
                Segment segment = buffer.head;
                if (segment != null) {
                    byte[] bArr = segment.data;
                    int i3 = segment.pos;
                    int i4 = segment.limit;
                    while (true) {
                        if (i3 >= i4) {
                            break;
                        }
                        byte b = bArr[i3];
                        byte b2 = (byte) 48;
                        if (b < b2 || b > ((byte) 57)) {
                            byte b3 = (byte) 97;
                            if ((b >= b3 && b <= ((byte) 102)) || (b >= (b3 = (byte) 65) && b <= ((byte) 70))) {
                                i = (b - b3) + 10;
                            } else if (i2 != 0) {
                                z = true;
                            } else {
                                StringBuilder j2 = b2.j("Expected leading [0-9a-fA-F] character but was 0x");
                                j2.append(Util.toHexString(b));
                                throw new NumberFormatException(j2.toString());
                            }
                        } else {
                            i = b - b2;
                        }
                        if ((-1152921504606846976L & j) == 0) {
                            j = (j << 4) | ((long) i);
                            i3++;
                            i2++;
                        } else {
                            Buffer writeByte = new Buffer().writeHexadecimalUnsignedLong(j).writeByte((int) b);
                            StringBuilder j3 = b2.j("Number too large: ");
                            j3.append(writeByte.readUtf8());
                            throw new NumberFormatException(j3.toString());
                        }
                    }
                    if (i3 == i4) {
                        buffer.head = segment.pop();
                        SegmentPool.INSTANCE.recycle(segment);
                    } else {
                        segment.pos = i3;
                    }
                    if (z) {
                        break;
                    }
                } else {
                    g00.e();
                    throw null;
                }
            } while (buffer.head != null);
            buffer.setSize$okio(buffer.size() - ((long) i2));
            return j;
        } else {
            throw new EOFException();
        }
    }

    public static final int commonReadInt(Buffer buffer) {
        if (buffer == null) {
            g00.f("$this$commonReadInt");
            throw null;
        } else if (buffer.size() >= 4) {
            Segment segment = buffer.head;
            if (segment != null) {
                int i = segment.pos;
                int i2 = segment.limit;
                if (((long) (i2 - i)) < 4) {
                    return (buffer.readByte() & ExifInterface.MARKER) | ((buffer.readByte() & ExifInterface.MARKER) << 24) | ((buffer.readByte() & ExifInterface.MARKER) << 16) | ((buffer.readByte() & ExifInterface.MARKER) << 8);
                }
                byte[] bArr = segment.data;
                int i3 = i + 1;
                int i4 = i3 + 1;
                int i5 = ((bArr[i] & ExifInterface.MARKER) << 24) | ((bArr[i3] & ExifInterface.MARKER) << 16);
                int i6 = i4 + 1;
                int i7 = i5 | ((bArr[i4] & ExifInterface.MARKER) << 8);
                int i8 = i6 + 1;
                int i9 = i7 | (bArr[i6] & ExifInterface.MARKER);
                buffer.setSize$okio(buffer.size() - 4);
                if (i8 == i2) {
                    buffer.head = segment.pop();
                    SegmentPool.INSTANCE.recycle(segment);
                } else {
                    segment.pos = i8;
                }
                return i9;
            }
            g00.e();
            throw null;
        } else {
            throw new EOFException();
        }
    }

    public static final long commonReadLong(Buffer buffer) {
        if (buffer == null) {
            g00.f("$this$commonReadLong");
            throw null;
        } else if (buffer.size() >= 8) {
            Segment segment = buffer.head;
            if (segment != null) {
                int i = segment.pos;
                int i2 = segment.limit;
                if (((long) (i2 - i)) < 8) {
                    return ((((long) buffer.readInt()) & 4294967295L) << 32) | (4294967295L & ((long) buffer.readInt()));
                }
                byte[] bArr = segment.data;
                int i3 = i + 1;
                int i4 = i3 + 1;
                int i5 = i4 + 1;
                long j = ((((long) bArr[i]) & 255) << 56) | ((((long) bArr[i3]) & 255) << 48) | ((((long) bArr[i4]) & 255) << 40);
                int i6 = i5 + 1;
                long j2 = ((((long) bArr[i5]) & 255) << 32) | j;
                int i7 = i6 + 1;
                int i8 = i7 + 1;
                long j3 = j2 | ((((long) bArr[i6]) & 255) << 24) | ((((long) bArr[i7]) & 255) << 16);
                int i9 = i8 + 1;
                int i10 = i9 + 1;
                long j4 = j3 | ((((long) bArr[i8]) & 255) << 8) | (((long) bArr[i9]) & 255);
                buffer.setSize$okio(buffer.size() - 8);
                if (i10 == i2) {
                    buffer.head = segment.pop();
                    SegmentPool.INSTANCE.recycle(segment);
                } else {
                    segment.pos = i10;
                }
                return j4;
            }
            g00.e();
            throw null;
        } else {
            throw new EOFException();
        }
    }

    public static final short commonReadShort(Buffer buffer) {
        if (buffer == null) {
            g00.f("$this$commonReadShort");
            throw null;
        } else if (buffer.size() >= 2) {
            Segment segment = buffer.head;
            if (segment != null) {
                int i = segment.pos;
                int i2 = segment.limit;
                if (i2 - i < 2) {
                    return (short) ((buffer.readByte() & ExifInterface.MARKER) | ((buffer.readByte() & ExifInterface.MARKER) << 8));
                }
                byte[] bArr = segment.data;
                int i3 = i + 1;
                int i4 = i3 + 1;
                int i5 = ((bArr[i] & ExifInterface.MARKER) << 8) | (bArr[i3] & ExifInterface.MARKER);
                buffer.setSize$okio(buffer.size() - 2);
                if (i4 == i2) {
                    buffer.head = segment.pop();
                    SegmentPool.INSTANCE.recycle(segment);
                } else {
                    segment.pos = i4;
                }
                return (short) i5;
            }
            g00.e();
            throw null;
        } else {
            throw new EOFException();
        }
    }

    public static final String commonReadUtf8(Buffer buffer, long j) {
        if (buffer != null) {
            if (!(j >= 0 && j <= ((long) Integer.MAX_VALUE))) {
                throw new IllegalArgumentException(b2.v("byteCount: ", j).toString());
            } else if (buffer.size() < j) {
                throw new EOFException();
            } else if (j == 0) {
                return "";
            } else {
                Segment segment = buffer.head;
                if (segment != null) {
                    int i = segment.pos;
                    if (((long) i) + j > ((long) segment.limit)) {
                        return _Utf8Kt.commonToUtf8String$default(buffer.readByteArray(j), 0, 0, 3, null);
                    }
                    int i2 = (int) j;
                    String commonToUtf8String = _Utf8Kt.commonToUtf8String(segment.data, i, i + i2);
                    segment.pos += i2;
                    buffer.setSize$okio(buffer.size() - j);
                    if (segment.pos == segment.limit) {
                        buffer.head = segment.pop();
                        SegmentPool.INSTANCE.recycle(segment);
                    }
                    return commonToUtf8String;
                }
                g00.e();
                throw null;
            }
        } else {
            g00.f("$this$commonReadUtf8");
            throw null;
        }
    }

    public static final int commonReadUtf8CodePoint(Buffer buffer) {
        int i;
        int i2;
        int i3;
        if (buffer == null) {
            g00.f("$this$commonReadUtf8CodePoint");
            throw null;
        } else if (buffer.size() != 0) {
            byte b = buffer.getByte(0);
            if ((b & 128) == 0) {
                i3 = b & Byte.MAX_VALUE;
                i2 = 1;
                i = 0;
            } else if ((b & 224) == 192) {
                i3 = b & 31;
                i2 = 2;
                i = 128;
            } else if ((b & 240) == 224) {
                i3 = b & 15;
                i2 = 3;
                i = 2048;
            } else if ((b & 248) == 240) {
                i3 = b & 7;
                i2 = 4;
                i = 65536;
            } else {
                buffer.skip(1);
                return Utf8.REPLACEMENT_CODE_POINT;
            }
            long j = (long) i2;
            if (buffer.size() >= j) {
                for (int i4 = 1; i4 < i2; i4++) {
                    long j2 = (long) i4;
                    byte b2 = buffer.getByte(j2);
                    if ((b2 & 192) == 128) {
                        i3 = (i3 << 6) | (b2 & Utf8.REPLACEMENT_BYTE);
                    } else {
                        buffer.skip(j2);
                        return Utf8.REPLACEMENT_CODE_POINT;
                    }
                }
                buffer.skip(j);
                if (i3 > 1114111) {
                    return Utf8.REPLACEMENT_CODE_POINT;
                }
                if ((55296 <= i3 && 57343 >= i3) || i3 < i) {
                    return Utf8.REPLACEMENT_CODE_POINT;
                }
                return i3;
            }
            StringBuilder k = b2.k("size < ", i2, ": ");
            k.append(buffer.size());
            k.append(" (to read code point prefixed 0x");
            k.append(Util.toHexString(b));
            k.append(')');
            throw new EOFException(k.toString());
        } else {
            throw new EOFException();
        }
    }

    public static final String commonReadUtf8Line(Buffer buffer) {
        if (buffer != null) {
            long indexOf = buffer.indexOf((byte) 10);
            if (indexOf != -1) {
                return readUtf8Line(buffer, indexOf);
            }
            if (buffer.size() != 0) {
                return buffer.readUtf8(buffer.size());
            }
            return null;
        }
        g00.f("$this$commonReadUtf8Line");
        throw null;
    }

    public static final String commonReadUtf8LineStrict(Buffer buffer, long j) {
        if (buffer != null) {
            if (j >= 0) {
                long j2 = Long.MAX_VALUE;
                if (j != Long.MAX_VALUE) {
                    j2 = j + 1;
                }
                byte b = (byte) 10;
                long indexOf = buffer.indexOf(b, 0, j2);
                if (indexOf != -1) {
                    return readUtf8Line(buffer, indexOf);
                }
                if (j2 < buffer.size() && buffer.getByte(j2 - 1) == ((byte) 13) && buffer.getByte(j2) == b) {
                    return readUtf8Line(buffer, j2);
                }
                Buffer buffer2 = new Buffer();
                buffer.copyTo(buffer2, 0, Math.min((long) 32, buffer.size()));
                throw new EOFException("\\n not found: limit=" + Math.min(buffer.size(), j) + " content=" + buffer2.readByteString().hex() + (char) 8230);
            }
            throw new IllegalArgumentException(b2.v("limit < 0: ", j).toString());
        }
        g00.f("$this$commonReadUtf8LineStrict");
        throw null;
    }

    public static final int commonSelect(Buffer buffer, Options options) {
        if (buffer == null) {
            g00.f("$this$commonSelect");
            throw null;
        } else if (options != null) {
            int selectPrefix$default = selectPrefix$default(buffer, options, false, 2, null);
            if (selectPrefix$default == -1) {
                return -1;
            }
            buffer.skip((long) options.getByteStrings$okio()[selectPrefix$default].size());
            return selectPrefix$default;
        } else {
            g00.f("options");
            throw null;
        }
    }

    public static final void commonSkip(Buffer buffer, long j) {
        if (buffer != null) {
            while (j > 0) {
                Segment segment = buffer.head;
                if (segment != null) {
                    int min = (int) Math.min(j, (long) (segment.limit - segment.pos));
                    long j2 = (long) min;
                    buffer.setSize$okio(buffer.size() - j2);
                    j -= j2;
                    int i = segment.pos + min;
                    segment.pos = i;
                    if (i == segment.limit) {
                        buffer.head = segment.pop();
                        SegmentPool.INSTANCE.recycle(segment);
                    }
                } else {
                    throw new EOFException();
                }
            }
            return;
        }
        g00.f("$this$commonSkip");
        throw null;
    }

    public static final ByteString commonSnapshot(Buffer buffer) {
        if (buffer != null) {
            if (buffer.size() <= ((long) Integer.MAX_VALUE)) {
                return buffer.snapshot((int) buffer.size());
            }
            StringBuilder j = b2.j("size > Int.MAX_VALUE: ");
            j.append(buffer.size());
            throw new IllegalStateException(j.toString().toString());
        }
        g00.f("$this$commonSnapshot");
        throw null;
    }

    public static final Segment commonWritableSegment(Buffer buffer, int i) {
        if (buffer != null) {
            boolean z = true;
            if (i < 1 || i > 8192) {
                z = false;
            }
            if (z) {
                Segment segment = buffer.head;
                if (segment == null) {
                    Segment take = SegmentPool.INSTANCE.take();
                    buffer.head = take;
                    take.prev = take;
                    take.next = take;
                    return take;
                } else if (segment != null) {
                    Segment segment2 = segment.prev;
                    if (segment2 != null) {
                        return (segment2.limit + i > 8192 || !segment2.owner) ? segment2.push(SegmentPool.INSTANCE.take()) : segment2;
                    }
                    g00.e();
                    throw null;
                } else {
                    g00.e();
                    throw null;
                }
            } else {
                throw new IllegalArgumentException("unexpected capacity".toString());
            }
        } else {
            g00.f("$this$commonWritableSegment");
            throw null;
        }
    }

    public static final Buffer commonWrite(Buffer buffer, ByteString byteString, int i, int i2) {
        if (buffer == null) {
            g00.f("$this$commonWrite");
            throw null;
        } else if (byteString != null) {
            byteString.write$okio(buffer, i, i2);
            return buffer;
        } else {
            g00.f("byteString");
            throw null;
        }
    }

    public static Buffer commonWrite$default(Buffer buffer, ByteString byteString, int i, int i2, int i3, Object obj) {
        if ((i3 & 2) != 0) {
            i = 0;
        }
        if ((i3 & 4) != 0) {
            i2 = byteString.size();
        }
        if (buffer == null) {
            g00.f("$this$commonWrite");
            throw null;
        } else if (byteString != null) {
            byteString.write$okio(buffer, i, i2);
            return buffer;
        } else {
            g00.f("byteString");
            throw null;
        }
    }

    public static final long commonWriteAll(Buffer buffer, Source source) {
        if (buffer == null) {
            g00.f("$this$commonWriteAll");
            throw null;
        } else if (source != null) {
            long j = 0;
            while (true) {
                long read = source.read(buffer, (long) 8192);
                if (read == -1) {
                    return j;
                }
                j += read;
            }
        } else {
            g00.f("source");
            throw null;
        }
    }

    public static final Buffer commonWriteByte(Buffer buffer, int i) {
        if (buffer != null) {
            Segment writableSegment$okio = buffer.writableSegment$okio(1);
            byte[] bArr = writableSegment$okio.data;
            int i2 = writableSegment$okio.limit;
            writableSegment$okio.limit = i2 + 1;
            bArr[i2] = (byte) i;
            buffer.setSize$okio(buffer.size() + 1);
            return buffer;
        }
        g00.f("$this$commonWriteByte");
        throw null;
    }

    public static final Buffer commonWriteDecimalLong(Buffer buffer, long j) {
        if (buffer == null) {
            g00.f("$this$commonWriteDecimalLong");
            throw null;
        } else if (j == 0) {
            return buffer.writeByte(48);
        } else {
            boolean z = false;
            int i = 1;
            if (j < 0) {
                j = -j;
                if (j < 0) {
                    return buffer.writeUtf8("-9223372036854775808");
                }
                z = true;
            }
            if (j >= 100000000) {
                i = j < 1000000000000L ? j < 10000000000L ? j < 1000000000 ? 9 : 10 : j < 100000000000L ? 11 : 12 : j < 1000000000000000L ? j < 10000000000000L ? 13 : j < 100000000000000L ? 14 : 15 : j < 100000000000000000L ? j < 10000000000000000L ? 16 : 17 : j < 1000000000000000000L ? 18 : 19;
            } else if (j >= 10000) {
                i = j < 1000000 ? j < IndexSeeker.MIN_TIME_BETWEEN_POINTS_US ? 5 : 6 : j < 10000000 ? 7 : 8;
            } else if (j >= 100) {
                i = j < 1000 ? 3 : 4;
            } else if (j >= 10) {
                i = 2;
            }
            if (z) {
                i++;
            }
            Segment writableSegment$okio = buffer.writableSegment$okio(i);
            byte[] bArr = writableSegment$okio.data;
            int i2 = writableSegment$okio.limit + i;
            while (j != 0) {
                long j2 = (long) 10;
                i2--;
                bArr[i2] = getHEX_DIGIT_BYTES()[(int) (j % j2)];
                j /= j2;
            }
            if (z) {
                bArr[i2 - 1] = (byte) 45;
            }
            writableSegment$okio.limit += i;
            buffer.setSize$okio(buffer.size() + ((long) i));
            return buffer;
        }
    }

    public static final Buffer commonWriteHexadecimalUnsignedLong(Buffer buffer, long j) {
        if (buffer == null) {
            g00.f("$this$commonWriteHexadecimalUnsignedLong");
            throw null;
        } else if (j == 0) {
            return buffer.writeByte(48);
        } else {
            long j2 = (j >>> 1) | j;
            long j3 = j2 | (j2 >>> 2);
            long j4 = j3 | (j3 >>> 4);
            long j5 = j4 | (j4 >>> 8);
            long j6 = j5 | (j5 >>> 16);
            long j7 = j6 | (j6 >>> 32);
            long j8 = j7 - ((j7 >>> 1) & 6148914691236517205L);
            long j9 = ((j8 >>> 2) & 3689348814741910323L) + (j8 & 3689348814741910323L);
            long j10 = ((j9 >>> 4) + j9) & 1085102592571150095L;
            long j11 = j10 + (j10 >>> 8);
            long j12 = j11 + (j11 >>> 16);
            int i = (int) ((((j12 & 63) + ((j12 >>> 32) & 63)) + ((long) 3)) / ((long) 4));
            Segment writableSegment$okio = buffer.writableSegment$okio(i);
            byte[] bArr = writableSegment$okio.data;
            int i2 = writableSegment$okio.limit;
            for (int i3 = (i2 + i) - 1; i3 >= i2; i3--) {
                bArr[i3] = getHEX_DIGIT_BYTES()[(int) (15 & j)];
                j >>>= 4;
            }
            writableSegment$okio.limit += i;
            buffer.setSize$okio(buffer.size() + ((long) i));
            return buffer;
        }
    }

    public static final Buffer commonWriteInt(Buffer buffer, int i) {
        if (buffer != null) {
            Segment writableSegment$okio = buffer.writableSegment$okio(4);
            byte[] bArr = writableSegment$okio.data;
            int i2 = writableSegment$okio.limit;
            int i3 = i2 + 1;
            bArr[i2] = (byte) ((i >>> 24) & 255);
            int i4 = i3 + 1;
            bArr[i3] = (byte) ((i >>> 16) & 255);
            int i5 = i4 + 1;
            bArr[i4] = (byte) ((i >>> 8) & 255);
            bArr[i5] = (byte) (i & 255);
            writableSegment$okio.limit = i5 + 1;
            buffer.setSize$okio(buffer.size() + 4);
            return buffer;
        }
        g00.f("$this$commonWriteInt");
        throw null;
    }

    public static final Buffer commonWriteLong(Buffer buffer, long j) {
        if (buffer != null) {
            Segment writableSegment$okio = buffer.writableSegment$okio(8);
            byte[] bArr = writableSegment$okio.data;
            int i = writableSegment$okio.limit;
            int i2 = i + 1;
            bArr[i] = (byte) ((int) ((j >>> 56) & 255));
            int i3 = i2 + 1;
            bArr[i2] = (byte) ((int) ((j >>> 48) & 255));
            int i4 = i3 + 1;
            bArr[i3] = (byte) ((int) ((j >>> 40) & 255));
            int i5 = i4 + 1;
            bArr[i4] = (byte) ((int) ((j >>> 32) & 255));
            int i6 = i5 + 1;
            bArr[i5] = (byte) ((int) ((j >>> 24) & 255));
            int i7 = i6 + 1;
            bArr[i6] = (byte) ((int) ((j >>> 16) & 255));
            int i8 = i7 + 1;
            bArr[i7] = (byte) ((int) ((j >>> 8) & 255));
            bArr[i8] = (byte) ((int) (j & 255));
            writableSegment$okio.limit = i8 + 1;
            buffer.setSize$okio(buffer.size() + 8);
            return buffer;
        }
        g00.f("$this$commonWriteLong");
        throw null;
    }

    public static final Buffer commonWriteShort(Buffer buffer, int i) {
        if (buffer != null) {
            Segment writableSegment$okio = buffer.writableSegment$okio(2);
            byte[] bArr = writableSegment$okio.data;
            int i2 = writableSegment$okio.limit;
            int i3 = i2 + 1;
            bArr[i2] = (byte) ((i >>> 8) & 255);
            bArr[i3] = (byte) (i & 255);
            writableSegment$okio.limit = i3 + 1;
            buffer.setSize$okio(buffer.size() + 2);
            return buffer;
        }
        g00.f("$this$commonWriteShort");
        throw null;
    }

    public static final Buffer commonWriteUtf8(Buffer buffer, String str, int i, int i2) {
        char charAt;
        if (buffer == null) {
            g00.f("$this$commonWriteUtf8");
            throw null;
        } else if (str != null) {
            if (i >= 0) {
                if (i2 >= i) {
                    if (i2 <= str.length()) {
                        while (i < i2) {
                            char charAt2 = str.charAt(i);
                            if (charAt2 < 128) {
                                Segment writableSegment$okio = buffer.writableSegment$okio(1);
                                byte[] bArr = writableSegment$okio.data;
                                int i3 = writableSegment$okio.limit - i;
                                int min = Math.min(i2, 8192 - i3);
                                int i4 = i + 1;
                                bArr[i + i3] = (byte) charAt2;
                                while (true) {
                                    i = i4;
                                    if (i >= min || (charAt = str.charAt(i)) >= 128) {
                                        int i5 = writableSegment$okio.limit;
                                        int i6 = (i3 + i) - i5;
                                        writableSegment$okio.limit = i5 + i6;
                                        buffer.setSize$okio(buffer.size() + ((long) i6));
                                    } else {
                                        i4 = i + 1;
                                        bArr[i + i3] = (byte) charAt;
                                    }
                                }
                                int i52 = writableSegment$okio.limit;
                                int i62 = (i3 + i) - i52;
                                writableSegment$okio.limit = i52 + i62;
                                buffer.setSize$okio(buffer.size() + ((long) i62));
                            } else {
                                if (charAt2 < 2048) {
                                    Segment writableSegment$okio2 = buffer.writableSegment$okio(2);
                                    byte[] bArr2 = writableSegment$okio2.data;
                                    int i7 = writableSegment$okio2.limit;
                                    bArr2[i7] = (byte) ((charAt2 >> 6) | PsExtractor.AUDIO_STREAM);
                                    bArr2[i7 + 1] = (byte) ((charAt2 & '?') | 128);
                                    writableSegment$okio2.limit = i7 + 2;
                                    buffer.setSize$okio(buffer.size() + 2);
                                } else if (charAt2 < 55296 || charAt2 > 57343) {
                                    Segment writableSegment$okio3 = buffer.writableSegment$okio(3);
                                    byte[] bArr3 = writableSegment$okio3.data;
                                    int i8 = writableSegment$okio3.limit;
                                    bArr3[i8] = (byte) ((charAt2 >> '\f') | 224);
                                    bArr3[i8 + 1] = (byte) ((63 & (charAt2 >> 6)) | 128);
                                    bArr3[i8 + 2] = (byte) ((charAt2 & '?') | 128);
                                    writableSegment$okio3.limit = i8 + 3;
                                    buffer.setSize$okio(buffer.size() + 3);
                                } else {
                                    int i9 = i + 1;
                                    char charAt3 = i9 < i2 ? str.charAt(i9) : 0;
                                    if (charAt2 > 56319 || 56320 > charAt3 || 57343 < charAt3) {
                                        buffer.writeByte(63);
                                        i = i9;
                                    } else {
                                        int i10 = (((charAt2 & 1023) << 10) | (charAt3 & 1023)) + 65536;
                                        Segment writableSegment$okio4 = buffer.writableSegment$okio(4);
                                        byte[] bArr4 = writableSegment$okio4.data;
                                        int i11 = writableSegment$okio4.limit;
                                        bArr4[i11] = (byte) ((i10 >> 18) | PsExtractor.VIDEO_STREAM_MASK);
                                        bArr4[i11 + 1] = (byte) (((i10 >> 12) & 63) | 128);
                                        bArr4[i11 + 2] = (byte) (((i10 >> 6) & 63) | 128);
                                        bArr4[i11 + 3] = (byte) ((i10 & 63) | 128);
                                        writableSegment$okio4.limit = i11 + 4;
                                        buffer.setSize$okio(buffer.size() + 4);
                                        i += 2;
                                    }
                                }
                                i++;
                            }
                        }
                        return buffer;
                    }
                    StringBuilder k = b2.k("endIndex > string.length: ", i2, " > ");
                    k.append(str.length());
                    throw new IllegalArgumentException(k.toString().toString());
                }
                throw new IllegalArgumentException(("endIndex < beginIndex: " + i2 + " < " + i).toString());
            }
            throw new IllegalArgumentException(b2.t("beginIndex < 0: ", i).toString());
        } else {
            g00.f("string");
            throw null;
        }
    }

    public static final Buffer commonWriteUtf8CodePoint(Buffer buffer, int i) {
        if (buffer != null) {
            if (i < 128) {
                buffer.writeByte(i);
            } else if (i < 2048) {
                Segment writableSegment$okio = buffer.writableSegment$okio(2);
                byte[] bArr = writableSegment$okio.data;
                int i2 = writableSegment$okio.limit;
                bArr[i2] = (byte) ((i >> 6) | PsExtractor.AUDIO_STREAM);
                bArr[i2 + 1] = (byte) ((i & 63) | 128);
                writableSegment$okio.limit = i2 + 2;
                buffer.setSize$okio(buffer.size() + 2);
            } else if (55296 <= i && 57343 >= i) {
                buffer.writeByte(63);
            } else if (i < 65536) {
                Segment writableSegment$okio2 = buffer.writableSegment$okio(3);
                byte[] bArr2 = writableSegment$okio2.data;
                int i3 = writableSegment$okio2.limit;
                bArr2[i3] = (byte) ((i >> 12) | 224);
                bArr2[i3 + 1] = (byte) (((i >> 6) & 63) | 128);
                bArr2[i3 + 2] = (byte) ((i & 63) | 128);
                writableSegment$okio2.limit = i3 + 3;
                buffer.setSize$okio(buffer.size() + 3);
            } else if (i <= 1114111) {
                Segment writableSegment$okio3 = buffer.writableSegment$okio(4);
                byte[] bArr3 = writableSegment$okio3.data;
                int i4 = writableSegment$okio3.limit;
                bArr3[i4] = (byte) ((i >> 18) | PsExtractor.VIDEO_STREAM_MASK);
                bArr3[i4 + 1] = (byte) (((i >> 12) & 63) | 128);
                bArr3[i4 + 2] = (byte) (((i >> 6) & 63) | 128);
                bArr3[i4 + 3] = (byte) ((i & 63) | 128);
                writableSegment$okio3.limit = i4 + 4;
                buffer.setSize$okio(buffer.size() + 4);
            } else {
                StringBuilder j = b2.j("Unexpected code point: 0x");
                j.append(Util.toHexString(i));
                throw new IllegalArgumentException(j.toString());
            }
            return buffer;
        }
        g00.f("$this$commonWriteUtf8CodePoint");
        throw null;
    }

    public static final byte[] getHEX_DIGIT_BYTES() {
        return HEX_DIGIT_BYTES;
    }

    public static final boolean rangeEquals(Segment segment, int i, byte[] bArr, int i2, int i3) {
        if (segment == null) {
            g00.f("segment");
            throw null;
        } else if (bArr != null) {
            int i4 = segment.limit;
            byte[] bArr2 = segment.data;
            while (i2 < i3) {
                if (i == i4) {
                    segment = segment.next;
                    if (segment != null) {
                        byte[] bArr3 = segment.data;
                        bArr2 = bArr3;
                        i = segment.pos;
                        i4 = segment.limit;
                    } else {
                        g00.e();
                        throw null;
                    }
                }
                if (bArr2[i] != bArr[i2]) {
                    return false;
                }
                i++;
                i2++;
            }
            return true;
        } else {
            g00.f("bytes");
            throw null;
        }
    }

    public static final String readUtf8Line(Buffer buffer, long j) {
        if (buffer != null) {
            if (j > 0) {
                long j2 = j - 1;
                if (buffer.getByte(j2) == ((byte) 13)) {
                    String readUtf8 = buffer.readUtf8(j2);
                    buffer.skip(2);
                    return readUtf8;
                }
            }
            String readUtf82 = buffer.readUtf8(j);
            buffer.skip(1);
            return readUtf82;
        }
        g00.f("$this$readUtf8Line");
        throw null;
    }

    public static final <T> T seek(Buffer buffer, long j, b00<? super Segment, ? super Long, ? extends T> b00) {
        if (buffer == null) {
            g00.f("$this$seek");
            throw null;
        } else if (b00 != null) {
            Segment segment = buffer.head;
            if (segment == null) {
                return (T) b00.invoke(null, -1L);
            }
            if (buffer.size() - j < j) {
                long size = buffer.size();
                while (size > j) {
                    segment = segment.prev;
                    if (segment != null) {
                        size -= (long) (segment.limit - segment.pos);
                    } else {
                        g00.e();
                        throw null;
                    }
                }
                return (T) b00.invoke(segment, Long.valueOf(size));
            }
            long j2 = 0;
            while (true) {
                long j3 = ((long) (segment.limit - segment.pos)) + j2;
                if (j3 > j) {
                    return (T) b00.invoke(segment, Long.valueOf(j2));
                }
                segment = segment.next;
                if (segment != null) {
                    j2 = j3;
                } else {
                    g00.e();
                    throw null;
                }
            }
        } else {
            g00.f("lambda");
            throw null;
        }
    }

    public static final int selectPrefix(Buffer buffer, Options options, boolean z) {
        int i;
        int i2;
        int i3;
        int i4;
        Segment segment;
        if (buffer == null) {
            g00.f("$this$selectPrefix");
            throw null;
        } else if (options != null) {
            Segment segment2 = buffer.head;
            if (segment2 != null) {
                byte[] bArr = segment2.data;
                int i5 = segment2.pos;
                int i6 = segment2.limit;
                int[] trie$okio = options.getTrie$okio();
                Segment segment3 = segment2;
                int i7 = 0;
                int i8 = -1;
                loop0:
                while (true) {
                    int i9 = i7 + 1;
                    int i10 = trie$okio[i7];
                    int i11 = i9 + 1;
                    int i12 = trie$okio[i9];
                    if (i12 != -1) {
                        i8 = i12;
                    }
                    if (segment3 == null) {
                        break;
                    }
                    if (i10 < 0) {
                        int i13 = (i10 * -1) + i11;
                        while (true) {
                            int i14 = i5 + 1;
                            int i15 = i11 + 1;
                            if ((bArr[i5] & ExifInterface.MARKER) != trie$okio[i11]) {
                                return i8;
                            }
                            boolean z2 = i15 == i13;
                            if (i14 != i6) {
                                i4 = i6;
                                i2 = i14;
                                segment = segment3;
                            } else if (segment3 != null) {
                                Segment segment4 = segment3.next;
                                if (segment4 != null) {
                                    i2 = segment4.pos;
                                    byte[] bArr2 = segment4.data;
                                    i4 = segment4.limit;
                                    if (segment4 != segment2) {
                                        segment = segment4;
                                        bArr = bArr2;
                                    } else if (!z2) {
                                        break loop0;
                                    } else {
                                        bArr = bArr2;
                                        segment = null;
                                    }
                                } else {
                                    g00.e();
                                    throw null;
                                }
                            } else {
                                g00.e();
                                throw null;
                            }
                            if (z2) {
                                i3 = trie$okio[i15];
                                segment3 = segment;
                                i = i4;
                                break;
                            }
                            i5 = i2;
                            i6 = i4;
                            i11 = i15;
                            segment3 = segment;
                        }
                    } else {
                        int i16 = i5 + 1;
                        int i17 = bArr[i5] & ExifInterface.MARKER;
                        int i18 = i11 + i10;
                        while (i11 != i18) {
                            if (i17 == trie$okio[i11]) {
                                i3 = trie$okio[i11 + i10];
                                if (i16 == i6) {
                                    segment3 = segment3.next;
                                    if (segment3 != null) {
                                        int i19 = segment3.pos;
                                        byte[] bArr3 = segment3.data;
                                        i = segment3.limit;
                                        if (segment3 == segment2) {
                                            segment3 = null;
                                        }
                                        i2 = i19;
                                        bArr = bArr3;
                                    } else {
                                        g00.e();
                                        throw null;
                                    }
                                } else {
                                    i = i6;
                                    i2 = i16;
                                }
                            } else {
                                i11++;
                            }
                        }
                        return i8;
                    }
                    if (i3 >= 0) {
                        return i3;
                    }
                    i7 = -i3;
                    i5 = i2;
                    i6 = i;
                }
                if (z) {
                    return -2;
                }
                return i8;
            } else if (z) {
                return -2;
            } else {
                return -1;
            }
        } else {
            g00.f("options");
            throw null;
        }
    }

    public static /* synthetic */ int selectPrefix$default(Buffer buffer, Options options, boolean z, int i, Object obj) {
        if ((i & 2) != 0) {
            z = false;
        }
        return selectPrefix(buffer, options, z);
    }

    public static final int commonRead(Buffer buffer, byte[] bArr, int i, int i2) {
        if (buffer == null) {
            g00.f("$this$commonRead");
            throw null;
        } else if (bArr != null) {
            Util.checkOffsetAndCount((long) bArr.length, (long) i, (long) i2);
            Segment segment = buffer.head;
            if (segment == null) {
                return -1;
            }
            int min = Math.min(i2, segment.limit - segment.pos);
            byte[] bArr2 = segment.data;
            int i3 = segment.pos;
            xz.a(bArr2, bArr, i, i3, i3 + min);
            segment.pos += min;
            buffer.setSize$okio(buffer.size() - ((long) min));
            if (segment.pos == segment.limit) {
                buffer.head = segment.pop();
                SegmentPool.INSTANCE.recycle(segment);
            }
            return min;
        } else {
            g00.f("sink");
            throw null;
        }
    }

    public static final byte[] commonReadByteArray(Buffer buffer, long j) {
        if (buffer != null) {
            if (!(j >= 0 && j <= ((long) Integer.MAX_VALUE))) {
                throw new IllegalArgumentException(b2.v("byteCount: ", j).toString());
            } else if (buffer.size() >= j) {
                byte[] bArr = new byte[((int) j)];
                buffer.readFully(bArr);
                return bArr;
            } else {
                throw new EOFException();
            }
        } else {
            g00.f("$this$commonReadByteArray");
            throw null;
        }
    }

    public static final ByteString commonReadByteString(Buffer buffer, long j) {
        if (buffer != null) {
            if (!(j >= 0 && j <= ((long) Integer.MAX_VALUE))) {
                throw new IllegalArgumentException(b2.v("byteCount: ", j).toString());
            } else if (buffer.size() < j) {
                throw new EOFException();
            } else if (j < ((long) 4096)) {
                return new ByteString(buffer.readByteArray(j));
            } else {
                ByteString snapshot = buffer.snapshot((int) j);
                buffer.skip(j);
                return snapshot;
            }
        } else {
            g00.f("$this$commonReadByteString");
            throw null;
        }
    }

    public static final Buffer commonWrite(Buffer buffer, byte[] bArr) {
        if (buffer == null) {
            g00.f("$this$commonWrite");
            throw null;
        } else if (bArr != null) {
            return buffer.write(bArr, 0, bArr.length);
        } else {
            g00.f("source");
            throw null;
        }
    }

    public static final void commonReadFully(Buffer buffer, Buffer buffer2, long j) {
        if (buffer == null) {
            g00.f("$this$commonReadFully");
            throw null;
        } else if (buffer2 == null) {
            g00.f("sink");
            throw null;
        } else if (buffer.size() >= j) {
            buffer2.write(buffer, j);
        } else {
            buffer2.write(buffer, buffer.size());
            throw new EOFException();
        }
    }

    public static final ByteString commonSnapshot(Buffer buffer, int i) {
        if (buffer == null) {
            g00.f("$this$commonSnapshot");
            throw null;
        } else if (i == 0) {
            return ByteString.EMPTY;
        } else {
            Util.checkOffsetAndCount(buffer.size(), 0, (long) i);
            Segment segment = buffer.head;
            int i2 = 0;
            int i3 = 0;
            int i4 = 0;
            while (i3 < i) {
                if (segment != null) {
                    int i5 = segment.limit;
                    int i6 = segment.pos;
                    if (i5 != i6) {
                        i3 += i5 - i6;
                        i4++;
                        segment = segment.next;
                    } else {
                        throw new AssertionError("s.limit == s.pos");
                    }
                } else {
                    g00.e();
                    throw null;
                }
            }
            byte[][] bArr = new byte[i4][];
            int[] iArr = new int[(i4 * 2)];
            Segment segment2 = buffer.head;
            int i7 = 0;
            while (i2 < i) {
                if (segment2 != null) {
                    bArr[i7] = segment2.data;
                    i2 += segment2.limit - segment2.pos;
                    iArr[i7] = Math.min(i2, i);
                    iArr[i7 + i4] = segment2.pos;
                    segment2.shared = true;
                    i7++;
                    segment2 = segment2.next;
                } else {
                    g00.e();
                    throw null;
                }
            }
            return new SegmentedByteString(bArr, iArr);
        }
    }

    public static final Buffer commonWrite(Buffer buffer, byte[] bArr, int i, int i2) {
        if (buffer == null) {
            g00.f("$this$commonWrite");
            throw null;
        } else if (bArr != null) {
            long j = (long) i2;
            Util.checkOffsetAndCount((long) bArr.length, (long) i, j);
            int i3 = i2 + i;
            while (i < i3) {
                Segment writableSegment$okio = buffer.writableSegment$okio(1);
                int min = Math.min(i3 - i, 8192 - writableSegment$okio.limit);
                int i4 = i + min;
                xz.a(bArr, writableSegment$okio.data, writableSegment$okio.limit, i, i4);
                writableSegment$okio.limit += min;
                i = i4;
            }
            buffer.setSize$okio(buffer.size() + j);
            return buffer;
        } else {
            g00.f("source");
            throw null;
        }
    }

    public static final Buffer commonWrite(Buffer buffer, Source source, long j) {
        if (buffer == null) {
            g00.f("$this$commonWrite");
            throw null;
        } else if (source != null) {
            while (j > 0) {
                long read = source.read(buffer, j);
                if (read != -1) {
                    j -= read;
                } else {
                    throw new EOFException();
                }
            }
            return buffer;
        } else {
            g00.f("source");
            throw null;
        }
    }

    public static final long commonRead(Buffer buffer, Buffer buffer2, long j) {
        if (buffer == null) {
            g00.f("$this$commonRead");
            throw null;
        } else if (buffer2 != null) {
            if (!(j >= 0)) {
                throw new IllegalArgumentException(b2.v("byteCount < 0: ", j).toString());
            } else if (buffer.size() == 0) {
                return -1;
            } else {
                if (j > buffer.size()) {
                    j = buffer.size();
                }
                buffer2.write(buffer, j);
                return j;
            }
        } else {
            g00.f("sink");
            throw null;
        }
    }

    public static final void commonWrite(Buffer buffer, Buffer buffer2, long j) {
        Segment segment;
        if (buffer == null) {
            g00.f("$this$commonWrite");
            throw null;
        } else if (buffer2 != null) {
            if (buffer2 != buffer) {
                Util.checkOffsetAndCount(buffer2.size(), 0, j);
                while (j > 0) {
                    Segment segment2 = buffer2.head;
                    if (segment2 != null) {
                        int i = segment2.limit;
                        if (segment2 != null) {
                            if (j < ((long) (i - segment2.pos))) {
                                Segment segment3 = buffer.head;
                                if (segment3 == null) {
                                    segment = null;
                                } else if (segment3 != null) {
                                    segment = segment3.prev;
                                } else {
                                    g00.e();
                                    throw null;
                                }
                                if (segment != null && segment.owner) {
                                    if ((((long) segment.limit) + j) - ((long) (segment.shared ? 0 : segment.pos)) <= ((long) 8192)) {
                                        if (segment2 != null) {
                                            segment2.writeTo(segment, (int) j);
                                            buffer2.setSize$okio(buffer2.size() - j);
                                            buffer.setSize$okio(buffer.size() + j);
                                            return;
                                        }
                                        g00.e();
                                        throw null;
                                    }
                                }
                                if (segment2 != null) {
                                    buffer2.head = segment2.split((int) j);
                                } else {
                                    g00.e();
                                    throw null;
                                }
                            }
                            Segment segment4 = buffer2.head;
                            if (segment4 != null) {
                                long j2 = (long) (segment4.limit - segment4.pos);
                                buffer2.head = segment4.pop();
                                Segment segment5 = buffer.head;
                                if (segment5 == null) {
                                    buffer.head = segment4;
                                    segment4.prev = segment4;
                                    segment4.next = segment4;
                                } else if (segment5 != null) {
                                    Segment segment6 = segment5.prev;
                                    if (segment6 != null) {
                                        segment6.push(segment4).compact();
                                    } else {
                                        g00.e();
                                        throw null;
                                    }
                                } else {
                                    g00.e();
                                    throw null;
                                }
                                buffer2.setSize$okio(buffer2.size() - j2);
                                buffer.setSize$okio(buffer.size() + j2);
                                j -= j2;
                            } else {
                                g00.e();
                                throw null;
                            }
                        } else {
                            g00.e();
                            throw null;
                        }
                    } else {
                        g00.e();
                        throw null;
                    }
                }
                return;
            }
            throw new IllegalArgumentException("source == this".toString());
        } else {
            g00.f("source");
            throw null;
        }
    }

    public static final long commonIndexOf(Buffer buffer, ByteString byteString, long j) {
        long j2 = j;
        if (buffer == null) {
            g00.f("$this$commonIndexOf");
            throw null;
        } else if (byteString == null) {
            g00.f("bytes");
            throw null;
        } else if (byteString.size() > 0) {
            long j3 = 0;
            if (j2 >= 0) {
                Segment segment = buffer.head;
                if (segment == null) {
                    return -1;
                }
                if (buffer.size() - j2 < j2) {
                    long size = buffer.size();
                    while (size > j2) {
                        segment = segment.prev;
                        if (segment != null) {
                            size -= (long) (segment.limit - segment.pos);
                        } else {
                            g00.e();
                            throw null;
                        }
                    }
                    byte[] internalArray$okio = byteString.internalArray$okio();
                    byte b = internalArray$okio[0];
                    int size2 = byteString.size();
                    long size3 = (buffer.size() - ((long) size2)) + 1;
                    Segment segment2 = segment;
                    while (size < size3) {
                        byte[] bArr = segment2.data;
                        int min = (int) Math.min((long) segment2.limit, (((long) segment2.pos) + size3) - size);
                        for (int i = (int) ((((long) segment2.pos) + j2) - size); i < min; i++) {
                            if (bArr[i] == b) {
                                if (rangeEquals(segment2, i + 1, internalArray$okio, 1, size2)) {
                                    return ((long) (i - segment2.pos)) + size;
                                }
                            }
                        }
                        j2 = size + ((long) (segment2.limit - segment2.pos));
                        segment2 = segment2.next;
                        if (segment2 != null) {
                            size = j2;
                        } else {
                            g00.e();
                            throw null;
                        }
                    }
                    return -1;
                }
                while (true) {
                    long j4 = ((long) (segment.limit - segment.pos)) + j3;
                    if (j4 > j2) {
                        byte[] internalArray$okio2 = byteString.internalArray$okio();
                        byte b2 = internalArray$okio2[0];
                        int size4 = byteString.size();
                        long size5 = (buffer.size() - ((long) size4)) + 1;
                        while (j3 < size5) {
                            byte[] bArr2 = segment.data;
                            int min2 = (int) Math.min((long) segment.limit, (((long) segment.pos) + size5) - j3);
                            for (int i2 = (int) ((((long) segment.pos) + j2) - j3); i2 < min2; i2++) {
                                if (bArr2[i2] == b2 && rangeEquals(segment, i2 + 1, internalArray$okio2, 1, size4)) {
                                    return ((long) (i2 - segment.pos)) + j3;
                                }
                            }
                            j3 += (long) (segment.limit - segment.pos);
                            segment = segment.next;
                            if (segment != null) {
                                j2 = j3;
                            } else {
                                g00.e();
                                throw null;
                            }
                        }
                        return -1;
                    }
                    segment = segment.next;
                    if (segment != null) {
                        j3 = j4;
                    } else {
                        g00.e();
                        throw null;
                    }
                }
            } else {
                throw new IllegalArgumentException(b2.v("fromIndex < 0: ", j2).toString());
            }
        } else {
            throw new IllegalArgumentException("bytes is empty".toString());
        }
    }
}
