package okio.internal;

import androidx.base.b;
import androidx.base.b2;
import androidx.base.g00;
import java.io.EOFException;
import okio.Buffer;
import okio.BufferedSource;
import okio.ByteString;
import okio.Okio;
import okio.Options;
import okio.PeekSource;
import okio.RealBufferedSource;
import okio.Sink;
import okio.Timeout;
import okio.Util;

public final class RealBufferedSourceKt {
    public static final void commonClose(RealBufferedSource realBufferedSource) {
        if (realBufferedSource == null) {
            g00.f("$this$commonClose");
            throw null;
        } else if (!realBufferedSource.closed) {
            realBufferedSource.closed = true;
            realBufferedSource.source.close();
            realBufferedSource.bufferField.clear();
        }
    }

    public static final boolean commonExhausted(RealBufferedSource realBufferedSource) {
        if (realBufferedSource == null) {
            g00.f("$this$commonExhausted");
            throw null;
        } else if (!(!realBufferedSource.closed)) {
            throw new IllegalStateException("closed".toString());
        } else if (!realBufferedSource.bufferField.exhausted() || realBufferedSource.source.read(realBufferedSource.bufferField, (long) 8192) != -1) {
            return false;
        } else {
            return true;
        }
    }

    public static final long commonIndexOf(RealBufferedSource realBufferedSource, byte b, long j, long j2) {
        if (realBufferedSource != null) {
            boolean z = true;
            if (!realBufferedSource.closed) {
                if (0 > j || j2 < j) {
                    z = false;
                }
                if (z) {
                    while (j < j2) {
                        long indexOf = realBufferedSource.bufferField.indexOf(b, j, j2);
                        if (indexOf == -1) {
                            long size = realBufferedSource.bufferField.size();
                            if (size >= j2 || realBufferedSource.source.read(realBufferedSource.bufferField, (long) 8192) == -1) {
                                break;
                            }
                            j = Math.max(j, size);
                        } else {
                            return indexOf;
                        }
                    }
                    return -1;
                }
                throw new IllegalArgumentException(("fromIndex=" + j + " toIndex=" + j2).toString());
            }
            throw new IllegalStateException("closed".toString());
        }
        g00.f("$this$commonIndexOf");
        throw null;
    }

    public static final long commonIndexOfElement(RealBufferedSource realBufferedSource, ByteString byteString, long j) {
        if (realBufferedSource == null) {
            g00.f("$this$commonIndexOfElement");
            throw null;
        } else if (byteString == null) {
            g00.f("targetBytes");
            throw null;
        } else if (!realBufferedSource.closed) {
            while (true) {
                long indexOfElement = realBufferedSource.bufferField.indexOfElement(byteString, j);
                if (indexOfElement != -1) {
                    return indexOfElement;
                }
                long size = realBufferedSource.bufferField.size();
                if (realBufferedSource.source.read(realBufferedSource.bufferField, (long) 8192) == -1) {
                    return -1;
                }
                j = Math.max(j, size);
            }
        } else {
            throw new IllegalStateException("closed".toString());
        }
    }

    public static final BufferedSource commonPeek(RealBufferedSource realBufferedSource) {
        if (realBufferedSource != null) {
            return Okio.buffer(new PeekSource(realBufferedSource));
        }
        g00.f("$this$commonPeek");
        throw null;
    }

    public static final boolean commonRangeEquals(RealBufferedSource realBufferedSource, long j, ByteString byteString, int i, int i2) {
        if (realBufferedSource == null) {
            g00.f("$this$commonRangeEquals");
            throw null;
        } else if (byteString == null) {
            g00.f("bytes");
            throw null;
        } else if (!(!realBufferedSource.closed)) {
            throw new IllegalStateException("closed".toString());
        } else if (j < 0 || i < 0 || i2 < 0 || byteString.size() - i < i2) {
            return false;
        } else {
            for (int i3 = 0; i3 < i2; i3++) {
                long j2 = ((long) i3) + j;
                if (!(realBufferedSource.request(1 + j2) && realBufferedSource.bufferField.getByte(j2) == byteString.getByte(i + i3))) {
                    return false;
                }
            }
            return true;
        }
    }

    public static final long commonRead(RealBufferedSource realBufferedSource, Buffer buffer, long j) {
        if (realBufferedSource == null) {
            g00.f("$this$commonRead");
            throw null;
        } else if (buffer != null) {
            if (!(j >= 0)) {
                throw new IllegalArgumentException(b2.v("byteCount < 0: ", j).toString());
            } else if (!(!realBufferedSource.closed)) {
                throw new IllegalStateException("closed".toString());
            } else if (realBufferedSource.bufferField.size() == 0 && realBufferedSource.source.read(realBufferedSource.bufferField, (long) 8192) == -1) {
                return -1;
            } else {
                return realBufferedSource.bufferField.read(buffer, Math.min(j, realBufferedSource.bufferField.size()));
            }
        } else {
            g00.f("sink");
            throw null;
        }
    }

    public static final long commonReadAll(RealBufferedSource realBufferedSource, Sink sink) {
        if (realBufferedSource == null) {
            g00.f("$this$commonReadAll");
            throw null;
        } else if (sink != null) {
            long j = 0;
            while (realBufferedSource.source.read(realBufferedSource.bufferField, (long) 8192) != -1) {
                long completeSegmentByteCount = realBufferedSource.bufferField.completeSegmentByteCount();
                if (completeSegmentByteCount > 0) {
                    j += completeSegmentByteCount;
                    sink.write(realBufferedSource.bufferField, completeSegmentByteCount);
                }
            }
            if (realBufferedSource.bufferField.size() <= 0) {
                return j;
            }
            long size = j + realBufferedSource.bufferField.size();
            Buffer buffer = realBufferedSource.bufferField;
            sink.write(buffer, buffer.size());
            return size;
        } else {
            g00.f("sink");
            throw null;
        }
    }

    public static final byte commonReadByte(RealBufferedSource realBufferedSource) {
        if (realBufferedSource != null) {
            realBufferedSource.require(1);
            return realBufferedSource.bufferField.readByte();
        }
        g00.f("$this$commonReadByte");
        throw null;
    }

    public static final byte[] commonReadByteArray(RealBufferedSource realBufferedSource, long j) {
        if (realBufferedSource != null) {
            realBufferedSource.require(j);
            return realBufferedSource.bufferField.readByteArray(j);
        }
        g00.f("$this$commonReadByteArray");
        throw null;
    }

    public static final ByteString commonReadByteString(RealBufferedSource realBufferedSource, long j) {
        if (realBufferedSource != null) {
            realBufferedSource.require(j);
            return realBufferedSource.bufferField.readByteString(j);
        }
        g00.f("$this$commonReadByteString");
        throw null;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:14:0x0030, code lost:
        if (r4 == 0) goto L_0x0033;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:15:0x0033, code lost:
        r10 = new java.lang.StringBuilder();
        r10.append("Expected leading [0-9] or '-' character but was 0x");
        androidx.base.b.k(16);
        androidx.base.b.k(16);
        r0 = java.lang.Integer.toString(r8, 16);
        androidx.base.g00.b(r0, "java.lang.Integer.toStri…(this, checkRadix(radix))");
        r10.append(r0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x005a, code lost:
        throw new java.lang.NumberFormatException(r10.toString());
     */
    public static final long commonReadDecimalLong(RealBufferedSource realBufferedSource) {
        if (realBufferedSource != null) {
            realBufferedSource.require(1);
            long j = 0;
            while (true) {
                long j2 = j + 1;
                if (!realBufferedSource.request(j2)) {
                    break;
                }
                byte b = realBufferedSource.bufferField.getByte(j);
                if ((b >= ((byte) 48) && b <= ((byte) 57)) || (j == 0 && b == ((byte) 45))) {
                    j = j2;
                }
            }
            return realBufferedSource.bufferField.readDecimalLong();
        }
        g00.f("$this$commonReadDecimalLong");
        throw null;
    }

    public static final void commonReadFully(RealBufferedSource realBufferedSource, byte[] bArr) {
        if (realBufferedSource == null) {
            g00.f("$this$commonReadFully");
            throw null;
        } else if (bArr != null) {
            try {
                realBufferedSource.require((long) bArr.length);
                realBufferedSource.bufferField.readFully(bArr);
            } catch (EOFException e) {
                int i = 0;
                while (realBufferedSource.bufferField.size() > 0) {
                    Buffer buffer = realBufferedSource.bufferField;
                    int read = buffer.read(bArr, i, (int) buffer.size());
                    if (read != -1) {
                        i += read;
                    } else {
                        throw new AssertionError();
                    }
                }
                throw e;
            }
        } else {
            g00.f("sink");
            throw null;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:18:0x003c  */
    public static final long commonReadHexadecimalUnsignedLong(RealBufferedSource realBufferedSource) {
        if (realBufferedSource != null) {
            realBufferedSource.require(1);
            int i = 0;
            while (true) {
                int i2 = i + 1;
                if (!realBufferedSource.request((long) i2)) {
                    break;
                }
                byte b = realBufferedSource.bufferField.getByte((long) i);
                if ((b >= ((byte) 48) && b <= ((byte) 57)) || ((b >= ((byte) 97) && b <= ((byte) 102)) || (b >= ((byte) 65) && b <= ((byte) 70)))) {
                    i = i2;
                } else if (i == 0) {
                    StringBuilder sb = new StringBuilder();
                    sb.append("Expected leading [0-9a-fA-F] character but was 0x");
                    b.k(16);
                    b.k(16);
                    String num = Integer.toString(b, 16);
                    g00.b(num, "java.lang.Integer.toStri…(this, checkRadix(radix))");
                    sb.append(num);
                    throw new NumberFormatException(sb.toString());
                }
            }
            if (i == 0) {
            }
            return realBufferedSource.bufferField.readHexadecimalUnsignedLong();
        }
        g00.f("$this$commonReadHexadecimalUnsignedLong");
        throw null;
    }

    public static final int commonReadInt(RealBufferedSource realBufferedSource) {
        if (realBufferedSource != null) {
            realBufferedSource.require(4);
            return realBufferedSource.bufferField.readInt();
        }
        g00.f("$this$commonReadInt");
        throw null;
    }

    public static final int commonReadIntLe(RealBufferedSource realBufferedSource) {
        if (realBufferedSource != null) {
            realBufferedSource.require(4);
            return realBufferedSource.bufferField.readIntLe();
        }
        g00.f("$this$commonReadIntLe");
        throw null;
    }

    public static final long commonReadLong(RealBufferedSource realBufferedSource) {
        if (realBufferedSource != null) {
            realBufferedSource.require(8);
            return realBufferedSource.bufferField.readLong();
        }
        g00.f("$this$commonReadLong");
        throw null;
    }

    public static final long commonReadLongLe(RealBufferedSource realBufferedSource) {
        if (realBufferedSource != null) {
            realBufferedSource.require(8);
            return realBufferedSource.bufferField.readLongLe();
        }
        g00.f("$this$commonReadLongLe");
        throw null;
    }

    public static final short commonReadShort(RealBufferedSource realBufferedSource) {
        if (realBufferedSource != null) {
            realBufferedSource.require(2);
            return realBufferedSource.bufferField.readShort();
        }
        g00.f("$this$commonReadShort");
        throw null;
    }

    public static final short commonReadShortLe(RealBufferedSource realBufferedSource) {
        if (realBufferedSource != null) {
            realBufferedSource.require(2);
            return realBufferedSource.bufferField.readShortLe();
        }
        g00.f("$this$commonReadShortLe");
        throw null;
    }

    public static final String commonReadUtf8(RealBufferedSource realBufferedSource, long j) {
        if (realBufferedSource != null) {
            realBufferedSource.require(j);
            return realBufferedSource.bufferField.readUtf8(j);
        }
        g00.f("$this$commonReadUtf8");
        throw null;
    }

    public static final int commonReadUtf8CodePoint(RealBufferedSource realBufferedSource) {
        if (realBufferedSource != null) {
            realBufferedSource.require(1);
            byte b = realBufferedSource.bufferField.getByte(0);
            if ((b & 224) == 192) {
                realBufferedSource.require(2);
            } else if ((b & 240) == 224) {
                realBufferedSource.require(3);
            } else if ((b & 248) == 240) {
                realBufferedSource.require(4);
            }
            return realBufferedSource.bufferField.readUtf8CodePoint();
        }
        g00.f("$this$commonReadUtf8CodePoint");
        throw null;
    }

    public static final String commonReadUtf8Line(RealBufferedSource realBufferedSource) {
        if (realBufferedSource != null) {
            long indexOf = realBufferedSource.indexOf((byte) 10);
            if (indexOf != -1) {
                return BufferKt.readUtf8Line(realBufferedSource.bufferField, indexOf);
            }
            if (realBufferedSource.bufferField.size() != 0) {
                return realBufferedSource.readUtf8(realBufferedSource.bufferField.size());
            }
            return null;
        }
        g00.f("$this$commonReadUtf8Line");
        throw null;
    }

    public static final String commonReadUtf8LineStrict(RealBufferedSource realBufferedSource, long j) {
        if (realBufferedSource != null) {
            if (j >= 0) {
                long j2 = j == Long.MAX_VALUE ? Long.MAX_VALUE : j + 1;
                byte b = (byte) 10;
                long indexOf = realBufferedSource.indexOf(b, 0, j2);
                if (indexOf != -1) {
                    return BufferKt.readUtf8Line(realBufferedSource.bufferField, indexOf);
                }
                if (j2 < Long.MAX_VALUE && realBufferedSource.request(j2) && realBufferedSource.bufferField.getByte(j2 - 1) == ((byte) 13) && realBufferedSource.request(1 + j2) && realBufferedSource.bufferField.getByte(j2) == b) {
                    return BufferKt.readUtf8Line(realBufferedSource.bufferField, j2);
                }
                Buffer buffer = new Buffer();
                Buffer buffer2 = realBufferedSource.bufferField;
                buffer2.copyTo(buffer, 0, Math.min((long) 32, buffer2.size()));
                throw new EOFException("\\n not found: limit=" + Math.min(realBufferedSource.bufferField.size(), j) + " content=" + buffer.readByteString().hex() + "…");
            }
            throw new IllegalArgumentException(b2.v("limit < 0: ", j).toString());
        }
        g00.f("$this$commonReadUtf8LineStrict");
        throw null;
    }

    public static final boolean commonRequest(RealBufferedSource realBufferedSource, long j) {
        if (realBufferedSource != null) {
            if (!(j >= 0)) {
                throw new IllegalArgumentException(b2.v("byteCount < 0: ", j).toString());
            } else if (!realBufferedSource.closed) {
                while (realBufferedSource.bufferField.size() < j) {
                    if (realBufferedSource.source.read(realBufferedSource.bufferField, (long) 8192) == -1) {
                        return false;
                    }
                }
                return true;
            } else {
                throw new IllegalStateException("closed".toString());
            }
        } else {
            g00.f("$this$commonRequest");
            throw null;
        }
    }

    public static final void commonRequire(RealBufferedSource realBufferedSource, long j) {
        if (realBufferedSource == null) {
            g00.f("$this$commonRequire");
            throw null;
        } else if (!realBufferedSource.request(j)) {
            throw new EOFException();
        }
    }

    public static final int commonSelect(RealBufferedSource realBufferedSource, Options options) {
        if (realBufferedSource == null) {
            g00.f("$this$commonSelect");
            throw null;
        } else if (options == null) {
            g00.f("options");
            throw null;
        } else if (!realBufferedSource.closed) {
            do {
                int selectPrefix = BufferKt.selectPrefix(realBufferedSource.bufferField, options, true);
                if (selectPrefix != -2) {
                    if (selectPrefix == -1) {
                        return -1;
                    }
                    realBufferedSource.bufferField.skip((long) options.getByteStrings$okio()[selectPrefix].size());
                    return selectPrefix;
                }
            } while (realBufferedSource.source.read(realBufferedSource.bufferField, (long) 8192) != -1);
            return -1;
        } else {
            throw new IllegalStateException("closed".toString());
        }
    }

    public static final void commonSkip(RealBufferedSource realBufferedSource, long j) {
        if (realBufferedSource == null) {
            g00.f("$this$commonSkip");
            throw null;
        } else if (!realBufferedSource.closed) {
            while (j > 0) {
                if (realBufferedSource.bufferField.size() == 0 && realBufferedSource.source.read(realBufferedSource.bufferField, (long) 8192) == -1) {
                    throw new EOFException();
                }
                long min = Math.min(j, realBufferedSource.bufferField.size());
                realBufferedSource.bufferField.skip(min);
                j -= min;
            }
        } else {
            throw new IllegalStateException("closed".toString());
        }
    }

    public static final Timeout commonTimeout(RealBufferedSource realBufferedSource) {
        if (realBufferedSource != null) {
            return realBufferedSource.source.timeout();
        }
        g00.f("$this$commonTimeout");
        throw null;
    }

    public static final String commonToString(RealBufferedSource realBufferedSource) {
        if (realBufferedSource != null) {
            StringBuilder j = b2.j("buffer(");
            j.append(realBufferedSource.source);
            j.append(')');
            return j.toString();
        }
        g00.f("$this$commonToString");
        throw null;
    }

    public static final byte[] commonReadByteArray(RealBufferedSource realBufferedSource) {
        if (realBufferedSource != null) {
            realBufferedSource.bufferField.writeAll(realBufferedSource.source);
            return realBufferedSource.bufferField.readByteArray();
        }
        g00.f("$this$commonReadByteArray");
        throw null;
    }

    public static final ByteString commonReadByteString(RealBufferedSource realBufferedSource) {
        if (realBufferedSource != null) {
            realBufferedSource.bufferField.writeAll(realBufferedSource.source);
            return realBufferedSource.bufferField.readByteString();
        }
        g00.f("$this$commonReadByteString");
        throw null;
    }

    public static final String commonReadUtf8(RealBufferedSource realBufferedSource) {
        if (realBufferedSource != null) {
            realBufferedSource.bufferField.writeAll(realBufferedSource.source);
            return realBufferedSource.bufferField.readUtf8();
        }
        g00.f("$this$commonReadUtf8");
        throw null;
    }

    public static final void commonReadFully(RealBufferedSource realBufferedSource, Buffer buffer, long j) {
        if (realBufferedSource == null) {
            g00.f("$this$commonReadFully");
            throw null;
        } else if (buffer != null) {
            try {
                realBufferedSource.require(j);
                realBufferedSource.bufferField.readFully(buffer, j);
            } catch (EOFException e) {
                buffer.writeAll(realBufferedSource.bufferField);
                throw e;
            }
        } else {
            g00.f("sink");
            throw null;
        }
    }

    public static final long commonIndexOf(RealBufferedSource realBufferedSource, ByteString byteString, long j) {
        if (realBufferedSource == null) {
            g00.f("$this$commonIndexOf");
            throw null;
        } else if (byteString == null) {
            g00.f("bytes");
            throw null;
        } else if (!realBufferedSource.closed) {
            while (true) {
                long indexOf = realBufferedSource.bufferField.indexOf(byteString, j);
                if (indexOf != -1) {
                    return indexOf;
                }
                long size = realBufferedSource.bufferField.size();
                if (realBufferedSource.source.read(realBufferedSource.bufferField, (long) 8192) == -1) {
                    return -1;
                }
                j = Math.max(j, (size - ((long) byteString.size())) + 1);
            }
        } else {
            throw new IllegalStateException("closed".toString());
        }
    }

    public static final int commonRead(RealBufferedSource realBufferedSource, byte[] bArr, int i, int i2) {
        if (realBufferedSource == null) {
            g00.f("$this$commonRead");
            throw null;
        } else if (bArr != null) {
            long j = (long) i2;
            Util.checkOffsetAndCount((long) bArr.length, (long) i, j);
            if (realBufferedSource.bufferField.size() == 0 && realBufferedSource.source.read(realBufferedSource.bufferField, (long) 8192) == -1) {
                return -1;
            }
            return realBufferedSource.bufferField.read(bArr, i, (int) Math.min(j, realBufferedSource.bufferField.size()));
        } else {
            g00.f("sink");
            throw null;
        }
    }
}
