package org.chromium.base;

import android.animation.Animator;
import android.animation.AnimatorListenerAdapter;
import android.animation.TimeAnimator;
import android.util.Log;
import org.chromium.base.annotations.MainDex;

@MainDex
public class AnimationFrameTimeHistogram {
    private static final int MAX_FRAME_TIME_NUM = 600;
    private static final String TAG = "AnimationFrameTimeHistogram";
    private final String mHistogramName;
    private final Recorder mRecorder = new Recorder();

    public static class Recorder implements TimeAnimator.TimeListener {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        private final TimeAnimator mAnimator;
        private int mFrameTimesCount;
        private long[] mFrameTimesMs;

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void cleanUp() {
            this.mFrameTimesMs = null;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private boolean endRecording() {
            boolean isStarted = this.mAnimator.isStarted();
            this.mAnimator.end();
            return isStarted;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private int getFrameTimesCount() {
            return this.mFrameTimesCount;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private long[] getFrameTimesMs() {
            return this.mFrameTimesMs;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void startRecording() {
            this.mFrameTimesCount = 0;
            this.mFrameTimesMs = new long[600];
            this.mAnimator.start();
        }

        public void onTimeUpdate(TimeAnimator timeAnimator, long j, long j2) {
            int i = this.mFrameTimesCount;
            long[] jArr = this.mFrameTimesMs;
            if (i == jArr.length) {
                this.mAnimator.end();
                cleanUp();
                Log.w(AnimationFrameTimeHistogram.TAG, "Animation frame time recording reached the maximum number. It's eitherthe animation took too long or recording end is not called.");
            } else if (j2 > 0) {
                this.mFrameTimesCount = i + 1;
                jArr[i] = j2;
            }
        }

        private Recorder() {
            TimeAnimator timeAnimator = new TimeAnimator();
            this.mAnimator = timeAnimator;
            timeAnimator.setTimeListener(this);
        }
    }

    public AnimationFrameTimeHistogram(String str) {
        this.mHistogramName = str;
    }

    public static Animator.AnimatorListener getAnimatorRecorder(String str) {
        return new AnimatorListenerAdapter(str) {
            /* class org.chromium.base.AnimationFrameTimeHistogram.AnonymousClass1 */
            private final AnimationFrameTimeHistogram mAnimationFrameTimeHistogram;
            public final /* synthetic */ String val$histogramName;

            {
                this.val$histogramName = r2;
                this.mAnimationFrameTimeHistogram = new AnimationFrameTimeHistogram(r2);
            }

            public void onAnimationCancel(Animator animator) {
                this.mAnimationFrameTimeHistogram.endRecording();
            }

            public void onAnimationEnd(Animator animator) {
                this.mAnimationFrameTimeHistogram.endRecording();
            }

            public void onAnimationStart(Animator animator) {
                this.mAnimationFrameTimeHistogram.startRecording();
            }
        };
    }

    private native void nativeSaveHistogram(String str, long[] jArr, int i);

    public void endRecording() {
        if (this.mRecorder.endRecording()) {
            nativeSaveHistogram(this.mHistogramName, this.mRecorder.getFrameTimesMs(), this.mRecorder.getFrameTimesCount());
        }
        this.mRecorder.cleanUp();
    }

    public void startRecording() {
        this.mRecorder.startRecording();
    }
}
