package org.chromium.base;

import android.content.Context;
import android.content.pm.PackageManager;
import android.os.Build;
import android.os.StrictMode;
import org.chromium.base.annotations.CalledByNative;

public class BuildInfo {
    private static final int MAX_FINGERPRINT_LENGTH = 128;
    private static final String TAG = "BuildInfo";

    private BuildInfo() {
    }

    @CalledByNative
    public static String getAndroidBuildFingerprint() {
        String str = Build.FINGERPRINT;
        return str.substring(0, Math.min(str.length(), 128));
    }

    @CalledByNative
    public static String getAndroidBuildId() {
        return Build.ID;
    }

    @CalledByNative
    public static String getBrand() {
        return Build.BRAND;
    }

    @CalledByNative
    public static String getBuildType() {
        return Build.TYPE;
    }

    @CalledByNative
    public static String getDevice() {
        return Build.DEVICE;
    }

    @CalledByNative
    public static String getDeviceManufacturer() {
        return Build.MANUFACTURER;
    }

    @CalledByNative
    public static String getDeviceModel() {
        return Build.MODEL;
    }

    @CalledByNative
    public static String getGMSVersionCode(Context context) {
        try {
            return Integer.toString(context.getPackageManager().getPackageInfo("com.google.android.gms", 0).versionCode);
        } catch (PackageManager.NameNotFoundException e) {
            Log.d(TAG, "GMS package is not found: %s", e);
            return "gms versionCode not available.";
        }
    }

    @CalledByNative
    public static String getPackageLabel(Context context) {
        String str = "";
        StrictMode.ThreadPolicy allowThreadDiskReads = StrictMode.allowThreadDiskReads();
        try {
            PackageManager packageManager = context.getPackageManager();
            CharSequence applicationLabel = packageManager.getApplicationLabel(packageManager.getApplicationInfo(context.getPackageName(), 128));
            if (applicationLabel != null) {
                str = applicationLabel.toString();
            }
            return str;
        } catch (PackageManager.NameNotFoundException unused) {
            return str;
        } finally {
            StrictMode.setThreadPolicy(allowThreadDiskReads);
        }
    }

    @CalledByNative
    public static String getPackageName(Context context) {
        String packageName = context != null ? context.getPackageName() : null;
        return packageName != null ? packageName : "";
    }

    @CalledByNative
    public static String getPackageVersionCode(Context context) {
        try {
            int i = context.getPackageManager().getPackageInfo(context.getPackageName(), 0).versionCode;
            if (i > 0) {
                return Integer.toString(i);
            }
            return "";
        } catch (PackageManager.NameNotFoundException unused) {
            Log.d(TAG, "versionCode not available.");
            return "versionCode not available.";
        }
    }

    @CalledByNative
    public static String getPackageVersionName(Context context) {
        String str = "versionName not available";
        try {
            str = "";
            String str2 = context.getPackageManager().getPackageInfo(context.getPackageName(), 0).versionName;
            return str2 != null ? str2 : str;
        } catch (PackageManager.NameNotFoundException unused) {
            Log.d(TAG, str);
            return str;
        }
    }

    @CalledByNative
    public static int getSdkInt() {
        return Build.VERSION.SDK_INT;
    }

    public static boolean isGreaterThanN() {
        return Build.VERSION.SDK_INT > 24 || Build.VERSION.CODENAME.equals("NMR1");
    }
}
