package org.chromium.base;

import android.content.ContentResolver;
import android.content.Context;
import android.database.Cursor;
import android.net.Uri;
import android.os.ParcelFileDescriptor;
import android.util.Log;
import java.io.File;
import java.io.FileNotFoundException;
import org.chromium.base.annotations.CalledByNative;

public abstract class ContentUriUtils {
    private static final String TAG = "ContentUriUtils";
    private static FileProviderUtil sFileProviderUtil;
    private static final Object sLock = new Object();

    public interface FileProviderUtil {
        Uri getContentUriFromFile(Context context, File file);
    }

    private ContentUriUtils() {
    }

    @CalledByNative
    public static boolean contentUriExists(Context context, String str) {
        return getParcelFileDescriptor(context, str) != null;
    }

    public static Uri getContentUriFromFile(Context context, File file) {
        synchronized (sLock) {
            FileProviderUtil fileProviderUtil = sFileProviderUtil;
            if (fileProviderUtil == null) {
                return null;
            }
            return fileProviderUtil.getContentUriFromFile(context, file);
        }
    }

    public static String getDisplayName(Uri uri, ContentResolver contentResolver, String str) {
        if (!(contentResolver == null || uri == null)) {
            Cursor cursor = null;
            try {
                Cursor query = contentResolver.query(uri, null, null, null, null);
                if (query != null && query.getCount() >= 1) {
                    query.moveToFirst();
                    int columnIndex = query.getColumnIndex(str);
                    if (columnIndex > -1) {
                        String string = query.getString(columnIndex);
                        query.close();
                        return string;
                    }
                }
                if (query != null) {
                    query.close();
                }
                return "";
            } catch (NullPointerException unused) {
                if (0 != 0) {
                    cursor.close();
                }
            } catch (Throwable th) {
                if (0 != 0) {
                    cursor.close();
                }
                throw th;
            }
        }
        return "";
    }

    @CalledByNative
    public static String getMimeType(Context context, String str) {
        ContentResolver contentResolver = context.getContentResolver();
        if (contentResolver == null) {
            return null;
        }
        return contentResolver.getType(Uri.parse(str));
    }

    private static ParcelFileDescriptor getParcelFileDescriptor(Context context, String str) {
        try {
            return context.getContentResolver().openFileDescriptor(Uri.parse(str), "r");
        } catch (FileNotFoundException e) {
            Log.w(TAG, "Cannot find content uri: " + str, e);
        } catch (SecurityException e2) {
            Log.w(TAG, "Cannot open content uri: " + str, e2);
        } catch (IllegalArgumentException e3) {
            Log.w(TAG, "Unknown content uri: " + str, e3);
        } catch (IllegalStateException e4) {
            Log.w(TAG, "Unknown content uri: " + str, e4);
        }
        return null;
    }

    @CalledByNative
    public static int openContentUriForRead(Context context, String str) {
        ParcelFileDescriptor parcelFileDescriptor = getParcelFileDescriptor(context, str);
        if (parcelFileDescriptor != null) {
            return parcelFileDescriptor.detachFd();
        }
        return -1;
    }

    public static void setFileProviderUtil(FileProviderUtil fileProviderUtil) {
        synchronized (sLock) {
            sFileProviderUtil = fileProviderUtil;
        }
    }
}
