package org.chromium.base;

import android.content.Context;
import android.content.SharedPreferences;
import android.preference.PreferenceManager;
import org.chromium.base.annotations.JNINamespace;

@JNINamespace("base::android")
public class ContextUtils {
    private static final String TAG = "ContextUtils";
    private static Context sApplicationContext;

    public static class Holder {
        private static SharedPreferences sSharedPreferences = ContextUtils.fetchAppSharedPreferences();

        private Holder() {
        }
    }

    /* access modifiers changed from: private */
    public static SharedPreferences fetchAppSharedPreferences() {
        return PreferenceManager.getDefaultSharedPreferences(sApplicationContext);
    }

    public static SharedPreferences getAppSharedPreferences() {
        return Holder.sSharedPreferences;
    }

    public static Context getApplicationContext() {
        return sApplicationContext;
    }

    public static void initApplicationContext(Context context) {
        Context context2 = sApplicationContext;
        if (context2 == null || context2 == context) {
            initJavaSideApplicationContext(context);
        } else {
            Log.d(TAG, "Multiple contexts detected, ignoring new application context.");
        }
    }

    public static void initApplicationContextForNative() {
        Context context = sApplicationContext;
        if (context != null) {
            nativeInitNativeSideApplicationContext(context);
            return;
        }
        throw new RuntimeException("Cannot have native global application context be null.");
    }

    @VisibleForTesting
    public static void initApplicationContextForTests(Context context) {
        initJavaSideApplicationContext(context);
        SharedPreferences unused = Holder.sSharedPreferences = fetchAppSharedPreferences();
    }

    private static void initJavaSideApplicationContext(Context context) {
        if (context != null) {
            sApplicationContext = context;
            return;
        }
        throw new RuntimeException("Global application context cannot be set to null.");
    }

    private static native void nativeInitNativeSideApplicationContext(Context context);
}
