package org.chromium.base;

import androidx.base.b2;
import com.google.android.exoplayer2.text.ttml.TtmlNode;
import java.util.Locale;
import org.chromium.base.annotations.CalledByNative;

public class LocaleUtils {
    private LocaleUtils() {
    }

    @CalledByNative
    private static String getDefaultCountryCode() {
        CommandLine instance = CommandLine.getInstance();
        return instance.hasSwitch(BaseSwitches.DEFAULT_COUNTRY_CODE_AT_INSTALL) ? instance.getSwitchValue(BaseSwitches.DEFAULT_COUNTRY_CODE_AT_INSTALL) : Locale.getDefault().getCountry();
    }

    @CalledByNative
    public static String getDefaultLocale() {
        return getLocale(Locale.getDefault());
    }

    public static String getLocale(Locale locale) {
        String language = locale.getLanguage();
        String country = locale.getCountry();
        if ("iw".equals(language)) {
            language = "he";
        } else if ("in".equals(language)) {
            language = TtmlNode.ATTR_ID;
        } else if ("tl".equals(language)) {
            language = "fil";
        }
        return country.isEmpty() ? language : b2.d(language, "-", country);
    }
}
