package org.chromium.base;

import android.content.Context;
import android.content.pm.ApplicationInfo;
import android.os.AsyncTask;
import android.os.Environment;
import android.os.StrictMode;
import android.os.SystemClock;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.atomic.AtomicBoolean;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.MainDex;
import org.chromium.base.metrics.RecordHistogram;

@MainDex
public abstract class PathUtils {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final int CACHE_DIRECTORY = 3;
    private static final int DATABASE_DIRECTORY = 2;
    private static final int DATA_DIRECTORY = 0;
    private static final int NUM_DIRECTORIES = 4;
    private static final int THUMBNAIL_DIRECTORY = 1;
    private static final String THUMBNAIL_DIRECTORY_NAME = "textures";
    private static Context sDataDirectoryAppContext;
    private static String sDataDirectorySuffix;
    private static AsyncTask<Void, Void, String[]> sDirPathFetchTask;
    private static final AtomicBoolean sInitializationStarted = new AtomicBoolean();

    public static class Holder {
        private static final String[] DIRECTORY_PATHS = PathUtils.getOrComputeDirectoryPaths();

        private Holder() {
        }
    }

    private PathUtils() {
    }

    @CalledByNative
    public static String getCacheDirectory(Context context) {
        return getDirectoryPath(3);
    }

    @CalledByNative
    public static String getDataDirectory(Context context) {
        return getDirectoryPath(0);
    }

    @CalledByNative
    public static String getDatabaseDirectory(Context context) {
        return getDirectoryPath(2);
    }

    private static String getDirectoryPath(int i) {
        return Holder.DIRECTORY_PATHS[i];
    }

    @CalledByNative
    private static String getDownloadsDirectory(Context context) {
        StrictMode.ThreadPolicy allowThreadDiskReads = StrictMode.allowThreadDiskReads();
        try {
            long elapsedRealtime = SystemClock.elapsedRealtime();
            String path = Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_DOWNLOADS).getPath();
            RecordHistogram.recordTimesHistogram("Android.StrictMode.DownloadsDir", SystemClock.elapsedRealtime() - elapsedRealtime, TimeUnit.MILLISECONDS);
            return path;
        } finally {
            StrictMode.setThreadPolicy(allowThreadDiskReads);
        }
    }

    @CalledByNative
    public static String getExternalStorageDirectory() {
        return Environment.getExternalStorageDirectory().getAbsolutePath();
    }

    @CalledByNative
    private static String getNativeLibraryDirectory(Context context) {
        ApplicationInfo applicationInfo = context.getApplicationInfo();
        int i = applicationInfo.flags;
        if ((i & 128) != 0 || (i & 1) == 0) {
            return applicationInfo.nativeLibraryDir;
        }
        return "/system/lib/";
    }

    /* access modifiers changed from: private */
    public static String[] getOrComputeDirectoryPaths() {
        if (!sDirPathFetchTask.cancel(false)) {
            return sDirPathFetchTask.get();
        }
        StrictMode.ThreadPolicy allowThreadDiskReads = StrictMode.allowThreadDiskReads();
        StrictMode.allowThreadDiskWrites();
        try {
            String[] privateDataDirectorySuffixInternal = setPrivateDataDirectorySuffixInternal();
            StrictMode.setThreadPolicy(allowThreadDiskReads);
            return privateDataDirectorySuffixInternal;
        } catch (InterruptedException | ExecutionException unused) {
            return null;
        } catch (Throwable th) {
            StrictMode.setThreadPolicy(allowThreadDiskReads);
            throw th;
        }
    }

    @CalledByNative
    public static String getThumbnailCacheDirectory(Context context) {
        return getDirectoryPath(1);
    }

    public static void setPrivateDataDirectorySuffix(String str, Context context) {
        if (!sInitializationStarted.getAndSet(true)) {
            sDataDirectorySuffix = str;
            sDataDirectoryAppContext = context.getApplicationContext();
            sDirPathFetchTask = new AsyncTask<Void, Void, String[]>() {
                /* class org.chromium.base.PathUtils.AnonymousClass1 */

                public String[] doInBackground(Void... voidArr) {
                    return PathUtils.setPrivateDataDirectorySuffixInternal();
                }
            }.executeOnExecutor(AsyncTask.THREAD_POOL_EXECUTOR, new Void[0]);
        }
    }

    /* access modifiers changed from: private */
    public static String[] setPrivateDataDirectorySuffixInternal() {
        String[] strArr = new String[4];
        strArr[0] = sDataDirectoryAppContext.getDir(sDataDirectorySuffix, 0).getPath();
        strArr[1] = sDataDirectoryAppContext.getDir(THUMBNAIL_DIRECTORY_NAME, 0).getPath();
        strArr[2] = sDataDirectoryAppContext.getDatabasePath("foo").getParent();
        if (sDataDirectoryAppContext.getCacheDir() != null) {
            strArr[3] = sDataDirectoryAppContext.getCacheDir().getPath();
        }
        return strArr;
    }
}
