package org.chromium.base;

import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Handler;
import android.os.Looper;
import org.chromium.base.ApplicationStatus;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;

@JNINamespace("base::android")
public class PowerMonitor implements ApplicationStatus.ApplicationStateListener {
    private static final long SUSPEND_DELAY_MS = 60000;
    private static PowerMonitor sInstance;
    private static final Runnable sSuspendTask = new Runnable() {
        /* class org.chromium.base.PowerMonitor.AnonymousClass1 */

        public void run() {
            PowerMonitor.nativeOnMainActivitySuspended();
        }
    };
    private final Handler mHandler;
    private boolean mIsBatteryPower;

    public static class LazyHolder {
        private static final PowerMonitor INSTANCE = new PowerMonitor();

        private LazyHolder() {
        }
    }

    public static void create(Context context) {
        Context applicationContext = context.getApplicationContext();
        if (sInstance == null) {
            PowerMonitor powerMonitor = LazyHolder.INSTANCE;
            sInstance = powerMonitor;
            ApplicationStatus.registerApplicationStateListener(powerMonitor);
            Intent registerReceiver = applicationContext.registerReceiver(null, new IntentFilter("android.intent.action.BATTERY_CHANGED"));
            if (registerReceiver != null) {
                onBatteryChargingChanged(registerReceiver);
            }
        }
    }

    public static void createForTests(Context context) {
        sInstance = LazyHolder.INSTANCE;
    }

    @CalledByNative
    private static boolean isBatteryPower() {
        return sInstance.mIsBatteryPower;
    }

    private static native void nativeOnBatteryChargingChanged();

    private static native void nativeOnMainActivityResumed();

    /* access modifiers changed from: private */
    public static native void nativeOnMainActivitySuspended();

    public static void onBatteryChargingChanged(Intent intent) {
        if (sInstance != null) {
            int intExtra = intent.getIntExtra("plugged", -1);
            PowerMonitor powerMonitor = sInstance;
            boolean z = true;
            if (intExtra == 2 || intExtra == 1) {
                z = false;
            }
            powerMonitor.mIsBatteryPower = z;
            nativeOnBatteryChargingChanged();
        }
    }

    @Override // org.chromium.base.ApplicationStatus.ApplicationStateListener
    public void onApplicationStateChange(int i) {
        if (i == 1) {
            this.mHandler.removeCallbacks(sSuspendTask);
            nativeOnMainActivityResumed();
        } else if (i == 2) {
            this.mHandler.postDelayed(sSuspendTask, 60000);
        }
    }

    private PowerMonitor() {
        this.mHandler = new Handler(Looper.getMainLooper());
    }
}
