package org.chromium.components.web_contents_delegate_android;

import android.content.Context;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;
import org.chromium.content.browser.ContentViewCore;
import org.chromium.ui.ColorPickerDialog;
import org.chromium.ui.ColorSuggestion;
import org.chromium.ui.OnColorChangedListener;
import org.chromium.ui.base.WindowAndroid;

@JNINamespace("web_contents_delegate_android")
public class ColorChooserAndroid {
    private final ColorPickerDialog mDialog;
    private final long mNativeColorChooserAndroid;

    private ColorChooserAndroid(long j, Context context, int i, ColorSuggestion[] colorSuggestionArr) {
        AnonymousClass1 r0 = new OnColorChangedListener() {
            /* class org.chromium.components.web_contents_delegate_android.ColorChooserAndroid.AnonymousClass1 */

            @Override // org.chromium.ui.OnColorChangedListener
            public void onColorChanged(int i) {
                ColorChooserAndroid.this.mDialog.dismiss();
                ColorChooserAndroid colorChooserAndroid = ColorChooserAndroid.this;
                colorChooserAndroid.nativeOnColorChosen(colorChooserAndroid.mNativeColorChooserAndroid, i);
            }
        };
        this.mNativeColorChooserAndroid = j;
        this.mDialog = new ColorPickerDialog(context, r0, i, colorSuggestionArr);
    }

    @CalledByNative
    private static void addToColorSuggestionArray(ColorSuggestion[] colorSuggestionArr, int i, int i2, String str) {
        colorSuggestionArr[i] = new ColorSuggestion(i2, str);
    }

    @CalledByNative
    public static ColorChooserAndroid createColorChooserAndroid(long j, ContentViewCore contentViewCore, int i, ColorSuggestion[] colorSuggestionArr) {
        if (contentViewCore.getWindowAndroid() == null) {
            return null;
        }
        Context context = contentViewCore.getWindowAndroid().getContext().get();
        if (WindowAndroid.activityFromContext(context) == null) {
            return null;
        }
        ColorChooserAndroid colorChooserAndroid = new ColorChooserAndroid(j, context, i, colorSuggestionArr);
        colorChooserAndroid.openColorChooser();
        return colorChooserAndroid;
    }

    @CalledByNative
    private static ColorSuggestion[] createColorSuggestionArray(int i) {
        return new ColorSuggestion[i];
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native void nativeOnColorChosen(long j, int i);

    private void openColorChooser() {
        this.mDialog.show();
    }

    @CalledByNative
    public void closeColorChooser() {
        this.mDialog.dismiss();
    }
}
