package org.chromium.components.web_contents_delegate_android;

import android.graphics.Point;
import android.graphics.RectF;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.widget.PopupWindow;
import android.widget.RelativeLayout;
import android.widget.TextView;
import org.chromium.base.ApiCompatibilityUtils;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.content.browser.ContentViewCore;
import org.chromium.content.browser.RenderCoordinates;

public class ValidationMessageBubble {
    private PopupWindow mPopup;

    private ValidationMessageBubble(ContentViewCore contentViewCore, RectF rectF, String str, String str2) {
        ViewGroup viewGroup = (ViewGroup) View.inflate(contentViewCore.getContext(), R.layout.validation_message_bubble, null);
        this.mPopup = new PopupWindow(viewGroup);
        updateTextViews(viewGroup, str, str2);
        measure(contentViewCore.getRenderCoordinates());
        Point adjustWindowPosition = adjustWindowPosition(contentViewCore, (int) (rectF.centerX() - getAnchorOffset()), (int) rectF.bottom);
        this.mPopup.showAtLocation(contentViewCore.getContainerView(), 0, adjustWindowPosition.x, adjustWindowPosition.y);
    }

    private Point adjustWindowPosition(ContentViewCore contentViewCore, int i, int i2) {
        RenderCoordinates renderCoordinates = contentViewCore.getRenderCoordinates();
        int lastFrameViewportWidthPixInt = renderCoordinates.getLastFrameViewportWidthPixInt();
        int lastFrameViewportHeightPixInt = renderCoordinates.getLastFrameViewportHeightPixInt() + ((int) getWebViewOffsetYPixInScreen(contentViewCore));
        int measuredWidth = this.mPopup.getContentView().getMeasuredWidth();
        int measuredHeight = this.mPopup.getContentView().getMeasuredHeight();
        if (i < 0) {
            i = 0;
        } else if (i + measuredWidth > lastFrameViewportWidthPixInt) {
            i = lastFrameViewportWidthPixInt - measuredWidth;
        }
        if (i2 + measuredHeight > lastFrameViewportHeightPixInt) {
            i2 = lastFrameViewportHeightPixInt - measuredHeight;
        }
        return new Point(i, i2);
    }

    @CalledByNative
    private void close() {
        PopupWindow popupWindow = this.mPopup;
        if (popupWindow != null) {
            popupWindow.dismiss();
            this.mPopup = null;
        }
    }

    @CalledByNative
    private static ValidationMessageBubble createAndShow(ContentViewCore contentViewCore, int i, int i2, int i3, int i4, String str, String str2) {
        return new ValidationMessageBubble(contentViewCore, makePixRectInScreen(contentViewCore, i, i2, i3, i4), str, str2);
    }

    private float getAnchorOffset() {
        View contentView = this.mPopup.getContentView();
        int measuredWidth = contentView.getMeasuredWidth();
        int measuredWidth2 = contentView.findViewById(R.id.arrow_image).getMeasuredWidth();
        if (ApiCompatibilityUtils.isLayoutRtl(contentView)) {
            return (float) (((measuredWidth * 3) / 4) - (measuredWidth2 / 2));
        }
        return (float) ((measuredWidth2 / 2) + (measuredWidth / 4));
    }

    private static float getWebViewOffsetYPixInScreen(ContentViewCore contentViewCore) {
        int[] iArr = new int[2];
        contentViewCore.getContainerView().getLocationOnScreen(iArr);
        return contentViewCore.getRenderCoordinates().getContentOffsetYPix() + ((float) iArr[1]);
    }

    private static RectF makePixRectInScreen(ContentViewCore contentViewCore, int i, int i2, int i3, int i4) {
        RenderCoordinates renderCoordinates = contentViewCore.getRenderCoordinates();
        float webViewOffsetYPixInScreen = getWebViewOffsetYPixInScreen(contentViewCore);
        return new RectF(renderCoordinates.fromLocalCssToPix((float) i), renderCoordinates.fromLocalCssToPix((float) i2) + webViewOffsetYPixInScreen, renderCoordinates.fromLocalCssToPix((float) (i + i3)), renderCoordinates.fromLocalCssToPix((float) (i2 + i4)) + webViewOffsetYPixInScreen);
    }

    private void measure(RenderCoordinates renderCoordinates) {
        this.mPopup.setHeight(-2);
        this.mPopup.setWidth(-2);
        this.mPopup.getContentView().setLayoutParams(new RelativeLayout.LayoutParams(-2, -2));
        this.mPopup.getContentView().measure(View.MeasureSpec.makeMeasureSpec(renderCoordinates.getLastFrameViewportWidthPixInt(), Integer.MIN_VALUE), View.MeasureSpec.makeMeasureSpec(renderCoordinates.getLastFrameViewportHeightPixInt(), Integer.MIN_VALUE));
    }

    @CalledByNative
    private void setPositionRelativeToAnchor(ContentViewCore contentViewCore, int i, int i2, int i3, int i4) {
        RectF makePixRectInScreen = makePixRectInScreen(contentViewCore, i, i2, i3, i4);
        Point adjustWindowPosition = adjustWindowPosition(contentViewCore, (int) (makePixRectInScreen.centerX() - getAnchorOffset()), (int) makePixRectInScreen.bottom);
        PopupWindow popupWindow = this.mPopup;
        popupWindow.update(adjustWindowPosition.x, adjustWindowPosition.y, popupWindow.getWidth(), this.mPopup.getHeight());
    }

    private static void updateTextViews(ViewGroup viewGroup, String str, String str2) {
        ((TextView) viewGroup.findViewById(R.id.main_text)).setText(str);
        TextView textView = (TextView) viewGroup.findViewById(R.id.sub_text);
        if (!TextUtils.isEmpty(str2)) {
            textView.setText(str2);
        } else {
            ((ViewGroup) textView.getParent()).removeView(textView);
        }
    }
}
