package org.chromium.content.browser;

import android.content.Context;
import android.os.Handler;
import android.os.StrictMode;
import java.util.ArrayList;
import java.util.List;
import org.chromium.base.Log;
import org.chromium.base.ResourceExtractor;
import org.chromium.base.ThreadUtils;
import org.chromium.base.VisibleForTesting;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;
import org.chromium.base.library_loader.LibraryLoader;
import org.chromium.base.library_loader.ProcessInitException;
import org.chromium.content.app.ContentMain;

@JNINamespace("content")
public class BrowserStartupController {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final boolean ALREADY_STARTED = true;
    private static final boolean NOT_ALREADY_STARTED = false;
    @VisibleForTesting
    public static final int STARTUP_FAILURE = 1;
    @VisibleForTesting
    public static final int STARTUP_SUCCESS = -1;
    private static final String TAG = "cr.BrowserStartup";
    private static boolean sBrowserMayStartAsynchronously = false;
    private static BrowserStartupController sInstance = null;
    private static boolean sShouldStartGpuProcessOnBrowserStartup = true;
    private final List<StartupCallback> mAsyncStartupCallbacks = new ArrayList();
    private final Context mContext;
    private boolean mHasStartedInitializingBrowserProcess;
    private int mLibraryProcessType;
    private boolean mPostResourceExtractionTasksCompleted;
    private boolean mStartupDone;
    private boolean mStartupSuccess;

    public interface StartupCallback {
        void onFailure();

        void onSuccess(boolean z);
    }

    public BrowserStartupController(Context context, int i) {
        this.mContext = context.getApplicationContext();
        this.mLibraryProcessType = i;
    }

    @VisibleForTesting
    @CalledByNative
    public static boolean browserMayStartAsynchonously() {
        return sBrowserMayStartAsynchronously;
    }

    @VisibleForTesting
    @CalledByNative
    public static void browserStartupComplete(int i) {
        BrowserStartupController browserStartupController = sInstance;
        if (browserStartupController != null) {
            browserStartupController.executeEnqueuedCallbacks(i, false);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void enqueueCallbackExecution(final int i, final boolean z) {
        new Handler().post(new Runnable() {
            /* class org.chromium.content.browser.BrowserStartupController.AnonymousClass2 */

            public void run() {
                BrowserStartupController.this.executeEnqueuedCallbacks(i, z);
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void executeEnqueuedCallbacks(int i, boolean z) {
        boolean z2 = true;
        this.mStartupDone = true;
        if (i > 0) {
            z2 = false;
        }
        this.mStartupSuccess = z2;
        for (StartupCallback startupCallback : this.mAsyncStartupCallbacks) {
            if (this.mStartupSuccess) {
                startupCallback.onSuccess(z);
            } else {
                startupCallback.onFailure();
            }
        }
        this.mAsyncStartupCallbacks.clear();
    }

    public static BrowserStartupController get(Context context, int i) {
        ThreadUtils.assertOnUiThread();
        if (sInstance == null) {
            sInstance = new BrowserStartupController(context, i);
        }
        return sInstance;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String getPlugins() {
        return PepperPluginManager.getPlugins(this.mContext);
    }

    private static native boolean nativeIsOfficialBuild();

    /* access modifiers changed from: private */
    public static native boolean nativeIsPluginEnabled();

    /* access modifiers changed from: private */
    public static native void nativeSetCommandLineFlags(boolean z, String str);

    @VisibleForTesting
    public static BrowserStartupController overrideInstanceForTest(BrowserStartupController browserStartupController) {
        if (sInstance == null) {
            sInstance = browserStartupController;
        }
        return sInstance;
    }

    private void postStartupCompleted(final StartupCallback startupCallback) {
        new Handler().post(new Runnable() {
            /* class org.chromium.content.browser.BrowserStartupController.AnonymousClass3 */

            public void run() {
                if (BrowserStartupController.this.mStartupSuccess) {
                    startupCallback.onSuccess(true);
                } else {
                    startupCallback.onFailure();
                }
            }
        });
    }

    private static void setAsynchronousStartup(boolean z) {
        sBrowserMayStartAsynchronously = z;
    }

    private static void setShouldStartGpuProcessOnBrowserStartup(boolean z) {
        sShouldStartGpuProcessOnBrowserStartup = z;
    }

    @CalledByNative
    public static boolean shouldStartGpuProcessOnBrowserStartup() {
        return sShouldStartGpuProcessOnBrowserStartup;
    }

    public void addStartupCompletedObserver(StartupCallback startupCallback) {
        ThreadUtils.assertOnUiThread();
        if (this.mStartupDone) {
            postStartupCompleted(startupCallback);
        } else {
            this.mAsyncStartupCallbacks.add(startupCallback);
        }
    }

    @VisibleForTesting
    public int contentStart() {
        return ContentMain.start();
    }

    public void initChromiumBrowserProcessForTests() {
        ResourceExtractor resourceExtractor = ResourceExtractor.get(this.mContext);
        resourceExtractor.startExtractingResources();
        resourceExtractor.waitForCompletion();
        nativeSetCommandLineFlags(false, null);
    }

    /* JADX INFO: finally extract failed */
    @VisibleForTesting
    public void prepareToStartBrowserProcess(final boolean z, final Runnable runnable) {
        Log.i(TAG, "Initializing chromium process, singleProcess=%b", Boolean.valueOf(z));
        ResourceExtractor resourceExtractor = ResourceExtractor.get(this.mContext);
        resourceExtractor.startExtractingResources();
        StrictMode.ThreadPolicy allowThreadDiskReads = StrictMode.allowThreadDiskReads();
        try {
            LibraryLoader.get(this.mLibraryProcessType).ensureInitialized(this.mContext);
            StrictMode.setThreadPolicy(allowThreadDiskReads);
            AnonymousClass4 r1 = new Runnable() {
                /* class org.chromium.content.browser.BrowserStartupController.AnonymousClass4 */

                public void run() {
                    if (!BrowserStartupController.this.mPostResourceExtractionTasksCompleted) {
                        DeviceUtils.addDeviceSpecificUserAgentSwitch(BrowserStartupController.this.mContext);
                        BrowserStartupController.nativeSetCommandLineFlags(z, BrowserStartupController.nativeIsPluginEnabled() ? BrowserStartupController.this.getPlugins() : null);
                        BrowserStartupController.this.mPostResourceExtractionTasksCompleted = true;
                    }
                    Runnable runnable = runnable;
                    if (runnable != null) {
                        runnable.run();
                    }
                }
            };
            if (runnable == null) {
                resourceExtractor.waitForCompletion();
                r1.run();
                return;
            }
            resourceExtractor.addCompletionCallback(r1);
        } catch (Throwable th) {
            StrictMode.setThreadPolicy(allowThreadDiskReads);
            throw th;
        }
    }

    public void startBrowserProcessesAsync(boolean z, StartupCallback startupCallback) {
        if (this.mStartupDone) {
            postStartupCompleted(startupCallback);
            return;
        }
        this.mAsyncStartupCallbacks.add(startupCallback);
        if (!this.mHasStartedInitializingBrowserProcess) {
            this.mHasStartedInitializingBrowserProcess = true;
            setAsynchronousStartup(true);
            setShouldStartGpuProcessOnBrowserStartup(z);
            prepareToStartBrowserProcess(false, new Runnable() {
                /* class org.chromium.content.browser.BrowserStartupController.AnonymousClass1 */

                public void run() {
                    ThreadUtils.assertOnUiThread();
                    if (BrowserStartupController.this.contentStart() > 0) {
                        BrowserStartupController.this.enqueueCallbackExecution(1, false);
                    }
                }
            });
        }
    }

    public void startBrowserProcessesSync(boolean z) {
        if (!this.mStartupDone) {
            if (!this.mHasStartedInitializingBrowserProcess || !this.mPostResourceExtractionTasksCompleted) {
                prepareToStartBrowserProcess(z, null);
            }
            setAsynchronousStartup(false);
            if (contentStart() > 0) {
                enqueueCallbackExecution(1, false);
            }
        }
        if (!this.mStartupSuccess) {
            throw new ProcessInitException(4);
        }
    }
}
