package org.chromium.content.browser;

import android.content.Context;
import android.graphics.SurfaceTexture;
import android.view.Surface;
import android.view.SurfaceHolder;
import android.view.SurfaceView;
import android.view.TextureView;
import android.widget.FrameLayout;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;
import org.chromium.ui.base.WindowAndroid;

@JNINamespace("content")
public class ContentViewRenderView extends FrameLayout {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private CompositingSurfaceType mCompositingSurfaceType;
    public ContentViewCore mContentViewCore;
    private boolean mFirstFrameReceived;
    private FirstRenderedFrameListener mFirstRenderedFrameListener;
    private long mNativeContentViewRenderView;
    private Surface mSurface;
    private SurfaceHolder.Callback mSurfaceCallback;
    private final SurfaceView mSurfaceView;
    private TextureView mTextureView;

    public enum CompositingSurfaceType {
        SURFACE_VIEW,
        TEXTURE_VIEW
    }

    public interface FirstRenderedFrameListener {
        void onFirstFrameReceived();
    }

    public ContentViewRenderView(Context context) {
        this(context, CompositingSurfaceType.SURFACE_VIEW);
    }

    private void initTextureView(Context context) {
        TextureView textureView = new TextureView(context);
        this.mTextureView = textureView;
        textureView.setBackgroundColor(-1);
        this.mTextureView.setSurfaceTextureListener(new TextureView.SurfaceTextureListener() {
            /* class org.chromium.content.browser.ContentViewRenderView.AnonymousClass1 */
            public static final /* synthetic */ boolean $assertionsDisabled = false;

            public void onSurfaceTextureAvailable(SurfaceTexture surfaceTexture, int i, int i2) {
                ContentViewRenderView.this.mSurface = new Surface(surfaceTexture);
                ContentViewRenderView contentViewRenderView = ContentViewRenderView.this;
                contentViewRenderView.nativeSurfaceCreated(contentViewRenderView.mNativeContentViewRenderView);
                onSurfaceTextureSizeChanged(surfaceTexture, i, i2);
                ContentViewRenderView.this.onReadyToRender();
            }

            public boolean onSurfaceTextureDestroyed(SurfaceTexture surfaceTexture) {
                ContentViewRenderView contentViewRenderView = ContentViewRenderView.this;
                contentViewRenderView.nativeSurfaceDestroyed(contentViewRenderView.mNativeContentViewRenderView);
                ContentViewRenderView.this.mSurface.release();
                ContentViewRenderView.this.mSurface = null;
                return true;
            }

            public void onSurfaceTextureSizeChanged(SurfaceTexture surfaceTexture, int i, int i2) {
                ContentViewRenderView contentViewRenderView = ContentViewRenderView.this;
                contentViewRenderView.nativeSurfaceChanged(contentViewRenderView.mNativeContentViewRenderView, 1, i, i2, ContentViewRenderView.this.mSurface);
                ContentViewCore contentViewCore = ContentViewRenderView.this.mContentViewCore;
                if (contentViewCore != null) {
                    contentViewCore.onPhysicalBackingSizeChanged(i, i2);
                }
            }

            public void onSurfaceTextureUpdated(SurfaceTexture surfaceTexture) {
            }
        });
    }

    private static boolean isOpaque(int i) {
        return ((i >> 24) & 255) == 255;
    }

    private native void nativeDestroy(long j);

    private native long nativeInit(long j);

    private native void nativeSetCurrentContentViewCore(long j, long j2);

    private native void nativeSetOverlayVideoMode(long j, boolean z);

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native void nativeSurfaceChanged(long j, int i, int i2, int i3, Surface surface);

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native void nativeSurfaceCreated(long j);

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native void nativeSurfaceDestroyed(long j);

    @CalledByNative
    private void onSwapBuffersCompleted() {
        ContentViewCore contentViewCore;
        if (!this.mFirstFrameReceived && (contentViewCore = this.mContentViewCore) != null && contentViewCore.getWebContents().isReady()) {
            this.mFirstFrameReceived = true;
            FirstRenderedFrameListener firstRenderedFrameListener = this.mFirstRenderedFrameListener;
            if (firstRenderedFrameListener != null) {
                firstRenderedFrameListener.onFirstFrameReceived();
            }
        }
        if (this.mCompositingSurfaceType != CompositingSurfaceType.TEXTURE_VIEW && this.mSurfaceView.getBackground() != null) {
            post(new Runnable() {
                /* class org.chromium.content.browser.ContentViewRenderView.AnonymousClass3 */

                public void run() {
                    ContentViewRenderView.this.mSurfaceView.setBackgroundResource(0);
                }
            });
        }
    }

    public SurfaceView createSurfaceView(Context context) {
        return new SurfaceView(context);
    }

    public void destroy() {
        if (this.mCompositingSurfaceType == CompositingSurfaceType.TEXTURE_VIEW) {
            this.mTextureView.setSurfaceTextureListener(null);
            Surface surface = this.mSurface;
            if (surface != null) {
                surface.release();
                this.mSurface = null;
            }
        } else {
            this.mSurfaceView.getHolder().removeCallback(this.mSurfaceCallback);
        }
        nativeDestroy(this.mNativeContentViewRenderView);
        this.mNativeContentViewRenderView = 0;
    }

    public SurfaceView getSurfaceView() {
        return this.mSurfaceView;
    }

    public boolean isInitialized() {
        return (this.mSurfaceView.getHolder().getSurface() == null && this.mSurface == null) ? false : true;
    }

    public void onNativeLibraryLoaded(WindowAndroid windowAndroid) {
        this.mNativeContentViewRenderView = nativeInit(windowAndroid.getNativePointer());
        if (this.mCompositingSurfaceType != CompositingSurfaceType.TEXTURE_VIEW) {
            this.mSurfaceCallback = new SurfaceHolder.Callback() {
                /* class org.chromium.content.browser.ContentViewRenderView.AnonymousClass2 */
                public static final /* synthetic */ boolean $assertionsDisabled = false;

                public void surfaceChanged(SurfaceHolder surfaceHolder, int i, int i2, int i3) {
                    ContentViewRenderView contentViewRenderView = ContentViewRenderView.this;
                    contentViewRenderView.nativeSurfaceChanged(contentViewRenderView.mNativeContentViewRenderView, i, i2, i3, surfaceHolder.getSurface());
                    ContentViewCore contentViewCore = ContentViewRenderView.this.mContentViewCore;
                    if (contentViewCore != null) {
                        contentViewCore.onPhysicalBackingSizeChanged(i2, i3);
                    }
                }

                public void surfaceCreated(SurfaceHolder surfaceHolder) {
                    ContentViewRenderView contentViewRenderView = ContentViewRenderView.this;
                    contentViewRenderView.nativeSurfaceCreated(contentViewRenderView.mNativeContentViewRenderView);
                    ContentViewRenderView.this.onReadyToRender();
                }

                public void surfaceDestroyed(SurfaceHolder surfaceHolder) {
                    ContentViewRenderView contentViewRenderView = ContentViewRenderView.this;
                    contentViewRenderView.nativeSurfaceDestroyed(contentViewRenderView.mNativeContentViewRenderView);
                }
            };
            this.mSurfaceView.getHolder().addCallback(this.mSurfaceCallback);
            this.mSurfaceView.setVisibility(0);
        }
    }

    public void onReadyToRender() {
    }

    public void registerFirstRenderedFrameListener(FirstRenderedFrameListener firstRenderedFrameListener) {
        this.mFirstRenderedFrameListener = firstRenderedFrameListener;
        if (this.mFirstFrameReceived && firstRenderedFrameListener != null) {
            firstRenderedFrameListener.onFirstFrameReceived();
        }
    }

    public void setCurrentContentViewCore(ContentViewCore contentViewCore) {
        this.mContentViewCore = contentViewCore;
        if (contentViewCore != null) {
            contentViewCore.onPhysicalBackingSizeChanged(getWidth(), getHeight());
            nativeSetCurrentContentViewCore(this.mNativeContentViewRenderView, this.mContentViewCore.getNativeContentViewCore());
            return;
        }
        nativeSetCurrentContentViewCore(this.mNativeContentViewRenderView, 0);
    }

    public void setOverlayVideoMode(boolean z) {
        if (this.mCompositingSurfaceType == CompositingSurfaceType.TEXTURE_VIEW) {
            nativeSetOverlayVideoMode(this.mNativeContentViewRenderView, z);
            return;
        }
        this.mSurfaceView.getHolder().setFormat(z ? -3 : -1);
        nativeSetOverlayVideoMode(this.mNativeContentViewRenderView, z);
    }

    public void setSurfaceViewBackgroundColor(int i) {
        SurfaceView surfaceView = this.mSurfaceView;
        if (surfaceView != null) {
            surfaceView.setBackgroundColor(i);
            return;
        }
        TextureView textureView = this.mTextureView;
        if (textureView != null) {
            textureView.setOpaque(isOpaque(i));
            this.mTextureView.setBackgroundColor(i);
        }
    }

    public void setZOrderOnTop(boolean z) {
        SurfaceView surfaceView = this.mSurfaceView;
        if (surfaceView != null) {
            surfaceView.setZOrderOnTop(z);
        }
    }

    public ContentViewRenderView(Context context, CompositingSurfaceType compositingSurfaceType) {
        super(context);
        this.mCompositingSurfaceType = compositingSurfaceType;
        if (compositingSurfaceType == CompositingSurfaceType.TEXTURE_VIEW) {
            initTextureView(context);
            addView(this.mTextureView, new FrameLayout.LayoutParams(-1, -1));
            this.mSurfaceView = null;
            this.mSurfaceCallback = null;
            return;
        }
        SurfaceView createSurfaceView = createSurfaceView(getContext());
        this.mSurfaceView = createSurfaceView;
        createSurfaceView.setZOrderMediaOverlay(true);
        setSurfaceViewBackgroundColor(-1);
        addView(createSurfaceView, new FrameLayout.LayoutParams(-1, -1));
        createSurfaceView.setVisibility(8);
    }
}
