package org.chromium.content.browser;

import android.view.MotionEvent;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;

@JNINamespace("content")
public class MotionEventSynthesizer {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final int ACTION_CANCEL = 2;
    private static final int ACTION_END = 3;
    private static final int ACTION_MOVE = 1;
    private static final int ACTION_SCROLL = 4;
    private static final int ACTION_START = 0;
    private static final int MAX_NUM_POINTERS = 16;
    private final ContentViewCore mContentViewCore;
    private long mDownTimeInMs;
    private final MotionEvent.PointerCoords[] mPointerCoords = new MotionEvent.PointerCoords[16];
    private final MotionEvent.PointerProperties[] mPointerProperties = new MotionEvent.PointerProperties[16];

    public MotionEventSynthesizer(ContentViewCore contentViewCore) {
        this.mContentViewCore = contentViewCore;
    }

    @CalledByNative
    public void inject(int i, int i2, long j) {
        if (i == 0) {
            this.mDownTimeInMs = j;
            MotionEvent obtain = MotionEvent.obtain(j, j, 0, 1, this.mPointerProperties, this.mPointerCoords, 0, 0, 1.0f, 1.0f, 0, 0, 0, 0);
            this.mContentViewCore.onTouchEvent(obtain);
            obtain.recycle();
            if (i2 > 1) {
                MotionEvent obtain2 = MotionEvent.obtain(this.mDownTimeInMs, j, 5, i2, this.mPointerProperties, this.mPointerCoords, 0, 0, 1.0f, 1.0f, 0, 0, 0, 0);
                this.mContentViewCore.onTouchEvent(obtain2);
                obtain2.recycle();
            }
        } else if (i == 1) {
            MotionEvent obtain3 = MotionEvent.obtain(this.mDownTimeInMs, j, 2, i2, this.mPointerProperties, this.mPointerCoords, 0, 0, 1.0f, 1.0f, 0, 0, 0, 0);
            this.mContentViewCore.onTouchEvent(obtain3);
            obtain3.recycle();
        } else if (i == 2) {
            MotionEvent obtain4 = MotionEvent.obtain(this.mDownTimeInMs, j, 3, 1, this.mPointerProperties, this.mPointerCoords, 0, 0, 1.0f, 1.0f, 0, 0, 0, 0);
            this.mContentViewCore.onTouchEvent(obtain4);
            obtain4.recycle();
        } else if (i == 3) {
            if (i2 > 1) {
                MotionEvent obtain5 = MotionEvent.obtain(this.mDownTimeInMs, j, 6, i2, this.mPointerProperties, this.mPointerCoords, 0, 0, 1.0f, 1.0f, 0, 0, 0, 0);
                this.mContentViewCore.onTouchEvent(obtain5);
                obtain5.recycle();
            }
            MotionEvent obtain6 = MotionEvent.obtain(this.mDownTimeInMs, j, 1, 1, this.mPointerProperties, this.mPointerCoords, 0, 0, 1.0f, 1.0f, 0, 0, 0, 0);
            this.mContentViewCore.onTouchEvent(obtain6);
            obtain6.recycle();
        } else if (i == 4) {
            MotionEvent obtain7 = MotionEvent.obtain(this.mDownTimeInMs, j, 8, i2, this.mPointerProperties, this.mPointerCoords, 0, 0, 1.0f, 1.0f, 0, 0, 2, 0);
            this.mContentViewCore.onGenericMotionEvent(obtain7);
            obtain7.recycle();
        }
    }

    @CalledByNative
    public void setPointer(int i, int i2, int i3, int i4) {
        float deviceScaleFactor = this.mContentViewCore.getRenderCoordinates().getDeviceScaleFactor();
        MotionEvent.PointerCoords pointerCoords = new MotionEvent.PointerCoords();
        pointerCoords.x = ((float) i2) * deviceScaleFactor;
        pointerCoords.y = deviceScaleFactor * ((float) i3);
        pointerCoords.pressure = 1.0f;
        this.mPointerCoords[i] = pointerCoords;
        MotionEvent.PointerProperties pointerProperties = new MotionEvent.PointerProperties();
        pointerProperties.id = i4;
        this.mPointerProperties[i] = pointerProperties;
    }

    @CalledByNative
    public void setScrollDeltas(int i, int i2, int i3, int i4) {
        setPointer(0, i, i2, 0);
        float deviceScaleFactor = this.mContentViewCore.getRenderCoordinates().getDeviceScaleFactor();
        this.mPointerCoords[0].setAxisValue(10, ((float) i3) * deviceScaleFactor);
        this.mPointerCoords[0].setAxisValue(9, deviceScaleFactor * ((float) i4));
    }
}
