package org.chromium.content.browser;

import android.annotation.SuppressLint;
import android.content.Context;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.PointF;
import android.graphics.PorterDuff;
import android.graphics.PorterDuffXfermode;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Region;
import android.graphics.drawable.ColorDrawable;
import android.graphics.drawable.Drawable;
import android.os.SystemClock;
import android.view.GestureDetector;
import android.view.MotionEvent;
import android.view.View;
import android.view.animation.Interpolator;
import android.view.animation.OvershootInterpolator;
import org.chromium.base.ApiCompatibilityUtils;
import org.chromium.base.Log;
import org.chromium.content.R;

public class PopupZoomer extends View {
    private static final long ANIMATION_DURATION = 300;
    private static final String TAG = "cr.PopupZoomer";
    private static final int ZOOM_BOUNDS_MARGIN = 25;
    private static float sOverlayCornerRadius;
    private static Drawable sOverlayDrawable;
    private static Rect sOverlayPadding;
    private boolean mAnimating;
    private long mAnimationStartTime;
    private float mBottomExtrusion;
    private RectF mClipRect;
    private RectF mDrawRect;
    private GestureDetector mGestureDetector;
    private final Interpolator mHideInterpolator;
    private float mLeftExtrusion;
    private float mMaxScrollX;
    private float mMaxScrollY;
    private float mMinScrollX;
    private float mMinScrollY;
    private boolean mNeedsToInitDimensions;
    private OnTapListener mOnTapListener = null;
    private OnVisibilityChangedListener mOnVisibilityChangedListener = null;
    private float mPopupScrollX;
    private float mPopupScrollY;
    private float mRightExtrusion;
    private float mScale;
    private float mShiftX;
    private float mShiftY;
    private final Interpolator mShowInterpolator;
    private boolean mShowing;
    private Rect mTargetBounds;
    private long mTimeLeft;
    private float mTopExtrusion;
    private final PointF mTouch;
    private RectF mViewClipRect;
    private Bitmap mZoomedBitmap;

    public interface OnTapListener {
        boolean onLongPress(View view, MotionEvent motionEvent);

        boolean onSingleTap(View view, MotionEvent motionEvent);
    }

    public interface OnVisibilityChangedListener {
        void onPopupZoomerHidden(PopupZoomer popupZoomer);

        void onPopupZoomerShown(PopupZoomer popupZoomer);
    }

    public static class ReverseInterpolator implements Interpolator {
        private final Interpolator mInterpolator;

        public ReverseInterpolator(Interpolator interpolator) {
            this.mInterpolator = interpolator;
        }

        public float getInterpolation(float f) {
            float f2 = 1.0f - f;
            Interpolator interpolator = this.mInterpolator;
            if (interpolator == null) {
                return f2;
            }
            return interpolator.getInterpolation(f2);
        }
    }

    public PopupZoomer(Context context) {
        super(context);
        OvershootInterpolator overshootInterpolator = new OvershootInterpolator();
        this.mShowInterpolator = overshootInterpolator;
        this.mHideInterpolator = new ReverseInterpolator(overshootInterpolator);
        this.mAnimating = false;
        this.mShowing = false;
        this.mAnimationStartTime = 0;
        this.mTimeLeft = 0;
        this.mShiftX = 0.0f;
        this.mShiftY = 0.0f;
        this.mScale = 1.0f;
        this.mTouch = new PointF();
        setVisibility(4);
        setFocusable(true);
        setFocusableInTouchMode(true);
        this.mGestureDetector = new GestureDetector(context, new GestureDetector.SimpleOnGestureListener() {
            /* class org.chromium.content.browser.PopupZoomer.AnonymousClass1 */

            private boolean handleTapOrPress(MotionEvent motionEvent, boolean z) {
                if (PopupZoomer.this.mAnimating) {
                    return true;
                }
                float x = motionEvent.getX();
                float y = motionEvent.getY();
                if (PopupZoomer.this.isTouchOutsideArea(x, y)) {
                    PopupZoomer.this.hide(true);
                } else if (PopupZoomer.this.mOnTapListener != null) {
                    PointF convertTouchPoint = PopupZoomer.this.convertTouchPoint(x, y);
                    MotionEvent obtainNoHistory = MotionEvent.obtainNoHistory(motionEvent);
                    obtainNoHistory.setLocation(convertTouchPoint.x, convertTouchPoint.y);
                    if (z) {
                        PopupZoomer.this.mOnTapListener.onLongPress(PopupZoomer.this, obtainNoHistory);
                    } else {
                        PopupZoomer.this.mOnTapListener.onSingleTap(PopupZoomer.this, obtainNoHistory);
                    }
                    PopupZoomer.this.hide(true);
                }
                return true;
            }

            public void onLongPress(MotionEvent motionEvent) {
                handleTapOrPress(motionEvent, true);
            }

            public boolean onScroll(MotionEvent motionEvent, MotionEvent motionEvent2, float f, float f2) {
                if (PopupZoomer.this.mAnimating) {
                    return true;
                }
                if (PopupZoomer.this.isTouchOutsideArea(motionEvent.getX(), motionEvent.getY())) {
                    PopupZoomer.this.hide(true);
                } else {
                    PopupZoomer.this.scroll(f, f2);
                }
                return true;
            }

            public boolean onSingleTapUp(MotionEvent motionEvent) {
                return handleTapOrPress(motionEvent, false);
            }
        });
    }

    private static float constrain(float f, float f2, float f3) {
        return f < f2 ? f2 : f > f3 ? f3 : f;
    }

    private static int constrain(int i, int i2, int i3) {
        return i < i2 ? i2 : i > i3 ? i3 : i;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private PointF convertTouchPoint(float f, float f2) {
        float f3 = f - this.mShiftX;
        float f4 = f2 - this.mShiftY;
        PointF pointF = this.mTouch;
        float f5 = pointF.x;
        float f6 = (f3 - f5) - this.mPopupScrollX;
        float f7 = this.mScale;
        float f8 = pointF.y;
        return new PointF((f6 / f7) + f5, (((f4 - f8) - this.mPopupScrollY) / f7) + f8);
    }

    private static float getOverlayCornerRadius(Context context) {
        if (sOverlayCornerRadius == 0.0f) {
            try {
                sOverlayCornerRadius = context.getResources().getDimension(R.dimen.link_preview_overlay_radius);
            } catch (Resources.NotFoundException unused) {
                Log.w(TAG, "No corner radius resource for PopupZoomer overlay found.", new Object[0]);
                sOverlayCornerRadius = 1.0f;
            }
        }
        return sOverlayCornerRadius;
    }

    private static Drawable getOverlayDrawable(Context context) {
        if (sOverlayDrawable == null) {
            try {
                sOverlayDrawable = ApiCompatibilityUtils.getDrawable(context.getResources(), R.drawable.ondemand_overlay);
            } catch (Resources.NotFoundException unused) {
                Log.w(TAG, "No drawable resource for PopupZoomer overlay found.", new Object[0]);
                sOverlayDrawable = new ColorDrawable();
            }
            Rect rect = new Rect();
            sOverlayPadding = rect;
            sOverlayDrawable.getPadding(rect);
        }
        return sOverlayDrawable;
    }

    private void hideImmediately() {
        this.mAnimating = false;
        this.mShowing = false;
        this.mTimeLeft = 0;
        OnVisibilityChangedListener onVisibilityChangedListener = this.mOnVisibilityChangedListener;
        if (onVisibilityChangedListener != null) {
            onVisibilityChangedListener.onPopupZoomerHidden(this);
        }
        setVisibility(4);
        this.mZoomedBitmap.recycle();
        this.mZoomedBitmap = null;
    }

    private void initDimensions() {
        if (this.mTargetBounds != null && this.mTouch != null) {
            float width = ((float) this.mZoomedBitmap.getWidth()) / ((float) this.mTargetBounds.width());
            this.mScale = width;
            PointF pointF = this.mTouch;
            float f = pointF.x;
            Rect rect = this.mTargetBounds;
            float f2 = f - ((f - ((float) rect.left)) * width);
            float f3 = pointF.y;
            float f4 = f3 - ((f3 - ((float) rect.top)) * width);
            this.mClipRect = new RectF(f2, f4, ((float) this.mZoomedBitmap.getWidth()) + f2, ((float) this.mZoomedBitmap.getHeight()) + f4);
            float width2 = (float) (getWidth() - 25);
            float height = (float) (getHeight() - 25);
            RectF rectF = new RectF(25.0f, 25.0f, width2, height);
            this.mViewClipRect = rectF;
            this.mShiftX = 0.0f;
            this.mShiftY = 0.0f;
            RectF rectF2 = this.mClipRect;
            float f5 = rectF2.left;
            if (f5 < 25.0f) {
                float f6 = 25.0f - f5;
                this.mShiftX = f6;
                rectF2.left = f5 + f6;
                rectF2.right += f6;
            } else {
                float f7 = rectF2.right;
                if (f7 > width2) {
                    float f8 = width2 - f7;
                    this.mShiftX = f8;
                    rectF2.right = f7 + f8;
                    rectF2.left = f5 + f8;
                }
            }
            float f9 = rectF2.top;
            if (f9 < 25.0f) {
                float f10 = 25.0f - f9;
                this.mShiftY = f10;
                rectF2.top = f9 + f10;
                rectF2.bottom += f10;
            } else {
                float f11 = rectF2.bottom;
                if (f11 > height) {
                    float f12 = height - f11;
                    this.mShiftY = f12;
                    rectF2.bottom = f11 + f12;
                    rectF2.top = f9 + f12;
                }
            }
            this.mMaxScrollY = 0.0f;
            this.mMinScrollY = 0.0f;
            this.mMaxScrollX = 0.0f;
            this.mMinScrollX = 0.0f;
            float f13 = rectF.right;
            float f14 = this.mShiftX;
            float f15 = rectF2.right;
            if (f13 + f14 < f15) {
                this.mMinScrollX = f13 - f15;
            }
            float f16 = rectF.left;
            float f17 = rectF2.left;
            if (f14 + f16 > f17) {
                this.mMaxScrollX = f16 - f17;
            }
            float f18 = rectF.top;
            float f19 = this.mShiftY;
            float f20 = rectF2.top;
            if (f18 + f19 > f20) {
                this.mMaxScrollY = f18 - f20;
            }
            float f21 = rectF.bottom;
            float f22 = rectF2.bottom;
            if (f19 + f21 < f22) {
                this.mMinScrollY = f21 - f22;
            }
            rectF2.intersect(rectF);
            PointF pointF2 = this.mTouch;
            float f23 = pointF2.x;
            RectF rectF3 = this.mClipRect;
            this.mLeftExtrusion = f23 - rectF3.left;
            this.mRightExtrusion = rectF3.right - f23;
            float f24 = pointF2.y;
            this.mTopExtrusion = f24 - rectF3.top;
            this.mBottomExtrusion = rectF3.bottom - f24;
            float f25 = this.mMaxScrollX;
            float f26 = this.mMinScrollX;
            float f27 = this.mMaxScrollY - this.mMinScrollY;
            float centerX = (f25 - f26) * (((f23 - ((float) this.mTargetBounds.centerX())) / (((float) this.mTargetBounds.width()) / 2.0f)) + 0.5f) * -1.0f;
            this.mPopupScrollX = centerX;
            this.mPopupScrollY = f27 * (((this.mTouch.y - ((float) this.mTargetBounds.centerY())) / (((float) this.mTargetBounds.height()) / 2.0f)) + 0.5f) * -1.0f;
            this.mPopupScrollX = constrain(centerX, f26, f25);
            this.mPopupScrollY = constrain(this.mPopupScrollY, this.mMinScrollY, this.mMaxScrollY);
            this.mDrawRect = new RectF();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean isTouchOutsideArea(float f, float f2) {
        return !this.mClipRect.contains(f, f2);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void scroll(float f, float f2) {
        this.mPopupScrollX = constrain(this.mPopupScrollX - f, this.mMinScrollX, this.mMaxScrollX);
        this.mPopupScrollY = constrain(this.mPopupScrollY - f2, this.mMinScrollY, this.mMaxScrollY);
        invalidate();
    }

    private void setTargetBounds(Rect rect) {
        this.mTargetBounds = rect;
    }

    private void startAnimation(boolean z) {
        this.mAnimating = true;
        this.mShowing = z;
        this.mTimeLeft = 0;
        if (z) {
            setVisibility(0);
            this.mNeedsToInitDimensions = true;
            OnVisibilityChangedListener onVisibilityChangedListener = this.mOnVisibilityChangedListener;
            if (onVisibilityChangedListener != null) {
                onVisibilityChangedListener.onPopupZoomerShown(this);
            }
        } else {
            long uptimeMillis = (this.mAnimationStartTime + ANIMATION_DURATION) - SystemClock.uptimeMillis();
            this.mTimeLeft = uptimeMillis;
            if (uptimeMillis < 0) {
                this.mTimeLeft = 0;
            }
        }
        this.mAnimationStartTime = SystemClock.uptimeMillis();
        invalidate();
    }

    public boolean acceptZeroSizeView() {
        return false;
    }

    public void hide(boolean z) {
        if (this.mShowing) {
            if (z) {
                startAnimation(false);
            } else {
                hideImmediately();
            }
        }
    }

    public boolean isShowing() {
        return this.mShowing || this.mAnimating;
    }

    public void onDraw(Canvas canvas) {
        float f;
        if (isShowing() && this.mZoomedBitmap != null) {
            if (acceptZeroSizeView() || !(getWidth() == 0 || getHeight() == 0)) {
                if (this.mNeedsToInitDimensions) {
                    this.mNeedsToInitDimensions = false;
                    initDimensions();
                }
                canvas.save();
                float constrain = constrain(((float) ((SystemClock.uptimeMillis() - this.mAnimationStartTime) + this.mTimeLeft)) / 300.0f, 0.0f, 1.0f);
                if (constrain >= 1.0f) {
                    this.mAnimating = false;
                    if (!isShowing()) {
                        hideImmediately();
                        return;
                    }
                } else {
                    invalidate();
                }
                if (this.mShowing) {
                    f = this.mShowInterpolator.getInterpolation(constrain);
                } else {
                    f = this.mHideInterpolator.getInterpolation(constrain);
                }
                canvas.drawARGB((int) (80.0f * f), 0, 0, 0);
                canvas.save();
                float f2 = this.mScale;
                float f3 = (1.0f / f2) + (((f2 - 1.0f) * f) / f2);
                float f4 = 1.0f - f;
                float f5 = ((-this.mShiftX) * f4) / f2;
                float f6 = ((-this.mShiftY) * f4) / f2;
                RectF rectF = this.mDrawRect;
                PointF pointF = this.mTouch;
                float f7 = pointF.x;
                rectF.left = (f7 - (this.mLeftExtrusion * f3)) + f5;
                float f8 = pointF.y;
                rectF.top = (f8 - (this.mTopExtrusion * f3)) + f6;
                rectF.right = (this.mRightExtrusion * f3) + f7 + f5;
                rectF.bottom = (this.mBottomExtrusion * f3) + f8 + f6;
                canvas.clipRect(rectF);
                RectF rectF2 = this.mDrawRect;
                canvas.scale(f3, f3, rectF2.left, rectF2.top);
                canvas.translate(this.mPopupScrollX, this.mPopupScrollY);
                Bitmap bitmap = this.mZoomedBitmap;
                RectF rectF3 = this.mDrawRect;
                canvas.drawBitmap(bitmap, rectF3.left, rectF3.top, (Paint) null);
                canvas.restore();
                Drawable overlayDrawable = getOverlayDrawable(getContext());
                RectF rectF4 = this.mDrawRect;
                Rect rect = sOverlayPadding;
                overlayDrawable.setBounds(((int) rectF4.left) - rect.left, ((int) rectF4.top) - rect.top, ((int) rectF4.right) + rect.right, ((int) rectF4.bottom) + rect.bottom);
                overlayDrawable.setAlpha(constrain((int) (f * 255.0f), 0, 255));
                overlayDrawable.draw(canvas);
                canvas.restore();
            }
        }
    }

    @SuppressLint({"ClickableViewAccessibility"})
    public boolean onTouchEvent(MotionEvent motionEvent) {
        this.mGestureDetector.onTouchEvent(motionEvent);
        return true;
    }

    public void setBitmap(Bitmap bitmap) {
        Bitmap bitmap2 = this.mZoomedBitmap;
        if (bitmap2 != null) {
            bitmap2.recycle();
            this.mZoomedBitmap = null;
        }
        this.mZoomedBitmap = bitmap;
        Canvas canvas = new Canvas(this.mZoomedBitmap);
        Path path = new Path();
        RectF rectF = new RectF(0.0f, 0.0f, (float) canvas.getWidth(), (float) canvas.getHeight());
        float overlayCornerRadius = getOverlayCornerRadius(getContext());
        path.addRoundRect(rectF, overlayCornerRadius, overlayCornerRadius, Path.Direction.CCW);
        canvas.clipPath(path, Region.Op.XOR);
        Paint paint = new Paint();
        paint.setXfermode(new PorterDuffXfermode(PorterDuff.Mode.SRC));
        paint.setColor(0);
        canvas.drawPaint(paint);
    }

    public void setLastTouch(float f, float f2) {
        PointF pointF = this.mTouch;
        pointF.x = f;
        pointF.y = f2;
    }

    public void setOnTapListener(OnTapListener onTapListener) {
        this.mOnTapListener = onTapListener;
    }

    public void setOnVisibilityChangedListener(OnVisibilityChangedListener onVisibilityChangedListener) {
        this.mOnVisibilityChangedListener = onVisibilityChangedListener;
    }

    public void show(Rect rect) {
        if (!this.mShowing && this.mZoomedBitmap != null) {
            setTargetBounds(rect);
            startAnimation(true);
        }
    }
}
