package org.chromium.content.browser;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.pm.ResolveInfo;
import android.content.pm.ServiceInfo;
import android.os.Bundle;
import android.speech.RecognitionListener;
import android.speech.SpeechRecognizer;
import java.util.ArrayList;
import org.chromium.base.PackageUtils;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;

@JNINamespace("content")
public class SpeechRecognition {
    private static final int PROVIDER_MIN_VERSION = 300207030;
    private static final String PROVIDER_PACKAGE_NAME = "com.google.android.googlequicksearchbox";
    private static final int STATE_AWAITING_SPEECH = 1;
    private static final int STATE_CAPTURING_SPEECH = 2;
    private static final int STATE_IDLE = 0;
    private static ComponentName sRecognitionProvider;
    private final Context mContext;
    private boolean mContinuous = false;
    private final Intent mIntent;
    private final RecognitionListener mListener;
    private long mNativeSpeechRecognizerImplAndroid;
    private SpeechRecognizer mRecognizer;
    private int mState;

    public class Listener implements RecognitionListener {
        public static final /* synthetic */ boolean $assertionsDisabled = false;

        public Listener() {
        }

        private void handleResults(Bundle bundle, boolean z) {
            boolean z2 = (!SpeechRecognition.this.mContinuous || !z) ? z : false;
            ArrayList<String> stringArrayList = bundle.getStringArrayList("results_recognition");
            float[] floatArray = bundle.getFloatArray("confidence_scores");
            SpeechRecognition speechRecognition = SpeechRecognition.this;
            speechRecognition.nativeOnRecognitionResults(speechRecognition.mNativeSpeechRecognizerImplAndroid, (String[]) stringArrayList.toArray(new String[stringArrayList.size()]), floatArray, z2);
        }

        public void onBeginningOfSpeech() {
            SpeechRecognition.this.mState = 2;
            SpeechRecognition speechRecognition = SpeechRecognition.this;
            speechRecognition.nativeOnSoundStart(speechRecognition.mNativeSpeechRecognizerImplAndroid);
        }

        public void onBufferReceived(byte[] bArr) {
        }

        public void onEndOfSpeech() {
            if (!SpeechRecognition.this.mContinuous) {
                SpeechRecognition speechRecognition = SpeechRecognition.this;
                speechRecognition.nativeOnSoundEnd(speechRecognition.mNativeSpeechRecognizerImplAndroid);
                SpeechRecognition speechRecognition2 = SpeechRecognition.this;
                speechRecognition2.nativeOnAudioEnd(speechRecognition2.mNativeSpeechRecognizerImplAndroid);
                SpeechRecognition.this.mState = 0;
            }
        }

        public void onError(int i) {
            int i2;
            switch (i) {
                case 1:
                case 2:
                case 4:
                    i2 = 4;
                    break;
                case 3:
                    i2 = 3;
                    break;
                case 5:
                    i2 = 2;
                    break;
                case 6:
                    i2 = 1;
                    break;
                case 7:
                    i2 = 9;
                    break;
                case 8:
                case 9:
                    i2 = 5;
                    break;
                default:
                    return;
            }
            SpeechRecognition.this.terminate(i2);
        }

        public void onEvent(int i, Bundle bundle) {
        }

        public void onPartialResults(Bundle bundle) {
            handleResults(bundle, true);
        }

        public void onReadyForSpeech(Bundle bundle) {
            SpeechRecognition.this.mState = 1;
            SpeechRecognition speechRecognition = SpeechRecognition.this;
            speechRecognition.nativeOnAudioStart(speechRecognition.mNativeSpeechRecognizerImplAndroid);
        }

        public void onResults(Bundle bundle) {
            handleResults(bundle, false);
            SpeechRecognition.this.terminate(0);
        }

        public void onRmsChanged(float f) {
        }
    }

    private SpeechRecognition(Context context, long j) {
        this.mContext = context;
        this.mNativeSpeechRecognizerImplAndroid = j;
        Listener listener = new Listener();
        this.mListener = listener;
        this.mIntent = new Intent("android.speech.action.RECOGNIZE_SPEECH");
        ComponentName componentName = sRecognitionProvider;
        if (componentName != null) {
            this.mRecognizer = SpeechRecognizer.createSpeechRecognizer(context, componentName);
        } else {
            this.mRecognizer = SpeechRecognizer.createSpeechRecognizer(context);
        }
        this.mRecognizer.setRecognitionListener(listener);
    }

    @CalledByNative
    private void abortRecognition() {
        SpeechRecognizer speechRecognizer = this.mRecognizer;
        if (speechRecognizer != null) {
            speechRecognizer.cancel();
            terminate(2);
        }
    }

    @CalledByNative
    private static SpeechRecognition createSpeechRecognition(Context context, long j) {
        return new SpeechRecognition(context, j);
    }

    public static boolean initialize(Context context) {
        if (!SpeechRecognizer.isRecognitionAvailable(context)) {
            return false;
        }
        for (ResolveInfo resolveInfo : context.getPackageManager().queryIntentServices(new Intent("android.speech.RecognitionService"), 4)) {
            ServiceInfo serviceInfo = resolveInfo.serviceInfo;
            if (serviceInfo.packageName.equals(PROVIDER_PACKAGE_NAME) && PackageUtils.getPackageVersion(context, serviceInfo.packageName) >= PROVIDER_MIN_VERSION) {
                sRecognitionProvider = new ComponentName(serviceInfo.packageName, serviceInfo.name);
                return true;
            }
        }
        return false;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native void nativeOnAudioEnd(long j);

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native void nativeOnAudioStart(long j);

    private native void nativeOnRecognitionEnd(long j);

    private native void nativeOnRecognitionError(long j, int i);

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native void nativeOnRecognitionResults(long j, String[] strArr, float[] fArr, boolean z);

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native void nativeOnSoundEnd(long j);

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native void nativeOnSoundStart(long j);

    @CalledByNative
    private void startRecognition(String str, boolean z, boolean z2) {
        if (this.mRecognizer != null) {
            this.mContinuous = z;
            this.mIntent.putExtra("android.speech.extra.DICTATION_MODE", z);
            this.mIntent.putExtra("android.speech.extra.LANGUAGE", str);
            this.mIntent.putExtra("android.speech.extra.PARTIAL_RESULTS", z2);
            this.mRecognizer.startListening(this.mIntent);
        }
    }

    @CalledByNative
    private void stopRecognition() {
        SpeechRecognizer speechRecognizer = this.mRecognizer;
        if (speechRecognizer != null) {
            this.mContinuous = false;
            speechRecognizer.stopListening();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void terminate(int i) {
        int i2 = this.mState;
        if (i2 != 0) {
            if (i2 == 2) {
                nativeOnSoundEnd(this.mNativeSpeechRecognizerImplAndroid);
            }
            nativeOnAudioEnd(this.mNativeSpeechRecognizerImplAndroid);
            this.mState = 0;
        }
        if (i != 0) {
            nativeOnRecognitionError(this.mNativeSpeechRecognizerImplAndroid, i);
        }
        this.mRecognizer.destroy();
        this.mRecognizer = null;
        nativeOnRecognitionEnd(this.mNativeSpeechRecognizerImplAndroid);
        this.mNativeSpeechRecognizerImplAndroid = 0;
    }
}
