package org.chromium.content.browser;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import org.chromium.base.Log;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;

@JNINamespace("content")
public class TimeZoneMonitor {
    private static final String TAG = "cr.TimeZoneMonitor";
    private final Context mAppContext;
    private final BroadcastReceiver mBroadcastReceiver;
    private final IntentFilter mFilter;
    private long mNativePtr;

    private TimeZoneMonitor(Context context, long j) {
        IntentFilter intentFilter = new IntentFilter("android.intent.action.TIMEZONE_CHANGED");
        this.mFilter = intentFilter;
        AnonymousClass1 r1 = new BroadcastReceiver() {
            /* class org.chromium.content.browser.TimeZoneMonitor.AnonymousClass1 */

            public void onReceive(Context context, Intent intent) {
                if (!intent.getAction().equals("android.intent.action.TIMEZONE_CHANGED")) {
                    Log.e(TimeZoneMonitor.TAG, "unexpected intent", new Object[0]);
                    return;
                }
                TimeZoneMonitor timeZoneMonitor = TimeZoneMonitor.this;
                timeZoneMonitor.nativeTimeZoneChangedFromJava(timeZoneMonitor.mNativePtr);
            }
        };
        this.mBroadcastReceiver = r1;
        Context applicationContext = context.getApplicationContext();
        this.mAppContext = applicationContext;
        this.mNativePtr = j;
        applicationContext.registerReceiver(r1, intentFilter);
    }

    @CalledByNative
    public static TimeZoneMonitor getInstance(Context context, long j) {
        return new TimeZoneMonitor(context, j);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native void nativeTimeZoneChangedFromJava(long j);

    @CalledByNative
    public void stop() {
        this.mAppContext.unregisterReceiver(this.mBroadcastReceiver);
        this.mNativePtr = 0;
    }
}
