package org.chromium.content.browser;

import android.view.View;
import android.view.ViewTreeObserver;
import java.util.ArrayList;
import org.chromium.content.browser.PositionObserver;

public class ViewPositionObserver implements PositionObserver {
    private final ArrayList<PositionObserver.Listener> mListeners;
    private final int[] mPosition = new int[2];
    private ViewTreeObserver.OnPreDrawListener mPreDrawListener;
    private View mView;

    public ViewPositionObserver(View view) {
        this.mView = view;
        this.mListeners = new ArrayList<>();
        updatePosition();
        this.mPreDrawListener = new ViewTreeObserver.OnPreDrawListener() {
            /* class org.chromium.content.browser.ViewPositionObserver.AnonymousClass1 */

            public boolean onPreDraw() {
                ViewPositionObserver.this.updatePosition();
                return true;
            }
        };
    }

    private void notifyListeners() {
        for (int i = 0; i < this.mListeners.size(); i++) {
            int[] iArr = this.mPosition;
            this.mListeners.get(i).onPositionChanged(iArr[0], iArr[1]);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void updatePosition() {
        int[] iArr = this.mPosition;
        int i = iArr[0];
        int i2 = iArr[1];
        this.mView.getLocationInWindow(iArr);
        int[] iArr2 = this.mPosition;
        if (iArr2[0] != i || iArr2[1] != i2) {
            notifyListeners();
        }
    }

    @Override // org.chromium.content.browser.PositionObserver
    public void addListener(PositionObserver.Listener listener) {
        if (!this.mListeners.contains(listener)) {
            if (this.mListeners.isEmpty()) {
                this.mView.getViewTreeObserver().addOnPreDrawListener(this.mPreDrawListener);
                updatePosition();
            }
            this.mListeners.add(listener);
        }
    }

    @Override // org.chromium.content.browser.PositionObserver
    public void clearListener() {
        this.mListeners.clear();
    }

    @Override // org.chromium.content.browser.PositionObserver
    public int getPositionX() {
        updatePosition();
        return this.mPosition[0];
    }

    @Override // org.chromium.content.browser.PositionObserver
    public int getPositionY() {
        updatePosition();
        return this.mPosition[1];
    }

    @Override // org.chromium.content.browser.PositionObserver
    public void removeListener(PositionObserver.Listener listener) {
        if (this.mListeners.contains(listener)) {
            this.mListeners.remove(listener);
            if (this.mListeners.isEmpty()) {
                this.mView.getViewTreeObserver().removeOnPreDrawListener(this.mPreDrawListener);
            }
        }
    }
}
