package org.chromium.content.browser;

import android.annotation.TargetApi;
import android.os.Build;
import android.view.ActionMode;
import android.view.View;
import android.view.ViewConfiguration;
import com.google.android.exoplayer2.SimpleExoPlayer;
import org.chromium.base.Log;

@TargetApi(23)
public class WebActionMode {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final int SHOW_DELAY_MS = 300;
    private static final String TAG = "cr.WebActionMode";
    public final ActionMode mActionMode;
    private boolean mHidden;
    private boolean mPendingInvalidateContentRect;
    private final Runnable mRepeatingHideRunnable = new Runnable() {
        /* class org.chromium.content.browser.WebActionMode.AnonymousClass1 */
        public static final /* synthetic */ boolean $assertionsDisabled = false;

        public void run() {
            long defaultHideDuration = WebActionMode.this.getDefaultHideDuration();
            WebActionMode.this.mView.postDelayed(WebActionMode.this.mRepeatingHideRunnable, defaultHideDuration - 1);
            WebActionMode.this.hideTemporarily(defaultHideDuration);
        }
    };
    private final View mView;

    public WebActionMode(ActionMode actionMode, View view) {
        this.mActionMode = actionMode;
        this.mView = view;
    }

    private boolean canHide() {
        if (Build.VERSION.SDK_INT < 23 || this.mActionMode.getType() != 1) {
            return false;
        }
        return true;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private long getDefaultHideDuration() {
        return Build.VERSION.SDK_INT >= 23 ? ViewConfiguration.getDefaultActionModeHideDuration() : SimpleExoPlayer.DEFAULT_DETACH_SURFACE_TIMEOUT_MS;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void hideTemporarily(long j) {
        if (Build.VERSION.SDK_INT >= 23) {
            this.mActionMode.hide(j);
        }
    }

    public void finish() {
        this.mActionMode.finish();
    }

    public void hide(boolean z) {
        if (canHide() && this.mHidden != z) {
            this.mHidden = z;
            if (z) {
                this.mRepeatingHideRunnable.run();
                return;
            }
            this.mHidden = false;
            this.mView.removeCallbacks(this.mRepeatingHideRunnable);
            hideTemporarily(300);
            if (this.mPendingInvalidateContentRect) {
                this.mPendingInvalidateContentRect = false;
                invalidateContentRect();
            }
        }
    }

    public void invalidate() {
        if (this.mHidden) {
            this.mHidden = false;
            this.mView.removeCallbacks(this.mRepeatingHideRunnable);
            this.mPendingInvalidateContentRect = false;
        }
        try {
            this.mActionMode.invalidate();
        } catch (NullPointerException e) {
            Log.w(TAG, "Ignoring NPE from ActionMode.invalidate() as workaround for L", e);
        }
    }

    public void invalidateContentRect() {
        if (Build.VERSION.SDK_INT < 23) {
            return;
        }
        if (this.mHidden) {
            this.mPendingInvalidateContentRect = true;
            return;
        }
        this.mPendingInvalidateContentRect = false;
        this.mActionMode.invalidateContentRect();
    }

    public void onWindowFocusChanged(boolean z) {
        if (Build.VERSION.SDK_INT >= 23) {
            this.mActionMode.onWindowFocusChanged(z);
        }
    }
}
