package org.chromium.content.browser.input;

import android.content.Context;
import android.content.res.TypedArray;
import android.util.AttributeSet;
import android.util.TypedValue;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.PopupWindow;
import org.chromium.content.browser.input.PastePopupMenu;

public class LegacyPastePopupMenu implements View.OnClickListener, PastePopupMenu {
    private final PopupWindow mContainer;
    private final Context mContext;
    private final PastePopupMenu.PastePopupMenuDelegate mDelegate;
    private final int mLineOffsetY;
    private final View mParent;
    private View mPasteView;
    private final int mPasteViewLayout;
    private int mRawPositionX;
    private int mRawPositionY;
    private int mStatusBarHeight;
    private final int mWidthOffsetX;

    public LegacyPastePopupMenu(Context context, View view, final PastePopupMenu.PastePopupMenuDelegate pastePopupMenuDelegate) {
        this.mParent = view;
        this.mDelegate = pastePopupMenuDelegate;
        this.mContext = context;
        PopupWindow popupWindow = new PopupWindow(context, (AttributeSet) null, 16843464);
        this.mContainer = popupWindow;
        popupWindow.setSplitTouchEnabled(true);
        popupWindow.setClippingEnabled(false);
        popupWindow.setAnimationStyle(0);
        popupWindow.setWidth(-2);
        popupWindow.setHeight(-2);
        popupWindow.setOnDismissListener(new PopupWindow.OnDismissListener() {
            /* class org.chromium.content.browser.input.LegacyPastePopupMenu.AnonymousClass1 */

            public void onDismiss() {
                pastePopupMenuDelegate.onDismiss();
            }
        });
        TypedArray obtainStyledAttributes = context.getTheme().obtainStyledAttributes(new int[]{16843540});
        this.mPasteViewLayout = obtainStyledAttributes.getResourceId(obtainStyledAttributes.getIndex(0), 0);
        obtainStyledAttributes.recycle();
        this.mLineOffsetY = (int) TypedValue.applyDimension(1, 5.0f, context.getResources().getDisplayMetrics());
        this.mWidthOffsetX = (int) TypedValue.applyDimension(1, 30.0f, context.getResources().getDisplayMetrics());
        int identifier = context.getResources().getIdentifier("status_bar_height", "dimen", "android");
        if (identifier > 0) {
            this.mStatusBarHeight = context.getResources().getDimensionPixelSize(identifier);
        }
    }

    private void paste() {
        this.mDelegate.paste();
    }

    private void positionAt(int i, int i2) {
        int i3;
        if (this.mRawPositionX != i || this.mRawPositionY != i2 || !isShowing()) {
            this.mRawPositionX = i;
            this.mRawPositionY = i2;
            View contentView = this.mContainer.getContentView();
            int measuredWidth = contentView.getMeasuredWidth();
            int measuredHeight = contentView.getMeasuredHeight();
            int i4 = (int) (((float) i) - (((float) measuredWidth) / 2.0f));
            int i5 = (i2 - measuredHeight) - this.mLineOffsetY;
            int i6 = this.mParent.getSystemUiVisibility() == 0 ? this.mStatusBarHeight : 0;
            int i7 = this.mContext.getResources().getDisplayMetrics().widthPixels;
            if (i5 < i6) {
                i5 = i5 + measuredHeight + this.mLineOffsetY;
                int i8 = this.mWidthOffsetX / 2;
                if (i + measuredWidth < i7) {
                    i3 = (measuredWidth / 2) + i8 + i4;
                } else {
                    i3 = i4 - ((measuredWidth / 2) + i8);
                }
            } else {
                i3 = Math.min(i7 - measuredWidth, Math.max(0, i4));
            }
            int[] iArr = new int[2];
            this.mParent.getLocationInWindow(iArr);
            int i9 = i3 + iArr[0];
            int i10 = i5 + iArr[1];
            if (!isShowing()) {
                this.mContainer.showAtLocation(this.mParent, 0, i9, i10);
            } else {
                this.mContainer.update(i9, i10, -1, -1);
            }
        }
    }

    private void updateContent() {
        if (this.mPasteView == null) {
            LayoutInflater layoutInflater = (LayoutInflater) this.mContext.getSystemService("layout_inflater");
            if (layoutInflater != null) {
                this.mPasteView = layoutInflater.inflate(this.mPasteViewLayout, (ViewGroup) null);
            }
            if (this.mPasteView != null) {
                int makeMeasureSpec = View.MeasureSpec.makeMeasureSpec(0, 0);
                this.mPasteView.setLayoutParams(new ViewGroup.LayoutParams(-2, -2));
                this.mPasteView.measure(makeMeasureSpec, makeMeasureSpec);
                this.mPasteView.setOnClickListener(this);
            } else {
                throw new IllegalArgumentException("Unable to inflate TextEdit paste window");
            }
        }
        this.mContainer.setContentView(this.mPasteView);
    }

    @Override // org.chromium.content.browser.input.PastePopupMenu
    public void hide() {
        this.mContainer.dismiss();
    }

    @Override // org.chromium.content.browser.input.PastePopupMenu
    public boolean isShowing() {
        return this.mContainer.isShowing();
    }

    public void onClick(View view) {
        paste();
        hide();
    }

    @Override // org.chromium.content.browser.input.PastePopupMenu
    public void show(int i, int i2) {
        updateContent();
        positionAt(i, i2);
    }
}
