package org.chromium.content.browser.input;

import android.annotation.SuppressLint;
import android.content.Context;
import android.graphics.Canvas;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.os.SystemClock;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.view.animation.AnimationUtils;
import android.widget.PopupWindow;
import java.lang.reflect.InvocationTargetException;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;
import org.chromium.content.browser.ContainerViewObserver;
import org.chromium.content.browser.ContentViewCore;
import org.chromium.content.browser.PositionObserver;
import org.chromium.content.browser.ViewPositionObserver;
import org.chromium.content_public.browser.GestureStateListener;

@JNINamespace("content")
public class PopupTouchHandleDrawable extends View {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final int FADE_IN_DURATION_MS = 200;
    private static final int MOVING_FADE_IN_DELAY_MS = 300;
    private float mAlpha;
    private boolean mAttachedToWindow;
    private final PopupWindow mContainer;
    private ContentViewCore mContentViewCore;
    private Runnable mDeferredHandleFadeInRunnable;
    private boolean mDelayVisibilityUpdateWAR;
    private Drawable mDrawable;
    private long mFadeStartTime;
    private boolean mFocused;
    private final GestureStateListener mGestureStateListener;
    private boolean mHasPendingInvalidate;
    private Runnable mInvalidationRunnable;
    private boolean mMirrorHorizontal;
    private boolean mMirrorVertical;
    private int mOrientation = 3;
    private final PositionObserver.Listener mParentPositionListener;
    private PositionObserver mParentPositionObserver;
    private int mParentPositionX;
    private int mParentPositionY;
    private final ContainerViewObserver mParentViewObserver;
    private int mPositionX;
    private int mPositionY;
    private boolean mScrolling;
    private final int[] mTempScreenCoords = new int[2];
    private boolean mTemporarilyHidden;
    private long mTemporarilyHiddenExpireTime;
    private Runnable mTemporarilyHiddenExpiredRunnable;
    private boolean mVisible;
    private boolean mWasShowingAllowed;

    private PopupTouchHandleDrawable(ContentViewCore contentViewCore) {
        super(contentViewCore.getContainerView().getContext());
        this.mContentViewCore = contentViewCore;
        PopupWindow popupWindow = new PopupWindow(this.mContentViewCore.getWindowAndroid().getContext().get(), (AttributeSet) null, 16843464);
        this.mContainer = popupWindow;
        boolean z = true;
        popupWindow.setSplitTouchEnabled(true);
        popupWindow.setClippingEnabled(false);
        popupWindow.setAnimationStyle(0);
        setWindowLayoutType(popupWindow, 1002);
        popupWindow.setWidth(-2);
        popupWindow.setHeight(-2);
        this.mAlpha = 1.0f;
        this.mVisible = getVisibility() != 0 ? false : z;
        this.mFocused = this.mContentViewCore.getContainerView().hasWindowFocus();
        this.mParentPositionObserver = new ViewPositionObserver(this.mContentViewCore.getContainerView());
        this.mParentPositionListener = new PositionObserver.Listener() {
            /* class org.chromium.content.browser.input.PopupTouchHandleDrawable.AnonymousClass1 */

            @Override // org.chromium.content.browser.PositionObserver.Listener
            public void onPositionChanged(int i, int i2) {
                PopupTouchHandleDrawable.this.updateParentPosition(i, i2);
            }
        };
        AnonymousClass2 r4 = new ContainerViewObserver() {
            /* class org.chromium.content.browser.input.PopupTouchHandleDrawable.AnonymousClass2 */

            @Override // org.chromium.content.browser.ContainerViewObserver
            public void onContainerViewChanged(ViewGroup viewGroup) {
                PopupTouchHandleDrawable.this.mParentPositionObserver.clearListener();
                PopupTouchHandleDrawable.this.mParentPositionObserver = new ViewPositionObserver(viewGroup);
                if (PopupTouchHandleDrawable.this.mContainer.isShowing()) {
                    PopupTouchHandleDrawable.this.mParentPositionObserver.addListener(PopupTouchHandleDrawable.this.mParentPositionListener);
                }
            }
        };
        this.mParentViewObserver = r4;
        AnonymousClass3 r0 = new GestureStateListener() {
            /* class org.chromium.content.browser.input.PopupTouchHandleDrawable.AnonymousClass3 */

            @Override // org.chromium.content_public.browser.GestureStateListener
            public void onDestroyed() {
                PopupTouchHandleDrawable.this.destroy();
            }

            @Override // org.chromium.content_public.browser.GestureStateListener
            public void onFlingStartGesture(int i, int i2, int i3, int i4) {
                PopupTouchHandleDrawable.this.setIsScrolling(false);
            }

            @Override // org.chromium.content_public.browser.GestureStateListener
            public void onScrollEnded(int i, int i2) {
                PopupTouchHandleDrawable.this.setIsScrolling(false);
            }

            @Override // org.chromium.content_public.browser.GestureStateListener
            public void onScrollOffsetOrExtentChanged(int i, int i2) {
                PopupTouchHandleDrawable.this.temporarilyHide();
            }

            @Override // org.chromium.content_public.browser.GestureStateListener
            public void onScrollStarted(int i, int i2) {
                PopupTouchHandleDrawable.this.setIsScrolling(true);
            }

            @Override // org.chromium.content_public.browser.GestureStateListener
            public void onWindowFocusChanged(boolean z) {
                PopupTouchHandleDrawable.this.setIsFocused(z);
            }
        };
        this.mGestureStateListener = r0;
        this.mContentViewCore.addGestureStateListener(r0);
        this.mContentViewCore.addContainerViewObserver(r4);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void beginFadeIn() {
        if (getVisibility() != 0) {
            this.mAlpha = 0.0f;
            this.mFadeStartTime = AnimationUtils.currentAnimationTimeMillis();
            doInvalidate();
        }
    }

    private void cancelFadeIn() {
        Runnable runnable = this.mDeferredHandleFadeInRunnable;
        if (runnable != null) {
            removeCallbacks(runnable);
        }
    }

    @CalledByNative
    private static PopupTouchHandleDrawable create(ContentViewCore contentViewCore) {
        return new PopupTouchHandleDrawable(contentViewCore);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    @CalledByNative
    private void destroy() {
        if (this.mContentViewCore != null) {
            hide();
            this.mContentViewCore.removeGestureStateListener(this.mGestureStateListener);
            this.mContentViewCore.removeContainerViewObserver(this.mParentViewObserver);
            this.mContentViewCore = null;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void doInvalidate() {
        if (this.mContainer.isShowing()) {
            updateVisibility();
            updatePosition();
            invalidate();
        }
    }

    private int getContainerPositionX() {
        return this.mParentPositionX + this.mPositionX;
    }

    private int getContainerPositionY() {
        return this.mParentPositionY + this.mPositionY;
    }

    private static Drawable getHandleDrawable(Context context, int i) {
        if (i == 0) {
            return HandleViewResources.getLeftHandleDrawable(context);
        }
        if (i == 1) {
            return HandleViewResources.getCenterHandleDrawable(context);
        }
        if (i != 2) {
            return HandleViewResources.getCenterHandleDrawable(context);
        }
        return HandleViewResources.getRightHandleDrawable(context);
    }

    @CalledByNative
    private float getHandleHorizontalPaddingRatio() {
        return HandleViewResources.getHandleHorizontalPaddingRatio();
    }

    @CalledByNative
    private int getPositionX() {
        return this.mPositionX;
    }

    @CalledByNative
    private int getPositionY() {
        return this.mPositionY;
    }

    @CalledByNative
    private int getVisibleHeight() {
        Drawable drawable = this.mDrawable;
        if (drawable == null) {
            return 0;
        }
        return drawable.getIntrinsicHeight();
    }

    @CalledByNative
    private int getVisibleWidth() {
        Drawable drawable = this.mDrawable;
        if (drawable == null) {
            return 0;
        }
        return drawable.getIntrinsicWidth();
    }

    @CalledByNative
    private void hide() {
        this.mTemporarilyHiddenExpireTime = 0;
        setTemporarilyHidden(false);
        this.mAlpha = 1.0f;
        if (this.mContainer.isShowing()) {
            try {
                this.mContainer.dismiss();
            } catch (IllegalArgumentException unused) {
            }
        }
        this.mParentPositionObserver.clearListener();
    }

    private boolean isShowingAllowed() {
        return this.mAttachedToWindow && this.mVisible && this.mFocused && !this.mScrolling && !this.mTemporarilyHidden;
    }

    private void onVisibilityInputChanged() {
        boolean isShowingAllowed;
        if (this.mContainer.isShowing() && this.mWasShowingAllowed != (isShowingAllowed = isShowingAllowed())) {
            this.mWasShowingAllowed = isShowingAllowed;
            cancelFadeIn();
            if (isShowingAllowed) {
                if (this.mDeferredHandleFadeInRunnable == null) {
                    this.mDeferredHandleFadeInRunnable = new Runnable() {
                        /* class org.chromium.content.browser.input.PopupTouchHandleDrawable.AnonymousClass5 */

                        public void run() {
                            PopupTouchHandleDrawable.this.beginFadeIn();
                        }
                    };
                }
                postOnAnimation(this.mDeferredHandleFadeInRunnable);
                return;
            }
            updateVisibility();
        }
    }

    private void scheduleInvalidate() {
        if (this.mInvalidationRunnable == null) {
            this.mInvalidationRunnable = new Runnable() {
                /* class org.chromium.content.browser.input.PopupTouchHandleDrawable.AnonymousClass6 */

                public void run() {
                    PopupTouchHandleDrawable.this.mHasPendingInvalidate = false;
                    PopupTouchHandleDrawable.this.doInvalidate();
                }
            };
        }
        if (!this.mHasPendingInvalidate) {
            this.mHasPendingInvalidate = true;
            postOnAnimation(this.mInvalidationRunnable);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setIsFocused(boolean z) {
        if (this.mFocused != z) {
            this.mFocused = z;
            onVisibilityInputChanged();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setIsScrolling(boolean z) {
        if (this.mScrolling != z) {
            this.mScrolling = z;
            onVisibilityInputChanged();
        }
    }

    @CalledByNative
    private void setOrientation(int i, boolean z, boolean z2) {
        boolean z3 = true;
        boolean z4 = this.mOrientation != i;
        if (this.mMirrorHorizontal == z2 && this.mMirrorVertical == z) {
            z3 = false;
        }
        this.mOrientation = i;
        this.mMirrorHorizontal = z2;
        this.mMirrorVertical = z;
        if (z4) {
            this.mDrawable = getHandleDrawable(getContext(), this.mOrientation);
        }
        Drawable drawable = this.mDrawable;
        if (drawable != null) {
            drawable.setAlpha((int) (this.mAlpha * 255.0f));
        }
        if (z4 || z3) {
            scheduleInvalidate();
        }
    }

    @CalledByNative
    private void setOrigin(float f, float f2) {
        if (((float) this.mPositionX) != f || ((float) this.mPositionY) != f2) {
            this.mPositionX = (int) f;
            this.mPositionY = (int) f2;
            if (getVisibility() == 0) {
                scheduleInvalidate();
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setTemporarilyHidden(boolean z) {
        if (this.mTemporarilyHidden != z) {
            this.mTemporarilyHidden = z;
            if (z) {
                if (this.mTemporarilyHiddenExpiredRunnable == null) {
                    this.mTemporarilyHiddenExpiredRunnable = new Runnable() {
                        /* class org.chromium.content.browser.input.PopupTouchHandleDrawable.AnonymousClass4 */

                        public void run() {
                            PopupTouchHandleDrawable.this.setTemporarilyHidden(false);
                        }
                    };
                }
                removeCallbacks(this.mTemporarilyHiddenExpiredRunnable);
                postDelayed(this.mTemporarilyHiddenExpiredRunnable, Math.max(0L, this.mTemporarilyHiddenExpireTime - SystemClock.uptimeMillis()));
            } else {
                Runnable runnable = this.mTemporarilyHiddenExpiredRunnable;
                if (runnable != null) {
                    removeCallbacks(runnable);
                }
            }
            onVisibilityInputChanged();
        }
    }

    @CalledByNative
    private void setVisible(boolean z) {
        if (this.mVisible != z) {
            this.mVisible = z;
            onVisibilityInputChanged();
        }
    }

    private static void setWindowLayoutType(PopupWindow popupWindow, int i) {
        if (Build.VERSION.SDK_INT >= 23) {
            popupWindow.setWindowLayoutType(i);
            return;
        }
        try {
            PopupWindow.class.getMethod("setWindowLayoutType", Integer.TYPE).invoke(popupWindow, Integer.valueOf(i));
        } catch (IllegalAccessException | NoSuchMethodException | RuntimeException | InvocationTargetException unused) {
        }
    }

    @CalledByNative
    private void show() {
        if (this.mContentViewCore != null && !this.mContainer.isShowing()) {
            updateParentPosition(this.mParentPositionObserver.getPositionX(), this.mParentPositionObserver.getPositionY());
            this.mParentPositionObserver.addListener(this.mParentPositionListener);
            this.mContainer.setContentView(this);
            try {
                this.mContainer.showAtLocation(this.mContentViewCore.getContainerView(), 0, getContainerPositionX(), getContainerPositionY());
            } catch (WindowManager.BadTokenException unused) {
                hide();
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void temporarilyHide() {
        if (this.mContainer.isShowing()) {
            this.mTemporarilyHiddenExpireTime = SystemClock.uptimeMillis() + 300;
            setTemporarilyHidden(true);
        }
    }

    private void updateAlpha() {
        if (this.mAlpha != 1.0f) {
            float min = Math.min(1.0f, ((float) (AnimationUtils.currentAnimationTimeMillis() - this.mFadeStartTime)) / 200.0f);
            this.mAlpha = min;
            this.mDrawable.setAlpha((int) (min * 255.0f));
            scheduleInvalidate();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void updateParentPosition(int i, int i2) {
        if (this.mParentPositionX != i || this.mParentPositionY != i2) {
            this.mParentPositionX = i;
            this.mParentPositionY = i2;
            temporarilyHide();
        }
    }

    private void updatePosition() {
        this.mContainer.update(getContainerPositionX(), getContainerPositionY(), getRight() - getLeft(), getBottom() - getTop());
    }

    private void updateVisibility() {
        int i = isShowingAllowed() ? 0 : 4;
        if (i != 0 || getVisibility() == 0 || this.mDelayVisibilityUpdateWAR) {
            this.mDelayVisibilityUpdateWAR = false;
            setVisibility(i);
            return;
        }
        this.mDelayVisibilityUpdateWAR = true;
        scheduleInvalidate();
    }

    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        this.mAttachedToWindow = true;
        onVisibilityInputChanged();
    }

    public void onDetachedFromWindow() {
        super.onDetachedFromWindow();
        this.mAttachedToWindow = false;
        onVisibilityInputChanged();
    }

    public void onDraw(Canvas canvas) {
        if (this.mDrawable != null) {
            boolean z = this.mMirrorHorizontal || this.mMirrorVertical;
            if (z) {
                canvas.save();
                float f = -1.0f;
                float f2 = this.mMirrorHorizontal ? -1.0f : 1.0f;
                if (!this.mMirrorVertical) {
                    f = 1.0f;
                }
                canvas.scale(f2, f, ((float) getWidth()) / 2.0f, ((float) getHeight()) / 2.0f);
            }
            updateAlpha();
            this.mDrawable.setBounds(0, 0, getRight() - getLeft(), getBottom() - getTop());
            this.mDrawable.draw(canvas);
            if (z) {
                canvas.restore();
            }
        }
    }

    public void onMeasure(int i, int i2) {
        Drawable drawable = this.mDrawable;
        if (drawable == null) {
            setMeasuredDimension(0, 0);
        } else {
            setMeasuredDimension(drawable.getIntrinsicWidth(), this.mDrawable.getIntrinsicHeight());
        }
    }

    @SuppressLint({"ClickableViewAccessibility"})
    public boolean onTouchEvent(MotionEvent motionEvent) {
        ContentViewCore contentViewCore = this.mContentViewCore;
        if (contentViewCore == null) {
            return false;
        }
        contentViewCore.getContainerView().getLocationOnScreen(this.mTempScreenCoords);
        MotionEvent obtainNoHistory = MotionEvent.obtainNoHistory(motionEvent);
        obtainNoHistory.offsetLocation((motionEvent.getRawX() - motionEvent.getX()) - ((float) this.mTempScreenCoords[0]), (motionEvent.getRawY() - motionEvent.getY()) - ((float) this.mTempScreenCoords[1]));
        boolean onTouchHandleEvent = this.mContentViewCore.onTouchHandleEvent(obtainNoHistory);
        obtainNoHistory.recycle();
        return onTouchHandleEvent;
    }
}
