package org.chromium.content.browser.input;

import android.content.Context;
import android.graphics.Rect;
import android.view.View;
import android.widget.AdapterView;
import android.widget.PopupWindow;
import java.util.List;
import org.chromium.content.browser.ContentViewCore;
import org.chromium.content.browser.RenderCoordinates;
import org.chromium.ui.DropdownAdapter;
import org.chromium.ui.DropdownPopupWindow;

public class SelectPopupDropdown implements SelectPopup {
    private final ContentViewCore mContentViewCore;
    private final Context mContext;
    private final DropdownPopupWindow mDropdownPopupWindow;
    private boolean mSelectionNotified;

    public SelectPopupDropdown(ContentViewCore contentViewCore, List<SelectPopupItem> list, Rect rect, int[] iArr, boolean z) {
        this.mContentViewCore = contentViewCore;
        Context context = contentViewCore.getContext();
        this.mContext = context;
        DropdownPopupWindow dropdownPopupWindow = new DropdownPopupWindow(context, contentViewCore.getViewAndroidDelegate());
        this.mDropdownPopupWindow = dropdownPopupWindow;
        dropdownPopupWindow.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            /* class org.chromium.content.browser.input.SelectPopupDropdown.AnonymousClass1 */

            @Override // android.widget.AdapterView.OnItemClickListener
            public void onItemClick(AdapterView<?> adapterView, View view, int i, long j) {
                SelectPopupDropdown.this.notifySelection(new int[]{i});
                SelectPopupDropdown.this.hide(false);
            }
        });
        dropdownPopupWindow.setInitialSelection(iArr.length > 0 ? iArr[0] : -1);
        dropdownPopupWindow.setAdapter(new DropdownAdapter(context, list, null));
        dropdownPopupWindow.setRtl(z);
        RenderCoordinates renderCoordinates = contentViewCore.getRenderCoordinates();
        float fromPixToDip = renderCoordinates.fromPixToDip(renderCoordinates.fromLocalCssToPix((float) rect.left));
        float fromPixToDip2 = renderCoordinates.fromPixToDip(renderCoordinates.fromLocalCssToPix((float) rect.top));
        dropdownPopupWindow.setAnchorRect(fromPixToDip, fromPixToDip2, renderCoordinates.fromPixToDip(renderCoordinates.fromLocalCssToPix((float) rect.right)) - fromPixToDip, renderCoordinates.fromPixToDip(renderCoordinates.fromLocalCssToPix((float) rect.bottom)) - fromPixToDip2);
        dropdownPopupWindow.setOnDismissListener(new PopupWindow.OnDismissListener() {
            /* class org.chromium.content.browser.input.SelectPopupDropdown.AnonymousClass2 */

            public void onDismiss() {
                SelectPopupDropdown.this.notifySelection(null);
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void notifySelection(int[] iArr) {
        if (!this.mSelectionNotified) {
            this.mContentViewCore.selectPopupMenuItems(iArr);
            this.mSelectionNotified = true;
        }
    }

    @Override // org.chromium.content.browser.input.SelectPopup
    public void hide(boolean z) {
        if (z) {
            this.mDropdownPopupWindow.dismiss();
            notifySelection(null);
            return;
        }
        this.mSelectionNotified = true;
        this.mDropdownPopupWindow.dismiss();
    }

    @Override // org.chromium.content.browser.input.SelectPopup
    public void show() {
        this.mDropdownPopupWindow.postShow();
    }
}
