package org.chromium.content.common;

import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import java.lang.ref.ReferenceQueue;
import java.lang.ref.WeakReference;
import java.util.HashSet;
import java.util.Set;
import org.chromium.base.Log;
import org.chromium.base.ThreadUtils;
import org.chromium.base.TraceEvent;

public class CleanupReference extends WeakReference<Object> {
    private static final int ADD_REF = 1;
    private static final boolean DEBUG = false;
    private static final int REMOVE_REF = 2;
    private static final String TAG = "cr.CleanupReference";
    private static Object sCleanupMonitor = new Object();
    private static ReferenceQueue<Object> sGcQueue = new ReferenceQueue<>();
    private static final Thread sReaperThread;
    private static Set<CleanupReference> sRefs = new HashSet();
    private Runnable mCleanupTask;

    public static class LazyHolder {
        public static final Handler sHandler = new Handler(ThreadUtils.getUiThreadLooper()) {
            /* class org.chromium.content.common.CleanupReference.LazyHolder.AnonymousClass1 */

            public void handleMessage(Message message) {
                try {
                    TraceEvent.begin("CleanupReference.LazyHolder.handleMessage");
                    CleanupReference cleanupReference = (CleanupReference) message.obj;
                    int i = message.what;
                    if (i == 1) {
                        CleanupReference.sRefs.add(cleanupReference);
                    } else if (i != 2) {
                        Log.e(CleanupReference.TAG, "Bad message=%d", Integer.valueOf(i));
                    } else {
                        cleanupReference.runCleanupTaskInternal();
                    }
                    synchronized (CleanupReference.sCleanupMonitor) {
                        while (true) {
                            CleanupReference cleanupReference2 = (CleanupReference) CleanupReference.sGcQueue.poll();
                            if (cleanupReference2 != null) {
                                cleanupReference2.runCleanupTaskInternal();
                            } else {
                                CleanupReference.sCleanupMonitor.notifyAll();
                            }
                        }
                    }
                } finally {
                    TraceEvent.end("CleanupReference.LazyHolder.handleMessage");
                }
            }
        };

        private LazyHolder() {
        }
    }

    static {
        AnonymousClass1 r0 = new Thread(TAG) {
            /* class org.chromium.content.common.CleanupReference.AnonymousClass1 */

            public void run() {
                while (true) {
                    try {
                        CleanupReference cleanupReference = (CleanupReference) CleanupReference.sGcQueue.remove();
                        synchronized (CleanupReference.sCleanupMonitor) {
                            Message.obtain(LazyHolder.sHandler, 2, cleanupReference).sendToTarget();
                            CleanupReference.sCleanupMonitor.wait(500);
                        }
                    } catch (Exception e) {
                        Log.e(CleanupReference.TAG, "Queue remove exception:", e);
                    }
                }
            }
        };
        sReaperThread = r0;
        r0.setDaemon(true);
        r0.start();
    }

    public CleanupReference(Object obj, Runnable runnable) {
        super(obj, sGcQueue);
        this.mCleanupTask = runnable;
        handleOnUiThread(1);
    }

    private void handleOnUiThread(int i) {
        Message obtain = Message.obtain(LazyHolder.sHandler, i, this);
        if (Looper.myLooper() == obtain.getTarget().getLooper()) {
            obtain.getTarget().handleMessage(obtain);
            obtain.recycle();
            return;
        }
        obtain.sendToTarget();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void runCleanupTaskInternal() {
        sRefs.remove(this);
        Runnable runnable = this.mCleanupTask;
        if (runnable != null) {
            runnable.run();
            this.mCleanupTask = null;
        }
        clear();
    }

    public void cleanupNow() {
        handleOnUiThread(2);
    }
}
