package org.chromium.device.battery;

import android.content.Context;
import android.util.Log;
import java.util.HashSet;
import java.util.Iterator;
import org.chromium.base.ThreadUtils;
import org.chromium.device.battery.BatteryStatusManager;
import org.chromium.mojom.device.BatteryMonitor;
import org.chromium.mojom.device.BatteryStatus;

public class BatteryMonitorFactory {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final String TAG = "BatteryMonitorFactory";
    private final BatteryStatusManager.BatteryStatusCallback mCallback;
    private final BatteryStatusManager mManager;
    private final HashSet<BatteryMonitorImpl> mSubscribedMonitors = new HashSet<>();

    public BatteryMonitorFactory(Context context) {
        AnonymousClass1 r0 = new BatteryStatusManager.BatteryStatusCallback() {
            /* class org.chromium.device.battery.BatteryMonitorFactory.AnonymousClass1 */

            @Override // org.chromium.device.battery.BatteryStatusManager.BatteryStatusCallback
            public void onBatteryStatusChanged(BatteryStatus batteryStatus) {
                ThreadUtils.assertOnUiThread();
                Iterator it = BatteryMonitorFactory.this.mSubscribedMonitors.iterator();
                while (it.hasNext()) {
                    ((BatteryMonitorImpl) it.next()).didChange(batteryStatus);
                }
            }
        };
        this.mCallback = r0;
        this.mManager = new BatteryStatusManager(context, r0);
    }

    public BatteryMonitor createMonitor() {
        ThreadUtils.assertOnUiThread();
        if (this.mSubscribedMonitors.isEmpty() && !this.mManager.start()) {
            Log.e(TAG, "BatteryStatusManager failed to start.");
        }
        BatteryMonitorImpl batteryMonitorImpl = new BatteryMonitorImpl(this);
        this.mSubscribedMonitors.add(batteryMonitorImpl);
        return batteryMonitorImpl;
    }

    public void unsubscribe(BatteryMonitorImpl batteryMonitorImpl) {
        ThreadUtils.assertOnUiThread();
        this.mSubscribedMonitors.remove(batteryMonitorImpl);
        if (this.mSubscribedMonitors.isEmpty()) {
            this.mManager.stop();
        }
    }
}
