package org.chromium.device.battery;

import android.annotation.TargetApi;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.BatteryManager;
import android.os.Build;
import android.util.Log;
import com.google.android.exoplayer2.source.rtsp.RtspHeaders;
import javax.annotation.Nullable;
import org.chromium.base.VisibleForTesting;
import org.chromium.mojom.device.BatteryStatus;

public class BatteryStatusManager {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final String TAG = "BatteryStatusManager";
    private AndroidBatteryManagerWrapper mAndroidBatteryManager;
    private final Context mAppContext;
    private final BatteryStatusCallback mCallback;
    private boolean mEnabled;
    private final IntentFilter mFilter;
    private final boolean mIgnoreBatteryPresentState;
    private final BroadcastReceiver mReceiver;

    @VisibleForTesting
    public static class AndroidBatteryManagerWrapper {
        private final BatteryManager mBatteryManager;

        public AndroidBatteryManagerWrapper(BatteryManager batteryManager) {
            this.mBatteryManager = batteryManager;
        }

        public int getIntProperty(int i) {
            return this.mBatteryManager.getIntProperty(i);
        }
    }

    public interface BatteryStatusCallback {
        void onBatteryStatusChanged(BatteryStatus batteryStatus);
    }

    private BatteryStatusManager(Context context, BatteryStatusCallback batteryStatusCallback, boolean z, @Nullable AndroidBatteryManagerWrapper androidBatteryManagerWrapper) {
        this.mFilter = new IntentFilter("android.intent.action.BATTERY_CHANGED");
        this.mReceiver = new BroadcastReceiver() {
            /* class org.chromium.device.battery.BatteryStatusManager.AnonymousClass1 */

            public void onReceive(Context context, Intent intent) {
                BatteryStatusManager.this.onReceive(intent);
            }
        };
        this.mEnabled = false;
        this.mAppContext = context.getApplicationContext();
        this.mCallback = batteryStatusCallback;
        this.mIgnoreBatteryPresentState = z;
        this.mAndroidBatteryManager = androidBatteryManagerWrapper;
    }

    public static BatteryStatusManager createBatteryStatusManagerForTesting(Context context, BatteryStatusCallback batteryStatusCallback, @Nullable AndroidBatteryManagerWrapper androidBatteryManagerWrapper) {
        return new BatteryStatusManager(context, batteryStatusCallback, false, androidBatteryManagerWrapper);
    }

    @TargetApi(21)
    private void updateBatteryStatusForLollipop(BatteryStatus batteryStatus) {
        double intProperty = (double) this.mAndroidBatteryManager.getIntProperty(4);
        Double.isNaN(intProperty);
        double d = intProperty / 100.0d;
        double intProperty2 = (double) this.mAndroidBatteryManager.getIntProperty(1);
        double intProperty3 = (double) this.mAndroidBatteryManager.getIntProperty(3);
        if (batteryStatus.charging) {
            if (batteryStatus.chargingTime == Double.POSITIVE_INFINITY && intProperty3 > 0.0d) {
                Double.isNaN(intProperty2);
                Double.isNaN(intProperty3);
                batteryStatus.chargingTime = Math.ceil((1.0d - d) * (intProperty2 / intProperty3) * 3600.0d);
            }
        } else if (intProperty3 < 0.0d) {
            Double.isNaN(intProperty3);
            Double.isNaN(intProperty2);
            batteryStatus.dischargingTime = Math.floor((intProperty2 / (-intProperty3)) * d * 3600.0d);
        }
    }

    @VisibleForTesting
    public void onReceive(Intent intent) {
        if (!intent.getAction().equals("android.intent.action.BATTERY_CHANGED")) {
            Log.e(TAG, "Unexpected intent.");
            return;
        }
        boolean z = true;
        boolean booleanExtra = this.mIgnoreBatteryPresentState ? true : intent.getBooleanExtra("present", false);
        int intExtra = intent.getIntExtra("plugged", -1);
        if (!booleanExtra || intExtra == -1) {
            this.mCallback.onBatteryStatusChanged(new BatteryStatus());
            return;
        }
        double intExtra2 = (double) intent.getIntExtra("level", -1);
        double intExtra3 = (double) intent.getIntExtra(RtspHeaders.SCALE, -1);
        Double.isNaN(intExtra2);
        Double.isNaN(intExtra3);
        double d = intExtra2 / intExtra3;
        double d2 = 0.0d;
        if (d < 0.0d || d > 1.0d) {
            d = 1.0d;
        }
        boolean z2 = intExtra != 0;
        if (intent.getIntExtra("status", -1) != 5) {
            z = false;
        }
        if (!z2 || !z) {
            d2 = Double.POSITIVE_INFINITY;
        }
        BatteryStatus batteryStatus = new BatteryStatus();
        batteryStatus.charging = z2;
        batteryStatus.chargingTime = d2;
        batteryStatus.dischargingTime = Double.POSITIVE_INFINITY;
        batteryStatus.level = d;
        if (this.mAndroidBatteryManager != null) {
            updateBatteryStatusForLollipop(batteryStatus);
        }
        this.mCallback.onBatteryStatusChanged(batteryStatus);
    }

    public boolean start() {
        if (!this.mEnabled && this.mAppContext.registerReceiver(this.mReceiver, this.mFilter) != null) {
            this.mEnabled = true;
        }
        return this.mEnabled;
    }

    public void stop() {
        if (this.mEnabled) {
            this.mAppContext.unregisterReceiver(this.mReceiver);
            this.mEnabled = false;
        }
    }

    /* JADX INFO: this call moved to the top of the method (can break code semantics) */
    public BatteryStatusManager(Context context, BatteryStatusCallback batteryStatusCallback) {
        this(context, batteryStatusCallback, Build.MODEL.equals("Galaxy Nexus"), Build.VERSION.SDK_INT >= 21 ? new AndroidBatteryManagerWrapper((BatteryManager) context.getSystemService("batterymanager")) : null);
    }
}
