package org.chromium.device.bluetooth;

import android.annotation.TargetApi;
import android.content.Context;
import android.os.ParcelUuid;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import org.chromium.base.Log;
import org.chromium.base.ThreadUtils;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;
import org.chromium.device.bluetooth.Wrappers;

@JNINamespace("device")
@TargetApi(21)
public final class ChromeBluetoothDevice {
    private static final String TAG = "Bluetooth";
    public Wrappers.BluetoothGattWrapper mBluetoothGatt;
    private final BluetoothGattCallbackImpl mBluetoothGattCallbackImpl = new BluetoothGattCallbackImpl();
    public final Wrappers.BluetoothDeviceWrapper mDevice;
    private long mNativeBluetoothDeviceAndroid;
    private HashSet<String> mUuidsFromScan = new HashSet<>();
    public final HashMap<Wrappers.BluetoothGattCharacteristicWrapper, ChromeBluetoothRemoteGattCharacteristic> mWrapperToChromeCharacteristicsMap = new HashMap<>();
    public final HashMap<Wrappers.BluetoothGattDescriptorWrapper, ChromeBluetoothRemoteGattDescriptor> mWrapperToChromeDescriptorsMap = new HashMap<>();

    public class BluetoothGattCallbackImpl extends Wrappers.BluetoothGattCallbackWrapper {
        private BluetoothGattCallbackImpl() {
        }

        @Override // org.chromium.device.bluetooth.Wrappers.BluetoothGattCallbackWrapper
        public void onCharacteristicChanged(final Wrappers.BluetoothGattCharacteristicWrapper bluetoothGattCharacteristicWrapper) {
            Log.i(ChromeBluetoothDevice.TAG, "device onCharacteristicChanged.", new Object[0]);
            ThreadUtils.runOnUiThread(new Runnable() {
                /* class org.chromium.device.bluetooth.ChromeBluetoothDevice.BluetoothGattCallbackImpl.AnonymousClass3 */

                public void run() {
                    ChromeBluetoothRemoteGattCharacteristic chromeBluetoothRemoteGattCharacteristic = ChromeBluetoothDevice.this.mWrapperToChromeCharacteristicsMap.get(bluetoothGattCharacteristicWrapper);
                    if (chromeBluetoothRemoteGattCharacteristic == null) {
                        Log.v(ChromeBluetoothDevice.TAG, "onCharacteristicChanged when chromeCharacteristic == null.");
                    } else {
                        chromeBluetoothRemoteGattCharacteristic.onCharacteristicChanged();
                    }
                }
            });
        }

        @Override // org.chromium.device.bluetooth.Wrappers.BluetoothGattCallbackWrapper
        public void onCharacteristicRead(final Wrappers.BluetoothGattCharacteristicWrapper bluetoothGattCharacteristicWrapper, final int i) {
            ThreadUtils.runOnUiThread(new Runnable() {
                /* class org.chromium.device.bluetooth.ChromeBluetoothDevice.BluetoothGattCallbackImpl.AnonymousClass4 */

                public void run() {
                    ChromeBluetoothRemoteGattCharacteristic chromeBluetoothRemoteGattCharacteristic = ChromeBluetoothDevice.this.mWrapperToChromeCharacteristicsMap.get(bluetoothGattCharacteristicWrapper);
                    if (chromeBluetoothRemoteGattCharacteristic == null) {
                        Log.v(ChromeBluetoothDevice.TAG, "onCharacteristicRead when chromeCharacteristic == null.");
                    } else {
                        chromeBluetoothRemoteGattCharacteristic.onCharacteristicRead(i);
                    }
                }
            });
        }

        @Override // org.chromium.device.bluetooth.Wrappers.BluetoothGattCallbackWrapper
        public void onCharacteristicWrite(final Wrappers.BluetoothGattCharacteristicWrapper bluetoothGattCharacteristicWrapper, final int i) {
            ThreadUtils.runOnUiThread(new Runnable() {
                /* class org.chromium.device.bluetooth.ChromeBluetoothDevice.BluetoothGattCallbackImpl.AnonymousClass5 */

                public void run() {
                    ChromeBluetoothRemoteGattCharacteristic chromeBluetoothRemoteGattCharacteristic = ChromeBluetoothDevice.this.mWrapperToChromeCharacteristicsMap.get(bluetoothGattCharacteristicWrapper);
                    if (chromeBluetoothRemoteGattCharacteristic == null) {
                        Log.v(ChromeBluetoothDevice.TAG, "onCharacteristicWrite when chromeCharacteristic == null.");
                    } else {
                        chromeBluetoothRemoteGattCharacteristic.onCharacteristicWrite(i);
                    }
                }
            });
        }

        @Override // org.chromium.device.bluetooth.Wrappers.BluetoothGattCallbackWrapper
        public void onConnectionStateChange(final int i, final int i2) {
            Wrappers.BluetoothGattWrapper bluetoothGattWrapper;
            Object[] objArr = new Object[2];
            objArr[0] = Integer.valueOf(i);
            objArr[1] = i2 == 2 ? "Connected" : "Disconnected";
            Log.i(ChromeBluetoothDevice.TAG, "onConnectionStateChange status:%d newState:%s", objArr);
            if (i2 == 2) {
                ChromeBluetoothDevice.this.mBluetoothGatt.discoverServices();
            } else if (i2 == 0 && (bluetoothGattWrapper = ChromeBluetoothDevice.this.mBluetoothGatt) != null) {
                bluetoothGattWrapper.close();
                ChromeBluetoothDevice.this.mBluetoothGatt = null;
            }
            ThreadUtils.runOnUiThread(new Runnable() {
                /* class org.chromium.device.bluetooth.ChromeBluetoothDevice.BluetoothGattCallbackImpl.AnonymousClass1 */

                public void run() {
                    if (ChromeBluetoothDevice.this.mNativeBluetoothDeviceAndroid != 0) {
                        ChromeBluetoothDevice chromeBluetoothDevice = ChromeBluetoothDevice.this;
                        chromeBluetoothDevice.nativeOnConnectionStateChange(chromeBluetoothDevice.mNativeBluetoothDeviceAndroid, i, i2 == 2);
                    }
                }
            });
        }

        @Override // org.chromium.device.bluetooth.Wrappers.BluetoothGattCallbackWrapper
        public void onDescriptorRead(final Wrappers.BluetoothGattDescriptorWrapper bluetoothGattDescriptorWrapper, final int i) {
            ThreadUtils.runOnUiThread(new Runnable() {
                /* class org.chromium.device.bluetooth.ChromeBluetoothDevice.BluetoothGattCallbackImpl.AnonymousClass6 */

                public void run() {
                    ChromeBluetoothRemoteGattDescriptor chromeBluetoothRemoteGattDescriptor = ChromeBluetoothDevice.this.mWrapperToChromeDescriptorsMap.get(bluetoothGattDescriptorWrapper);
                    if (chromeBluetoothRemoteGattDescriptor == null) {
                        Log.v(ChromeBluetoothDevice.TAG, "onDescriptorRead when chromeDescriptor == null.");
                    } else {
                        chromeBluetoothRemoteGattDescriptor.onDescriptorRead(i);
                    }
                }
            });
        }

        @Override // org.chromium.device.bluetooth.Wrappers.BluetoothGattCallbackWrapper
        public void onDescriptorWrite(final Wrappers.BluetoothGattDescriptorWrapper bluetoothGattDescriptorWrapper, final int i) {
            ThreadUtils.runOnUiThread(new Runnable() {
                /* class org.chromium.device.bluetooth.ChromeBluetoothDevice.BluetoothGattCallbackImpl.AnonymousClass7 */

                public void run() {
                    ChromeBluetoothRemoteGattDescriptor chromeBluetoothRemoteGattDescriptor = ChromeBluetoothDevice.this.mWrapperToChromeDescriptorsMap.get(bluetoothGattDescriptorWrapper);
                    if (chromeBluetoothRemoteGattDescriptor == null) {
                        Log.v(ChromeBluetoothDevice.TAG, "onDescriptorWrite when chromeDescriptor == null.");
                    } else {
                        chromeBluetoothRemoteGattDescriptor.onDescriptorWrite(i);
                    }
                }
            });
        }

        @Override // org.chromium.device.bluetooth.Wrappers.BluetoothGattCallbackWrapper
        public void onServicesDiscovered(int i) {
            Object[] objArr = new Object[2];
            objArr[0] = Integer.valueOf(i);
            objArr[1] = i == 0 ? "OK" : "Error";
            Log.i(ChromeBluetoothDevice.TAG, "onServicesDiscovered status:%d==%s", objArr);
            ThreadUtils.runOnUiThread(new Runnable() {
                /* class org.chromium.device.bluetooth.ChromeBluetoothDevice.BluetoothGattCallbackImpl.AnonymousClass2 */

                public void run() {
                    if (ChromeBluetoothDevice.this.mNativeBluetoothDeviceAndroid != 0) {
                        for (Wrappers.BluetoothGattServiceWrapper bluetoothGattServiceWrapper : ChromeBluetoothDevice.this.mBluetoothGatt.getServices()) {
                            ChromeBluetoothDevice chromeBluetoothDevice = ChromeBluetoothDevice.this;
                            chromeBluetoothDevice.nativeCreateGattRemoteService(chromeBluetoothDevice.mNativeBluetoothDeviceAndroid, ChromeBluetoothDevice.this.getAddress() + "/" + bluetoothGattServiceWrapper.getUuid().toString() + "," + bluetoothGattServiceWrapper.getInstanceId(), bluetoothGattServiceWrapper);
                        }
                        ChromeBluetoothDevice chromeBluetoothDevice2 = ChromeBluetoothDevice.this;
                        chromeBluetoothDevice2.nativeOnGattServicesDiscovered(chromeBluetoothDevice2.mNativeBluetoothDeviceAndroid);
                    }
                }
            });
        }
    }

    private ChromeBluetoothDevice(long j, Wrappers.BluetoothDeviceWrapper bluetoothDeviceWrapper) {
        this.mNativeBluetoothDeviceAndroid = j;
        this.mDevice = bluetoothDeviceWrapper;
        Log.v(TAG, "ChromeBluetoothDevice created.");
    }

    @CalledByNative
    private static ChromeBluetoothDevice create(long j, Object obj) {
        return new ChromeBluetoothDevice(j, (Wrappers.BluetoothDeviceWrapper) obj);
    }

    @CalledByNative
    private void createGattConnectionImpl(Context context) {
        Log.i(TAG, "connectGatt", new Object[0]);
        Wrappers.BluetoothGattWrapper bluetoothGattWrapper = this.mBluetoothGatt;
        if (bluetoothGattWrapper != null) {
            bluetoothGattWrapper.close();
        }
        this.mBluetoothGatt = this.mDevice.connectGatt(context, false, this.mBluetoothGattCallbackImpl);
    }

    @CalledByNative
    private void disconnectGatt() {
        Log.i(TAG, "BluetoothGatt.disconnect", new Object[0]);
        Wrappers.BluetoothGattWrapper bluetoothGattWrapper = this.mBluetoothGatt;
        if (bluetoothGattWrapper != null) {
            bluetoothGattWrapper.disconnect();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    @CalledByNative
    private String getAddress() {
        return this.mDevice.getAddress();
    }

    @CalledByNative
    private int getBluetoothClass() {
        return this.mDevice.getBluetoothClass_getDeviceClass();
    }

    @CalledByNative
    private String getDeviceName() {
        return this.mDevice.getName();
    }

    @CalledByNative
    private String[] getUuids() {
        HashSet<String> hashSet = this.mUuidsFromScan;
        return (String[]) hashSet.toArray(new String[hashSet.size()]);
    }

    @CalledByNative
    private boolean isPaired() {
        return this.mDevice.getBondState() == 12;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native void nativeCreateGattRemoteService(long j, String str, Object obj);

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native void nativeOnConnectionStateChange(long j, int i, boolean z);

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native void nativeOnGattServicesDiscovered(long j);

    @CalledByNative
    private void onBluetoothDeviceAndroidDestruction() {
        Wrappers.BluetoothGattWrapper bluetoothGattWrapper = this.mBluetoothGatt;
        if (bluetoothGattWrapper != null) {
            bluetoothGattWrapper.close();
            this.mBluetoothGatt = null;
        }
        this.mNativeBluetoothDeviceAndroid = 0;
    }

    @CalledByNative
    private boolean updateAdvertisedUUIDs(List<ParcelUuid> list) {
        boolean z = false;
        if (list == null) {
            return false;
        }
        for (ParcelUuid parcelUuid : list) {
            z |= this.mUuidsFromScan.add(parcelUuid.toString());
        }
        return z;
    }
}
