package org.chromium.device.bluetooth;

import org.chromium.base.Log;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;
import org.chromium.device.bluetooth.Wrappers;

@JNINamespace("device")
public final class ChromeBluetoothRemoteGattDescriptor {
    private static final String TAG = "Bluetooth";
    public final ChromeBluetoothDevice mChromeDevice;
    public final Wrappers.BluetoothGattDescriptorWrapper mDescriptor;
    private long mNativeBluetoothRemoteGattDescriptorAndroid;

    private ChromeBluetoothRemoteGattDescriptor(long j, Wrappers.BluetoothGattDescriptorWrapper bluetoothGattDescriptorWrapper, ChromeBluetoothDevice chromeBluetoothDevice) {
        this.mNativeBluetoothRemoteGattDescriptorAndroid = j;
        this.mDescriptor = bluetoothGattDescriptorWrapper;
        this.mChromeDevice = chromeBluetoothDevice;
        chromeBluetoothDevice.mWrapperToChromeDescriptorsMap.put(bluetoothGattDescriptorWrapper, this);
        Log.v(TAG, "ChromeBluetoothRemoteGattDescriptor created.");
    }

    @CalledByNative
    private static ChromeBluetoothRemoteGattDescriptor create(long j, Object obj, ChromeBluetoothDevice chromeBluetoothDevice) {
        return new ChromeBluetoothRemoteGattDescriptor(j, (Wrappers.BluetoothGattDescriptorWrapper) obj, chromeBluetoothDevice);
    }

    @CalledByNative
    private String getUUID() {
        return this.mDescriptor.getUuid().toString();
    }

    @CalledByNative
    private void onBluetoothRemoteGattDescriptorAndroidDestruction() {
        Log.v(TAG, "ChromeBluetoothRemoteGattDescriptor Destroyed.");
        this.mNativeBluetoothRemoteGattDescriptorAndroid = 0;
        this.mChromeDevice.mWrapperToChromeDescriptorsMap.remove(this.mDescriptor);
    }

    @CalledByNative
    private boolean readRemoteDescriptor() {
        if (this.mChromeDevice.mBluetoothGatt.readDescriptor(this.mDescriptor)) {
            return true;
        }
        Log.i(TAG, "readRemoteDescriptor readDescriptor failed.", new Object[0]);
        return false;
    }

    @CalledByNative
    private boolean writeRemoteDescriptor(byte[] bArr) {
        if (!this.mDescriptor.setValue(bArr)) {
            Log.i(TAG, "writeRemoteDescriptor setValue failed.", new Object[0]);
            return false;
        } else if (this.mChromeDevice.mBluetoothGatt.writeDescriptor(this.mDescriptor)) {
            return true;
        } else {
            Log.i(TAG, "writeRemoteDescriptor writeDescriptor failed.", new Object[0]);
            return false;
        }
    }

    public native void nativeOnRead(long j, int i, byte[] bArr);

    public native void nativeOnWrite(long j, int i);

    public void onDescriptorRead(int i) {
        Object[] objArr = new Object[2];
        objArr[0] = Integer.valueOf(i);
        objArr[1] = i == 0 ? "OK" : "Error";
        Log.i(TAG, "onDescriptorRead status:%d==%s", objArr);
        long j = this.mNativeBluetoothRemoteGattDescriptorAndroid;
        if (j != 0) {
            nativeOnRead(j, i, this.mDescriptor.getValue());
        }
    }

    public void onDescriptorWrite(int i) {
        Object[] objArr = new Object[2];
        objArr[0] = Integer.valueOf(i);
        objArr[1] = i == 0 ? "OK" : "Error";
        Log.i(TAG, "onDescriptorWrite status:%d==%s", objArr);
        long j = this.mNativeBluetoothRemoteGattDescriptorAndroid;
        if (j != 0) {
            nativeOnWrite(j, i);
        }
    }
}
