package org.chromium.device.usb;

import android.hardware.usb.UsbEndpoint;
import android.hardware.usb.UsbInterface;
import org.chromium.base.Log;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;

@JNINamespace("device")
public final class ChromeUsbInterface {
    private static final String TAG = "Usb";
    public final UsbInterface mInterface;

    private ChromeUsbInterface(UsbInterface usbInterface) {
        this.mInterface = usbInterface;
        Log.v(TAG, "ChromeUsbInterface created.");
    }

    @CalledByNative
    private static ChromeUsbInterface create(UsbInterface usbInterface) {
        return new ChromeUsbInterface(usbInterface);
    }

    @CalledByNative
    private int getAlternateSetting() {
        return this.mInterface.getAlternateSetting();
    }

    @CalledByNative
    private UsbEndpoint[] getEndpoints() {
        int endpointCount = this.mInterface.getEndpointCount();
        UsbEndpoint[] usbEndpointArr = new UsbEndpoint[endpointCount];
        for (int i = 0; i < endpointCount; i++) {
            usbEndpointArr[i] = this.mInterface.getEndpoint(i);
        }
        return usbEndpointArr;
    }

    @CalledByNative
    private int getInterfaceClass() {
        return this.mInterface.getInterfaceClass();
    }

    @CalledByNative
    private int getInterfaceNumber() {
        return this.mInterface.getId();
    }

    @CalledByNative
    private int getInterfaceProtocol() {
        return this.mInterface.getInterfaceProtocol();
    }

    @CalledByNative
    private int getInterfaceSubclass() {
        return this.mInterface.getInterfaceSubclass();
    }
}
