package org.chromium.device.usb;

import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.hardware.usb.UsbDevice;
import android.hardware.usb.UsbDeviceConnection;
import android.hardware.usb.UsbManager;
import org.chromium.base.Log;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;

@JNINamespace("device")
public final class ChromeUsbService {
    private static final String ACTION_USB_PERMISSION = "org.chromium.device.ACTION_USB_PERMISSION";
    private static final String TAG = "Usb";
    public Context mContext;
    public BroadcastReceiver mUsbDeviceReceiver;
    public UsbManager mUsbManager;
    public long mUsbServiceAndroid;

    private ChromeUsbService(Context context, long j) {
        this.mContext = context;
        this.mUsbServiceAndroid = j;
        this.mUsbManager = (UsbManager) context.getSystemService("usb");
        registerForUsbDeviceIntentBroadcast();
        Log.v(TAG, "ChromeUsbService created.");
    }

    @CalledByNative
    private void close() {
        unregisterForUsbDeviceIntentBroadcast();
    }

    @CalledByNative
    private static ChromeUsbService create(Context context, long j) {
        return new ChromeUsbService(context, j);
    }

    @CalledByNative
    private Object[] getDevices() {
        return this.mUsbManager.getDeviceList().values().toArray();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native void nativeDeviceAttached(long j, UsbDevice usbDevice);

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native void nativeDeviceDetached(long j, int i);

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native void nativeDevicePermissionRequestComplete(long j, int i, boolean z);

    @CalledByNative
    private UsbDeviceConnection openDevice(ChromeUsbDevice chromeUsbDevice) {
        return this.mUsbManager.openDevice(chromeUsbDevice.getDevice());
    }

    private void registerForUsbDeviceIntentBroadcast() {
        this.mUsbDeviceReceiver = new BroadcastReceiver() {
            /* class org.chromium.device.usb.ChromeUsbService.AnonymousClass1 */

            public void onReceive(Context context, Intent intent) {
                UsbDevice usbDevice = (UsbDevice) intent.getParcelableExtra("device");
                if ("android.hardware.usb.action.USB_DEVICE_ATTACHED".equals(intent.getAction())) {
                    ChromeUsbService chromeUsbService = ChromeUsbService.this;
                    chromeUsbService.nativeDeviceAttached(chromeUsbService.mUsbServiceAndroid, usbDevice);
                } else if ("android.hardware.usb.action.USB_DEVICE_DETACHED".equals(intent.getAction())) {
                    ChromeUsbService chromeUsbService2 = ChromeUsbService.this;
                    chromeUsbService2.nativeDeviceDetached(chromeUsbService2.mUsbServiceAndroid, usbDevice.getDeviceId());
                } else if (ChromeUsbService.ACTION_USB_PERMISSION.equals(intent.getAction())) {
                    ChromeUsbService chromeUsbService3 = ChromeUsbService.this;
                    chromeUsbService3.nativeDevicePermissionRequestComplete(chromeUsbService3.mUsbServiceAndroid, usbDevice.getDeviceId(), intent.getBooleanExtra("permission", false));
                }
            }
        };
        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction("android.hardware.usb.action.USB_DEVICE_ATTACHED");
        intentFilter.addAction("android.hardware.usb.action.USB_DEVICE_DETACHED");
        intentFilter.addAction(ACTION_USB_PERMISSION);
        this.mContext.registerReceiver(this.mUsbDeviceReceiver, intentFilter);
    }

    @CalledByNative
    private void requestDevicePermission(ChromeUsbDevice chromeUsbDevice, long j) {
        UsbDevice device = chromeUsbDevice.getDevice();
        if (this.mUsbManager.hasPermission(device)) {
            nativeDevicePermissionRequestComplete(this.mUsbServiceAndroid, device.getDeviceId(), true);
            return;
        }
        this.mUsbManager.requestPermission(chromeUsbDevice.getDevice(), PendingIntent.getBroadcast(this.mContext, 0, new Intent(ACTION_USB_PERMISSION), 0));
    }

    private void unregisterForUsbDeviceIntentBroadcast() {
        this.mContext.unregisterReceiver(this.mUsbDeviceReceiver);
        this.mUsbDeviceReceiver = null;
    }
}
