package org.chromium.media;

import android.content.Context;
import android.graphics.ImageFormat;
import android.hardware.Camera;
import android.os.Build;
import androidx.base.b2;
import androidx.room.RoomDatabase;
import java.util.ArrayList;
import java.util.List;
import org.chromium.base.Log;

public class VideoCaptureAndroid extends VideoCaptureCamera {
    private static final int NUM_CAPTURE_BUFFERS = 3;
    private static final String TAG = "cr.media";
    private int mExpectedFrameSize;

    public static class BuggyDeviceHack {
        private static final String[] COLORSPACE_BUGGY_DEVICE_LIST = {"SAMSUNG-SGH-I747", "ODROID-U2", "XT1092", "XT1095", "XT1096", "XT1097"};

        private BuggyDeviceHack() {
        }

        public static int getImageFormat() {
            for (String str : COLORSPACE_BUGGY_DEVICE_LIST) {
                if (str.contentEquals(Build.MODEL)) {
                    return 17;
                }
            }
            return 842094169;
        }
    }

    public VideoCaptureAndroid(Context context, int i, long j) {
        super(context, i, j);
    }

    public static int getCaptureApiType(int i) {
        return VideoCaptureCamera.getCameraInfo(i) == null ? 5 : 0;
    }

    public static VideoCaptureFormat[] getDeviceSupportedFormats(int i) {
        try {
            Camera open = Camera.open(i);
            Camera.Parameters cameraParameters = VideoCaptureCamera.getCameraParameters(open);
            if (cameraParameters == null) {
                return null;
            }
            ArrayList arrayList = new ArrayList();
            List<Integer> supportedPreviewFormats = cameraParameters.getSupportedPreviewFormats();
            if (supportedPreviewFormats == null) {
                supportedPreviewFormats = new ArrayList<>();
            }
            if (supportedPreviewFormats.size() == 0) {
                supportedPreviewFormats.add(0);
            }
            for (Integer num : supportedPreviewFormats) {
                int i2 = 842094169;
                if (num.intValue() != 842094169) {
                    if (num.intValue() != 17) {
                        i2 = 0;
                    }
                }
                List<int[]> supportedPreviewFpsRange = cameraParameters.getSupportedPreviewFpsRange();
                if (supportedPreviewFpsRange == null) {
                    supportedPreviewFpsRange = new ArrayList<>();
                }
                if (supportedPreviewFpsRange.size() == 0) {
                    supportedPreviewFpsRange.add(new int[]{0, 0});
                }
                for (int[] iArr : supportedPreviewFpsRange) {
                    List<Camera.Size> supportedPreviewSizes = cameraParameters.getSupportedPreviewSizes();
                    if (supportedPreviewSizes == null) {
                        supportedPreviewSizes = new ArrayList<>();
                    }
                    if (supportedPreviewSizes.size() == 0) {
                        open.getClass();
                        supportedPreviewSizes.add(new Camera.Size(open, 0, 0));
                    }
                    for (Camera.Size size : supportedPreviewSizes) {
                        arrayList.add(new VideoCaptureFormat(size.width, size.height, (iArr[1] + RoomDatabase.MAX_BIND_PARAMETER_CNT) / 1000, i2));
                    }
                }
            }
            open.release();
            return (VideoCaptureFormat[]) arrayList.toArray(new VideoCaptureFormat[arrayList.size()]);
        } catch (RuntimeException e) {
            Log.e(TAG, "Camera.open: ", e);
            return null;
        }
    }

    public static String getName(int i) {
        Camera.CameraInfo cameraInfo = VideoCaptureCamera.getCameraInfo(i);
        if (cameraInfo == null) {
            return null;
        }
        StringBuilder k = b2.k("camera ", i, ", facing ");
        k.append(cameraInfo.facing == 1 ? "front" : "back");
        return k.toString();
    }

    public static int getNumberOfCameras() {
        return Camera.getNumberOfCameras();
    }

    @Override // org.chromium.media.VideoCaptureCamera
    public void allocateBuffers() {
        VideoCaptureFormat videoCaptureFormat = this.mCaptureFormat;
        this.mExpectedFrameSize = (ImageFormat.getBitsPerPixel(videoCaptureFormat.mPixelFormat) * (videoCaptureFormat.mWidth * videoCaptureFormat.mHeight)) / 8;
        for (int i = 0; i < 3; i++) {
            this.mCamera.addCallbackBuffer(new byte[this.mExpectedFrameSize]);
        }
    }

    public void onPreviewFrame(byte[] bArr, Camera camera) {
        this.mPreviewBufferLock.lock();
        try {
            if (this.mIsRunning) {
                int length = bArr.length;
                int i = this.mExpectedFrameSize;
                if (length == i) {
                    nativeOnFrameAvailable(this.mNativeVideoCaptureDeviceAndroid, bArr, i, getCameraRotation());
                }
                this.mPreviewBufferLock.unlock();
                if (camera != null) {
                    camera.addCallbackBuffer(bArr);
                }
            }
        } finally {
            this.mPreviewBufferLock.unlock();
            if (camera != null) {
                camera.addCallbackBuffer(bArr);
            }
        }
    }

    @Override // org.chromium.media.VideoCaptureCamera
    public void setCaptureParameters(int i, int i2, int i3, Camera.Parameters parameters) {
        this.mCaptureFormat = new VideoCaptureFormat(i, i2, i3, BuggyDeviceHack.getImageFormat());
    }

    @Override // org.chromium.media.VideoCaptureCamera
    public void setPreviewCallback(Camera.PreviewCallback previewCallback) {
        this.mCamera.setPreviewCallbackWithBuffer(previewCallback);
    }
}
