package org.chromium.media;

import android.content.Context;
import android.hardware.Camera;
import com.google.android.exoplayer2.text.ttml.TtmlNode;
import com.google.android.exoplayer2.upstream.cache.CacheDataSink;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Arrays;
import org.chromium.base.Log;

public class VideoCaptureTango extends VideoCaptureCamera {
    private static final CamParams[] CAM_PARAMS = {new CamParams(0, "depth", 320, 240), new CamParams(1, "fisheye", 640, 480), new CamParams(2, "4MP", SF_WIDTH, SF_LINES_BIGIMAGE)};
    private static final byte CHROMA_ZERO_LEVEL = Byte.MAX_VALUE;
    private static final int DEPTH_CAMERA_ID = 0;
    private static final int FISHEYE_CAMERA_ID = 1;
    private static final int FOURMP_CAMERA_ID = 2;
    private static final int SF_FULL_HEIGHT = 1752;
    private static final int SF_HEIGHT = 1168;
    private static final int SF_LINES_BIGIMAGE = 720;
    private static final int SF_LINES_DEPTH = 60;
    private static final int SF_LINES_DEPTH_PADDED = 112;
    private static final int SF_LINES_FISHEYE = 240;
    private static final int SF_LINES_HEADER = 16;
    private static final int SF_LINES_RESERVED = 80;
    private static final int SF_OFFSET_4MP_CHROMA = 112;
    private static final int SF_WIDTH = 1280;
    private static final String TAG = "cr.media";
    private ByteBuffer mFrameBuffer = null;
    private final int mTangoCameraId;

    public static class CamParams {
        public final int mHeight;
        public final int mId;
        public final String mName;
        public final int mWidth;

        public CamParams(int i, String str, int i2, int i3) {
            this.mId = i;
            this.mName = str;
            this.mWidth = i2;
            this.mHeight = i3;
        }
    }

    public VideoCaptureTango(Context context, int i, long j) {
        super(context, 0, j);
        this.mTangoCameraId = i;
    }

    public static int getCaptureApiType(int i) {
        return i >= CAM_PARAMS.length ? 0 : 4;
    }

    public static VideoCaptureFormat[] getDeviceSupportedFormats(int i) {
        ArrayList arrayList = new ArrayList();
        if (i == 0) {
            arrayList.add(new VideoCaptureFormat(320, 180, 5, 842094169));
        } else if (i == 1) {
            arrayList.add(new VideoCaptureFormat(640, 480, 30, 842094169));
        } else if (i == 2) {
            arrayList.add(new VideoCaptureFormat(SF_WIDTH, SF_LINES_BIGIMAGE, 20, 842094169));
        }
        return (VideoCaptureFormat[]) arrayList.toArray(new VideoCaptureFormat[arrayList.size()]);
    }

    public static String getName(int i) {
        CamParams[] camParamsArr = CAM_PARAMS;
        if (i >= camParamsArr.length) {
            return "";
        }
        return camParamsArr[i].mName;
    }

    public static int numberOfCameras() {
        return CAM_PARAMS.length;
    }

    @Override // org.chromium.media.VideoCaptureCamera
    public void allocateBuffers() {
        VideoCaptureFormat videoCaptureFormat = this.mCaptureFormat;
        ByteBuffer allocateDirect = ByteBuffer.allocateDirect(((videoCaptureFormat.mWidth * videoCaptureFormat.mHeight) * 3) / 2);
        this.mFrameBuffer = allocateDirect;
        Arrays.fill(allocateDirect.array(), (byte) CHROMA_ZERO_LEVEL);
    }

    public void onPreviewFrame(byte[] bArr, Camera camera) {
        this.mPreviewBufferLock.lock();
        try {
            if (this.mIsRunning) {
                if (bArr.length == 2242560) {
                    int i = this.mTangoCameraId;
                    if (i == 0) {
                        for (int i2 = 430080; i2 < 583680; i2 += 2) {
                            this.mFrameBuffer.put((byte) ((bArr[i2 + 1] << 4) | ((bArr[i2] & 240) >> 4)));
                        }
                        int i3 = 0;
                        while (true) {
                            VideoCaptureFormat videoCaptureFormat = this.mCaptureFormat;
                            if (i3 >= (videoCaptureFormat.mWidth * videoCaptureFormat.mHeight) - 76800) {
                                break;
                            }
                            this.mFrameBuffer.put((byte) 0);
                            i3++;
                        }
                    } else if (i == 1) {
                        ByteBuffer.wrap(bArr, CacheDataSink.DEFAULT_BUFFER_SIZE, 307200).get(this.mFrameBuffer.array(), 0, 307200);
                    } else if (i == 2) {
                        ByteBuffer.wrap(bArr, 573440, 921600).get(this.mFrameBuffer.array(), 0, 921600);
                        ByteBuffer.wrap(bArr, 1638400, 230400).get(this.mFrameBuffer.array(), 921600, 230400);
                        ByteBuffer.wrap(bArr, 2012160, 230400).get(this.mFrameBuffer.array(), 1152000, 230400);
                    } else {
                        Log.e(TAG, "Unknown camera, #id: %d", Integer.valueOf(i));
                    }
                    this.mFrameBuffer.rewind();
                    nativeOnFrameAvailable(this.mNativeVideoCaptureDeviceAndroid, this.mFrameBuffer.array(), this.mFrameBuffer.capacity(), getCameraRotation());
                }
                this.mPreviewBufferLock.unlock();
            }
        } finally {
            this.mPreviewBufferLock.unlock();
        }
    }

    @Override // org.chromium.media.VideoCaptureCamera
    public void setCaptureParameters(int i, int i2, int i3, Camera.Parameters parameters) {
        CamParams[] camParamsArr = CAM_PARAMS;
        int i4 = this.mTangoCameraId;
        this.mCaptureFormat = new VideoCaptureFormat(camParamsArr[i4].mWidth, camParamsArr[i4].mHeight, i3, 842094169);
        parameters.set("sf-mode", TtmlNode.COMBINE_ALL);
    }

    @Override // org.chromium.media.VideoCaptureCamera
    public void setPreviewCallback(Camera.PreviewCallback previewCallback) {
        this.mCamera.setPreviewCallback(previewCallback);
    }
}
