package org.chromium.media.midi;

import android.annotation.TargetApi;
import android.media.midi.MidiDevice;
import android.media.midi.MidiDeviceInfo;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;

@JNINamespace("media::midi")
@TargetApi(23)
public class MidiDeviceAndroid {
    private final MidiDevice mDevice;
    private final MidiInputPortAndroid[] mInputPorts;
    private boolean mIsOpen = true;
    private final MidiOutputPortAndroid[] mOutputPorts;

    public MidiDeviceAndroid(MidiDevice midiDevice) {
        this.mDevice = midiDevice;
        this.mOutputPorts = new MidiOutputPortAndroid[getInfo().getInputPortCount()];
        int i = 0;
        int i2 = 0;
        while (true) {
            MidiOutputPortAndroid[] midiOutputPortAndroidArr = this.mOutputPorts;
            if (i2 >= midiOutputPortAndroidArr.length) {
                break;
            }
            midiOutputPortAndroidArr[i2] = new MidiOutputPortAndroid(midiDevice, i2);
            i2++;
        }
        this.mInputPorts = new MidiInputPortAndroid[getInfo().getOutputPortCount()];
        while (true) {
            MidiInputPortAndroid[] midiInputPortAndroidArr = this.mInputPorts;
            if (i < midiInputPortAndroidArr.length) {
                midiInputPortAndroidArr[i] = new MidiInputPortAndroid(midiDevice, i);
                i++;
            } else {
                return;
            }
        }
    }

    private String getProperty(String str) {
        return this.mDevice.getInfo().getProperties().getString(str);
    }

    public void close() {
        this.mIsOpen = false;
        for (MidiInputPortAndroid midiInputPortAndroid : this.mInputPorts) {
            midiInputPortAndroid.close();
        }
        for (MidiOutputPortAndroid midiOutputPortAndroid : this.mOutputPorts) {
            midiOutputPortAndroid.close();
        }
    }

    public MidiDevice getDevice() {
        return this.mDevice;
    }

    public MidiDeviceInfo getInfo() {
        return this.mDevice.getInfo();
    }

    @CalledByNative
    public MidiInputPortAndroid[] getInputPorts() {
        return this.mInputPorts;
    }

    @CalledByNative
    public String getManufacturer() {
        return getProperty("manufacturer");
    }

    @CalledByNative
    public MidiOutputPortAndroid[] getOutputPorts() {
        return this.mOutputPorts;
    }

    @CalledByNative
    public String getProduct() {
        return getProperty("product");
    }

    @CalledByNative
    public String getVersion() {
        return getProperty("version");
    }

    public boolean isOpen() {
        return this.mIsOpen;
    }
}
