package org.chromium.media.midi;

import android.annotation.TargetApi;
import android.media.midi.MidiDevice;
import android.media.midi.MidiOutputPort;
import android.media.midi.MidiReceiver;
import java.io.IOException;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;

@JNINamespace("media::midi")
@TargetApi(23)
public class MidiInputPortAndroid {
    private final MidiDevice mDevice;
    private final int mIndex;
    private long mNativeReceiverPointer;
    private MidiOutputPort mPort;

    public MidiInputPortAndroid(MidiDevice midiDevice, int i) {
        this.mDevice = midiDevice;
        this.mIndex = i;
    }

    /* access modifiers changed from: private */
    public static native void nativeOnData(long j, byte[] bArr, int i, int i2, long j2);

    @CalledByNative
    public void close() {
        MidiOutputPort midiOutputPort = this.mPort;
        if (midiOutputPort != null) {
            try {
                midiOutputPort.close();
            } catch (IOException unused) {
            }
            this.mNativeReceiverPointer = 0;
            this.mPort = null;
        }
    }

    @CalledByNative
    public boolean open(long j) {
        if (this.mPort != null) {
            return true;
        }
        MidiOutputPort openOutputPort = this.mDevice.openOutputPort(this.mIndex);
        this.mPort = openOutputPort;
        if (openOutputPort == null) {
            return false;
        }
        this.mNativeReceiverPointer = j;
        openOutputPort.connect(new MidiReceiver() {
            /* class org.chromium.media.midi.MidiInputPortAndroid.AnonymousClass1 */

            @Override // android.media.midi.MidiReceiver
            public void onSend(byte[] bArr, int i, int i2, long j) {
                MidiInputPortAndroid.nativeOnData(MidiInputPortAndroid.this.mNativeReceiverPointer, bArr, i, i2, j);
            }
        });
        return true;
    }
}
