package org.chromium.media.midi;

import android.annotation.TargetApi;
import android.content.Context;
import android.media.midi.MidiDevice;
import android.media.midi.MidiDeviceInfo;
import android.media.midi.MidiManager;
import android.os.Handler;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import org.chromium.base.ThreadUtils;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;

@JNINamespace("media::midi")
@TargetApi(23)
public class MidiManagerAndroid {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private final List<MidiDeviceAndroid> mDevices = new ArrayList();
    private final Handler mHandler;
    private boolean mIsInitializing = true;
    private final MidiManager mManager;
    private final long mNativeManagerPointer;
    private final Set<MidiDeviceInfo> mPendingDevices = new HashSet();

    public MidiManagerAndroid(Context context, long j) {
        this.mManager = (MidiManager) context.getSystemService("midi");
        this.mHandler = new Handler(ThreadUtils.getUiThreadLooper());
        this.mNativeManagerPointer = j;
    }

    @CalledByNative
    public static MidiManagerAndroid create(Context context, long j) {
        return new MidiManagerAndroid(context, j);
    }

    public static native void nativeOnAttached(long j, MidiDeviceAndroid midiDeviceAndroid);

    public static native void nativeOnDetached(long j, MidiDeviceAndroid midiDeviceAndroid);

    public static native void nativeOnInitialized(long j, MidiDeviceAndroid[] midiDeviceAndroidArr);

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void onDeviceAdded(MidiDeviceInfo midiDeviceInfo) {
        if (this.mIsInitializing) {
            this.mPendingDevices.add(midiDeviceInfo);
        }
        openDevice(midiDeviceInfo);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void onDeviceOpened(MidiDevice midiDevice, MidiDeviceInfo midiDeviceInfo) {
        this.mPendingDevices.remove(midiDeviceInfo);
        if (midiDevice != null) {
            MidiDeviceAndroid midiDeviceAndroid = new MidiDeviceAndroid(midiDevice);
            this.mDevices.add(midiDeviceAndroid);
            if (!this.mIsInitializing) {
                nativeOnAttached(this.mNativeManagerPointer, midiDeviceAndroid);
            }
        }
        if (this.mIsInitializing && this.mPendingDevices.isEmpty()) {
            nativeOnInitialized(this.mNativeManagerPointer, (MidiDeviceAndroid[]) this.mDevices.toArray(new MidiDeviceAndroid[0]));
            this.mIsInitializing = false;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void onDeviceRemoved(MidiDeviceInfo midiDeviceInfo) {
        for (MidiDeviceAndroid midiDeviceAndroid : this.mDevices) {
            if (midiDeviceAndroid.isOpen() && midiDeviceAndroid.getInfo().getId() == midiDeviceInfo.getId()) {
                midiDeviceAndroid.close();
                nativeOnDetached(this.mNativeManagerPointer, midiDeviceAndroid);
            }
        }
    }

    private void openDevice(final MidiDeviceInfo midiDeviceInfo) {
        this.mManager.openDevice(midiDeviceInfo, new MidiManager.OnDeviceOpenedListener() {
            /* class org.chromium.media.midi.MidiManagerAndroid.AnonymousClass3 */

            public void onDeviceOpened(MidiDevice midiDevice) {
                MidiManagerAndroid.this.onDeviceOpened(midiDevice, midiDeviceInfo);
            }
        }, this.mHandler);
    }

    @CalledByNative
    public void initialize() {
        this.mManager.registerDeviceCallback(new MidiManager.DeviceCallback() {
            /* class org.chromium.media.midi.MidiManagerAndroid.AnonymousClass1 */

            public void onDeviceAdded(MidiDeviceInfo midiDeviceInfo) {
                MidiManagerAndroid.this.onDeviceAdded(midiDeviceInfo);
            }

            public void onDeviceRemoved(MidiDeviceInfo midiDeviceInfo) {
                MidiManagerAndroid.this.onDeviceRemoved(midiDeviceInfo);
            }
        }, this.mHandler);
        MidiDeviceInfo[] devices = this.mManager.getDevices();
        for (MidiDeviceInfo midiDeviceInfo : devices) {
            this.mPendingDevices.add(midiDeviceInfo);
            openDevice(midiDeviceInfo);
        }
        this.mHandler.post(new Runnable() {
            /* class org.chromium.media.midi.MidiManagerAndroid.AnonymousClass2 */

            public void run() {
                if (MidiManagerAndroid.this.mPendingDevices.isEmpty() && MidiManagerAndroid.this.mIsInitializing) {
                    MidiManagerAndroid.nativeOnInitialized(MidiManagerAndroid.this.mNativeManagerPointer, (MidiDeviceAndroid[]) MidiManagerAndroid.this.mDevices.toArray(new MidiDeviceAndroid[0]));
                    MidiManagerAndroid.this.mIsInitializing = false;
                }
            }
        });
    }
}
