package org.chromium.media.midi;

import android.annotation.TargetApi;
import android.media.midi.MidiDevice;
import android.media.midi.MidiInputPort;
import java.io.IOException;
import org.chromium.base.Log;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;

@JNINamespace("media::midi")
@TargetApi(23)
public class MidiOutputPortAndroid {
    private static final String TAG = "media_midi";
    private final MidiDevice mDevice;
    private final int mIndex;
    private MidiInputPort mPort;

    public MidiOutputPortAndroid(MidiDevice midiDevice, int i) {
        this.mDevice = midiDevice;
        this.mIndex = i;
    }

    @CalledByNative
    public void close() {
        MidiInputPort midiInputPort = this.mPort;
        if (midiInputPort != null) {
            try {
                midiInputPort.close();
            } catch (IOException unused) {
            }
            this.mPort = null;
        }
    }

    @CalledByNative
    public boolean open() {
        if (this.mPort != null) {
            return true;
        }
        MidiInputPort openInputPort = this.mDevice.openInputPort(this.mIndex);
        this.mPort = openInputPort;
        if (openInputPort != null) {
            return true;
        }
        return false;
    }

    @CalledByNative
    public void send(byte[] bArr) {
        MidiInputPort midiInputPort = this.mPort;
        if (midiInputPort != null) {
            try {
                midiInputPort.send(bArr, 0, bArr.length);
            } catch (IOException e) {
                Log.e(TAG, "MidiOutputPortAndroid.send: " + e, new Object[0]);
            }
        }
    }
}
