package org.chromium.media.midi;

import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.hardware.usb.UsbDevice;
import android.hardware.usb.UsbInterface;
import android.hardware.usb.UsbManager;
import android.os.Parcelable;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Set;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;

@JNINamespace("media::midi")
public class UsbMidiDeviceFactoryAndroid {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final String ACTION_USB_PERMISSION = "org.chromium.media.USB_PERMISSION";
    private final List<UsbMidiDeviceAndroid> mDevices = new ArrayList();
    private boolean mIsEnumeratingDevices;
    private long mNativePointer;
    private BroadcastReceiver mReceiver;
    private Set<UsbDevice> mRequestedDevices;
    private UsbManager mUsbManager;

    public UsbMidiDeviceFactoryAndroid(Context context, long j) {
        this.mUsbManager = (UsbManager) context.getSystemService("usb");
        this.mNativePointer = j;
        this.mReceiver = new BroadcastReceiver() {
            /* class org.chromium.media.midi.UsbMidiDeviceFactoryAndroid.AnonymousClass1 */

            public void onReceive(Context context, Intent intent) {
                Parcelable parcelableExtra = intent.getParcelableExtra("device");
                if ("android.hardware.usb.action.USB_DEVICE_ATTACHED".equals(intent.getAction())) {
                    UsbMidiDeviceFactoryAndroid.this.requestDevicePermissionIfNecessary(context, (UsbDevice) parcelableExtra);
                }
                if ("android.hardware.usb.action.USB_DEVICE_DETACHED".equals(intent.getAction())) {
                    UsbMidiDeviceFactoryAndroid.this.onUsbDeviceDetached((UsbDevice) parcelableExtra);
                }
                if (UsbMidiDeviceFactoryAndroid.ACTION_USB_PERMISSION.equals(intent.getAction())) {
                    UsbMidiDeviceFactoryAndroid.this.onUsbDevicePermissionRequestDone(context, intent);
                }
            }
        };
        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction("android.hardware.usb.action.USB_DEVICE_ATTACHED");
        intentFilter.addAction("android.hardware.usb.action.USB_DEVICE_DETACHED");
        intentFilter.addAction(ACTION_USB_PERMISSION);
        context.registerReceiver(this.mReceiver, intentFilter);
        this.mRequestedDevices = new HashSet();
    }

    @CalledByNative
    public static UsbMidiDeviceFactoryAndroid create(Context context, long j) {
        return new UsbMidiDeviceFactoryAndroid(context, j);
    }

    private static native void nativeOnUsbMidiDeviceAttached(long j, Object obj);

    private static native void nativeOnUsbMidiDeviceDetached(long j, int i);

    private static native void nativeOnUsbMidiDeviceRequestDone(long j, Object[] objArr);

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void onUsbDeviceDetached(UsbDevice usbDevice) {
        Iterator<UsbDevice> it = this.mRequestedDevices.iterator();
        while (true) {
            if (!it.hasNext()) {
                break;
            }
            UsbDevice next = it.next();
            if (next.getDeviceId() == usbDevice.getDeviceId()) {
                this.mRequestedDevices.remove(next);
                break;
            }
        }
        for (int i = 0; i < this.mDevices.size(); i++) {
            UsbMidiDeviceAndroid usbMidiDeviceAndroid = this.mDevices.get(i);
            if (!usbMidiDeviceAndroid.isClosed() && usbMidiDeviceAndroid.getUsbDevice().getDeviceId() == usbDevice.getDeviceId()) {
                usbMidiDeviceAndroid.close();
                if (this.mIsEnumeratingDevices) {
                    this.mDevices.remove(i);
                    return;
                }
                long j = this.mNativePointer;
                if (j != 0) {
                    nativeOnUsbMidiDeviceDetached(j, i);
                    return;
                }
                return;
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    /* JADX WARNING: Code restructure failed: missing block: B:3:0x001d, code lost:
        if (r7.getBooleanExtra("permission", false) == false) goto L_0x001f;
     */
    private void onUsbDevicePermissionRequestDone(Context context, Intent intent) {
        UsbDevice usbDevice = (UsbDevice) intent.getParcelableExtra("device");
        UsbMidiDeviceAndroid usbMidiDeviceAndroid = null;
        if (this.mRequestedDevices.contains(usbDevice)) {
            this.mRequestedDevices.remove(usbDevice);
        }
        usbDevice = null;
        if (usbDevice != null) {
            Iterator<UsbMidiDeviceAndroid> it = this.mDevices.iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                UsbMidiDeviceAndroid next = it.next();
                if (!next.isClosed() && next.getUsbDevice().getDeviceId() == usbDevice.getDeviceId()) {
                    usbDevice = null;
                    break;
                }
            }
        }
        if (usbDevice != null) {
            usbMidiDeviceAndroid = new UsbMidiDeviceAndroid(this.mUsbManager, usbDevice);
            this.mDevices.add(usbMidiDeviceAndroid);
        }
        if (this.mRequestedDevices.isEmpty()) {
            long j = this.mNativePointer;
            if (j != 0) {
                if (this.mIsEnumeratingDevices) {
                    nativeOnUsbMidiDeviceRequestDone(j, this.mDevices.toArray());
                    this.mIsEnumeratingDevices = false;
                } else if (usbMidiDeviceAndroid != null) {
                    nativeOnUsbMidiDeviceAttached(j, usbMidiDeviceAndroid);
                }
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void requestDevicePermissionIfNecessary(Context context, UsbDevice usbDevice) {
        for (UsbDevice usbDevice2 : this.mRequestedDevices) {
            if (usbDevice2.getDeviceId() == usbDevice.getDeviceId()) {
                return;
            }
        }
        for (int i = 0; i < usbDevice.getInterfaceCount(); i++) {
            UsbInterface usbInterface = usbDevice.getInterface(i);
            if (usbInterface.getInterfaceClass() == 1 && usbInterface.getInterfaceSubclass() == 3) {
                this.mUsbManager.requestPermission(usbDevice, PendingIntent.getBroadcast(context, 0, new Intent(ACTION_USB_PERMISSION), 0));
                this.mRequestedDevices.add(usbDevice);
                return;
            }
        }
    }

    @CalledByNative
    public void close(Context context) {
        this.mNativePointer = 0;
        context.unregisterReceiver(this.mReceiver);
    }

    @CalledByNative
    public boolean enumerateDevices(Context context) {
        this.mIsEnumeratingDevices = true;
        HashMap<String, UsbDevice> deviceList = this.mUsbManager.getDeviceList();
        if (deviceList.isEmpty()) {
            this.mIsEnumeratingDevices = false;
            return false;
        }
        for (UsbDevice usbDevice : deviceList.values()) {
            requestDevicePermissionIfNecessary(context, usbDevice);
        }
        return !this.mRequestedDevices.isEmpty();
    }
}
