package org.chromium.mojo.bindings;

import java.util.Collections;
import java.util.Set;
import java.util.WeakHashMap;
import org.chromium.mojo.system.MojoException;

public class DelegatingConnectionErrorHandler implements ConnectionErrorHandler {
    private final Set<ConnectionErrorHandler> mHandlers = Collections.newSetFromMap(new WeakHashMap());

    public void addConnectionErrorHandler(ConnectionErrorHandler connectionErrorHandler) {
        this.mHandlers.add(connectionErrorHandler);
    }

    @Override // org.chromium.mojo.bindings.ConnectionErrorHandler
    public void onConnectionError(MojoException mojoException) {
        for (ConnectionErrorHandler connectionErrorHandler : this.mHandlers) {
            connectionErrorHandler.onConnectionError(mojoException);
        }
    }

    public void removeConnectionErrorHandler(ConnectionErrorHandler connectionErrorHandler) {
        this.mHandlers.remove(connectionErrorHandler);
    }
}
