package org.chromium.mojo.bindings;

import java.io.Closeable;
import org.chromium.mojo.bindings.Callbacks;
import org.chromium.mojo.system.Core;
import org.chromium.mojo.system.MessagePipeHandle;
import org.chromium.mojo.system.MojoException;
import org.chromium.mojo.system.Pair;

public interface Interface extends ConnectionErrorHandler, Closeable {

    public static abstract class AbstractProxy implements Proxy {
        private final HandlerImpl mHandler;

        public static class HandlerImpl implements Proxy.Handler, ConnectionErrorHandler {
            private final Core mCore;
            private ConnectionErrorHandler mErrorHandler = null;
            private final MessageReceiverWithResponder mMessageReceiver;
            private int mVersion = 0;

            public HandlerImpl(Core core, MessageReceiverWithResponder messageReceiverWithResponder) {
                this.mCore = core;
                this.mMessageReceiver = messageReceiverWithResponder;
            }

            @Override // java.io.Closeable, java.lang.AutoCloseable
            public void close() {
                this.mMessageReceiver.close();
            }

            public Core getCore() {
                return this.mCore;
            }

            public MessageReceiverWithResponder getMessageReceiver() {
                return this.mMessageReceiver;
            }

            @Override // org.chromium.mojo.bindings.Interface.Proxy.Handler
            public int getVersion() {
                return this.mVersion;
            }

            @Override // org.chromium.mojo.bindings.ConnectionErrorHandler
            public void onConnectionError(MojoException mojoException) {
                ConnectionErrorHandler connectionErrorHandler = this.mErrorHandler;
                if (connectionErrorHandler != null) {
                    connectionErrorHandler.onConnectionError(mojoException);
                }
            }

            @Override // org.chromium.mojo.bindings.Interface.Proxy.Handler
            public MessagePipeHandle passHandle() {
                return (MessagePipeHandle) ((HandleOwner) this.mMessageReceiver).passHandle();
            }

            @Override // org.chromium.mojo.bindings.Interface.Proxy.Handler
            public void queryVersion(final Callbacks.Callback1<Integer> callback1) {
                RunMessageParams runMessageParams = new RunMessageParams();
                runMessageParams.reserved0 = 16;
                runMessageParams.reserved1 = 0;
                runMessageParams.queryVersion = new QueryVersion();
                InterfaceControlMessagesHelper.sendRunMessage(getCore(), this.mMessageReceiver, runMessageParams, new Callbacks.Callback1<RunResponseMessageParams>() {
                    /* class org.chromium.mojo.bindings.Interface.AbstractProxy.HandlerImpl.AnonymousClass1 */

                    public void call(RunResponseMessageParams runResponseMessageParams) {
                        HandlerImpl.this.mVersion = runResponseMessageParams.queryVersionResult.version;
                        callback1.call(Integer.valueOf(HandlerImpl.this.mVersion));
                    }
                });
            }

            @Override // org.chromium.mojo.bindings.Interface.Proxy.Handler
            public void requireVersion(int i) {
                if (this.mVersion < i) {
                    this.mVersion = i;
                    RunOrClosePipeMessageParams runOrClosePipeMessageParams = new RunOrClosePipeMessageParams();
                    runOrClosePipeMessageParams.reserved0 = 16;
                    runOrClosePipeMessageParams.reserved1 = 0;
                    RequireVersion requireVersion = new RequireVersion();
                    runOrClosePipeMessageParams.requireVersion = requireVersion;
                    requireVersion.version = i;
                    InterfaceControlMessagesHelper.sendRunOrClosePipeMessage(getCore(), this.mMessageReceiver, runOrClosePipeMessageParams);
                }
            }

            @Override // org.chromium.mojo.bindings.Interface.Proxy.Handler
            public void setErrorHandler(ConnectionErrorHandler connectionErrorHandler) {
                this.mErrorHandler = connectionErrorHandler;
            }

            public void setVersion(int i) {
                this.mVersion = i;
            }
        }

        public AbstractProxy(Core core, MessageReceiverWithResponder messageReceiverWithResponder) {
            this.mHandler = new HandlerImpl(core, messageReceiverWithResponder);
        }

        @Override // java.io.Closeable, java.lang.AutoCloseable, org.chromium.mojo.bindings.Interface
        public void close() {
            this.mHandler.close();
        }

        @Override // org.chromium.mojo.bindings.ConnectionErrorHandler
        public void onConnectionError(MojoException mojoException) {
            this.mHandler.onConnectionError(mojoException);
        }

        @Override // org.chromium.mojo.bindings.Interface.Proxy
        public HandlerImpl getProxyHandler() {
            return this.mHandler;
        }
    }

    public interface Proxy extends Interface {

        public interface Handler extends Closeable {
            int getVersion();

            MessagePipeHandle passHandle();

            void queryVersion(Callbacks.Callback1<Integer> callback1);

            void requireVersion(int i);

            void setErrorHandler(ConnectionErrorHandler connectionErrorHandler);
        }

        Handler getProxyHandler();
    }

    public static abstract class Stub<I extends Interface> implements MessageReceiverWithResponder {
        private final Core mCore;
        private final I mImpl;

        public Stub(Core core, I i) {
            this.mCore = core;
            this.mImpl = i;
        }

        @Override // org.chromium.mojo.bindings.MessageReceiver, java.io.Closeable, java.lang.AutoCloseable
        public void close() {
            this.mImpl.close();
        }

        public Core getCore() {
            return this.mCore;
        }

        public I getImpl() {
            return this.mImpl;
        }
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    void close();

    public static abstract class Manager<I extends Interface, P extends Proxy> {
        public final InterfaceRequest<I> asInterfaceRequest(MessagePipeHandle messagePipeHandle) {
            return new InterfaceRequest<>(messagePipeHandle);
        }

        public final P attachProxy(MessagePipeHandle messagePipeHandle, int i) {
            RouterImpl routerImpl = new RouterImpl(messagePipeHandle);
            P attachProxy = attachProxy(messagePipeHandle.getCore(), routerImpl);
            DelegatingConnectionErrorHandler delegatingConnectionErrorHandler = new DelegatingConnectionErrorHandler();
            delegatingConnectionErrorHandler.addConnectionErrorHandler(attachProxy);
            routerImpl.setErrorHandler(delegatingConnectionErrorHandler);
            routerImpl.start();
            ((AbstractProxy.HandlerImpl) attachProxy.getProxyHandler()).setVersion(i);
            return attachProxy;
        }

        public void bind(I i, MessagePipeHandle messagePipeHandle) {
            RouterImpl routerImpl = new RouterImpl(messagePipeHandle);
            bind(messagePipeHandle.getCore(), i, routerImpl);
            routerImpl.start();
        }

        public abstract I[] buildArray(int i);

        public abstract P buildProxy(Core core, MessageReceiverWithResponder messageReceiverWithResponder);

        public abstract Stub<I> buildStub(Core core, I i);

        public final Pair<P, InterfaceRequest<I>> getInterfaceRequest(Core core) {
            Pair<MessagePipeHandle, MessagePipeHandle> createMessagePipe = core.createMessagePipe(null);
            return Pair.create(attachProxy(createMessagePipe.first, 0), new InterfaceRequest(createMessagePipe.second));
        }

        public abstract String getName();

        public abstract int getVersion();

        public final void bind(I i, InterfaceRequest<I> interfaceRequest) {
            bind(i, interfaceRequest.passHandle());
        }

        public final void bind(Core core, I i, Router router) {
            router.setErrorHandler(i);
            router.setIncomingMessageReceiver(buildStub(core, i));
        }

        public final P attachProxy(Core core, Router router) {
            return buildProxy(core, new AutoCloseableRouter(core, router));
        }
    }
}
