package org.chromium.mojo.bindings;

import android.annotation.SuppressLint;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.Executor;
import org.chromium.mojo.system.AsyncWaiter;
import org.chromium.mojo.system.Core;
import org.chromium.mojo.system.MessagePipeHandle;

@SuppressLint({"UseSparseArrays"})
public class RouterImpl implements Router {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private final Connector mConnector;
    private final Executor mExecutor;
    private MessageReceiverWithResponder mIncomingMessageReceiver;
    private long mNextRequestId;
    private Map<Long, MessageReceiver> mResponders;

    public class HandleIncomingMessageThunk implements MessageReceiver {
        private HandleIncomingMessageThunk() {
        }

        @Override // org.chromium.mojo.bindings.MessageReceiver
        public boolean accept(Message message) {
            return RouterImpl.this.handleIncomingMessage(message);
        }

        @Override // org.chromium.mojo.bindings.MessageReceiver, java.io.Closeable, java.lang.AutoCloseable
        public void close() {
            RouterImpl.this.handleConnectorClose();
        }
    }

    public class ResponderThunk implements MessageReceiver {
        private boolean mAcceptWasInvoked = false;

        public ResponderThunk() {
        }

        @Override // org.chromium.mojo.bindings.MessageReceiver
        public boolean accept(Message message) {
            this.mAcceptWasInvoked = true;
            return RouterImpl.this.accept(message);
        }

        @Override // org.chromium.mojo.bindings.MessageReceiver, java.io.Closeable, java.lang.AutoCloseable
        public void close() {
            RouterImpl.this.close();
        }

        @Override // java.lang.Object
        public void finalize() {
            if (!this.mAcceptWasInvoked) {
                RouterImpl.this.closeOnHandleThread();
            }
            super.finalize();
        }
    }

    public RouterImpl(MessagePipeHandle messagePipeHandle) {
        this(messagePipeHandle, BindingsHelper.getDefaultAsyncWaiterForHandle(messagePipeHandle));
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void closeOnHandleThread() {
        Executor executor = this.mExecutor;
        if (executor != null) {
            executor.execute(new Runnable() {
                /* class org.chromium.mojo.bindings.RouterImpl.AnonymousClass1 */

                public void run() {
                    RouterImpl.this.close();
                }
            });
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleConnectorClose() {
        MessageReceiverWithResponder messageReceiverWithResponder = this.mIncomingMessageReceiver;
        if (messageReceiverWithResponder != null) {
            messageReceiverWithResponder.close();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean handleIncomingMessage(Message message) {
        MessageHeader header = message.asServiceMessage().getHeader();
        if (header.hasFlag(1)) {
            MessageReceiverWithResponder messageReceiverWithResponder = this.mIncomingMessageReceiver;
            if (messageReceiverWithResponder != null) {
                return messageReceiverWithResponder.acceptWithResponder(message, new ResponderThunk());
            }
            close();
            return false;
        } else if (header.hasFlag(2)) {
            long requestId = header.getRequestId();
            MessageReceiver messageReceiver = this.mResponders.get(Long.valueOf(requestId));
            if (messageReceiver == null) {
                return false;
            }
            this.mResponders.remove(Long.valueOf(requestId));
            return messageReceiver.accept(message);
        } else {
            MessageReceiverWithResponder messageReceiverWithResponder2 = this.mIncomingMessageReceiver;
            if (messageReceiverWithResponder2 != null) {
                return messageReceiverWithResponder2.accept(message);
            }
            return false;
        }
    }

    @Override // org.chromium.mojo.bindings.MessageReceiver
    public boolean accept(Message message) {
        return this.mConnector.accept(message);
    }

    @Override // org.chromium.mojo.bindings.MessageReceiverWithResponder
    public boolean acceptWithResponder(Message message, MessageReceiver messageReceiver) {
        ServiceMessage asServiceMessage = message.asServiceMessage();
        long j = this.mNextRequestId;
        long j2 = j + 1;
        this.mNextRequestId = j2;
        if (j == 0) {
            this.mNextRequestId = 1 + j2;
            j = j2;
        }
        if (!this.mResponders.containsKey(Long.valueOf(j))) {
            asServiceMessage.setRequestId(j);
            if (!this.mConnector.accept(asServiceMessage)) {
                return false;
            }
            this.mResponders.put(Long.valueOf(j), messageReceiver);
            return true;
        }
        throw new IllegalStateException("Unable to find a new request identifier.");
    }

    @Override // org.chromium.mojo.bindings.MessageReceiver, java.io.Closeable, java.lang.AutoCloseable, org.chromium.mojo.bindings.HandleOwner
    public void close() {
        this.mConnector.close();
    }

    @Override // org.chromium.mojo.bindings.Router
    public void setErrorHandler(ConnectionErrorHandler connectionErrorHandler) {
        this.mConnector.setErrorHandler(connectionErrorHandler);
    }

    @Override // org.chromium.mojo.bindings.Router
    public void setIncomingMessageReceiver(MessageReceiverWithResponder messageReceiverWithResponder) {
        this.mIncomingMessageReceiver = messageReceiverWithResponder;
    }

    @Override // org.chromium.mojo.bindings.Router
    public void start() {
        this.mConnector.start();
    }

    public RouterImpl(MessagePipeHandle messagePipeHandle, AsyncWaiter asyncWaiter) {
        this.mNextRequestId = 1;
        this.mResponders = new HashMap();
        Connector connector = new Connector(messagePipeHandle, asyncWaiter);
        this.mConnector = connector;
        connector.setIncomingMessageReceiver(new HandleIncomingMessageThunk());
        Core core = messagePipeHandle.getCore();
        if (core != null) {
            this.mExecutor = ExecutorFactory.getExecutorForCurrentThread(core);
        } else {
            this.mExecutor = null;
        }
    }

    @Override // org.chromium.mojo.bindings.HandleOwner
    public MessagePipeHandle passHandle() {
        return this.mConnector.passHandle();
    }
}
