package org.chromium.mojo.system.impl;

import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;
import org.chromium.mojo.system.RunLoop;

@JNINamespace("mojo::android")
public class BaseRunLoop implements RunLoop {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private final CoreImpl mCore;
    private long mRunLoopID = nativeCreateBaseRunLoop();

    public BaseRunLoop(CoreImpl coreImpl) {
        this.mCore = coreImpl;
    }

    private native long nativeCreateBaseRunLoop();

    private native void nativeDeleteMessageLoop(long j);

    private native void nativePostDelayedTask(long j, Runnable runnable, long j2);

    private native void nativeQuit(long j);

    private native void nativeRun(long j);

    private native void nativeRunUntilIdle(long j);

    @CalledByNative
    private static void runRunnable(Runnable runnable) {
        runnable.run();
    }

    @Override // java.io.Closeable, org.chromium.mojo.system.RunLoop, java.lang.AutoCloseable
    public void close() {
        if (this.mRunLoopID != 0) {
            this.mCore.clearCurrentRunLoop();
            nativeDeleteMessageLoop(this.mRunLoopID);
            this.mRunLoopID = 0;
        }
    }

    @Override // org.chromium.mojo.system.RunLoop
    public void postDelayedTask(Runnable runnable, long j) {
        nativePostDelayedTask(this.mRunLoopID, runnable, j);
    }

    @Override // org.chromium.mojo.system.RunLoop
    public void quit() {
        nativeQuit(this.mRunLoopID);
    }

    @Override // org.chromium.mojo.system.RunLoop
    public void run() {
        nativeRun(this.mRunLoopID);
    }

    @Override // org.chromium.mojo.system.RunLoop
    public void runUntilIdle() {
        nativeRunUntilIdle(this.mRunLoopID);
    }
}
