package org.chromium.net;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.net.Uri;
import android.os.Build;
import android.text.TextUtils;
import android.util.Log;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;
import org.chromium.base.annotations.NativeClassQualifiedName;

@JNINamespace("net")
public class ProxyChangeListener {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final String TAG = "ProxyChangeListener";
    private static boolean sEnabled = true;
    private Context mContext;
    private Delegate mDelegate;
    private long mNativePtr;
    private ProxyReceiver mProxyReceiver;

    public interface Delegate {
        void proxySettingsChanged();
    }

    public static class ProxyConfig {
        public final String[] mExclusionList;
        public final String mHost;
        public final String mPacUrl;
        public final int mPort;

        public ProxyConfig(String str, int i, String str2, String[] strArr) {
            this.mHost = str;
            this.mPort = i;
            this.mPacUrl = str2;
            this.mExclusionList = strArr;
        }
    }

    public class ProxyReceiver extends BroadcastReceiver {
        private ProxyReceiver() {
        }

        private ProxyConfig extractNewProxy(Intent intent) {
            String str;
            String str2;
            String[] strArr;
            try {
                int i = Build.VERSION.SDK_INT;
                if (i < 21) {
                    str2 = "android.net.ProxyProperties";
                    str = "proxy";
                } else {
                    str2 = "android.net.ProxyInfo";
                    str = "android.intent.extra.PROXY_INFO";
                }
                Object obj = intent.getExtras().get(str);
                if (obj == null) {
                    return null;
                }
                Class<?> cls = Class.forName(str2);
                Method declaredMethod = cls.getDeclaredMethod("getHost", new Class[0]);
                Method declaredMethod2 = cls.getDeclaredMethod("getPort", new Class[0]);
                Method declaredMethod3 = cls.getDeclaredMethod("getExclusionList", new Class[0]);
                String str3 = (String) declaredMethod.invoke(obj, new Object[0]);
                int intValue = ((Integer) declaredMethod2.invoke(obj, new Object[0])).intValue();
                if (i < 21) {
                    strArr = ((String) declaredMethod3.invoke(obj, new Object[0])).split(",");
                } else {
                    strArr = (String[]) declaredMethod3.invoke(obj, new Object[0]);
                }
                if (i >= 19 && i < 21) {
                    String str4 = (String) cls.getDeclaredMethod("getPacFileUrl", new Class[0]).invoke(obj, new Object[0]);
                    if (!TextUtils.isEmpty(str4)) {
                        return new ProxyConfig(str3, intValue, str4, strArr);
                    }
                } else if (i >= 21) {
                    Uri uri = (Uri) cls.getDeclaredMethod("getPacFileUrl", new Class[0]).invoke(obj, new Object[0]);
                    if (!Uri.EMPTY.equals(uri)) {
                        return new ProxyConfig(str3, intValue, uri.toString(), strArr);
                    }
                }
                return new ProxyConfig(str3, intValue, null, strArr);
            } catch (ClassNotFoundException e) {
                Log.e(ProxyChangeListener.TAG, "Using no proxy configuration due to exception:" + e);
                return null;
            } catch (NoSuchMethodException e2) {
                Log.e(ProxyChangeListener.TAG, "Using no proxy configuration due to exception:" + e2);
                return null;
            } catch (IllegalAccessException e3) {
                Log.e(ProxyChangeListener.TAG, "Using no proxy configuration due to exception:" + e3);
                return null;
            } catch (InvocationTargetException e4) {
                Log.e(ProxyChangeListener.TAG, "Using no proxy configuration due to exception:" + e4);
                return null;
            } catch (NullPointerException e5) {
                Log.e(ProxyChangeListener.TAG, "Using no proxy configuration due to exception:" + e5);
                return null;
            }
        }

        public void onReceive(Context context, Intent intent) {
            if (intent.getAction().equals("android.intent.action.PROXY_CHANGE")) {
                ProxyChangeListener.this.proxySettingsChanged(extractNewProxy(intent));
            }
        }
    }

    private ProxyChangeListener(Context context) {
        this.mContext = context;
    }

    @CalledByNative
    public static ProxyChangeListener create(Context context) {
        return new ProxyChangeListener(context);
    }

    @CalledByNative
    public static String getProperty(String str) {
        return System.getProperty(str);
    }

    @NativeClassQualifiedName("ProxyConfigServiceAndroid::JNIDelegate")
    private native void nativeProxySettingsChanged(long j);

    @NativeClassQualifiedName("ProxyConfigServiceAndroid::JNIDelegate")
    private native void nativeProxySettingsChangedTo(long j, String str, int i, String str2, String[] strArr);

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void proxySettingsChanged(ProxyConfig proxyConfig) {
        if (sEnabled) {
            Delegate delegate = this.mDelegate;
            if (delegate != null) {
                delegate.proxySettingsChanged();
            }
            long j = this.mNativePtr;
            if (j != 0) {
                if (proxyConfig != null) {
                    nativeProxySettingsChangedTo(j, proxyConfig.mHost, proxyConfig.mPort, proxyConfig.mPacUrl, proxyConfig.mExclusionList);
                } else {
                    nativeProxySettingsChanged(j);
                }
            }
        }
    }

    private void registerReceiver() {
        if (this.mProxyReceiver == null) {
            IntentFilter intentFilter = new IntentFilter();
            intentFilter.addAction("android.intent.action.PROXY_CHANGE");
            this.mProxyReceiver = new ProxyReceiver();
            this.mContext.getApplicationContext().registerReceiver(this.mProxyReceiver, intentFilter);
        }
    }

    public static void setEnabled(boolean z) {
        sEnabled = z;
    }

    private void unregisterReceiver() {
        ProxyReceiver proxyReceiver = this.mProxyReceiver;
        if (proxyReceiver != null) {
            this.mContext.unregisterReceiver(proxyReceiver);
            this.mProxyReceiver = null;
        }
    }

    public void setDelegateForTesting(Delegate delegate) {
        this.mDelegate = delegate;
    }

    @CalledByNative
    public void start(long j) {
        this.mNativePtr = j;
        registerReceiver();
    }

    @CalledByNative
    public void stop() {
        this.mNativePtr = 0;
        unregisterReceiver();
    }
}
