package org.chromium.ui;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.TextView;

public class ColorPickerDialog extends AlertDialog implements OnColorChangedListener {
    private final ColorPickerAdvanced mAdvancedColorPicker;
    private int mCurrentColor;
    private final View mCurrentColorView;
    private final int mInitialColor;
    private final OnColorChangedListener mListener;
    private final Button mMoreButton;
    private final ColorPickerSimple mSimpleColorPicker;

    public ColorPickerDialog(Context context, OnColorChangedListener onColorChangedListener, int i, ColorSuggestion[] colorSuggestionArr) {
        super(context, 0);
        this.mListener = onColorChangedListener;
        this.mInitialColor = i;
        this.mCurrentColor = i;
        LayoutInflater layoutInflater = (LayoutInflater) context.getSystemService("layout_inflater");
        View inflate = layoutInflater.inflate(R.layout.color_picker_dialog_title, (ViewGroup) null);
        setCustomTitle(inflate);
        this.mCurrentColorView = inflate.findViewById(R.id.selected_color_view);
        ((TextView) inflate.findViewById(R.id.title)).setText(R.string.color_picker_dialog_title);
        setButton(-1, context.getString(R.string.color_picker_button_set), new DialogInterface.OnClickListener() {
            /* class org.chromium.ui.ColorPickerDialog.AnonymousClass1 */

            public void onClick(DialogInterface dialogInterface, int i) {
                ColorPickerDialog colorPickerDialog = ColorPickerDialog.this;
                colorPickerDialog.tryNotifyColorSet(colorPickerDialog.mCurrentColor);
            }
        });
        setButton(-2, context.getString(R.string.color_picker_button_cancel), new DialogInterface.OnClickListener() {
            /* class org.chromium.ui.ColorPickerDialog.AnonymousClass2 */

            public void onClick(DialogInterface dialogInterface, int i) {
                ColorPickerDialog colorPickerDialog = ColorPickerDialog.this;
                colorPickerDialog.tryNotifyColorSet(colorPickerDialog.mInitialColor);
            }
        });
        setOnCancelListener(new DialogInterface.OnCancelListener() {
            /* class org.chromium.ui.ColorPickerDialog.AnonymousClass3 */

            public void onCancel(DialogInterface dialogInterface) {
                ColorPickerDialog colorPickerDialog = ColorPickerDialog.this;
                colorPickerDialog.tryNotifyColorSet(colorPickerDialog.mInitialColor);
            }
        });
        View inflate2 = layoutInflater.inflate(R.layout.color_picker_dialog_content, (ViewGroup) null);
        setView(inflate2);
        Button button = (Button) inflate2.findViewById(R.id.more_colors_button);
        this.mMoreButton = button;
        button.setOnClickListener(new View.OnClickListener() {
            /* class org.chromium.ui.ColorPickerDialog.AnonymousClass4 */

            public void onClick(View view) {
                ColorPickerDialog.this.showAdvancedView();
            }
        });
        ColorPickerAdvanced colorPickerAdvanced = (ColorPickerAdvanced) inflate2.findViewById(R.id.color_picker_advanced);
        this.mAdvancedColorPicker = colorPickerAdvanced;
        colorPickerAdvanced.setVisibility(8);
        ColorPickerSimple colorPickerSimple = (ColorPickerSimple) inflate2.findViewById(R.id.color_picker_simple);
        this.mSimpleColorPicker = colorPickerSimple;
        colorPickerSimple.init(colorSuggestionArr, this);
        updateCurrentColor(i);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void showAdvancedView() {
        findViewById(R.id.more_colors_button_border).setVisibility(8);
        findViewById(R.id.color_picker_simple).setVisibility(8);
        this.mAdvancedColorPicker.setVisibility(0);
        this.mAdvancedColorPicker.setListener(this);
        this.mAdvancedColorPicker.setColor(this.mCurrentColor);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void tryNotifyColorSet(int i) {
        OnColorChangedListener onColorChangedListener = this.mListener;
        if (onColorChangedListener != null) {
            onColorChangedListener.onColorChanged(i);
        }
    }

    private void updateCurrentColor(int i) {
        this.mCurrentColor = i;
        View view = this.mCurrentColorView;
        if (view != null) {
            view.setBackgroundColor(i);
        }
    }

    @Override // org.chromium.ui.OnColorChangedListener
    public void onColorChanged(int i) {
        updateCurrentColor(i);
    }
}
