package org.chromium.ui;

import android.content.Context;
import android.os.Handler;
import android.view.Choreographer;
import android.view.WindowManager;
import org.chromium.base.TraceEvent;

public class VSyncMonitor {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final long NANOSECONDS_PER_MICROSECOND = 1000;
    private static final long NANOSECONDS_PER_SECOND = 1000000000;
    private final Choreographer mChoreographer;
    private boolean mConsecutiveVSync = false;
    private long mGoodStartingPointNano;
    private final Handler mHandler = new Handler();
    private boolean mHaveRequestInFlight;
    private boolean mInsideVSync = false;
    private Listener mListener;
    private long mRefreshPeriodNano;
    private final Choreographer.FrameCallback mVSyncFrameCallback;

    public interface Listener {
        void onVSync(VSyncMonitor vSyncMonitor, long j);
    }

    public VSyncMonitor(Context context, Listener listener) {
        final boolean z = false;
        this.mListener = listener;
        float refreshRate = ((WindowManager) context.getSystemService("window")).getDefaultDisplay().getRefreshRate();
        z = refreshRate < 30.0f ? true : z;
        this.mRefreshPeriodNano = (long) (1.0E9f / (refreshRate <= 0.0f ? 60.0f : refreshRate));
        this.mChoreographer = Choreographer.getInstance();
        this.mVSyncFrameCallback = new Choreographer.FrameCallback() {
            /* class org.chromium.ui.VSyncMonitor.AnonymousClass1 */

            public void doFrame(long j) {
                TraceEvent.begin("VSync");
                if (z && VSyncMonitor.this.mConsecutiveVSync) {
                    VSyncMonitor vSyncMonitor = VSyncMonitor.this;
                    VSyncMonitor.access$214(vSyncMonitor, (long) (((float) ((j - VSyncMonitor.this.mGoodStartingPointNano) - vSyncMonitor.mRefreshPeriodNano)) * 0.1f));
                }
                VSyncMonitor.this.mGoodStartingPointNano = j;
                VSyncMonitor vSyncMonitor2 = VSyncMonitor.this;
                vSyncMonitor2.onVSyncCallback(j, vSyncMonitor2.getCurrentNanoTime());
                TraceEvent.end("VSync");
            }
        };
        this.mGoodStartingPointNano = getCurrentNanoTime();
    }

    public static /* synthetic */ long access$214(VSyncMonitor vSyncMonitor, long j) {
        long j2 = vSyncMonitor.mRefreshPeriodNano + j;
        vSyncMonitor.mRefreshPeriodNano = j2;
        return j2;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private long getCurrentNanoTime() {
        return System.nanoTime();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void onVSyncCallback(long j, long j2) {
        this.mInsideVSync = true;
        this.mHaveRequestInFlight = false;
        try {
            Listener listener = this.mListener;
            if (listener != null) {
                listener.onVSync(this, j / 1000);
            }
        } finally {
            this.mInsideVSync = false;
        }
    }

    private void postCallback() {
        if (!this.mHaveRequestInFlight) {
            this.mHaveRequestInFlight = true;
            this.mConsecutiveVSync = this.mInsideVSync;
            this.mChoreographer.postFrameCallback(this.mVSyncFrameCallback);
        }
    }

    public long getVSyncPeriodInMicroseconds() {
        return this.mRefreshPeriodNano / 1000;
    }

    public boolean isInsideVSync() {
        return this.mInsideVSync;
    }

    public void requestUpdate() {
        postCallback();
    }
}
