package org.chromium.ui.base;

import android.content.Context;
import android.os.Build;
import android.util.DisplayMetrics;
import android.view.WindowManager;
import org.chromium.base.annotations.CalledByNative;

public class DeviceFormFactor {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final int MINIMUM_LARGE_TABLET_WIDTH_DP = 720;
    public static final int MINIMUM_TABLET_WIDTH_DP = 600;
    private static Float sDensity;
    private static Boolean sIsLargeTablet;
    private static Boolean sIsTablet;
    private static Integer sMinimumTabletWidthPx;

    public static int getMinimumTabletWidthPx(Context context) {
        if (sMinimumTabletWidthPx == null) {
            sMinimumTabletWidthPx = Integer.valueOf(Math.round(context.getResources().getDisplayMetrics().density * 600.0f));
        }
        return sMinimumTabletWidthPx.intValue();
    }

    public static int getSmallestDeviceWidthDp(Context context) {
        if (Build.VERSION.SDK_INT < 17) {
            return context.getResources().getConfiguration().smallestScreenWidthDp;
        }
        DisplayMetrics displayMetrics = new DisplayMetrics();
        ((WindowManager) context.getApplicationContext().getSystemService("window")).getDefaultDisplay().getRealMetrics(displayMetrics);
        float f = displayMetrics.density;
        return Math.round(Math.min(((float) displayMetrics.heightPixels) / f, ((float) displayMetrics.widthPixels) / f));
    }

    public static boolean isLargeTablet(Context context) {
        if (sIsLargeTablet == null) {
            sIsLargeTablet = Boolean.valueOf(getSmallestDeviceWidthDp(context) >= MINIMUM_LARGE_TABLET_WIDTH_DP);
        }
        return sIsLargeTablet.booleanValue();
    }

    @CalledByNative
    public static boolean isTablet(Context context) {
        if (sIsTablet == null) {
            sIsTablet = Boolean.valueOf(getSmallestDeviceWidthDp(context) >= 600);
        }
        return sIsTablet.booleanValue();
    }

    public static void resetValuesIfNeeded(Context context) {
        float f = context.getResources().getDisplayMetrics().density;
        Float f2 = sDensity;
        if (!(f2 == null || f2.floatValue() == f)) {
            sIsTablet = null;
            sIsLargeTablet = null;
            sMinimumTabletWidthPx = null;
        }
        sDensity = Float.valueOf(f);
    }
}
