package org.chromium.ui.base;

import android.content.Context;
import android.content.res.Resources;
import android.content.res.TypedArray;
import androidx.base.b2;
import java.io.File;
import java.util.Locale;
import org.chromium.base.ResourceExtractor;
import org.chromium.base.ThreadUtils;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;
import org.chromium.base.annotations.SuppressFBWarnings;

@JNINamespace("ui")
public class ResourceBundle {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static ResourceExtractor.ResourceEntry[] sActiveLocaleResources;

    @SuppressFBWarnings({"MS_EXPOSE_REP"})
    public static ResourceExtractor.ResourceEntry[] getActiveLocaleResources() {
        return sActiveLocaleResources;
    }

    @CalledByNative
    private static String getLocalePakResourcePath(String str) {
        if (sActiveLocaleResources == null) {
            return null;
        }
        String c = b2.c(str, ".pak");
        ResourceExtractor.ResourceEntry[] resourceEntryArr = sActiveLocaleResources;
        for (ResourceExtractor.ResourceEntry resourceEntry : resourceEntryArr) {
            if (c.equals(resourceEntry.extractedFileName)) {
                return resourceEntry.pathWithinApk;
            }
        }
        return null;
    }

    @SuppressFBWarnings({"LI_LAZY_INIT_UPDATE_STATIC"})
    public static void initializeLocalePaks(Context context, int i) {
        ThreadUtils.assertOnUiThread();
        Resources resources = context.getResources();
        TypedArray obtainTypedArray = resources.obtainTypedArray(i);
        try {
            int length = obtainTypedArray.length();
            sActiveLocaleResources = new ResourceExtractor.ResourceEntry[length];
            for (int i2 = 0; i2 < length; i2++) {
                int resourceId = obtainTypedArray.getResourceId(i2, 0);
                String string = resources.getString(resourceId);
                sActiveLocaleResources[i2] = new ResourceExtractor.ResourceEntry(resourceId, string, toChromeLocaleName(new File(string).getName()));
            }
        } finally {
            obtainTypedArray.recycle();
        }
    }

    private static String toChromeLocaleName(String str) {
        String replace = str.replace(".lpak", ".pak");
        String[] split = replace.split("_");
        if (split.length <= 1) {
            return replace;
        }
        int indexOf = split[1].indexOf(46);
        return split[0] + "-" + split[1].substring(0, indexOf).toUpperCase(Locale.ENGLISH) + split[1].substring(indexOf);
    }
}
