package org.chromium.ui.gfx;

import android.annotation.TargetApi;
import android.content.Context;
import android.graphics.PixelFormat;
import android.graphics.Point;
import android.os.Build;
import android.util.DisplayMetrics;
import android.view.Display;
import android.view.WindowManager;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;

@JNINamespace("gfx")
public class DeviceDisplayInfo {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private final Context mAppContext;
    private DisplayMetrics mTempMetrics = new DisplayMetrics();
    private Point mTempPoint = new Point();
    private final WindowManager mWinManager;

    private DeviceDisplayInfo(Context context) {
        Context applicationContext = context.getApplicationContext();
        this.mAppContext = applicationContext;
        this.mWinManager = (WindowManager) applicationContext.getSystemService("window");
    }

    @CalledByNative
    public static DeviceDisplayInfo create(Context context) {
        return new DeviceDisplayInfo(context);
    }

    private Display getDisplay() {
        return this.mWinManager.getDefaultDisplay();
    }

    private int getPixelFormat() {
        if (Build.VERSION.SDK_INT < 17) {
            return getDisplay().getPixelFormat();
        }
        return 1;
    }

    @CalledByNative
    private int getSmallestDIPWidth() {
        return this.mAppContext.getResources().getConfiguration().smallestScreenWidthDp;
    }

    private native void nativeUpdateSharedDeviceDisplayInfo(int i, int i2, int i3, int i4, int i5, int i6, double d, int i7, int i8);

    @CalledByNative
    public int getBitsPerComponent() {
        switch (getPixelFormat()) {
            case 4:
            case 6:
                return 5;
            case 5:
            default:
                return 8;
            case 7:
                return 4;
            case 8:
            case 9:
            case 10:
                return 0;
            case 11:
                return 2;
        }
    }

    @CalledByNative
    public int getBitsPerPixel() {
        int pixelFormat = getPixelFormat();
        PixelFormat pixelFormat2 = new PixelFormat();
        PixelFormat.getPixelFormatInfo(pixelFormat, pixelFormat2);
        return pixelFormat2.bitsPerPixel;
    }

    @CalledByNative
    public double getDIPScale() {
        getDisplay().getMetrics(this.mTempMetrics);
        return (double) this.mTempMetrics.density;
    }

    @CalledByNative
    public int getDisplayHeight() {
        getDisplay().getSize(this.mTempPoint);
        return this.mTempPoint.y;
    }

    @CalledByNative
    public int getDisplayWidth() {
        getDisplay().getSize(this.mTempPoint);
        return this.mTempPoint.x;
    }

    @TargetApi(17)
    @CalledByNative
    public int getPhysicalDisplayHeight() {
        if (Build.VERSION.SDK_INT < 17) {
            return 0;
        }
        getDisplay().getRealSize(this.mTempPoint);
        return this.mTempPoint.y;
    }

    @TargetApi(17)
    @CalledByNative
    public int getPhysicalDisplayWidth() {
        if (Build.VERSION.SDK_INT < 17) {
            return 0;
        }
        getDisplay().getRealSize(this.mTempPoint);
        return this.mTempPoint.x;
    }

    @CalledByNative
    public int getRotationDegrees() {
        int rotation = getDisplay().getRotation();
        if (rotation == 0) {
            return 0;
        }
        if (rotation == 1) {
            return 90;
        }
        if (rotation != 2) {
            return rotation != 3 ? 0 : 270;
        }
        return 180;
    }

    public void updateNativeSharedDisplayInfo() {
        nativeUpdateSharedDeviceDisplayInfo(getDisplayHeight(), getDisplayWidth(), getPhysicalDisplayHeight(), getPhysicalDisplayWidth(), getBitsPerPixel(), getBitsPerComponent(), getDIPScale(), getSmallestDIPWidth(), getRotationDegrees());
    }
}
