package org.chromium.ui.picker;

import android.content.Context;
import java.text.DateFormatSymbols;
import java.util.Arrays;
import java.util.Calendar;
import java.util.Locale;
import java.util.TimeZone;
import org.chromium.ui.R;

public class MonthPicker extends TwoFieldDatePicker {
    private static final int MONTHS_NUMBER = 12;
    private final String[] mShortMonths = DateFormatSymbols.getInstance(Locale.getDefault()).getShortMonths();

    public MonthPicker(Context context, double d, double d2) {
        super(context, d, d2);
        getPositionInYearSpinner().setContentDescription(getResources().getString(R.string.accessibility_date_picker_month));
        if (usingNumericMonths()) {
            int i = 0;
            while (true) {
                String[] strArr = this.mShortMonths;
                if (i >= strArr.length) {
                    break;
                }
                int i2 = i + 1;
                strArr[i] = String.format("%d", Integer.valueOf(i2));
                i = i2;
            }
        }
        Calendar instance = Calendar.getInstance(TimeZone.getTimeZone("UTC"));
        init(instance.get(1), instance.get(2), null);
    }

    public static Calendar createDateFromValue(double d) {
        Calendar instance = Calendar.getInstance(TimeZone.getTimeZone("UTC"));
        instance.clear();
        instance.set((int) Math.min((d / 12.0d) + 1970.0d, 2.147483647E9d), (int) (d % 12.0d), 1);
        return instance;
    }

    @Override // org.chromium.ui.picker.TwoFieldDatePicker
    public Calendar getDateForValue(double d) {
        return createDateFromValue(d);
    }

    @Override // org.chromium.ui.picker.TwoFieldDatePicker
    public int getMaxPositionInYear(int i) {
        if (i == getMaxDate().get(1)) {
            return getMaxDate().get(2);
        }
        return 11;
    }

    @Override // org.chromium.ui.picker.TwoFieldDatePicker
    public int getMaxYear() {
        return getMaxDate().get(1);
    }

    @Override // org.chromium.ui.picker.TwoFieldDatePicker
    public int getMinPositionInYear(int i) {
        if (i == getMinDate().get(1)) {
            return getMinDate().get(2);
        }
        return 0;
    }

    @Override // org.chromium.ui.picker.TwoFieldDatePicker
    public int getMinYear() {
        return getMinDate().get(1);
    }

    public int getMonth() {
        return getCurrentDate().get(2);
    }

    @Override // org.chromium.ui.picker.TwoFieldDatePicker
    public int getPositionInYear() {
        return getMonth();
    }

    @Override // org.chromium.ui.picker.TwoFieldDatePicker
    public void setCurrentDate(int i, int i2) {
        Calendar instance = Calendar.getInstance(TimeZone.getTimeZone("UTC"));
        instance.set(i, i2, 1);
        if (instance.before(getMinDate())) {
            setCurrentDate(getMinDate());
        } else if (instance.after(getMaxDate())) {
            setCurrentDate(getMaxDate());
        } else {
            setCurrentDate(instance);
        }
    }

    @Override // org.chromium.ui.picker.TwoFieldDatePicker
    public void updateSpinners() {
        super.updateSpinners();
        getPositionInYearSpinner().setDisplayedValues((String[]) Arrays.copyOfRange(this.mShortMonths, getPositionInYearSpinner().getMinValue(), getPositionInYearSpinner().getMaxValue() + 1));
    }

    public boolean usingNumericMonths() {
        return Character.isDigit(this.mShortMonths[0].charAt(0));
    }
}
