package org.chromium.ui.picker;

import android.annotation.TargetApi;
import android.content.Context;
import android.os.Build;
import android.text.format.DateFormat;
import android.text.format.DateUtils;
import android.view.LayoutInflater;
import android.view.ViewGroup;
import android.view.accessibility.AccessibilityEvent;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import android.widget.NumberPicker;
import androidx.base.b2;
import java.util.Calendar;
import java.util.Locale;
import java.util.TimeZone;
import org.chromium.ui.R;

public abstract class TwoFieldDatePicker extends FrameLayout {
    private Calendar mCurrentDate = Calendar.getInstance(TimeZone.getTimeZone("UTC"));
    private Calendar mMaxDate;
    private Calendar mMinDate;
    private OnMonthOrWeekChangedListener mMonthOrWeekChangedListener;
    private final NumberPicker mPositionInYearSpinner;
    private final NumberPicker mYearSpinner;

    public interface OnMonthOrWeekChangedListener {
        void onMonthOrWeekChanged(TwoFieldDatePicker twoFieldDatePicker, int i, int i2);
    }

    public TwoFieldDatePicker(Context context, double d, double d2) {
        super(context, null, 16843612);
        ((LayoutInflater) context.getSystemService("layout_inflater")).inflate(R.layout.two_field_date_picker, (ViewGroup) this, true);
        AnonymousClass1 r4 = new NumberPicker.OnValueChangeListener() {
            /* class org.chromium.ui.picker.TwoFieldDatePicker.AnonymousClass1 */

            public void onValueChange(NumberPicker numberPicker, int i, int i2) {
                int i3;
                int year = TwoFieldDatePicker.this.getYear();
                int positionInYear = TwoFieldDatePicker.this.getPositionInYear();
                if (numberPicker == TwoFieldDatePicker.this.mPositionInYearSpinner) {
                    if (i == numberPicker.getMaxValue() && i2 == numberPicker.getMinValue()) {
                        i2 = year + 1;
                        i3 = TwoFieldDatePicker.this.getMinPositionInYear(i2);
                    } else if (i == numberPicker.getMinValue() && i2 == numberPicker.getMaxValue()) {
                        i2 = year - 1;
                        i3 = TwoFieldDatePicker.this.getMaxPositionInYear(i2);
                    } else {
                        i3 = i2;
                        i2 = year;
                    }
                } else if (numberPicker == TwoFieldDatePicker.this.mYearSpinner) {
                    i3 = positionInYear;
                } else {
                    throw new IllegalArgumentException();
                }
                TwoFieldDatePicker.this.setCurrentDate(i2, i3);
                TwoFieldDatePicker.this.updateSpinners();
                TwoFieldDatePicker.this.notifyDateChanged();
            }
        };
        if (d >= d2) {
            Calendar instance = Calendar.getInstance(TimeZone.getTimeZone("UTC"));
            this.mMinDate = instance;
            instance.set(0, 0, 1);
            Calendar instance2 = Calendar.getInstance(TimeZone.getTimeZone("UTC"));
            this.mMaxDate = instance2;
            instance2.set(9999, 0, 1);
        } else {
            this.mMinDate = getDateForValue(d);
            this.mMaxDate = getDateForValue(d2);
        }
        NumberPicker numberPicker = (NumberPicker) findViewById(R.id.position_in_year);
        this.mPositionInYearSpinner = numberPicker;
        numberPicker.setOnLongPressUpdateInterval(200);
        numberPicker.setOnValueChangedListener(r4);
        NumberPicker numberPicker2 = (NumberPicker) findViewById(R.id.year);
        this.mYearSpinner = numberPicker2;
        numberPicker2.setOnLongPressUpdateInterval(100);
        numberPicker2.setOnValueChangedListener(r4);
        reorderSpinners();
    }

    @TargetApi(18)
    private void reorderSpinners() {
        boolean z;
        boolean z2;
        LinearLayout linearLayout = (LinearLayout) findViewById(R.id.pickers);
        linearLayout.removeView(this.mPositionInYearSpinner);
        linearLayout.removeView(this.mYearSpinner);
        int i = 0;
        if (Build.VERSION.SDK_INT >= 18) {
            String bestDateTimePattern = DateFormat.getBestDateTimePattern(Locale.getDefault(), "yyyyMMMdd");
            z2 = false;
            z = false;
            while (i < bestDateTimePattern.length()) {
                char charAt = bestDateTimePattern.charAt(i);
                if (charAt == '\'') {
                    i = bestDateTimePattern.indexOf(39, i + 1);
                    if (i == -1) {
                        throw new IllegalArgumentException(b2.c("Bad quoting in ", bestDateTimePattern));
                    }
                } else if ((charAt == 'M' || charAt == 'L') && !z2) {
                    linearLayout.addView(this.mPositionInYearSpinner);
                    z2 = true;
                } else if (charAt == 'y' && !z) {
                    linearLayout.addView(this.mYearSpinner);
                    z = true;
                }
                i++;
            }
        } else {
            char[] dateFormatOrder = DateFormat.getDateFormatOrder(getContext());
            z2 = false;
            z = false;
            while (i < dateFormatOrder.length) {
                if (dateFormatOrder[i] == 'M') {
                    linearLayout.addView(this.mPositionInYearSpinner);
                    z2 = true;
                } else if (dateFormatOrder[i] == 'y') {
                    linearLayout.addView(this.mYearSpinner);
                    z = true;
                }
                i++;
            }
        }
        if (!z2) {
            linearLayout.addView(this.mPositionInYearSpinner);
        }
        if (!z) {
            linearLayout.addView(this.mYearSpinner);
        }
    }

    public boolean dispatchPopulateAccessibilityEvent(AccessibilityEvent accessibilityEvent) {
        onPopulateAccessibilityEvent(accessibilityEvent);
        return true;
    }

    public Calendar getCurrentDate() {
        return this.mCurrentDate;
    }

    public abstract Calendar getDateForValue(double d);

    public Calendar getMaxDate() {
        return this.mMaxDate;
    }

    public abstract int getMaxPositionInYear(int i);

    public abstract int getMaxYear();

    public Calendar getMinDate() {
        return this.mMinDate;
    }

    public abstract int getMinPositionInYear(int i);

    public abstract int getMinYear();

    public abstract int getPositionInYear();

    public NumberPicker getPositionInYearSpinner() {
        return this.mPositionInYearSpinner;
    }

    public int getYear() {
        return this.mCurrentDate.get(1);
    }

    public NumberPicker getYearSpinner() {
        return this.mYearSpinner;
    }

    public void init(int i, int i2, OnMonthOrWeekChangedListener onMonthOrWeekChangedListener) {
        setCurrentDate(i, i2);
        updateSpinners();
        this.mMonthOrWeekChangedListener = onMonthOrWeekChangedListener;
    }

    public boolean isNewDate(int i, int i2) {
        return (getYear() == i && getPositionInYear() == i2) ? false : true;
    }

    public void notifyDateChanged() {
        sendAccessibilityEvent(4);
        OnMonthOrWeekChangedListener onMonthOrWeekChangedListener = this.mMonthOrWeekChangedListener;
        if (onMonthOrWeekChangedListener != null) {
            onMonthOrWeekChangedListener.onMonthOrWeekChanged(this, getYear(), getPositionInYear());
        }
    }

    public void onPopulateAccessibilityEvent(AccessibilityEvent accessibilityEvent) {
        super.onPopulateAccessibilityEvent(accessibilityEvent);
        accessibilityEvent.getText().add(DateUtils.formatDateTime(getContext(), this.mCurrentDate.getTimeInMillis(), 20));
    }

    public abstract void setCurrentDate(int i, int i2);

    public void setCurrentDate(Calendar calendar) {
        this.mCurrentDate = calendar;
    }

    public void updateDate(int i, int i2) {
        if (isNewDate(i, i2)) {
            setCurrentDate(i, i2);
            updateSpinners();
            notifyDateChanged();
        }
    }

    public void updateSpinners() {
        this.mPositionInYearSpinner.setDisplayedValues(null);
        this.mPositionInYearSpinner.setMinValue(getMinPositionInYear(getYear()));
        this.mPositionInYearSpinner.setMaxValue(getMaxPositionInYear(getYear()));
        this.mPositionInYearSpinner.setWrapSelectorWheel(!this.mCurrentDate.equals(this.mMinDate) && !this.mCurrentDate.equals(this.mMaxDate));
        this.mYearSpinner.setMinValue(getMinYear());
        this.mYearSpinner.setMaxValue(getMaxYear());
        this.mYearSpinner.setWrapSelectorWheel(false);
        this.mYearSpinner.setValue(getYear());
        this.mPositionInYearSpinner.setValue(getPositionInYear());
    }
}
