package org.chromium.ui.picker;

import android.content.Context;
import java.util.Calendar;
import java.util.TimeZone;
import org.chromium.ui.R;

public class WeekPicker extends TwoFieldDatePicker {
    public WeekPicker(Context context, double d, double d2) {
        super(context, d, d2);
        getPositionInYearSpinner().setContentDescription(getResources().getString(R.string.accessibility_date_picker_week));
        Calendar instance = Calendar.getInstance(TimeZone.getTimeZone("UTC"));
        instance.setFirstDayOfWeek(2);
        instance.setMinimalDaysInFirstWeek(4);
        instance.setTimeInMillis(System.currentTimeMillis());
        init(getISOWeekYearForDate(instance), getWeekForDate(instance), null);
    }

    public static Calendar createDateFromValue(double d) {
        Calendar instance = Calendar.getInstance(TimeZone.getTimeZone("UTC"));
        instance.clear();
        instance.setFirstDayOfWeek(2);
        instance.setMinimalDaysInFirstWeek(4);
        instance.setTimeInMillis((long) d);
        return instance;
    }

    public static Calendar createDateFromWeek(int i, int i2) {
        Calendar instance = Calendar.getInstance(TimeZone.getTimeZone("UTC"));
        instance.clear();
        instance.setFirstDayOfWeek(2);
        instance.setMinimalDaysInFirstWeek(4);
        instance.set(7, 2);
        instance.set(1, i);
        instance.set(3, i2);
        return instance;
    }

    public static int getISOWeekYearForDate(Calendar calendar) {
        int i = calendar.get(1);
        int i2 = calendar.get(2);
        int i3 = calendar.get(3);
        if (i2 != 0 || i3 <= 51) {
            return (i2 == 11 && i3 == 1) ? i + 1 : i;
        }
        return i - 1;
    }

    private int getNumberOfWeeks(int i) {
        return createDateFromWeek(i, 20).getActualMaximum(3);
    }

    public static int getWeekForDate(Calendar calendar) {
        return calendar.get(3);
    }

    @Override // org.chromium.ui.picker.TwoFieldDatePicker
    public Calendar getDateForValue(double d) {
        return createDateFromValue(d);
    }

    @Override // org.chromium.ui.picker.TwoFieldDatePicker
    public int getMaxPositionInYear(int i) {
        if (i == getISOWeekYearForDate(getMaxDate())) {
            return getWeekForDate(getMaxDate());
        }
        return getNumberOfWeeks(i);
    }

    @Override // org.chromium.ui.picker.TwoFieldDatePicker
    public int getMaxYear() {
        return getISOWeekYearForDate(getMaxDate());
    }

    @Override // org.chromium.ui.picker.TwoFieldDatePicker
    public int getMinPositionInYear(int i) {
        if (i == getISOWeekYearForDate(getMinDate())) {
            return getWeekForDate(getMinDate());
        }
        return 1;
    }

    @Override // org.chromium.ui.picker.TwoFieldDatePicker
    public int getMinYear() {
        return getISOWeekYearForDate(getMinDate());
    }

    @Override // org.chromium.ui.picker.TwoFieldDatePicker
    public int getPositionInYear() {
        return getWeek();
    }

    public int getWeek() {
        return getWeekForDate(getCurrentDate());
    }

    @Override // org.chromium.ui.picker.TwoFieldDatePicker
    public int getYear() {
        return getISOWeekYearForDate(getCurrentDate());
    }

    @Override // org.chromium.ui.picker.TwoFieldDatePicker
    public void setCurrentDate(int i, int i2) {
        Calendar createDateFromWeek = createDateFromWeek(i, i2);
        if (createDateFromWeek.before(getMinDate())) {
            setCurrentDate(getMinDate());
        } else if (createDateFromWeek.after(getMaxDate())) {
            setCurrentDate(getMaxDate());
        } else {
            setCurrentDate(createDateFromWeek);
        }
    }
}
