package org.chromium.ui.resources.async;

import android.os.AsyncTask;
import android.util.SparseArray;
import java.util.concurrent.ExecutionException;
import org.chromium.base.TraceEvent;
import org.chromium.ui.resources.Resource;
import org.chromium.ui.resources.ResourceLoader;

public class AsyncPreloadResourceLoader extends ResourceLoader {
    private final ResourceCreator mCreator;
    private final SparseArray<AsyncLoadTask> mOutstandingLoads = new SparseArray<>();

    public class AsyncLoadTask extends AsyncTask<Void, Void, Resource> {
        private final int mResourceId;

        public AsyncLoadTask(int i) {
            this.mResourceId = i;
        }

        public Resource doInBackground(Void... voidArr) {
            return AsyncPreloadResourceLoader.this.createResource(this.mResourceId);
        }

        public void onPostExecute(Resource resource) {
            if (AsyncPreloadResourceLoader.this.mOutstandingLoads.get(this.mResourceId) != null) {
                AsyncPreloadResourceLoader.this.registerResource(resource, this.mResourceId);
            }
        }
    }

    public interface ResourceCreator {
        Resource create(int i);
    }

    public AsyncPreloadResourceLoader(int i, ResourceLoader.ResourceLoaderCallback resourceLoaderCallback, ResourceCreator resourceCreator) {
        super(i, resourceLoaderCallback);
        this.mCreator = resourceCreator;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Resource createResource(int i) {
        try {
            TraceEvent.begin("AsyncPreloadResourceLoader.createResource");
            return this.mCreator.create(i);
        } finally {
            TraceEvent.end("AsyncPreloadResourceLoader.createResource");
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void registerResource(Resource resource, int i) {
        notifyLoadFinished(i, resource);
        if (resource != null) {
            resource.getBitmap().recycle();
        }
        this.mOutstandingLoads.remove(i);
    }

    @Override // org.chromium.ui.resources.ResourceLoader
    public void loadResource(int i) {
        AsyncLoadTask asyncLoadTask = this.mOutstandingLoads.get(i);
        if (asyncLoadTask == null || asyncLoadTask.cancel(false)) {
            registerResource(createResource(i), i);
            return;
        }
        try {
            registerResource((Resource) asyncLoadTask.get(), i);
        } catch (InterruptedException unused) {
            notifyLoadFinished(i, null);
        } catch (ExecutionException unused2) {
            notifyLoadFinished(i, null);
        }
    }

    @Override // org.chromium.ui.resources.ResourceLoader
    public void preloadResource(int i) {
        if (this.mOutstandingLoads.get(i) == null) {
            AsyncLoadTask asyncLoadTask = new AsyncLoadTask(i);
            asyncLoadTask.executeOnExecutor(AsyncTask.SERIAL_EXECUTOR, null);
            this.mOutstandingLoads.put(i, asyncLoadTask);
        }
    }
}
