package org.chromium.ui.resources.dynamics;

import android.graphics.Bitmap;
import android.graphics.Rect;

public class BitmapDynamicResource implements DynamicResource {
    private static final Rect EMPTY_RECT = new Rect();
    private Bitmap mBitmap;
    private boolean mIsDirty = true;
    private final int mResId;
    private final Rect mSize = new Rect();

    public BitmapDynamicResource(int i) {
        this.mResId = i;
    }

    @Override // org.chromium.ui.resources.Resource
    public Rect getAperture() {
        return EMPTY_RECT;
    }

    @Override // org.chromium.ui.resources.Resource
    public Bitmap getBitmap() {
        this.mIsDirty = false;
        return this.mBitmap;
    }

    @Override // org.chromium.ui.resources.Resource
    public Rect getBitmapSize() {
        return this.mSize;
    }

    @Override // org.chromium.ui.resources.Resource
    public Rect getPadding() {
        return EMPTY_RECT;
    }

    public int getResId() {
        return this.mResId;
    }

    @Override // org.chromium.ui.resources.dynamics.DynamicResource
    public boolean isDirty() {
        return this.mIsDirty;
    }

    public void setBitmap(Bitmap bitmap) {
        if (bitmap != null) {
            this.mIsDirty = true;
            Bitmap bitmap2 = this.mBitmap;
            if (bitmap2 != null) {
                bitmap2.recycle();
            }
            this.mBitmap = bitmap;
            this.mSize.set(0, 0, bitmap.getWidth(), this.mBitmap.getHeight());
        }
    }
}
