package org.xwalk.core;

import androidx.base.b2;
import java.lang.reflect.Field;
import java.util.concurrent.RejectedExecutionException;

public class ReflectField {
    private Class<?> mClass;
    private Field mField;
    private Object mInstance;
    private String mName;

    public ReflectField() {
    }

    public Object get() {
        Field field = this.mField;
        if (field != null) {
            try {
                return field.get(this.mInstance);
            } catch (IllegalAccessException | NullPointerException e) {
                throw new RejectedExecutionException(e);
            } catch (IllegalArgumentException e2) {
                throw e2;
            } catch (ExceptionInInitializerError e3) {
                throw new RuntimeException(e3);
            }
        } else {
            throw new UnsupportedOperationException(toString());
        }
    }

    public Object getInstance() {
        return this.mInstance;
    }

    public String getName() {
        return this.mName;
    }

    public boolean init(Object obj, Class<?> cls, String str) {
        this.mInstance = obj;
        if (cls == null) {
            cls = obj != null ? obj.getClass() : null;
        }
        this.mClass = cls;
        this.mName = str;
        this.mField = null;
        if (cls == null) {
            return false;
        }
        try {
            this.mField = cls.getField(str);
        } catch (NoSuchFieldException unused) {
            for (Class<?> cls2 = this.mClass; cls2 != null; cls2 = cls2.getSuperclass()) {
                try {
                    Field declaredField = cls2.getDeclaredField(this.mName);
                    this.mField = declaredField;
                    declaredField.setAccessible(true);
                    break;
                } catch (NoSuchFieldException unused2) {
                }
            }
        }
        if (this.mField != null) {
            return true;
        }
        return false;
    }

    public boolean isNull() {
        return this.mField == null;
    }

    public String toString() {
        Field field = this.mField;
        if (field != null) {
            return field.toString();
        }
        String str = "";
        if (this.mClass != null) {
            StringBuilder j = b2.j(str);
            j.append(this.mClass.toString());
            j.append(".");
            str = j.toString();
        }
        if (this.mName == null) {
            return str;
        }
        StringBuilder j2 = b2.j(str);
        j2.append(this.mName);
        return j2.toString();
    }

    public ReflectField(Object obj, String str) {
        init(obj, null, str);
    }

    public ReflectField(Class<?> cls, String str) {
        init(null, cls, str);
    }
}
