package org.xwalk.core;

import androidx.base.b2;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.concurrent.RejectedExecutionException;

public class ReflectMethod {
    private Object[] mArguments;
    private Class<?> mClass;
    private Object mInstance;
    private Method mMethod;
    private String mName;
    private Class<?>[] mParameterTypes;

    public ReflectMethod() {
    }

    public Object[] getArguments() {
        return this.mArguments;
    }

    public Object getInstance() {
        return this.mInstance;
    }

    public String getName() {
        return this.mName;
    }

    public boolean init(Object obj, Class<?> cls, String str, Class<?>... clsArr) {
        this.mInstance = obj;
        if (cls == null) {
            cls = obj != null ? obj.getClass() : null;
        }
        this.mClass = cls;
        this.mName = str;
        this.mParameterTypes = clsArr;
        this.mMethod = null;
        if (cls == null) {
            return false;
        }
        try {
            this.mMethod = cls.getMethod(str, clsArr);
        } catch (NoSuchMethodException unused) {
            for (Class<?> cls2 = this.mClass; cls2 != null; cls2 = cls2.getSuperclass()) {
                try {
                    Method declaredMethod = cls2.getDeclaredMethod(this.mName, this.mParameterTypes);
                    this.mMethod = declaredMethod;
                    declaredMethod.setAccessible(true);
                    break;
                } catch (NoSuchMethodException unused2) {
                }
            }
        }
        if (this.mMethod != null) {
            return true;
        }
        return false;
    }

    public Object invoke(Object... objArr) {
        Method method = this.mMethod;
        if (method != null) {
            try {
                return method.invoke(this.mInstance, objArr);
            } catch (IllegalAccessException | NullPointerException e) {
                throw new RejectedExecutionException(e);
            } catch (IllegalArgumentException e2) {
                throw e2;
            } catch (InvocationTargetException e3) {
                throw new RuntimeException(e3.getCause());
            }
        } else {
            throw new UnsupportedOperationException(toString());
        }
    }

    public Object invokeWithArguments() {
        return invoke(this.mArguments);
    }

    public boolean isNull() {
        return this.mMethod == null;
    }

    public void setArguments(Object... objArr) {
        this.mArguments = objArr;
    }

    public String toString() {
        Method method = this.mMethod;
        if (method != null) {
            return method.toString();
        }
        String str = "";
        if (this.mClass != null) {
            StringBuilder j = b2.j(str);
            j.append(this.mClass.toString());
            j.append(".");
            str = j.toString();
        }
        if (this.mName == null) {
            return str;
        }
        StringBuilder j2 = b2.j(str);
        j2.append(this.mName);
        return j2.toString();
    }

    public ReflectMethod(Object obj, String str, Class<?>... clsArr) {
        init(obj, null, str, clsArr);
    }

    public ReflectMethod(Class<?> cls, String str, Class<?>... clsArr) {
        init(null, cls, str, clsArr);
    }
}
