package org.xwalk.core;

import android.content.Context;
import android.content.res.Resources;
import android.os.SystemClock;
import android.util.Log;
import androidx.base.b2;
import androidx.base.c;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;
import java.util.concurrent.RejectedExecutionException;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;

public class XWalkDecompressor {
    private static final int LZMA_OUTSIZE = 8;
    private static final int LZMA_PROP_SIZE = 5;
    private static final String[] MANDATORY_LIBRARIES = {"libxwalkcore.so"};
    private static final String[] MANDATORY_RESOURCES = {"libxwalkcore.so", "classes.dex", "icudtl.dat", "xwalk.pak", "xwalk_100_percent.pak"};
    private static final int STREAM_BUFFER_SIZE = 4096;
    private static final String TAG = "XWalkLib";

    public static class DecompressResourceTask implements Callable<Boolean> {
        public File mDestFile;
        public ZipEntry mZipEntry;
        public ZipFile mZipFile;

        public DecompressResourceTask(ZipFile zipFile, ZipEntry zipEntry, File file) {
            this.mZipFile = zipFile;
            this.mZipEntry = zipEntry;
            this.mDestFile = file;
        }

        @Override // java.util.concurrent.Callable
        public Boolean call() {
            try {
                Log.d(XWalkDecompressor.TAG, "Decompressing " + this.mZipEntry.getName());
                XWalkDecompressor.extractLzmaToFile(this.mZipFile.getInputStream(this.mZipEntry), this.mDestFile);
                return Boolean.TRUE;
            } catch (IOException e) {
                Log.e(XWalkDecompressor.TAG, e.getLocalizedMessage());
                return Boolean.FALSE;
            }
        }
    }

    public static boolean decompressLibrary() {
        String privateDataDir = XWalkEnvironment.getPrivateDataDir();
        File file = new File(privateDataDir);
        if (file.exists() && file.isFile()) {
            file.delete();
        }
        if (!(file.exists() || file.mkdirs())) {
            return false;
        }
        long uptimeMillis = SystemClock.uptimeMillis();
        String[] strArr = MANDATORY_LIBRARIES;
        for (String str : strArr) {
            try {
                Log.d(TAG, "Decompressing " + str);
                extractLzmaToFile(openRawResource(str), new File(privateDataDir, str));
            } catch (Resources.NotFoundException unused) {
                Log.d(TAG, str + " not found");
                return false;
            } catch (IOException e) {
                Log.e(TAG, e.getLocalizedMessage());
                return false;
            }
        }
        StringBuilder j = b2.j("Time to decompress : ");
        j.append(SystemClock.uptimeMillis() - uptimeMillis);
        j.append(" ms");
        Log.d(TAG, j.toString());
        return true;
    }

    public static boolean decompressResource(String str, String str2) {
        Throwable th;
        IOException e;
        Log.d(TAG, "Decompress resource from Apk " + str);
        long uptimeMillis = SystemClock.uptimeMillis();
        String[] strArr = MANDATORY_RESOURCES;
        ArrayList arrayList = new ArrayList(strArr.length);
        ExecutorService newFixedThreadPool = Executors.newFixedThreadPool(strArr.length);
        ZipFile zipFile = null;
        try {
            ZipFile zipFile2 = new ZipFile(str);
            try {
                for (String str3 : strArr) {
                    ZipEntry entry = zipFile2.getEntry("assets" + File.separator + str3 + ".lzma");
                    if (entry == null) {
                        Log.e(TAG, str3 + " not found");
                        try {
                            zipFile2.close();
                        } catch (IOException | NullPointerException unused) {
                        }
                        return false;
                    }
                    arrayList.add(new DecompressResourceTask(zipFile2, entry, new File(str2, str3)));
                }
                try {
                    boolean z = true;
                    for (Future future : newFixedThreadPool.invokeAll(arrayList)) {
                        z &= ((Boolean) future.get()).booleanValue();
                    }
                    try {
                        zipFile2.close();
                    } catch (IOException | NullPointerException unused2) {
                    }
                    StringBuilder j = b2.j("Time to decompress : ");
                    j.append(SystemClock.uptimeMillis() - uptimeMillis);
                    j.append(" ms");
                    Log.d(TAG, j.toString());
                    return z;
                } catch (InterruptedException | ExecutionException | RejectedExecutionException unused3) {
                    Log.d(TAG, "Failed to execute decompression");
                    try {
                        zipFile2.close();
                    } catch (IOException | NullPointerException unused4) {
                    }
                    return false;
                } finally {
                    newFixedThreadPool.shutdown();
                }
            } catch (IOException e2) {
                e = e2;
                zipFile = zipFile2;
                try {
                    Log.d(TAG, e.getLocalizedMessage());
                    try {
                        zipFile.close();
                    } catch (IOException | NullPointerException unused5) {
                    }
                    return false;
                } catch (Throwable th2) {
                    th = th2;
                    zipFile2 = zipFile;
                    try {
                        zipFile2.close();
                    } catch (IOException | NullPointerException unused6) {
                    }
                    throw th;
                }
            } catch (Throwable th3) {
                th = th3;
                zipFile2.close();
                throw th;
            }
        } catch (IOException e3) {
            e = e3;
            Log.d(TAG, e.getLocalizedMessage());
            zipFile.close();
            return false;
        }
    }

    /* access modifiers changed from: private */
    /* JADX WARNING: Can't wrap try/catch for region: R(7:20|21|22|23|24|25|59) */
    /* JADX WARNING: Can't wrap try/catch for region: R(9:46|47|48|49|50|51|52|53|55) */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:22:0x0049 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:24:0x004c */
    /* JADX WARNING: Missing exception handler attribute for start block: B:50:0x0087 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:52:0x008a */
    /* JADX WARNING: Removed duplicated region for block: B:44:0x007e A[Catch:{ all -> 0x0082 }] */
    public static void extractLzmaToFile(InputStream inputStream, File file) {
        Throwable th;
        BufferedInputStream bufferedInputStream;
        BufferedOutputStream bufferedOutputStream;
        IOException e;
        BufferedOutputStream bufferedOutputStream2 = null;
        try {
            bufferedInputStream = new BufferedInputStream(inputStream);
            try {
                bufferedOutputStream = new BufferedOutputStream(new FileOutputStream(file));
            } catch (IOException e2) {
                e = e2;
                bufferedOutputStream = null;
                try {
                    if (file.isFile()) {
                    }
                    throw e;
                } catch (Throwable th2) {
                    th = th2;
                    bufferedOutputStream2 = bufferedOutputStream;
                    bufferedOutputStream2.flush();
                    bufferedOutputStream2.close();
                    try {
                        bufferedInputStream.close();
                    } catch (IOException | NullPointerException unused) {
                    }
                    throw th;
                }
            } catch (Throwable th3) {
                th = th3;
                bufferedOutputStream2.flush();
                bufferedOutputStream2.close();
                bufferedInputStream.close();
                throw th;
            }
            try {
                byte[] bArr = new byte[5];
                if (bufferedInputStream.read(bArr, 0, 5) == 5) {
                    c cVar = new c();
                    if (cVar.b(bArr)) {
                        long j = 0;
                        for (int i = 0; i < 8; i++) {
                            int read = bufferedInputStream.read();
                            if (read < 0) {
                                Log.w(TAG, "Can't read stream size");
                            }
                            j |= ((long) read) << (i * 8);
                        }
                        if (cVar.a(bufferedInputStream, bufferedOutputStream, j)) {
                            bufferedOutputStream.flush();
                            bufferedOutputStream.close();
                            try {
                                bufferedInputStream.close();
                            } catch (IOException | NullPointerException unused2) {
                            }
                        } else {
                            throw new IOException("Error in data stream");
                        }
                    } else {
                        throw new IOException("Incorrect lzma properties");
                    }
                } else {
                    throw new IOException("Input lzma file is too short");
                }
            } catch (IOException e3) {
                e = e3;
                if (file.isFile()) {
                    file.delete();
                }
                throw e;
            }
        } catch (IOException e4) {
            bufferedInputStream = null;
            e = e4;
            bufferedOutputStream = null;
            if (file.isFile()) {
            }
            throw e;
        } catch (Throwable th4) {
            th = th4;
            bufferedInputStream = null;
            bufferedOutputStream2.flush();
            bufferedOutputStream2.close();
            bufferedInputStream.close();
            throw th;
        }
    }

    public static boolean extractResource(String str, String str2) {
        Throwable th;
        IOException e;
        ZipEntry zipEntry;
        Log.d(TAG, "Extract resource from Apk " + str);
        long uptimeMillis = SystemClock.uptimeMillis();
        ZipFile zipFile = null;
        try {
            ZipFile zipFile2 = new ZipFile(str);
            try {
                String[] strArr = MANDATORY_RESOURCES;
                for (String str3 : strArr) {
                    if (isNativeLibrary(str3)) {
                        String deviceAbi = XWalkEnvironment.getDeviceAbi();
                        StringBuilder sb = new StringBuilder();
                        sb.append("lib");
                        String str4 = File.separator;
                        sb.append(str4);
                        sb.append(deviceAbi);
                        sb.append(str4);
                        sb.append(str3);
                        zipEntry = zipFile2.getEntry(sb.toString());
                        if (zipEntry == null && XWalkEnvironment.is64bitDevice()) {
                            if (deviceAbi.equals("arm64-v8a")) {
                                deviceAbi = "armeabi-v7a";
                            } else if (deviceAbi.equals("x86_64")) {
                                deviceAbi = "x86";
                            }
                            zipEntry = zipFile2.getEntry("lib" + str4 + deviceAbi + str4 + str3);
                        }
                    } else if (isAsset(str3)) {
                        zipEntry = zipFile2.getEntry("assets" + File.separator + str3);
                    } else {
                        zipEntry = zipFile2.getEntry(str3);
                    }
                    if (zipEntry == null) {
                        Log.e(TAG, str3 + " not found");
                        try {
                            zipFile2.close();
                        } catch (IOException | NullPointerException unused) {
                        }
                        return false;
                    }
                    Log.d(TAG, "Extracting " + str3);
                    extractStreamToFile(zipFile2.getInputStream(zipEntry), new File(str2, str3));
                }
                try {
                    zipFile2.close();
                } catch (IOException | NullPointerException unused2) {
                }
                StringBuilder j = b2.j("Time to extract : ");
                j.append(SystemClock.uptimeMillis() - uptimeMillis);
                j.append(" ms");
                Log.d(TAG, j.toString());
                return true;
            } catch (IOException e2) {
                e = e2;
                zipFile = zipFile2;
                try {
                    Log.d(TAG, e.getLocalizedMessage());
                    try {
                        zipFile.close();
                    } catch (IOException | NullPointerException unused3) {
                    }
                    return false;
                } catch (Throwable th2) {
                    th = th2;
                    zipFile2 = zipFile;
                    try {
                        zipFile2.close();
                    } catch (IOException | NullPointerException unused4) {
                    }
                    throw th;
                }
            } catch (Throwable th3) {
                th = th3;
                zipFile2.close();
                throw th;
            }
        } catch (IOException e3) {
            e = e3;
            Log.d(TAG, e.getLocalizedMessage());
            zipFile.close();
            return false;
        }
    }

    /* JADX WARNING: Can't wrap try/catch for region: R(7:9|10|11|12|13|14|35) */
    /* JADX WARNING: Can't wrap try/catch for region: R(9:25|26|27|28|29|30|31|32|34) */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:11:0x001b */
    /* JADX WARNING: Missing exception handler attribute for start block: B:13:0x001e */
    /* JADX WARNING: Missing exception handler attribute for start block: B:29:0x0039 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:31:0x003c */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x0030 A[Catch:{ all -> 0x0034 }] */
    private static void extractStreamToFile(InputStream inputStream, File file) {
        Throwable th;
        FileOutputStream fileOutputStream;
        IOException e;
        FileOutputStream fileOutputStream2 = null;
        try {
            inputStream.available();
            fileOutputStream = new FileOutputStream(file);
            try {
                byte[] bArr = new byte[4096];
                while (true) {
                    int read = inputStream.read(bArr);
                    if (read >= 0) {
                        fileOutputStream.write(bArr, 0, read);
                    } else {
                        fileOutputStream.flush();
                        fileOutputStream.close();
                        try {
                            inputStream.close();
                            return;
                        } catch (IOException | NullPointerException unused) {
                            return;
                        }
                    }
                }
            } catch (IOException e2) {
                e = e2;
                try {
                    if (file.isFile()) {
                    }
                    throw e;
                } catch (Throwable th2) {
                    th = th2;
                    fileOutputStream2 = fileOutputStream;
                    fileOutputStream2.flush();
                    fileOutputStream2.close();
                    try {
                        inputStream.close();
                    } catch (IOException | NullPointerException unused2) {
                    }
                    throw th;
                }
            }
        } catch (IOException e3) {
            fileOutputStream = null;
            e = e3;
            if (file.isFile()) {
                file.delete();
            }
            throw e;
        } catch (Throwable th3) {
            th = th3;
            fileOutputStream2.flush();
            fileOutputStream2.close();
            inputStream.close();
            throw th;
        }
    }

    private static boolean isAsset(String str) {
        return str.endsWith(".dat") || str.endsWith(".pak");
    }

    public static boolean isLibraryCompressed() {
        for (String str : MANDATORY_LIBRARIES) {
            try {
                try {
                    openRawResource(str).close();
                } catch (IOException unused) {
                }
            } catch (Resources.NotFoundException unused2) {
                return false;
            }
        }
        return true;
    }

    private static boolean isNativeLibrary(String str) {
        return str.endsWith(".so");
    }

    /* JADX WARNING: Missing exception handler attribute for start block: B:25:0x0046 */
    public static boolean isResourceCompressed(String str) {
        ZipFile zipFile;
        Throwable th;
        zipFile = null;
        try {
            ZipFile zipFile2 = new ZipFile(str);
            try {
                String[] strArr = MANDATORY_RESOURCES;
                for (String str2 : strArr) {
                    if (zipFile2.getEntry("assets" + File.separator + str2 + ".lzma") == null) {
                        try {
                            zipFile2.close();
                        } catch (IOException | NullPointerException unused) {
                        }
                        return false;
                    }
                }
                try {
                    zipFile2.close();
                    return true;
                } catch (IOException | NullPointerException unused2) {
                    return true;
                }
            } catch (IOException unused3) {
                zipFile = zipFile2;
                try {
                    zipFile.close();
                } catch (IOException | NullPointerException unused4) {
                }
                return false;
            } catch (Throwable th2) {
                th = th2;
                zipFile = zipFile2;
                try {
                    zipFile.close();
                } catch (IOException | NullPointerException unused5) {
                }
                throw th;
            }
        } catch (IOException unknown) {
            zipFile.close();
            return false;
        } catch (Throwable th3) {
            th = th3;
            zipFile.close();
            throw th;
        }
    }

    private static InputStream openRawResource(String str) {
        Context applicationContext = XWalkEnvironment.getApplicationContext();
        Resources resources = applicationContext.getResources();
        return resources.openRawResource(resources.getIdentifier(str.split("\\.")[0], "raw", applicationContext.getPackageName()));
    }
}
