package org.xwalk.core;

import java.util.ArrayList;

public class XWalkJavascriptResultHandler implements XWalkJavascriptResult {
    private Object bridge;
    private ReflectMethod cancelMethod = new ReflectMethod((Class<?>) null, "cancel", (Class<?>[]) new Class[0]);
    private ReflectMethod confirmMethod = new ReflectMethod((Class<?>) null, "confirm", (Class<?>[]) new Class[0]);
    private ReflectMethod confirmWithResultStringMethod = new ReflectMethod((Class<?>) null, "confirmWithResult", (Class<?>[]) new Class[0]);
    private ArrayList<Object> constructorParams;
    private ArrayList<Object> constructorTypes;
    private XWalkCoreWrapper coreWrapper;
    private ReflectMethod postWrapperMethod;

    public XWalkJavascriptResultHandler(Object obj) {
        this.bridge = obj;
        reflectionInit();
    }

    @Override // org.xwalk.core.XWalkJavascriptResult
    public void cancel() {
        try {
            this.cancelMethod.invoke(new Object[0]);
        } catch (UnsupportedOperationException e) {
            if (this.coreWrapper != null) {
                XWalkCoreWrapper.handleRuntimeError(e);
                return;
            }
            throw new RuntimeException("Crosswalk's APIs are not ready yet");
        }
    }

    @Override // org.xwalk.core.XWalkJavascriptResult
    public void confirm() {
        try {
            this.confirmMethod.invoke(new Object[0]);
        } catch (UnsupportedOperationException e) {
            if (this.coreWrapper != null) {
                XWalkCoreWrapper.handleRuntimeError(e);
                return;
            }
            throw new RuntimeException("Crosswalk's APIs are not ready yet");
        }
    }

    @Override // org.xwalk.core.XWalkJavascriptResult
    public void confirmWithResult(String str) {
        try {
            this.confirmWithResultStringMethod.invoke(str);
        } catch (UnsupportedOperationException e) {
            if (this.coreWrapper != null) {
                XWalkCoreWrapper.handleRuntimeError(e);
                return;
            }
            throw new RuntimeException("Crosswalk's APIs are not ready yet");
        }
    }

    public Object getBridge() {
        return this.bridge;
    }

    public void reflectionInit() {
        XWalkCoreWrapper.initEmbeddedMode();
        XWalkCoreWrapper instance = XWalkCoreWrapper.getInstance();
        this.coreWrapper = instance;
        if (instance == null) {
            XWalkCoreWrapper.reserveReflectObject(this);
            return;
        }
        this.confirmMethod.init(this.bridge, null, "confirmSuper", new Class[0]);
        this.confirmWithResultStringMethod.init(this.bridge, null, "confirmWithResultSuper", String.class);
        this.cancelMethod.init(this.bridge, null, "cancelSuper", new Class[0]);
    }
}
