package org.xwalk.core;

import java.util.ArrayList;

public class XWalkNavigationHistory {
    private Object bridge;
    private ReflectMethod canGoBackMethod = new ReflectMethod((Class<?>) null, "canGoBack", (Class<?>[]) new Class[0]);
    private ReflectMethod canGoForwardMethod = new ReflectMethod((Class<?>) null, "canGoForward", (Class<?>[]) new Class[0]);
    private ReflectMethod clearMethod = new ReflectMethod((Class<?>) null, "clear", (Class<?>[]) new Class[0]);
    private ArrayList<Object> constructorParams;
    private ArrayList<Object> constructorTypes;
    private XWalkCoreWrapper coreWrapper;
    private ReflectMethod enumDirectionClassValueOfMethod = new ReflectMethod();
    private ReflectMethod getCurrentIndexMethod = new ReflectMethod((Class<?>) null, "getCurrentIndex", (Class<?>[]) new Class[0]);
    private ReflectMethod getCurrentItemMethod = new ReflectMethod((Class<?>) null, "getCurrentItem", (Class<?>[]) new Class[0]);
    private ReflectMethod getItemAtintMethod = new ReflectMethod((Class<?>) null, "getItemAt", (Class<?>[]) new Class[0]);
    private ReflectMethod hasItemAtintMethod = new ReflectMethod((Class<?>) null, "hasItemAt", (Class<?>[]) new Class[0]);
    private ReflectMethod navigateDirectionInternalintMethod = new ReflectMethod((Class<?>) null, "navigate", (Class<?>[]) new Class[0]);
    private ReflectMethod postWrapperMethod;
    private ReflectMethod sizeMethod = new ReflectMethod((Class<?>) null, "size", (Class<?>[]) new Class[0]);

    public enum Direction {
        BACKWARD,
        FORWARD
    }

    public XWalkNavigationHistory(Object obj) {
        this.bridge = obj;
        reflectionInit();
    }

    private Object ConvertDirection(Direction direction) {
        return this.enumDirectionClassValueOfMethod.invoke(direction.toString());
    }

    public boolean canGoBack() {
        try {
            return ((Boolean) this.canGoBackMethod.invoke(new Object[0])).booleanValue();
        } catch (UnsupportedOperationException e) {
            if (this.coreWrapper != null) {
                XWalkCoreWrapper.handleRuntimeError(e);
                return false;
            }
            throw new RuntimeException("Crosswalk's APIs are not ready yet");
        }
    }

    public boolean canGoForward() {
        try {
            return ((Boolean) this.canGoForwardMethod.invoke(new Object[0])).booleanValue();
        } catch (UnsupportedOperationException e) {
            if (this.coreWrapper != null) {
                XWalkCoreWrapper.handleRuntimeError(e);
                return false;
            }
            throw new RuntimeException("Crosswalk's APIs are not ready yet");
        }
    }

    public void clear() {
        try {
            this.clearMethod.invoke(new Object[0]);
        } catch (UnsupportedOperationException e) {
            if (this.coreWrapper != null) {
                XWalkCoreWrapper.handleRuntimeError(e);
                return;
            }
            throw new RuntimeException("Crosswalk's APIs are not ready yet");
        }
    }

    public Object getBridge() {
        return this.bridge;
    }

    public int getCurrentIndex() {
        try {
            return ((Integer) this.getCurrentIndexMethod.invoke(new Object[0])).intValue();
        } catch (UnsupportedOperationException e) {
            if (this.coreWrapper != null) {
                XWalkCoreWrapper.handleRuntimeError(e);
                return 0;
            }
            throw new RuntimeException("Crosswalk's APIs are not ready yet");
        }
    }

    public XWalkNavigationItem getCurrentItem() {
        try {
            return (XWalkNavigationItem) this.coreWrapper.getWrapperObject(this.getCurrentItemMethod.invoke(new Object[0]));
        } catch (UnsupportedOperationException e) {
            if (this.coreWrapper != null) {
                XWalkCoreWrapper.handleRuntimeError(e);
                return null;
            }
            throw new RuntimeException("Crosswalk's APIs are not ready yet");
        }
    }

    public XWalkNavigationItem getItemAt(int i) {
        try {
            return (XWalkNavigationItem) this.coreWrapper.getWrapperObject(this.getItemAtintMethod.invoke(Integer.valueOf(i)));
        } catch (UnsupportedOperationException e) {
            if (this.coreWrapper != null) {
                XWalkCoreWrapper.handleRuntimeError(e);
                return null;
            }
            throw new RuntimeException("Crosswalk's APIs are not ready yet");
        }
    }

    public boolean hasItemAt(int i) {
        try {
            return ((Boolean) this.hasItemAtintMethod.invoke(Integer.valueOf(i))).booleanValue();
        } catch (UnsupportedOperationException e) {
            if (this.coreWrapper != null) {
                XWalkCoreWrapper.handleRuntimeError(e);
                return false;
            }
            throw new RuntimeException("Crosswalk's APIs are not ready yet");
        }
    }

    public void navigate(Direction direction, int i) {
        try {
            this.navigateDirectionInternalintMethod.invoke(ConvertDirection(direction), Integer.valueOf(i));
        } catch (UnsupportedOperationException e) {
            if (this.coreWrapper != null) {
                XWalkCoreWrapper.handleRuntimeError(e);
                return;
            }
            throw new RuntimeException("Crosswalk's APIs are not ready yet");
        }
    }

    public void reflectionInit() {
        XWalkCoreWrapper.initEmbeddedMode();
        XWalkCoreWrapper instance = XWalkCoreWrapper.getInstance();
        this.coreWrapper = instance;
        if (instance == null) {
            XWalkCoreWrapper.reserveReflectObject(this);
            return;
        }
        this.enumDirectionClassValueOfMethod.init(null, instance.getBridgeClass("XWalkNavigationHistoryInternal$DirectionInternal"), "valueOf", String.class);
        this.sizeMethod.init(this.bridge, null, "sizeSuper", new Class[0]);
        ReflectMethod reflectMethod = this.hasItemAtintMethod;
        Object obj = this.bridge;
        Class<?> cls = Integer.TYPE;
        reflectMethod.init(obj, null, "hasItemAtSuper", cls);
        this.getItemAtintMethod.init(this.bridge, null, "getItemAtSuper", cls);
        this.getCurrentItemMethod.init(this.bridge, null, "getCurrentItemSuper", new Class[0]);
        this.canGoBackMethod.init(this.bridge, null, "canGoBackSuper", new Class[0]);
        this.canGoForwardMethod.init(this.bridge, null, "canGoForwardSuper", new Class[0]);
        this.navigateDirectionInternalintMethod.init(this.bridge, null, "navigateSuper", this.coreWrapper.getBridgeClass("XWalkNavigationHistoryInternal$DirectionInternal"), cls);
        this.getCurrentIndexMethod.init(this.bridge, null, "getCurrentIndexSuper", new Class[0]);
        this.clearMethod.init(this.bridge, null, "clearSuper", new Class[0]);
    }

    public int size() {
        try {
            return ((Integer) this.sizeMethod.invoke(new Object[0])).intValue();
        } catch (UnsupportedOperationException e) {
            if (this.coreWrapper != null) {
                XWalkCoreWrapper.handleRuntimeError(e);
                return 0;
            }
            throw new RuntimeException("Crosswalk's APIs are not ready yet");
        }
    }
}
