package org.xwalk.core;

import java.util.ArrayList;

public class XWalkNavigationItem {
    private Object bridge;
    private ArrayList<Object> constructorParams;
    private ArrayList<Object> constructorTypes;
    private XWalkCoreWrapper coreWrapper;
    private ReflectMethod getOriginalUrlMethod = new ReflectMethod((Class<?>) null, "getOriginalUrl", (Class<?>[]) new Class[0]);
    private ReflectMethod getTitleMethod = new ReflectMethod((Class<?>) null, "getTitle", (Class<?>[]) new Class[0]);
    private ReflectMethod getUrlMethod = new ReflectMethod((Class<?>) null, "getUrl", (Class<?>[]) new Class[0]);
    private ReflectMethod postWrapperMethod;

    public XWalkNavigationItem(Object obj) {
        this.bridge = obj;
        reflectionInit();
    }

    public Object getBridge() {
        return this.bridge;
    }

    public String getOriginalUrl() {
        try {
            return (String) this.getOriginalUrlMethod.invoke(new Object[0]);
        } catch (UnsupportedOperationException e) {
            if (this.coreWrapper != null) {
                XWalkCoreWrapper.handleRuntimeError(e);
                return null;
            }
            throw new RuntimeException("Crosswalk's APIs are not ready yet");
        }
    }

    public String getTitle() {
        try {
            return (String) this.getTitleMethod.invoke(new Object[0]);
        } catch (UnsupportedOperationException e) {
            if (this.coreWrapper != null) {
                XWalkCoreWrapper.handleRuntimeError(e);
                return null;
            }
            throw new RuntimeException("Crosswalk's APIs are not ready yet");
        }
    }

    public String getUrl() {
        try {
            return (String) this.getUrlMethod.invoke(new Object[0]);
        } catch (UnsupportedOperationException e) {
            if (this.coreWrapper != null) {
                XWalkCoreWrapper.handleRuntimeError(e);
                return null;
            }
            throw new RuntimeException("Crosswalk's APIs are not ready yet");
        }
    }

    public void reflectionInit() {
        XWalkCoreWrapper.initEmbeddedMode();
        XWalkCoreWrapper instance = XWalkCoreWrapper.getInstance();
        this.coreWrapper = instance;
        if (instance == null) {
            XWalkCoreWrapper.reserveReflectObject(this);
            return;
        }
        this.getUrlMethod.init(this.bridge, null, "getUrlSuper", new Class[0]);
        this.getOriginalUrlMethod.init(this.bridge, null, "getOriginalUrlSuper", new Class[0]);
        this.getTitleMethod.init(this.bridge, null, "getTitleSuper", new Class[0]);
    }
}
