package org.xwalk.core;

public class XWalkPreferences {
    public static final String ALLOW_UNIVERSAL_ACCESS_FROM_FILE = "allow-universal-access-from-file";
    public static final String ANIMATABLE_XWALK_VIEW = "animatable-xwalk-view";
    public static final String ENABLE_EXTENSIONS = "enable-extensions";
    public static final String ENABLE_JAVASCRIPT = "enable-javascript";
    public static final String ENABLE_THEME_COLOR = "enable-theme-color";
    public static final String JAVASCRIPT_CAN_OPEN_WINDOW = "javascript-can-open-window";
    public static final String PROFILE_NAME = "profile-name";
    public static final String REMOTE_DEBUGGING = "remote-debugging";
    public static final String SPATIAL_NAVIGATION = "enable-spatial-navigation";
    public static final String SUPPORT_MULTIPLE_WINDOWS = "support-multiple-windows";
    private static XWalkCoreWrapper coreWrapper;
    private static ReflectMethod getBooleanValueStringMethod = new ReflectMethod((Class<?>) null, "getBooleanValue", (Class<?>[]) new Class[0]);
    private static ReflectMethod getIntegerValueStringMethod = new ReflectMethod((Class<?>) null, "getIntegerValue", (Class<?>[]) new Class[0]);
    private static ReflectMethod getStringValueStringMethod = new ReflectMethod((Class<?>) null, "getStringValue", (Class<?>[]) new Class[0]);
    private static ReflectMethod getValueStringMethod = new ReflectMethod((Class<?>) null, "getValue", (Class<?>[]) new Class[0]);
    private static ReflectMethod setValueStringStringMethod = new ReflectMethod((Class<?>) null, "setValue", (Class<?>[]) new Class[0]);
    private static ReflectMethod setValueStringbooleanMethod = new ReflectMethod((Class<?>) null, "setValue", (Class<?>[]) new Class[0]);
    private static ReflectMethod setValueStringintMethod = new ReflectMethod((Class<?>) null, "setValue", (Class<?>[]) new Class[0]);

    public static boolean getBooleanValue(String str) {
        reflectionInit();
        try {
            return ((Boolean) getBooleanValueStringMethod.invoke(str)).booleanValue();
        } catch (UnsupportedOperationException e) {
            if (coreWrapper != null) {
                XWalkCoreWrapper.handleRuntimeError(e);
                return false;
            }
            throw new RuntimeException("Crosswalk's APIs are not ready yet");
        }
    }

    public static int getIntegerValue(String str) {
        reflectionInit();
        try {
            return ((Integer) getIntegerValueStringMethod.invoke(str)).intValue();
        } catch (UnsupportedOperationException e) {
            if (coreWrapper != null) {
                XWalkCoreWrapper.handleRuntimeError(e);
                return 0;
            }
            throw new RuntimeException("Crosswalk's APIs are not ready yet");
        }
    }

    public static String getStringValue(String str) {
        reflectionInit();
        try {
            return (String) getStringValueStringMethod.invoke(str);
        } catch (UnsupportedOperationException e) {
            if (coreWrapper != null) {
                XWalkCoreWrapper.handleRuntimeError(e);
                return null;
            }
            throw new RuntimeException("Crosswalk's APIs are not ready yet");
        }
    }

    public static boolean getValue(String str) {
        reflectionInit();
        try {
            return ((Boolean) getValueStringMethod.invoke(str)).booleanValue();
        } catch (UnsupportedOperationException e) {
            if (coreWrapper != null) {
                XWalkCoreWrapper.handleRuntimeError(e);
                return false;
            }
            throw new RuntimeException("Crosswalk's APIs are not ready yet");
        }
    }

    public static void reflectionInit() {
        if (coreWrapper == null) {
            XWalkCoreWrapper.initEmbeddedMode();
            XWalkCoreWrapper instance = XWalkCoreWrapper.getInstance();
            coreWrapper = instance;
            if (instance == null) {
                XWalkCoreWrapper.reserveReflectClass(XWalkPreferences.class);
                return;
            }
            Class<?> bridgeClass = instance.getBridgeClass("XWalkPreferencesBridge");
            setValueStringbooleanMethod.init(null, bridgeClass, "setValue", String.class, Boolean.TYPE);
            setValueStringintMethod.init(null, bridgeClass, "setValue", String.class, Integer.TYPE);
            setValueStringStringMethod.init(null, bridgeClass, "setValue", String.class, String.class);
            getValueStringMethod.init(null, bridgeClass, "getValue", String.class);
            getBooleanValueStringMethod.init(null, bridgeClass, "getBooleanValue", String.class);
            getIntegerValueStringMethod.init(null, bridgeClass, "getIntegerValue", String.class);
            getStringValueStringMethod.init(null, bridgeClass, "getStringValue", String.class);
        }
    }

    public static void setValue(String str, boolean z) {
        reflectionInit();
        try {
            setValueStringbooleanMethod.invoke(str, Boolean.valueOf(z));
        } catch (UnsupportedOperationException e) {
            if (coreWrapper == null) {
                setValueStringbooleanMethod.setArguments(str, Boolean.valueOf(z));
                XWalkCoreWrapper.reserveReflectMethod(setValueStringbooleanMethod);
                return;
            }
            XWalkCoreWrapper.handleRuntimeError(e);
        }
    }

    public static void setValue(String str, int i) {
        reflectionInit();
        try {
            setValueStringintMethod.invoke(str, Integer.valueOf(i));
        } catch (UnsupportedOperationException e) {
            if (coreWrapper == null) {
                setValueStringintMethod.setArguments(str, Integer.valueOf(i));
                XWalkCoreWrapper.reserveReflectMethod(setValueStringintMethod);
                return;
            }
            XWalkCoreWrapper.handleRuntimeError(e);
        }
    }

    public static void setValue(String str, String str2) {
        reflectionInit();
        try {
            setValueStringStringMethod.invoke(str, str2);
        } catch (UnsupportedOperationException e) {
            if (coreWrapper == null) {
                setValueStringStringMethod.setArguments(str, str2);
                XWalkCoreWrapper.reserveReflectMethod(setValueStringStringMethod);
                return;
            }
            XWalkCoreWrapper.handleRuntimeError(e);
        }
    }
}
