package org.xwalk.core;

import android.content.ActivityNotFoundException;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.content.pm.ResolveInfo;
import android.content.pm.Signature;
import android.net.Uri;
import android.os.AsyncTask;
import android.util.Log;
import java.io.File;
import java.util.List;
import org.xwalk.core.XWalkLibraryLoader;

public class XWalkUpdater {
    private static final String ANDROID_MARKET_DETAILS = "market://details?id=";
    private static final String GOOGLE_PLAY_PACKAGE = "com.android.vending";
    private static final String TAG = "XWalkLib";
    private XWalkBackgroundUpdateListener mBackgroundUpdateListener;
    private Runnable mCancelCommand;
    private Context mContext;
    private XWalkDialogManager mDialogManager;
    private Runnable mDownloadCommand;
    private XWalkUpdateListener mUpdateListener;

    public class BackgroundListener implements XWalkLibraryLoader.DownloadListener {
        private BackgroundListener() {
        }

        @Override // org.xwalk.core.XWalkLibraryLoader.DownloadListener
        public void onDownloadCancelled() {
            XWalkUpdater.this.mBackgroundUpdateListener.onXWalkUpdateCancelled();
        }

        @Override // org.xwalk.core.XWalkLibraryLoader.DownloadListener
        public void onDownloadCompleted(Uri uri) {
            final String path = uri.getPath();
            final String extractedCoreDir = XWalkEnvironment.getExtractedCoreDir();
            Log.d(XWalkUpdater.TAG, "Download mode extract dir: " + extractedCoreDir);
            new AsyncTask<Void, Void, Boolean>() {
                /* class org.xwalk.core.XWalkUpdater.BackgroundListener.AnonymousClass1 */

                public Boolean doInBackground(Void... voidArr) {
                    if (XWalkEnvironment.isXWalkVerify() && !XWalkUpdater.this.verifyDownloadedXWalkRuntime(path)) {
                        return Boolean.FALSE;
                    }
                    if (XWalkDecompressor.isResourceCompressed(path)) {
                        if (!XWalkDecompressor.decompressResource(path, extractedCoreDir)) {
                            return Boolean.FALSE;
                        }
                    } else if (!XWalkDecompressor.extractResource(path, extractedCoreDir)) {
                        return Boolean.FALSE;
                    }
                    return Boolean.TRUE;
                }

                public void onPostExecute(Boolean bool) {
                    new File(path).delete();
                    if (!bool.booleanValue()) {
                        XWalkUpdater.this.mBackgroundUpdateListener.onXWalkUpdateFailed();
                    } else {
                        XWalkUpdater.this.mBackgroundUpdateListener.onXWalkUpdateCompleted();
                    }
                }
            }.execute(new Void[0]);
        }

        @Override // org.xwalk.core.XWalkLibraryLoader.DownloadListener
        public void onDownloadFailed(int i, int i2) {
            XWalkUpdater.this.mBackgroundUpdateListener.onXWalkUpdateFailed();
        }

        @Override // org.xwalk.core.XWalkLibraryLoader.DownloadListener
        public void onDownloadStarted() {
            XWalkUpdater.this.mBackgroundUpdateListener.onXWalkUpdateStarted();
        }

        @Override // org.xwalk.core.XWalkLibraryLoader.DownloadListener
        public void onDownloadUpdated(int i) {
            XWalkUpdater.this.mBackgroundUpdateListener.onXWalkUpdateProgress(i);
        }
    }

    public class ForegroundListener implements XWalkLibraryLoader.DownloadListener {
        private ForegroundListener() {
        }

        @Override // org.xwalk.core.XWalkLibraryLoader.DownloadListener
        public void onDownloadCancelled() {
            XWalkUpdater.this.mUpdateListener.onXWalkUpdateCancelled();
        }

        @Override // org.xwalk.core.XWalkLibraryLoader.DownloadListener
        public void onDownloadCompleted(Uri uri) {
            XWalkUpdater.this.mDialogManager.dismissDialog();
            Log.d(XWalkUpdater.TAG, "Install the Crosswalk runtime: " + uri.toString());
            Intent intent = new Intent("android.intent.action.VIEW");
            intent.setFlags(268435456);
            intent.setDataAndType(uri, "application/vnd.android.package-archive");
            XWalkUpdater.this.mContext.startActivity(intent);
        }

        @Override // org.xwalk.core.XWalkLibraryLoader.DownloadListener
        public void onDownloadFailed(int i, int i2) {
            XWalkUpdater.this.mDialogManager.dismissDialog();
            XWalkUpdater.this.mDialogManager.showDownloadError(XWalkUpdater.this.mCancelCommand, XWalkUpdater.this.mDownloadCommand);
        }

        @Override // org.xwalk.core.XWalkLibraryLoader.DownloadListener
        public void onDownloadStarted() {
            XWalkUpdater.this.mDialogManager.showDownloadProgress(new Runnable() {
                /* class org.xwalk.core.XWalkUpdater.ForegroundListener.AnonymousClass1 */

                public void run() {
                    XWalkLibraryLoader.cancelDownloadManager();
                }
            });
        }

        @Override // org.xwalk.core.XWalkLibraryLoader.DownloadListener
        public void onDownloadUpdated(int i) {
            XWalkUpdater.this.mDialogManager.setProgress(i, 100);
        }
    }

    public interface XWalkBackgroundUpdateListener {
        void onXWalkUpdateCancelled();

        void onXWalkUpdateCompleted();

        void onXWalkUpdateFailed();

        void onXWalkUpdateProgress(int i);

        void onXWalkUpdateStarted();
    }

    public interface XWalkUpdateListener {
        void onXWalkUpdateCancelled();
    }

    public XWalkUpdater(XWalkUpdateListener xWalkUpdateListener, Context context) {
        this.mUpdateListener = xWalkUpdateListener;
        this.mContext = context;
        this.mDialogManager = new XWalkDialogManager(context);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void downloadXWalkApk() {
        String str;
        String xWalkApkUrl = XWalkEnvironment.getXWalkApkUrl();
        if (!xWalkApkUrl.isEmpty()) {
            XWalkLibraryLoader.startDownloadManager(new ForegroundListener(), this.mContext, xWalkApkUrl);
            return;
        }
        final Intent intent = new Intent("android.intent.action.VIEW");
        intent.setData(Uri.parse("market://details?id=org.xwalk.core"));
        List<ResolveInfo> queryIntentActivities = this.mContext.getPackageManager().queryIntentActivities(intent, 131072);
        StringBuilder sb = new StringBuilder();
        boolean z = false;
        Log.d(TAG, "Available Stores:");
        for (ResolveInfo resolveInfo : queryIntentActivities) {
            Log.d(TAG, resolveInfo.activityInfo.packageName);
            z |= resolveInfo.activityInfo.packageName.equals(GOOGLE_PLAY_PACKAGE);
            String storeName = getStoreName(resolveInfo.activityInfo.packageName);
            if (storeName != null) {
                if (sb.length() > 0) {
                    sb.append("/");
                }
                sb.append(storeName);
            }
        }
        if (sb.length() == 0) {
            this.mDialogManager.showUnsupportedStore(this.mCancelCommand);
            return;
        }
        if (z || !XWalkEnvironment.isIaDevice()) {
            str = XWalkEnvironment.is64bitApp() ? XWalkLibraryInterface.XWALK_CORE64_PACKAGE : XWalkLibraryInterface.XWALK_CORE_PACKAGE;
        } else {
            str = XWalkEnvironment.is64bitApp() ? XWalkLibraryInterface.XWALK_CORE64_IA_PACKAGE : XWalkLibraryInterface.XWALK_CORE_IA_PACKAGE;
        }
        Log.d(TAG, "Package name of Crosswalk to download: " + str);
        intent.setData(Uri.parse(ANDROID_MARKET_DETAILS + str));
        String storeName2 = z ? getStoreName(GOOGLE_PLAY_PACKAGE) : sb.toString();
        Log.d(TAG, "Supported Stores: " + storeName2);
        this.mDialogManager.showSelectStore(new Runnable() {
            /* class org.xwalk.core.XWalkUpdater.AnonymousClass3 */

            public void run() {
                try {
                    XWalkUpdater.this.mContext.startActivity(intent);
                } catch (ActivityNotFoundException unused) {
                    XWalkUpdater.this.mDialogManager.showUnsupportedStore(XWalkUpdater.this.mCancelCommand);
                }
            }
        }, storeName2);
    }

    private String getStoreName(String str) {
        if (str.equals(GOOGLE_PLAY_PACKAGE)) {
            return this.mContext.getString(R.string.google_play_store);
        }
        return null;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean verifyDownloadedXWalkRuntime(String str) {
        Signature[] signatureArr;
        PackageInfo packageArchiveInfo = this.mContext.getPackageManager().getPackageArchiveInfo(str, 64);
        if (packageArchiveInfo == null) {
            Log.e(TAG, "The downloaded XWalkRuntimeLib.apk is invalid!");
            return false;
        }
        try {
            PackageInfo packageInfo = this.mContext.getPackageManager().getPackageInfo(this.mContext.getPackageName(), 64);
            Signature[] signatureArr2 = packageArchiveInfo.signatures;
            if (signatureArr2 == null || (signatureArr = packageInfo.signatures) == null) {
                Log.e(TAG, "No signature in package info");
                return false;
            } else if (signatureArr2.length != signatureArr.length) {
                Log.e(TAG, "signatures length not equal");
                return false;
            } else {
                for (int i = 0; i < packageArchiveInfo.signatures.length; i++) {
                    Log.d(TAG, "Checking signature " + i);
                    if (!packageInfo.signatures[i].equals(packageArchiveInfo.signatures[i])) {
                        Log.e(TAG, "signatures do not match");
                        return false;
                    }
                }
                Log.d(TAG, "Signature check passed");
                return true;
            }
        } catch (PackageManager.NameNotFoundException unused) {
        }
    }

    public boolean cancelBackgroundDownload() {
        return XWalkLibraryLoader.cancelHttpDownload();
    }

    public boolean dismissDialog() {
        XWalkDialogManager xWalkDialogManager = this.mDialogManager;
        if (xWalkDialogManager == null || !xWalkDialogManager.isShowingDialog()) {
            return false;
        }
        this.mDialogManager.dismissDialog();
        return true;
    }

    public void setXWalkApkUrl(String str) {
        XWalkEnvironment.setXWalkApkUrl(str);
    }

    public boolean updateXWalkRuntime() {
        if (XWalkLibraryLoader.isInitializing() || XWalkLibraryLoader.isDownloading()) {
            Log.d(TAG, "Other initialization or download is proceeding");
            return false;
        } else if (XWalkLibraryLoader.isLibraryReady()) {
            Log.d(TAG, "Initialization has been completed. Do not need to update");
            return false;
        } else {
            int libraryStatus = XWalkLibraryLoader.getLibraryStatus();
            if (libraryStatus == 0) {
                throw new RuntimeException("Must invoke XWalkInitializer.initAsync() first");
            } else if (this.mUpdateListener != null) {
                this.mDownloadCommand = new Runnable() {
                    /* class org.xwalk.core.XWalkUpdater.AnonymousClass1 */

                    public void run() {
                        XWalkUpdater.this.downloadXWalkApk();
                    }
                };
                AnonymousClass2 r1 = new Runnable() {
                    /* class org.xwalk.core.XWalkUpdater.AnonymousClass2 */

                    public void run() {
                        Log.d(XWalkUpdater.TAG, "XWalkUpdater cancelled");
                        XWalkUpdater.this.mUpdateListener.onXWalkUpdateCancelled();
                    }
                };
                this.mCancelCommand = r1;
                this.mDialogManager.showInitializationError(libraryStatus, r1, this.mDownloadCommand);
                return true;
            } else if (this.mBackgroundUpdateListener != null) {
                XWalkLibraryLoader.startHttpDownload(new BackgroundListener(), this.mContext, XWalkEnvironment.getXWalkApkUrl());
                return true;
            } else {
                throw new IllegalArgumentException("Update listener is null");
            }
        }
    }

    public XWalkUpdater(XWalkUpdateListener xWalkUpdateListener, Context context, XWalkDialogManager xWalkDialogManager) {
        this.mUpdateListener = xWalkUpdateListener;
        this.mContext = context;
        this.mDialogManager = xWalkDialogManager;
    }

    public XWalkUpdater(XWalkBackgroundUpdateListener xWalkBackgroundUpdateListener, Context context) {
        this.mBackgroundUpdateListener = xWalkBackgroundUpdateListener;
        this.mContext = context;
    }
}
