package org.xwalk.core.extension;

import android.util.Log;
import androidx.core.app.NotificationCompat;
import com.google.android.exoplayer2.source.rtsp.SessionDescription;
import org.json.JSONArray;
import org.json.JSONObject;

public class BindingObjectAutoJS extends BindingObject {
    public static void dispatchEvent(JsContextInfo jsContextInfo, String str, Object obj) {
        if (!jsContextInfo.getTargetReflect().isEventSupported(str)) {
            String tag = jsContextInfo.getTag();
            Log.w(tag, "Unsupport event in extension: " + str);
            return;
        }
        try {
            JSONObject jSONObject = new JSONObject();
            jSONObject.put("cmd", "dispatchEvent");
            jSONObject.put("constructorName", jsContextInfo.getConstructorName());
            jSONObject.put("objectId", jsContextInfo.getObjectId());
            jSONObject.put("type", str);
            jSONObject.put(NotificationCompat.CATEGORY_EVENT, ReflectionHelper.toSerializableObject(obj));
            jsContextInfo.postMessage(jSONObject);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public static void invokeJsCallback(JsContextInfo jsContextInfo, String str, Object... objArr) {
        JSONArray jSONArray;
        if (objArr.length != 1 || !(objArr[0] instanceof JSONArray)) {
            jSONArray = (JSONArray) ReflectionHelper.toSerializableObject(objArr);
        } else {
            jSONArray = (JSONArray) objArr[0];
        }
        try {
            JSONObject jSONObject = new JSONObject();
            jSONObject.put("cmd", "invokeCallback");
            jSONObject.put("callbackId", str);
            jSONObject.put("args", jSONArray);
            jsContextInfo.postMessage(jSONObject);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public static void sendEvent(JsContextInfo jsContextInfo, String str, Object obj) {
        jsContextInfo.getExtensionClient().sendEvent(str, obj);
    }

    public static void updateProperty(JsContextInfo jsContextInfo, String str) {
        String str2;
        ReflectionHelper targetReflect = jsContextInfo.getTargetReflect();
        if (!targetReflect.hasProperty(str).booleanValue()) {
            String tag = jsContextInfo.getTag();
            Log.w(tag, "Unexposed property in extension: " + str);
            return;
        }
        boolean z = targetReflect.getMemberInfo(str).isStatic;
        try {
            JSONObject jSONObject = new JSONObject();
            jSONObject.put("cmd", "updateProperty");
            if (z) {
                str2 = SessionDescription.SUPPORTED_SDP_VERSION;
            } else {
                str2 = jsContextInfo.getObjectId();
            }
            jSONObject.put("objectId", str2);
            jSONObject.put("constructorName", jsContextInfo.getConstructorName());
            jSONObject.put("name", str);
            jsContextInfo.postMessage(jSONObject);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public JsContextInfo getJsContextInfo() {
        return new JsContextInfo(this.mInstanceHelper.getId(), this.mInstanceHelper.getExtension(), getClass(), this.mObjectId);
    }

    @Override // org.xwalk.core.extension.BindingObject
    public Object handleMessage(MessageInfo messageInfo) {
        try {
            return this.mInstanceHelper.getExtension().getReflection().getReflectionByBindingClass(getClass().getName()).handleMessage(messageInfo, this);
        } catch (Exception e) {
            Log.e("BindingObjectAutoJs", e.toString());
            return null;
        }
    }

    public void sendEvent(String str, Object obj) {
        sendEvent(getJsContextInfo(), str, obj);
    }

    public void invokeJsCallback(String str, Object... objArr) {
        invokeJsCallback(getJsContextInfo(), str, objArr);
    }

    public static void invokeJsCallback(JsContextInfo jsContextInfo, byte[] bArr) {
        jsContextInfo.postMessage(bArr);
    }

    public void dispatchEvent(String str, Object obj) {
        dispatchEvent(getJsContextInfo(), str, obj);
    }

    public void invokeJsCallback(byte[] bArr) {
        getJsContextInfo().postMessage(bArr);
    }

    public void updateProperty(String str) {
        updateProperty(getJsContextInfo(), str);
    }
}
