package org.xwalk.core.extension;

import android.util.Log;
import java.util.HashMap;
import java.util.Map;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class EventTarget extends BindingObject {
    private String TAG = "EventTarget";
    private Map<String, MessageInfo> mEvents = new HashMap();

    public EventTarget() {
        this.mHandler.register("addEventListener", this);
        this.mHandler.register("removeEventListener", this);
    }

    public void dispatchEvent(String str) {
        dispatchEvent(str, null);
    }

    public boolean isEventActive(String str) {
        return this.mEvents.containsKey(str);
    }

    public void onAddEventListener(MessageInfo messageInfo) {
        try {
            String string = messageInfo.getArgs().getString(0);
            if (this.mEvents.containsKey(string)) {
                String str = this.TAG;
                Log.w(str, "Trying to re-add the event :" + string);
                return;
            }
            this.mEvents.put(string, messageInfo);
            startEvent(string);
        } catch (JSONException e) {
            Log.e(this.TAG, e.toString());
        }
    }

    public void onRemoveEventListener(MessageInfo messageInfo) {
        try {
            String string = messageInfo.getArgs().getString(0);
            if (!this.mEvents.containsKey(string)) {
                String str = this.TAG;
                Log.w(str, "Attempt to remove non-existing event :" + string);
                return;
            }
            stopEvent(string);
            this.mEvents.remove(string);
        } catch (JSONException e) {
            Log.e(this.TAG, e.toString());
        }
    }

    public void startEvent(String str) {
    }

    public void stopEvent(String str) {
    }

    public void dispatchEvent(String str, JSONObject jSONObject) {
        try {
            if (!this.mEvents.containsKey(str)) {
                String str2 = this.TAG;
                Log.w(str2, "Attempt to dispatch to non-existing event :" + str);
                return;
            }
            MessageInfo messageInfo = this.mEvents.get(str);
            JSONArray jSONArray = new JSONArray();
            if (jSONObject != null) {
                jSONArray.put(0, jSONObject);
            }
            messageInfo.postResult(jSONArray);
        } catch (JSONException e) {
            Log.e(this.TAG, e.toString());
        }
    }
}
