package org.xwalk.core.extension;

import android.util.Log;
import java.lang.reflect.InvocationTargetException;
import java.util.HashMap;
import java.util.Map;
import org.xwalk.core.extension.ReflectionHelper;

public class MessageHandler {
    private String TAG;
    private Map<String, Handler> mHandlers;

    public MessageHandler() {
        this.TAG = "MessageHandler";
        this.mHandlers = new HashMap();
    }

    public Object handleMessage(MessageInfo messageInfo) {
        Object obj;
        ReflectionHelper reflectionHelper;
        String jsName = messageInfo.getJsName();
        Handler handler = this.mHandlers.get(jsName);
        if (handler == null || (obj = handler.targetObject) == null) {
            String str = this.TAG;
            Log.w(str, "Cannot find handler for method " + jsName);
            return null;
        } else if (!messageInfo.getExtension().isAutoJS() || (reflectionHelper = handler.reflection) == null) {
            try {
                return obj.getClass().getMethod(handler.javaName, MessageInfo.class).invoke(obj, messageInfo);
            } catch (IllegalAccessException | IllegalArgumentException | NoSuchMethodException | SecurityException | InvocationTargetException e) {
                Log.e(this.TAG, e.toString());
                return null;
            }
        } else {
            try {
                return reflectionHelper.handleMessage(messageInfo, obj);
            } catch (Exception e2) {
                Log.e(this.TAG, e2.toString());
                return null;
            }
        }
    }

    public void register(String str, String str2, ReflectionHelper.MemberType memberType, Object obj, ReflectionHelper reflectionHelper) {
        if (this.mHandlers.containsKey(str)) {
            String str3 = this.TAG;
            Log.w(str3, "Existing handler for " + str);
            return;
        }
        this.mHandlers.put(str, new Handler(str2, memberType, obj, reflectionHelper));
    }

    public MessageHandler(MessageHandler messageHandler) {
        this.TAG = "MessageHandler";
        HashMap hashMap = new HashMap();
        this.mHandlers = hashMap;
        hashMap.putAll(messageHandler.mHandlers);
    }

    public class Handler {
        public String javaName;
        public ReflectionHelper reflection;
        public Object targetObject;
        public ReflectionHelper.MemberType type;

        public Handler(String str, ReflectionHelper.MemberType memberType, Object obj, ReflectionHelper reflectionHelper) {
            this.type = memberType;
            this.javaName = str;
            this.targetObject = obj;
            this.reflection = reflectionHelper;
        }

        public Handler(MessageHandler messageHandler, String str, ReflectionHelper.MemberType memberType, Object obj) {
            this(str, memberType, obj, null);
        }
    }

    public void register(String str, String str2, ReflectionHelper.MemberType memberType, Object obj) {
        register(str, str2, memberType, obj, null);
    }

    public void register(String str, String str2, Object obj) {
        register(str, str2, ReflectionHelper.MemberType.JS_METHOD, obj, null);
    }

    public void register(String str, Object obj) {
        register(str, str, ReflectionHelper.MemberType.JS_METHOD, obj, null);
    }
}
