package com.google.android.exoplayer2.upstream.cache;

import androidx.annotation.Nullable;
import androidx.annotation.WorkerThread;
import androidx.base.np;
import com.google.android.exoplayer2.upstream.DataSpec;
import com.google.android.exoplayer2.util.Util;
import java.io.IOException;
import java.io.InterruptedIOException;

public final class CacheWriter {
    public static final int DEFAULT_BUFFER_SIZE_BYTES = 131072;
    private long bytesCached;
    private final Cache cache;
    private final String cacheKey;
    private final CacheDataSource dataSource;
    private final DataSpec dataSpec;
    private long endPosition;
    private volatile boolean isCanceled;
    private long nextPosition;
    @Nullable
    private final ProgressListener progressListener;
    private final byte[] temporaryBuffer;

    public interface ProgressListener {
        void onProgress(long j, long j2, long j3);
    }

    public CacheWriter(CacheDataSource cacheDataSource, DataSpec dataSpec2, @Nullable byte[] bArr, @Nullable ProgressListener progressListener2) {
        this.dataSource = cacheDataSource;
        this.cache = cacheDataSource.getCache();
        this.dataSpec = dataSpec2;
        this.temporaryBuffer = bArr == null ? new byte[131072] : bArr;
        this.progressListener = progressListener2;
        this.cacheKey = cacheDataSource.getCacheKeyFactory().buildCacheKey(dataSpec2);
        this.nextPosition = dataSpec2.position;
    }

    private long getLength() {
        long j = this.endPosition;
        if (j == -1) {
            return -1;
        }
        return j - this.dataSpec.position;
    }

    private void onNewBytesCached(long j) {
        this.bytesCached += j;
        ProgressListener progressListener2 = this.progressListener;
        if (progressListener2 != null) {
            progressListener2.onProgress(getLength(), this.bytesCached, j);
        }
    }

    private void onRequestEndPosition(long j) {
        if (this.endPosition != j) {
            this.endPosition = j;
            ProgressListener progressListener2 = this.progressListener;
            if (progressListener2 != null) {
                progressListener2.onProgress(getLength(), this.bytesCached, 0);
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:15:0x003a  */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x006f A[Catch:{ IOException -> 0x0068 }] */
    /* JADX WARNING: Removed duplicated region for block: B:36:0x0085 A[Catch:{ IOException -> 0x0068 }] */
    private long readBlockToCache(long j, long j2) {
        long j3;
        int i;
        boolean z = true;
        boolean z2 = j + j2 == this.endPosition || j2 == -1;
        if (j2 != -1) {
            try {
                j3 = this.dataSource.open(this.dataSpec.buildUpon().setPosition(j).setLength(j2).build());
            } catch (IOException unused) {
                Util.closeQuietly(this.dataSource);
            }
            if (!z) {
                throwIfCanceled();
                try {
                    j3 = this.dataSource.open(this.dataSpec.buildUpon().setPosition(j).setLength(-1).build());
                } catch (IOException e) {
                    Util.closeQuietly(this.dataSource);
                    throw e;
                }
            }
            if (z2 && j3 != -1) {
                onRequestEndPosition(j3 + j);
            }
            i = 0;
            int i2 = 0;
            while (i != -1) {
                throwIfCanceled();
                CacheDataSource cacheDataSource = this.dataSource;
                byte[] bArr = this.temporaryBuffer;
                i = cacheDataSource.read(bArr, 0, bArr.length);
                if (i != -1) {
                    onNewBytesCached((long) i);
                    i2 += i;
                }
            }
            if (z2) {
                onRequestEndPosition(j + ((long) i2));
            }
            this.dataSource.close();
            return (long) i2;
        }
        j3 = -1;
        z = false;
        if (!z) {
        }
        try {
            onRequestEndPosition(j3 + j);
            i = 0;
            int i22 = 0;
            while (i != -1) {
            }
            if (z2) {
            }
            this.dataSource.close();
            return (long) i22;
        } catch (IOException e2) {
            Util.closeQuietly(this.dataSource);
            throw e2;
        }
    }

    private void throwIfCanceled() {
        if (this.isCanceled) {
            throw new InterruptedIOException();
        }
    }

    @WorkerThread
    public void cache() {
        throwIfCanceled();
        Cache cache2 = this.cache;
        String str = this.cacheKey;
        DataSpec dataSpec2 = this.dataSpec;
        this.bytesCached = cache2.getCachedBytes(str, dataSpec2.position, dataSpec2.length);
        DataSpec dataSpec3 = this.dataSpec;
        long j = dataSpec3.length;
        if (j != -1) {
            this.endPosition = dataSpec3.position + j;
        } else {
            long a = np.a(this.cache.getContentMetadata(this.cacheKey));
            if (a == -1) {
                a = -1;
            }
            this.endPosition = a;
        }
        ProgressListener progressListener2 = this.progressListener;
        if (progressListener2 != null) {
            progressListener2.onProgress(getLength(), this.bytesCached, 0);
        }
        while (true) {
            long j2 = this.endPosition;
            if (j2 == -1 || this.nextPosition < j2) {
                throwIfCanceled();
                long j3 = this.endPosition;
                long cachedLength = this.cache.getCachedLength(this.cacheKey, this.nextPosition, j3 == -1 ? Long.MAX_VALUE : j3 - this.nextPosition);
                if (cachedLength > 0) {
                    this.nextPosition += cachedLength;
                } else {
                    long j4 = -cachedLength;
                    if (j4 == Long.MAX_VALUE) {
                        j4 = -1;
                    }
                    long j5 = this.nextPosition;
                    this.nextPosition = j5 + readBlockToCache(j5, j4);
                }
            } else {
                return;
            }
        }
    }

    public void cancel() {
        this.isCanceled = true;
    }
}
