package com.kingja.loadsir.core;

import android.content.Context;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import androidx.annotation.NonNull;
import com.kingja.loadsir.LoadSirUtil;
import com.kingja.loadsir.callback.Callback;
import com.kingja.loadsir.callback.SuccessCallback;
import java.util.HashMap;
import java.util.Map;

public class LoadLayout extends FrameLayout {
    private static final int CALLBACK_CUSTOM_INDEX = 1;
    private final String TAG;
    private Map<Class<? extends Callback>, Callback> callbacks;
    private Context context;
    private Class<? extends Callback> curCallback;
    private Callback.OnReloadListener onReloadListener;
    private Class<? extends Callback> preCallback;

    public LoadLayout(@NonNull Context context2) {
        super(context2);
        this.TAG = getClass().getSimpleName();
        this.callbacks = new HashMap();
    }

    private void checkCallbackExist(Class<? extends Callback> cls) {
        if (!this.callbacks.containsKey(cls)) {
            throw new IllegalArgumentException(String.format("The Callback (%s) is nonexistent.", cls.getSimpleName()));
        }
    }

    private void postToMainThread(final Class<? extends Callback> cls) {
        post(new Runnable() {
            /* class com.kingja.loadsir.core.LoadLayout.AnonymousClass1 */

            public void run() {
                LoadLayout.this.showCallbackView(cls);
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void showCallbackView(Class<? extends Callback> cls) {
        Class<? extends Callback> cls2 = this.preCallback;
        if (cls2 != null) {
            if (cls2 != cls) {
                this.callbacks.get(cls2).onDetach();
            } else {
                return;
            }
        }
        if (getChildCount() > 1) {
            removeViewAt(1);
        }
        for (Class<? extends Callback> cls3 : this.callbacks.keySet()) {
            if (cls3 == cls) {
                SuccessCallback successCallback = (SuccessCallback) this.callbacks.get(SuccessCallback.class);
                if (cls3 == SuccessCallback.class) {
                    successCallback.show();
                } else {
                    successCallback.showWithCallback(this.callbacks.get(cls3).getSuccessVisible());
                    View rootView = this.callbacks.get(cls3).getRootView();
                    addView(rootView);
                    this.callbacks.get(cls3).onAttach(this.context, rootView);
                }
                this.preCallback = cls;
            }
        }
        this.curCallback = cls;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r0v2, resolved type: java.util.Map<java.lang.Class<? extends com.kingja.loadsir.callback.Callback>, com.kingja.loadsir.callback.Callback> */
    /* JADX WARN: Multi-variable type inference failed */
    public void addCallback(Callback callback) {
        if (!this.callbacks.containsKey(callback.getClass())) {
            this.callbacks.put(callback.getClass(), callback);
        }
    }

    public Class<? extends Callback> getCurrentCallback() {
        return this.curCallback;
    }

    public void setCallBack(Class<? extends Callback> cls, Transport transport) {
        if (transport != null) {
            checkCallbackExist(cls);
            transport.order(this.context, this.callbacks.get(cls).obtainRootView());
        }
    }

    public void setupCallback(Callback callback) {
        Callback copy = callback.copy();
        copy.setCallback(this.context, this.onReloadListener);
        addCallback(copy);
    }

    public void setupSuccessLayout(Callback callback) {
        addCallback(callback);
        View rootView = callback.getRootView();
        rootView.setVisibility(4);
        addView(rootView, new ViewGroup.LayoutParams(-1, -1));
        this.curCallback = SuccessCallback.class;
    }

    public void showCallback(Class<? extends Callback> cls) {
        checkCallbackExist(cls);
        if (LoadSirUtil.isMainThread()) {
            showCallbackView(cls);
        } else {
            postToMainThread(cls);
        }
    }

    public LoadLayout(@NonNull Context context2, Callback.OnReloadListener onReloadListener2) {
        this(context2);
        this.context = context2;
        this.onReloadListener = onReloadListener2;
    }
}
