package com.orhanobut.hawk;

import androidx.base.b2;

public class DefaultHawkFacade implements HawkFacade {
    private final Converter converter;
    private final Encryption encryption;
    private final LogInterceptor logInterceptor;
    private final Serializer serializer;
    private final Storage storage;

    public DefaultHawkFacade(HawkBuilder hawkBuilder) {
        Encryption encryption2 = hawkBuilder.getEncryption();
        this.encryption = encryption2;
        this.storage = hawkBuilder.getStorage();
        this.converter = hawkBuilder.getConverter();
        this.serializer = hawkBuilder.getSerializer();
        LogInterceptor logInterceptor2 = hawkBuilder.getLogInterceptor();
        this.logInterceptor = logInterceptor2;
        StringBuilder j = b2.j("Hawk.init -> Encryption : ");
        j.append(encryption2.getClass().getSimpleName());
        logInterceptor2.onLog(j.toString());
    }

    private void log(String str) {
        this.logInterceptor.onLog(str);
    }

    @Override // com.orhanobut.hawk.HawkFacade
    public boolean contains(String str) {
        return this.storage.contains(str);
    }

    @Override // com.orhanobut.hawk.HawkFacade
    public long count() {
        return this.storage.count();
    }

    @Override // com.orhanobut.hawk.HawkFacade
    public boolean delete(String str) {
        return this.storage.delete(str);
    }

    @Override // com.orhanobut.hawk.HawkFacade
    public boolean deleteAll() {
        return this.storage.deleteAll();
    }

    @Override // com.orhanobut.hawk.HawkFacade
    public void destroy() {
    }

    /* JADX WARNING: Removed duplicated region for block: B:21:0x0076  */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x007c A[SYNTHETIC, Splitter:B:23:0x007c] */
    @Override // com.orhanobut.hawk.HawkFacade
    public <T> T get(String str) {
        String str2;
        Exception e;
        log(b2.c("Hawk.get -> key: ", str));
        T t = null;
        if (str == null) {
            log("Hawk.get -> null key, returning null value ");
            return null;
        }
        String str3 = (String) this.storage.get(str);
        log(b2.c("Hawk.get -> Fetched from storage : ", str3));
        if (str3 == null) {
            log("Hawk.get -> Fetching from storage failed");
            return null;
        }
        DataInfo deserialize = this.serializer.deserialize(str3);
        log("Hawk.get -> Deserialized");
        if (deserialize == null) {
            log("Hawk.get -> Deserialization failed");
            return null;
        }
        try {
            str2 = this.encryption.decrypt(str, deserialize.cipherText);
            try {
                log("Hawk.get -> Decrypted to : " + str2);
            } catch (Exception e2) {
                e = e2;
            }
        } catch (Exception e3) {
            e = e3;
            str2 = null;
            StringBuilder j = b2.j("Hawk.get -> Decrypt failed: ");
            j.append(e.getMessage());
            log(j.toString());
            if (str2 != null) {
            }
        }
        if (str2 != null) {
            log("Hawk.get -> Decrypt failed");
            return null;
        }
        try {
            t = (T) this.converter.fromString(str2, deserialize);
            log("Hawk.get -> Converted to : " + ((Object) t));
            return t;
        } catch (Exception unused) {
            log("Hawk.get -> Converter failed");
            return t;
        }
    }

    @Override // com.orhanobut.hawk.HawkFacade
    public boolean isBuilt() {
        return true;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r0v8, resolved type: com.orhanobut.hawk.Storage */
    /* JADX WARN: Multi-variable type inference failed */
    @Override // com.orhanobut.hawk.HawkFacade
    public <T> boolean put(String str, T t) {
        HawkUtils.checkNull("Key", str);
        log("Hawk.put -> key: " + str + ", value: " + ((Object) t));
        if (t == null) {
            log("Hawk.put -> Value is null. Any existing value will be deleted with the given key");
            return delete(str);
        }
        String converter2 = this.converter.toString(t);
        log(b2.c("Hawk.put -> Converted to ", converter2));
        if (converter2 == null) {
            log("Hawk.put -> Converter failed");
            return false;
        }
        String str2 = null;
        try {
            str2 = this.encryption.encrypt(str, converter2);
            log("Hawk.put -> Encrypted to  " + str2);
        } catch (Exception e) {
            e.printStackTrace();
        }
        if (str2 == null) {
            log("Hawk.put -> Encryption failed");
            return false;
        }
        String serialize = this.serializer.serialize(str2, t);
        log(b2.c("Hawk.put -> Serialized to", serialize));
        if (serialize == null) {
            log("Hawk.put -> Serialization failed");
            return false;
        } else if (this.storage.put(str, serialize)) {
            log("Hawk.put -> Stored successfully");
            return true;
        } else {
            log("Hawk.put -> Store operation failed");
            return false;
        }
    }

    @Override // com.orhanobut.hawk.HawkFacade
    public <T> T get(String str, T t) {
        T t2 = (T) get(str);
        return t2 == null ? t : t2;
    }
}
