package com.thoughtworks.xstream.converters.extended;

import androidx.base.b2;
import com.thoughtworks.xstream.converters.ConversionException;
import com.thoughtworks.xstream.converters.Converter;
import com.thoughtworks.xstream.converters.MarshallingContext;
import com.thoughtworks.xstream.converters.UnmarshallingContext;
import com.thoughtworks.xstream.core.ClassLoaderReference;
import com.thoughtworks.xstream.core.util.Fields;
import com.thoughtworks.xstream.io.HierarchicalStreamReader;
import com.thoughtworks.xstream.io.HierarchicalStreamWriter;
import com.thoughtworks.xstream.mapper.Mapper;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Method;
import java.lang.reflect.Proxy;
import java.util.ArrayList;

public class DynamicProxyConverter implements Converter {
    public static /* synthetic */ Class class$com$thoughtworks$xstream$converters$extended$DynamicProxyConverter;
    public static /* synthetic */ Class class$com$thoughtworks$xstream$mapper$DynamicProxyMapper$DynamicProxy;
    public static /* synthetic */ Class class$java$lang$reflect$InvocationHandler;
    public static /* synthetic */ Class class$java$lang$reflect$Proxy;
    private ClassLoaderReference classLoaderReference;
    private Mapper mapper;

    public static class Reflections {
        private static final InvocationHandler DUMMY = new InvocationHandler() {
            /* class com.thoughtworks.xstream.converters.extended.DynamicProxyConverter.Reflections.AnonymousClass1 */

            @Override // java.lang.reflect.InvocationHandler
            public Object invoke(Object obj, Method method, Object[] objArr) {
                return null;
            }
        };
        private static final Field HANDLER;

        static {
            Class cls = DynamicProxyConverter.class$java$lang$reflect$Proxy;
            if (cls == null) {
                cls = DynamicProxyConverter.class$("java.lang.reflect.Proxy");
                DynamicProxyConverter.class$java$lang$reflect$Proxy = cls;
            }
            Class cls2 = DynamicProxyConverter.class$java$lang$reflect$InvocationHandler;
            if (cls2 == null) {
                cls2 = DynamicProxyConverter.class$("java.lang.reflect.InvocationHandler");
                DynamicProxyConverter.class$java$lang$reflect$InvocationHandler = cls2;
            }
            HANDLER = Fields.locate(cls, cls2, false);
        }

        private Reflections() {
        }
    }

    /* JADX WARNING: Illegal instructions before constructor call */
    public DynamicProxyConverter(Mapper mapper2) {
        this(mapper2, r0.getClassLoader());
        Class cls = class$com$thoughtworks$xstream$converters$extended$DynamicProxyConverter;
        if (cls == null) {
            cls = class$("com.thoughtworks.xstream.converters.extended.DynamicProxyConverter");
            class$com$thoughtworks$xstream$converters$extended$DynamicProxyConverter = cls;
        }
    }

    private void addInterfacesToXml(Object obj, HierarchicalStreamWriter hierarchicalStreamWriter) {
        Class<?>[] interfaces = obj.getClass().getInterfaces();
        for (Class<?> cls : interfaces) {
            hierarchicalStreamWriter.startNode("interface");
            hierarchicalStreamWriter.setValue(this.mapper.serializedClass(cls));
            hierarchicalStreamWriter.endNode();
        }
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e) {
            throw b2.n(e);
        }
    }

    @Override // com.thoughtworks.xstream.converters.ConverterMatcher
    public boolean canConvert(Class cls) {
        if (cls != null) {
            Class cls2 = class$com$thoughtworks$xstream$mapper$DynamicProxyMapper$DynamicProxy;
            if (cls2 == null) {
                cls2 = class$("com.thoughtworks.xstream.mapper.DynamicProxyMapper$DynamicProxy");
                class$com$thoughtworks$xstream$mapper$DynamicProxyMapper$DynamicProxy = cls2;
            }
            if (cls.equals(cls2) || Proxy.isProxyClass(cls)) {
                return true;
            }
        }
        return false;
    }

    @Override // com.thoughtworks.xstream.converters.Converter
    public void marshal(Object obj, HierarchicalStreamWriter hierarchicalStreamWriter, MarshallingContext marshallingContext) {
        InvocationHandler invocationHandler = Proxy.getInvocationHandler(obj);
        addInterfacesToXml(obj, hierarchicalStreamWriter);
        hierarchicalStreamWriter.startNode("handler");
        String aliasForSystemAttribute = this.mapper.aliasForSystemAttribute("class");
        if (aliasForSystemAttribute != null) {
            hierarchicalStreamWriter.addAttribute(aliasForSystemAttribute, this.mapper.serializedClass(invocationHandler.getClass()));
        }
        marshallingContext.convertAnother(invocationHandler);
        hierarchicalStreamWriter.endNode();
    }

    @Override // com.thoughtworks.xstream.converters.Converter
    public Object unmarshal(HierarchicalStreamReader hierarchicalStreamReader, UnmarshallingContext unmarshallingContext) {
        Object obj;
        Class cls;
        String aliasForSystemAttribute;
        ArrayList arrayList = new ArrayList();
        while (true) {
            obj = null;
            if (!hierarchicalStreamReader.hasMoreChildren()) {
                cls = null;
                break;
            }
            hierarchicalStreamReader.moveDown();
            String nodeName = hierarchicalStreamReader.getNodeName();
            if (!nodeName.equals("interface")) {
                if (nodeName.equals("handler") && (aliasForSystemAttribute = this.mapper.aliasForSystemAttribute("class")) != null) {
                    cls = this.mapper.realClass(hierarchicalStreamReader.getAttribute(aliasForSystemAttribute));
                    break;
                }
            } else {
                arrayList.add(this.mapper.realClass(hierarchicalStreamReader.getValue()));
            }
            hierarchicalStreamReader.moveUp();
        }
        if (cls != null) {
            Class[] clsArr = new Class[arrayList.size()];
            arrayList.toArray(clsArr);
            if (Reflections.HANDLER != null) {
                obj = Proxy.newProxyInstance(this.classLoaderReference.getReference(), clsArr, Reflections.DUMMY);
            }
            InvocationHandler invocationHandler = (InvocationHandler) unmarshallingContext.convertAnother(obj, cls);
            hierarchicalStreamReader.moveUp();
            if (Reflections.HANDLER == null) {
                return Proxy.newProxyInstance(this.classLoaderReference.getReference(), clsArr, invocationHandler);
            }
            Fields.write(Reflections.HANDLER, obj, invocationHandler);
            return obj;
        }
        throw new ConversionException("No InvocationHandler specified for dynamic proxy");
    }

    public DynamicProxyConverter(Mapper mapper2, ClassLoaderReference classLoaderReference2) {
        this.classLoaderReference = classLoaderReference2;
        this.mapper = mapper2;
    }

    public DynamicProxyConverter(Mapper mapper2, ClassLoader classLoader) {
        this(mapper2, new ClassLoaderReference(classLoader));
    }
}
