package com.thoughtworks.xstream.converters.extended;

import androidx.base.b2;
import com.thoughtworks.xstream.converters.ConversionException;
import com.thoughtworks.xstream.converters.basic.AbstractSingleValueConverter;
import com.thoughtworks.xstream.core.JVM;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class StackTraceElementConverter extends AbstractSingleValueConverter {
    private static final StackTraceElementFactory FACTORY;
    private static final Pattern PATTERN = Pattern.compile("^(.+)\\.([^\\(]+)\\(([^:]*)(:(\\d+))?\\)$");
    public static /* synthetic */ Class class$java$lang$StackTraceElement;

    /* JADX WARNING: Removed duplicated region for block: B:8:0x0021  */
    static {
        StackTraceElementFactory stackTraceElementFactory;
        StackTraceElementFactory stackTraceElementFactory2 = null;
        if (JVM.isVersion(5)) {
            try {
                stackTraceElementFactory = (StackTraceElementFactory) JVM.loadClassForName("com.thoughtworks.xstream.converters.extended.StackTraceElementFactory15", false).newInstance();
            } catch (Exception | LinkageError unused) {
            }
            if (stackTraceElementFactory == null) {
                stackTraceElementFactory = new StackTraceElementFactory();
            }
            stackTraceElementFactory.unknownSourceElement("a", "b");
            stackTraceElementFactory2 = stackTraceElementFactory;
            FACTORY = stackTraceElementFactory2;
        }
        stackTraceElementFactory = null;
        if (stackTraceElementFactory == null) {
        }
        try {
            stackTraceElementFactory.unknownSourceElement("a", "b");
            stackTraceElementFactory2 = stackTraceElementFactory;
        } catch (Exception | NoClassDefFoundError unused2) {
        }
        FACTORY = stackTraceElementFactory2;
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e) {
            throw b2.n(e);
        }
    }

    @Override // com.thoughtworks.xstream.converters.ConverterMatcher, com.thoughtworks.xstream.converters.basic.AbstractSingleValueConverter
    public boolean canConvert(Class cls) {
        Class cls2 = class$java$lang$StackTraceElement;
        if (cls2 == null) {
            cls2 = class$("java.lang.StackTraceElement");
            class$java$lang$StackTraceElement = cls2;
        }
        return cls2.equals(cls) && FACTORY != null;
    }

    @Override // com.thoughtworks.xstream.converters.basic.AbstractSingleValueConverter, com.thoughtworks.xstream.converters.SingleValueConverter
    public Object fromString(String str) {
        Matcher matcher = PATTERN.matcher(str);
        if (matcher.matches()) {
            String group = matcher.group(1);
            String group2 = matcher.group(2);
            String group3 = matcher.group(3);
            if (group3.equals("Unknown Source")) {
                return FACTORY.unknownSourceElement(group, group2);
            }
            if (group3.equals("Native Method")) {
                return FACTORY.nativeMethodElement(group, group2);
            }
            if (matcher.group(4) == null) {
                return FACTORY.element(group, group2, group3);
            }
            return FACTORY.element(group, group2, group3, Integer.parseInt(matcher.group(5)));
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Could not parse StackTraceElement : ");
        stringBuffer.append(str);
        throw new ConversionException(stringBuffer.toString());
    }

    @Override // com.thoughtworks.xstream.converters.basic.AbstractSingleValueConverter, com.thoughtworks.xstream.converters.SingleValueConverter
    public String toString(Object obj) {
        return super.toString(obj).replaceFirst(":\\?\\?\\?", "");
    }
}
