package com.thoughtworks.xstream.converters.javabean;

import androidx.base.b2;
import com.thoughtworks.xstream.converters.ConversionException;
import com.thoughtworks.xstream.converters.Converter;
import com.thoughtworks.xstream.converters.MarshallingContext;
import com.thoughtworks.xstream.converters.UnmarshallingContext;
import com.thoughtworks.xstream.converters.javabean.JavaBeanProvider;
import com.thoughtworks.xstream.converters.reflection.MissingFieldException;
import com.thoughtworks.xstream.core.util.FastField;
import com.thoughtworks.xstream.io.ExtendedHierarchicalStreamWriterHelper;
import com.thoughtworks.xstream.io.HierarchicalStreamReader;
import com.thoughtworks.xstream.io.HierarchicalStreamWriter;
import com.thoughtworks.xstream.mapper.Mapper;
import java.util.HashSet;

public class JavaBeanConverter implements Converter {
    public static /* synthetic */ Class class$com$thoughtworks$xstream$mapper$Mapper$Null;
    public final JavaBeanProvider beanProvider;
    private String classAttributeIdentifier;
    public final Mapper mapper;
    private final Class type;

    public static class DuplicateFieldException extends ConversionException {
        public DuplicateFieldException(String str) {
            super(str);
        }
    }

    public static class DuplicatePropertyException extends ConversionException {
        /* JADX WARNING: Illegal instructions before constructor call */
        public DuplicatePropertyException(String str) {
            super(r0.toString());
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("Duplicate property ");
            stringBuffer.append(str);
            add("property", str);
        }
    }

    public JavaBeanConverter(Mapper mapper2) {
        this(mapper2, (Class) null);
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e) {
            throw b2.n(e);
        }
    }

    private Class determineType(HierarchicalStreamReader hierarchicalStreamReader, Object obj, String str) {
        String str2;
        String str3 = this.classAttributeIdentifier;
        if (str3 == null) {
            str3 = this.mapper.aliasForSystemAttribute("class");
        }
        if (str3 == null) {
            str2 = null;
        } else {
            str2 = hierarchicalStreamReader.getAttribute(str3);
        }
        if (str2 != null) {
            return this.mapper.realClass(str2);
        }
        return this.mapper.defaultImplementationOf(this.beanProvider.getPropertyType(obj, str));
    }

    private Object instantiateNewInstance(UnmarshallingContext unmarshallingContext) {
        Object currentObject = unmarshallingContext.currentObject();
        return currentObject == null ? this.beanProvider.newInstance(unmarshallingContext.getRequiredType()) : currentObject;
    }

    @Override // com.thoughtworks.xstream.converters.ConverterMatcher
    public boolean canConvert(Class cls) {
        Class cls2 = this.type;
        return (cls2 == null || cls2 == cls) && this.beanProvider.canInstantiate(cls);
    }

    @Override // com.thoughtworks.xstream.converters.Converter
    public void marshal(final Object obj, final HierarchicalStreamWriter hierarchicalStreamWriter, final MarshallingContext marshallingContext) {
        final String aliasForSystemAttribute = this.mapper.aliasForSystemAttribute("class");
        this.beanProvider.visitSerializableProperties(obj, new JavaBeanProvider.Visitor() {
            /* class com.thoughtworks.xstream.converters.javabean.JavaBeanConverter.AnonymousClass1 */

            private void writeField(String str, Class cls, Object obj) {
                String str2;
                Class<?> cls2 = obj.getClass();
                Class defaultImplementationOf = JavaBeanConverter.this.mapper.defaultImplementationOf(cls);
                ExtendedHierarchicalStreamWriterHelper.startNode(hierarchicalStreamWriter, JavaBeanConverter.this.mapper.serializedMember(obj.getClass(), str), cls2);
                if (!cls2.equals(defaultImplementationOf) && (str2 = aliasForSystemAttribute) != null) {
                    hierarchicalStreamWriter.addAttribute(str2, JavaBeanConverter.this.mapper.serializedClass(cls2));
                }
                marshallingContext.convertAnother(obj);
                hierarchicalStreamWriter.endNode();
            }

            private void writeNullField(String str) {
                String serializedMember = JavaBeanConverter.this.mapper.serializedMember(obj.getClass(), str);
                HierarchicalStreamWriter hierarchicalStreamWriter = hierarchicalStreamWriter;
                Class cls = JavaBeanConverter.class$com$thoughtworks$xstream$mapper$Mapper$Null;
                if (cls == null) {
                    cls = JavaBeanConverter.class$("com.thoughtworks.xstream.mapper.Mapper$Null");
                    JavaBeanConverter.class$com$thoughtworks$xstream$mapper$Mapper$Null = cls;
                }
                ExtendedHierarchicalStreamWriterHelper.startNode(hierarchicalStreamWriter, serializedMember, cls);
                HierarchicalStreamWriter hierarchicalStreamWriter2 = hierarchicalStreamWriter;
                String str2 = aliasForSystemAttribute;
                Mapper mapper = JavaBeanConverter.this.mapper;
                Class cls2 = JavaBeanConverter.class$com$thoughtworks$xstream$mapper$Mapper$Null;
                if (cls2 == null) {
                    cls2 = JavaBeanConverter.class$("com.thoughtworks.xstream.mapper.Mapper$Null");
                    JavaBeanConverter.class$com$thoughtworks$xstream$mapper$Mapper$Null = cls2;
                }
                hierarchicalStreamWriter2.addAttribute(str2, mapper.serializedClass(cls2));
                hierarchicalStreamWriter.endNode();
            }

            @Override // com.thoughtworks.xstream.converters.javabean.JavaBeanProvider.Visitor
            public boolean shouldVisit(String str, Class cls) {
                return JavaBeanConverter.this.mapper.shouldSerializeMember(cls, str);
            }

            @Override // com.thoughtworks.xstream.converters.javabean.JavaBeanProvider.Visitor
            public void visit(String str, Class cls, Class cls2, Object obj) {
                if (obj != null) {
                    writeField(str, cls, obj);
                } else {
                    writeNullField(str);
                }
            }
        });
    }

    @Override // com.thoughtworks.xstream.converters.Converter
    public Object unmarshal(HierarchicalStreamReader hierarchicalStreamReader, UnmarshallingContext unmarshallingContext) {
        Object instantiateNewInstance = instantiateNewInstance(unmarshallingContext);
        AnonymousClass2 r1 = new HashSet() {
            /* class com.thoughtworks.xstream.converters.javabean.JavaBeanConverter.AnonymousClass2 */

            @Override // java.util.HashSet, java.util.AbstractCollection, java.util.Collection, java.util.Set
            public boolean add(Object obj) {
                if (super.add(obj)) {
                    return true;
                }
                throw new DuplicatePropertyException(((FastField) obj).getName());
            }
        };
        Class<?> cls = instantiateNewInstance.getClass();
        while (hierarchicalStreamReader.hasMoreChildren()) {
            hierarchicalStreamReader.moveDown();
            String realMember = this.mapper.realMember(cls, hierarchicalStreamReader.getNodeName());
            if (this.mapper.shouldSerializeMember(cls, realMember)) {
                if (this.beanProvider.propertyDefinedInClass(realMember, cls)) {
                    this.beanProvider.writeProperty(instantiateNewInstance, realMember, unmarshallingContext.convertAnother(instantiateNewInstance, determineType(hierarchicalStreamReader, instantiateNewInstance, realMember)));
                    r1.add(new FastField(cls, realMember));
                } else if (!this.mapper.isIgnoredElement(realMember)) {
                    throw new MissingFieldException(cls.getName(), realMember);
                }
            }
            hierarchicalStreamReader.moveUp();
        }
        return instantiateNewInstance;
    }

    public JavaBeanConverter(Mapper mapper2, Class cls) {
        this(mapper2, new BeanProvider(), cls);
    }

    public JavaBeanConverter(Mapper mapper2, JavaBeanProvider javaBeanProvider) {
        this(mapper2, javaBeanProvider, null);
    }

    public JavaBeanConverter(Mapper mapper2, JavaBeanProvider javaBeanProvider, Class cls) {
        this.mapper = mapper2;
        this.beanProvider = javaBeanProvider;
        this.type = cls;
    }

    public JavaBeanConverter(Mapper mapper2, String str) {
        this(mapper2, new BeanProvider());
        this.classAttributeIdentifier = str;
    }
}
