package com.thoughtworks.xstream.converters.reflection;

import androidx.base.b2;
import com.thoughtworks.xstream.converters.ConversionException;
import com.thoughtworks.xstream.converters.Converter;
import com.thoughtworks.xstream.converters.MarshallingContext;
import com.thoughtworks.xstream.converters.SingleValueConverter;
import com.thoughtworks.xstream.converters.UnmarshallingContext;
import com.thoughtworks.xstream.converters.reflection.ReflectionProvider;
import com.thoughtworks.xstream.core.Caching;
import com.thoughtworks.xstream.core.ReferencingMarshallingContext;
import com.thoughtworks.xstream.core.util.ArrayIterator;
import com.thoughtworks.xstream.core.util.FastField;
import com.thoughtworks.xstream.core.util.Fields;
import com.thoughtworks.xstream.core.util.HierarchicalStreams;
import com.thoughtworks.xstream.core.util.Primitives;
import com.thoughtworks.xstream.core.util.SerializationMembers;
import com.thoughtworks.xstream.io.ExtendedHierarchicalStreamWriterHelper;
import com.thoughtworks.xstream.io.HierarchicalStreamReader;
import com.thoughtworks.xstream.io.HierarchicalStreamWriter;
import com.thoughtworks.xstream.mapper.CannotResolveClassException;
import com.thoughtworks.xstream.mapper.Mapper;
import java.lang.reflect.Array;
import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.util.AbstractList;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;

public abstract class AbstractReflectionConverter implements Converter, Caching {
    public static /* synthetic */ Class class$com$thoughtworks$xstream$mapper$Mapper$Null;
    public static /* synthetic */ Class class$java$lang$Object;
    public static /* synthetic */ Class class$java$util$Collection;
    public static /* synthetic */ Class class$java$util$Map;
    public static /* synthetic */ Class class$java$util$Map$Entry;
    public final Mapper mapper;
    private transient ReflectionProvider pureJavaReflectionProvider;
    public final ReflectionProvider reflectionProvider;
    public transient SerializationMembers serializationMembers;
    public transient SerializationMethodInvoker serializationMethodInvoker;

    public static class ArraysList extends ArrayList {
        public final Class physicalFieldType;

        public ArraysList(Class cls) {
            this.physicalFieldType = cls;
        }

        public Object toPhysicalArray() {
            Object[] array = toArray();
            Object newInstance = Array.newInstance(this.physicalFieldType.getComponentType(), array.length);
            if (this.physicalFieldType.getComponentType().isPrimitive()) {
                for (int i = 0; i < array.length; i++) {
                    Array.set(newInstance, i, Array.get(array, i));
                }
            } else {
                System.arraycopy(array, 0, newInstance, 0, array.length);
            }
            return newInstance;
        }
    }

    public static class DuplicateFieldException extends ConversionException {
        /* JADX WARNING: Illegal instructions before constructor call */
        public DuplicateFieldException(String str) {
            super(r0.toString());
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("Duplicate field ");
            stringBuffer.append(str);
            add("field", str);
        }
    }

    public static class FieldInfo extends FieldLocation {
        public final Class type;
        public final Object value;

        public FieldInfo(String str, Class cls, Class cls2, Object obj) {
            super(str, cls2);
            this.type = cls;
            this.value = obj;
        }
    }

    public static class FieldLocation {
        public final Class definedIn;
        public final String fieldName;

        public FieldLocation(String str, Class cls) {
            this.fieldName = str;
            this.definedIn = cls;
        }

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (obj == null || getClass() != obj.getClass()) {
                return false;
            }
            FieldLocation fieldLocation = (FieldLocation) obj;
            if (this.definedIn != fieldLocation.definedIn) {
                return false;
            }
            String str = this.fieldName;
            if (str == null) {
                if (fieldLocation.fieldName != null) {
                    return false;
                }
            } else if (!str.equals(fieldLocation.fieldName)) {
                return false;
            }
            return true;
        }

        public int hashCode() {
            Class cls = this.definedIn;
            int i = 0;
            int hashCode = ((cls == null ? 0 : cls.getName().hashCode()) + 7) * 7;
            String str = this.fieldName;
            if (str != null) {
                i = str.hashCode();
            }
            return hashCode + i;
        }
    }

    public interface FieldMarshaller {
        void writeField(String str, String str2, Class cls, Class cls2, Object obj);

        void writeItem(Object obj);
    }

    public class MappingList extends AbstractList {
        private final Map fieldCache = new HashMap();
        private final String keyFieldName;
        private final Map map;

        public MappingList(Map map2, String str) {
            this.map = map2;
            this.keyFieldName = str;
        }

        @Override // java.util.AbstractCollection, java.util.List, java.util.Collection, java.util.AbstractList
        public boolean add(Object obj) {
            if (obj == null) {
                boolean z = !this.map.containsKey(null);
                this.map.put(null, null);
                return z;
            }
            Class<?> cls = obj.getClass();
            if (this.keyFieldName != null) {
                Field field = (Field) this.fieldCache.get(cls);
                if (field == null) {
                    field = AbstractReflectionConverter.this.reflectionProvider.getField(cls, this.keyFieldName);
                    this.fieldCache.put(cls, field);
                }
                if (field != null) {
                    if (this.map.put(Fields.read(field, obj), obj) == null) {
                        return true;
                    }
                    return false;
                }
            } else if (obj instanceof Map.Entry) {
                Map.Entry entry = (Map.Entry) obj;
                if (this.map.put(entry.getKey(), entry.getValue()) == null) {
                    return true;
                }
                return false;
            }
            ConversionException conversionException = new ConversionException("Element  is not defined as entry for implicit map");
            conversionException.add("map-type", this.map.getClass().getName());
            conversionException.add("element-type", obj.getClass().getName());
            throw conversionException;
        }

        @Override // java.util.List, java.util.AbstractList
        public Object get(int i) {
            throw new UnsupportedOperationException();
        }

        public int size() {
            return this.map.size();
        }
    }

    public static class UnknownFieldException extends ConversionException {
        /* JADX WARNING: Illegal instructions before constructor call */
        public UnknownFieldException(String str, String str2) {
            super(r0.toString());
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("No such field ");
            stringBuffer.append(str);
            stringBuffer.append(".");
            stringBuffer.append(str2);
            add("field", str2);
        }
    }

    public AbstractReflectionConverter(Mapper mapper2, ReflectionProvider reflectionProvider2) {
        this.mapper = mapper2;
        this.reflectionProvider = reflectionProvider2;
        SerializationMethodInvoker serializationMethodInvoker2 = new SerializationMethodInvoker();
        this.serializationMethodInvoker = serializationMethodInvoker2;
        this.serializationMembers = serializationMethodInvoker2.serializationMembers;
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e) {
            throw b2.n(e);
        }
    }

    private void handleUnknownField(Class cls, String str, Class cls2, String str2) {
        if (cls == null) {
            for (Class cls3 = cls2; cls3 != null; cls3 = cls3.getSuperclass()) {
                if (!this.mapper.shouldSerializeMember(cls3, str2)) {
                    return;
                }
            }
        }
        throw new UnknownFieldException(cls2.getName(), str);
    }

    private Class readDeclaringClass(HierarchicalStreamReader hierarchicalStreamReader) {
        String str;
        String aliasForSystemAttribute = this.mapper.aliasForSystemAttribute("defined-in");
        if (aliasForSystemAttribute == null) {
            str = null;
        } else {
            str = hierarchicalStreamReader.getAttribute(aliasForSystemAttribute);
        }
        if (str == null) {
            return null;
        }
        return this.mapper.realClass(str);
    }

    private void writeValueToImplicitCollection(Object obj, Map map, Object obj2, FieldLocation fieldLocation) {
        Class cls;
        Collection collection;
        Collection collection2 = (Collection) map.get(fieldLocation);
        if (collection2 == null) {
            Field fieldOrNull = this.reflectionProvider.getFieldOrNull(fieldLocation.definedIn, fieldLocation.fieldName);
            Class<?> cls2 = null;
            if (fieldOrNull != null) {
                cls = fieldOrNull.getType();
            } else {
                cls = this.reflectionProvider.getFieldType(obj2, fieldLocation.fieldName, null);
            }
            if (cls.isArray()) {
                collection2 = new ArraysList(cls);
            } else {
                Class<?> defaultImplementationOf = this.mapper.defaultImplementationOf(cls);
                Class cls3 = class$java$util$Collection;
                if (cls3 == null) {
                    cls3 = class$("java.util.Collection");
                    class$java$util$Collection = cls3;
                }
                if (!cls3.isAssignableFrom(defaultImplementationOf)) {
                    Class cls4 = class$java$util$Map;
                    if (cls4 == null) {
                        cls4 = class$("java.util.Map");
                        class$java$util$Map = cls4;
                    }
                    if (!cls4.isAssignableFrom(defaultImplementationOf)) {
                        ObjectAccessException objectAccessException = new ObjectAccessException("Field is configured for an implicit Collection or Map, but is of an incompatible type");
                        StringBuffer stringBuffer = new StringBuffer();
                        stringBuffer.append(obj2.getClass().getName());
                        stringBuffer.append(".");
                        stringBuffer.append(fieldLocation.fieldName);
                        objectAccessException.add("field", stringBuffer.toString());
                        objectAccessException.add("field-type", defaultImplementationOf.getName());
                        throw objectAccessException;
                    }
                }
                if (this.pureJavaReflectionProvider == null) {
                    this.pureJavaReflectionProvider = new PureJavaReflectionProvider();
                }
                Object newInstance = this.pureJavaReflectionProvider.newInstance(defaultImplementationOf);
                if (newInstance instanceof Collection) {
                    collection = (Collection) newInstance;
                } else {
                    collection = new MappingList((Map) newInstance, this.mapper.getImplicitCollectionDefForFieldName(fieldLocation.definedIn, fieldLocation.fieldName).getKeyFieldName());
                }
                ReflectionProvider reflectionProvider2 = this.reflectionProvider;
                String str = fieldLocation.fieldName;
                if (fieldOrNull != null) {
                    cls2 = fieldOrNull.getDeclaringClass();
                }
                reflectionProvider2.writeField(obj2, str, newInstance, cls2);
                collection2 = collection;
            }
            map.put(fieldLocation, collection2);
        }
        collection2.add(obj);
    }

    public boolean canAccess(Class cls) {
        try {
            this.reflectionProvider.getFieldOrNull(cls, "%");
            return true;
        } catch (NoClassDefFoundError unused) {
            return false;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:18:0x008d  */
    /* JADX WARNING: Removed duplicated region for block: B:64:0x017f  */
    public void doMarshal(final Object obj, final HierarchicalStreamWriter hierarchicalStreamWriter, final MarshallingContext marshallingContext) {
        Mapper.ImplicitCollectionMapping implicitCollectionMapping;
        Iterator it;
        String str;
        Class<?> cls;
        String str2;
        Object obj2;
        final ArrayList arrayList = new ArrayList();
        final HashMap hashMap = new HashMap();
        final Class<?> cls2 = obj.getClass();
        this.reflectionProvider.visitSerializableFields(obj, new ReflectionProvider.Visitor() {
            /* class com.thoughtworks.xstream.converters.reflection.AbstractReflectionConverter.AnonymousClass1 */
            public final Set writtenAttributes = new HashSet();

            @Override // com.thoughtworks.xstream.converters.reflection.ReflectionProvider.Visitor
            public void visit(String str, Class cls, Class cls2, Object obj) {
                if (AbstractReflectionConverter.this.mapper.shouldSerializeMember(cls2, str)) {
                    if (!hashMap.containsKey(str)) {
                        Class<?> cls3 = obj.getClass();
                        if (cls2 != cls2 && !AbstractReflectionConverter.this.mapper.shouldSerializeMember(cls3, str)) {
                            cls3 = cls2;
                        }
                        hashMap.put(str, AbstractReflectionConverter.this.reflectionProvider.getField(cls3, str));
                    }
                    SingleValueConverter converterFromItemType = AbstractReflectionConverter.this.mapper.getConverterFromItemType(str, cls, cls2);
                    if (converterFromItemType != null) {
                        Mapper mapper = AbstractReflectionConverter.this.mapper;
                        String aliasForAttribute = mapper.aliasForAttribute(mapper.serializedMember(cls2, str));
                        if (obj != null) {
                            if (!this.writtenAttributes.contains(str)) {
                                String singleValueConverter = converterFromItemType.toString(obj);
                                if (singleValueConverter != null) {
                                    hierarchicalStreamWriter.addAttribute(aliasForAttribute, singleValueConverter);
                                }
                            } else {
                                ConversionException conversionException = new ConversionException("Cannot write field as attribute for object, attribute name already in use");
                                conversionException.add("field-name", str);
                                conversionException.add("object-type", cls2.getName());
                                throw conversionException;
                            }
                        }
                        this.writtenAttributes.add(str);
                        return;
                    }
                    arrayList.add(new FieldInfo(str, cls, cls2, obj));
                }
            }
        });
        AnonymousClass2 r6 = new FieldMarshaller() {
            /* class com.thoughtworks.xstream.converters.reflection.AbstractReflectionConverter.AnonymousClass2 */

            @Override // com.thoughtworks.xstream.converters.reflection.AbstractReflectionConverter.FieldMarshaller
            public void writeField(String str, String str2, Class cls, Class cls2, Object obj) {
                String aliasForSystemAttribute;
                String aliasForSystemAttribute2;
                Class<?> cls3 = obj != null ? obj.getClass() : cls;
                HierarchicalStreamWriter hierarchicalStreamWriter = hierarchicalStreamWriter;
                if (str2 == null) {
                    str2 = AbstractReflectionConverter.this.mapper.serializedMember(cls2, str);
                }
                ExtendedHierarchicalStreamWriterHelper.startNode(hierarchicalStreamWriter, str2, cls3);
                if (obj != null) {
                    Class defaultImplementationOf = AbstractReflectionConverter.this.mapper.defaultImplementationOf(cls);
                    if (!cls3.equals(defaultImplementationOf)) {
                        String serializedClass = AbstractReflectionConverter.this.mapper.serializedClass(cls3);
                        if (!serializedClass.equals(AbstractReflectionConverter.this.mapper.serializedClass(defaultImplementationOf)) && (aliasForSystemAttribute2 = AbstractReflectionConverter.this.mapper.aliasForSystemAttribute("class")) != null) {
                            hierarchicalStreamWriter.addAttribute(aliasForSystemAttribute2, serializedClass);
                        }
                    }
                    if (!(((Field) hashMap.get(str)).getDeclaringClass() == cls2 || (aliasForSystemAttribute = AbstractReflectionConverter.this.mapper.aliasForSystemAttribute("defined-in")) == null)) {
                        hierarchicalStreamWriter.addAttribute(aliasForSystemAttribute, AbstractReflectionConverter.this.mapper.serializedClass(cls2));
                    }
                    AbstractReflectionConverter.this.marshallField(marshallingContext, obj, AbstractReflectionConverter.this.reflectionProvider.getField(cls2, str));
                }
                hierarchicalStreamWriter.endNode();
            }

            @Override // com.thoughtworks.xstream.converters.reflection.AbstractReflectionConverter.FieldMarshaller
            public void writeItem(Object obj) {
                if (obj == null) {
                    String serializedClass = AbstractReflectionConverter.this.mapper.serializedClass(null);
                    HierarchicalStreamWriter hierarchicalStreamWriter = hierarchicalStreamWriter;
                    Class cls = AbstractReflectionConverter.class$com$thoughtworks$xstream$mapper$Mapper$Null;
                    if (cls == null) {
                        cls = AbstractReflectionConverter.class$("com.thoughtworks.xstream.mapper.Mapper$Null");
                        AbstractReflectionConverter.class$com$thoughtworks$xstream$mapper$Mapper$Null = cls;
                    }
                    ExtendedHierarchicalStreamWriterHelper.startNode(hierarchicalStreamWriter, serializedClass, cls);
                    hierarchicalStreamWriter.endNode();
                    return;
                }
                ExtendedHierarchicalStreamWriterHelper.startNode(hierarchicalStreamWriter, AbstractReflectionConverter.this.mapper.serializedClass(obj.getClass()), obj.getClass());
                marshallingContext.convertAnother(obj);
                hierarchicalStreamWriter.endNode();
            }
        };
        HashMap hashMap2 = new HashMap();
        Iterator it2 = arrayList.iterator();
        while (it2.hasNext()) {
            FieldInfo fieldInfo = (FieldInfo) it2.next();
            if (fieldInfo.value != null) {
                Mapper mapper2 = this.mapper;
                Class<?> declaringClass = ((Field) hashMap.get(fieldInfo.fieldName)).getDeclaringClass();
                Class<?> cls3 = fieldInfo.definedIn;
                if (declaringClass == cls3) {
                    cls3 = cls2;
                }
                Mapper.ImplicitCollectionMapping implicitCollectionDefForFieldName = mapper2.getImplicitCollectionDefForFieldName(cls3, fieldInfo.fieldName);
                if (implicitCollectionDefForFieldName != null) {
                    Set set = (Set) hashMap2.get(fieldInfo.fieldName);
                    if (set == null) {
                        HashSet hashSet = new HashSet();
                        hashSet.add(implicitCollectionDefForFieldName);
                        hashMap2.put(fieldInfo.fieldName, hashSet);
                    } else if (!set.add(implicitCollectionDefForFieldName)) {
                        implicitCollectionMapping = null;
                        if (implicitCollectionMapping == null) {
                            if (!(!(marshallingContext instanceof ReferencingMarshallingContext) || (obj2 = fieldInfo.value) == Collections.EMPTY_LIST || obj2 == Collections.EMPTY_SET || obj2 == Collections.EMPTY_MAP)) {
                                ((ReferencingMarshallingContext) marshallingContext).registerImplicit(obj2);
                            }
                            Object obj3 = fieldInfo.value;
                            boolean z = obj3 instanceof Collection;
                            boolean z2 = (obj3 instanceof Map) && implicitCollectionMapping.getKeyFieldName() == null;
                            if (fieldInfo.value.getClass().isArray()) {
                                it = new ArrayIterator(fieldInfo.value);
                            } else if (z) {
                                it = ((Collection) fieldInfo.value).iterator();
                            } else if (z2) {
                                it = ((Map) fieldInfo.value).entrySet().iterator();
                            } else {
                                it = ((Map) fieldInfo.value).values().iterator();
                            }
                            while (it.hasNext()) {
                                Object next = it.next();
                                if (next == null) {
                                    cls = class$java$lang$Object;
                                    if (cls == null) {
                                        cls = class$("java.lang.Object");
                                        class$java$lang$Object = cls;
                                    }
                                    str = this.mapper.serializedClass(null);
                                } else if (z2) {
                                    if (implicitCollectionMapping.getItemFieldName() != null) {
                                        str2 = implicitCollectionMapping.getItemFieldName();
                                    } else {
                                        Mapper mapper3 = this.mapper;
                                        Class cls4 = class$java$util$Map$Entry;
                                        if (cls4 == null) {
                                            cls4 = class$("java.util.Map$Entry");
                                            class$java$util$Map$Entry = cls4;
                                        }
                                        str2 = mapper3.serializedClass(cls4);
                                    }
                                    Map.Entry entry = (Map.Entry) next;
                                    ExtendedHierarchicalStreamWriterHelper.startNode(hierarchicalStreamWriter, str2, entry.getClass());
                                    r6.writeItem(entry.getKey());
                                    r6.writeItem(entry.getValue());
                                    hierarchicalStreamWriter.endNode();
                                } else if (implicitCollectionMapping.getItemFieldName() != null) {
                                    cls = implicitCollectionMapping.getItemType();
                                    str = implicitCollectionMapping.getItemFieldName();
                                } else {
                                    cls = next.getClass();
                                    str = this.mapper.serializedClass(cls);
                                }
                                r6.writeField(fieldInfo.fieldName, str, cls, fieldInfo.definedIn, next);
                            }
                        } else {
                            r6.writeField(fieldInfo.fieldName, null, fieldInfo.type, fieldInfo.definedIn, fieldInfo.value);
                        }
                    }
                }
                implicitCollectionMapping = implicitCollectionDefForFieldName;
                if (implicitCollectionMapping == null) {
                }
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:100:0x022f  */
    /* JADX WARNING: Removed duplicated region for block: B:49:0x0101  */
    /* JADX WARNING: Removed duplicated region for block: B:50:0x0104  */
    /* JADX WARNING: Removed duplicated region for block: B:99:0x0219  */
    public Object doUnmarshal(Object obj, HierarchicalStreamReader hierarchicalStreamReader, UnmarshallingContext unmarshallingContext) {
        String str;
        Class cls;
        Field field;
        Object obj2;
        Class<?> cls2;
        Class cls3;
        Class cls4 = obj.getClass();
        AnonymousClass3 r5 = new HashSet() {
            /* class com.thoughtworks.xstream.converters.reflection.AbstractReflectionConverter.AnonymousClass3 */

            @Override // java.util.HashSet, java.util.AbstractCollection, java.util.Collection, java.util.Set
            public boolean add(Object obj) {
                if (super.add(obj)) {
                    return true;
                }
                throw new DuplicateFieldException(((FastField) obj).getName());
            }
        };
        Iterator attributeNames = hierarchicalStreamReader.getAttributeNames();
        while (attributeNames.hasNext()) {
            String str2 = (String) attributeNames.next();
            Mapper mapper2 = this.mapper;
            String realMember = mapper2.realMember(cls4, mapper2.attributeForAlias(str2));
            Field fieldOrNull = this.reflectionProvider.getFieldOrNull(cls4, realMember);
            if (fieldOrNull != null && shouldUnmarshalField(fieldOrNull)) {
                Class<?> declaringClass = fieldOrNull.getDeclaringClass();
                if (!this.mapper.shouldSerializeMember(declaringClass, realMember)) {
                    continue;
                } else {
                    SingleValueConverter converterFromAttribute = this.mapper.getConverterFromAttribute(declaringClass, realMember, fieldOrNull.getType());
                    Class<?> type = fieldOrNull.getType();
                    if (converterFromAttribute != null) {
                        Object fromString = converterFromAttribute.fromString(hierarchicalStreamReader.getAttribute(str2));
                        if (type.isPrimitive()) {
                            type = Primitives.box(type);
                        }
                        if (fromString == null || type.isAssignableFrom(fromString.getClass())) {
                            r5.add(new FastField(declaringClass, realMember));
                            this.reflectionProvider.writeField(obj, realMember, fromString, declaringClass);
                        } else {
                            ConversionException conversionException = new ConversionException("Cannot convert type");
                            conversionException.add("source-type", fromString.getClass().getName());
                            conversionException.add("target-type", type.getName());
                            throw conversionException;
                        }
                    } else {
                        continue;
                    }
                }
            }
        }
        HashMap hashMap = null;
        while (hierarchicalStreamReader.hasMoreChildren()) {
            hierarchicalStreamReader.moveDown();
            String nodeName = hierarchicalStreamReader.getNodeName();
            Class readDeclaringClass = readDeclaringClass(hierarchicalStreamReader);
            Class cls5 = readDeclaringClass == null ? cls4 : readDeclaringClass;
            String realMember2 = this.mapper.realMember(cls5, nodeName);
            Mapper.ImplicitCollectionMapping implicitCollectionDefForFieldName = this.mapper.getImplicitCollectionDefForFieldName(cls5, realMember2);
            if (implicitCollectionDefForFieldName == null) {
                field = this.reflectionProvider.getFieldOrNull(cls5, realMember2);
                if (field == null) {
                    cls = this.mapper.getItemTypeForItemFieldName(cls5, realMember2);
                    if (cls != null) {
                        String readClassAttribute = HierarchicalStreams.readClassAttribute(hierarchicalStreamReader, this.mapper);
                        if (readClassAttribute != null) {
                            cls = this.mapper.realClass(readClassAttribute);
                        }
                        str = null;
                    } else {
                        try {
                            cls = this.mapper.realClass(nodeName);
                            try {
                                str = this.mapper.getFieldNameForItemTypeAndName(cls5, cls, nodeName);
                            } catch (CannotResolveClassException unused) {
                            }
                        } catch (CannotResolveClassException unused2) {
                            cls = null;
                            str = null;
                            handleUnknownField(readDeclaringClass, realMember2, cls5, nodeName);
                            cls = null;
                            if (cls != null) {
                            }
                            if (obj2 != null) {
                            }
                            if (field == null) {
                            }
                            hierarchicalStreamReader.moveUp();
                        }
                        if (cls == null || str == null) {
                            handleUnknownField(readDeclaringClass, realMember2, cls5, nodeName);
                            cls = null;
                        }
                    }
                    if (cls != null) {
                        obj2 = null;
                    } else {
                        Class cls6 = class$java$util$Map$Entry;
                        if (cls6 == null) {
                            cls6 = class$("java.util.Map$Entry");
                            class$java$util$Map$Entry = cls6;
                        }
                        if (cls6.equals(cls)) {
                            hierarchicalStreamReader.moveDown();
                            Object convertAnother = unmarshallingContext.convertAnother(obj, HierarchicalStreams.readClassType(hierarchicalStreamReader, this.mapper));
                            hierarchicalStreamReader.moveUp();
                            hierarchicalStreamReader.moveDown();
                            Object convertAnother2 = unmarshallingContext.convertAnother(obj, HierarchicalStreams.readClassType(hierarchicalStreamReader, this.mapper));
                            hierarchicalStreamReader.moveUp();
                            obj2 = Collections.singletonMap(convertAnother, convertAnother2).entrySet().iterator().next();
                        } else {
                            obj2 = unmarshallingContext.convertAnother(obj, cls);
                        }
                    }
                } else {
                    boolean z = false;
                    if (readDeclaringClass == null) {
                        boolean z2 = false;
                        while (field != null) {
                            z2 = shouldUnmarshalField(field) && this.mapper.shouldSerializeMember(field.getDeclaringClass(), realMember2);
                            if (z2) {
                                break;
                            }
                            field = this.reflectionProvider.getFieldOrNull(field.getDeclaringClass().getSuperclass(), realMember2);
                        }
                        z = z2;
                    }
                    if (field == null || (!z && (!shouldUnmarshalField(field) || !this.mapper.shouldSerializeMember(field.getDeclaringClass(), realMember2)))) {
                        obj2 = null;
                        cls = null;
                    } else {
                        String readClassAttribute2 = HierarchicalStreams.readClassAttribute(hierarchicalStreamReader, this.mapper);
                        if (readClassAttribute2 != null) {
                            cls3 = this.mapper.realClass(readClassAttribute2);
                        } else {
                            cls3 = this.mapper.defaultImplementationOf(field.getType());
                        }
                        Object unmarshallField = unmarshallField(unmarshallingContext, obj, cls3, field);
                        Class type2 = field.getType();
                        if (!type2.isPrimitive()) {
                            cls3 = type2;
                        }
                        cls = cls3;
                        obj2 = unmarshallField;
                    }
                    str = null;
                }
            } else {
                str = implicitCollectionDefForFieldName.getFieldName();
                Class itemType = implicitCollectionDefForFieldName.getItemType();
                if (itemType == null) {
                    String readClassAttribute3 = HierarchicalStreams.readClassAttribute(hierarchicalStreamReader, this.mapper);
                    Mapper mapper3 = this.mapper;
                    if (readClassAttribute3 == null) {
                        readClassAttribute3 = nodeName;
                    }
                    itemType = mapper3.realClass(readClassAttribute3);
                }
                cls = itemType;
                obj2 = unmarshallingContext.convertAnother(obj, cls);
                field = null;
            }
            if (obj2 != null || cls.isAssignableFrom(obj2.getClass())) {
                if (field == null) {
                    this.reflectionProvider.writeField(obj, realMember2, obj2, field.getDeclaringClass());
                    r5.add(new FastField(field.getDeclaringClass(), realMember2));
                } else if (cls != null) {
                    if (str == null) {
                        Mapper mapper4 = this.mapper;
                        if (obj2 != null) {
                            cls2 = obj2.getClass();
                        } else {
                            cls2 = class$com$thoughtworks$xstream$mapper$Mapper$Null;
                            if (cls2 == null) {
                                cls2 = class$("com.thoughtworks.xstream.mapper.Mapper$Null");
                                class$com$thoughtworks$xstream$mapper$Mapper$Null = cls2;
                            }
                        }
                        str = mapper4.getFieldNameForItemTypeAndName(cls5, cls2, nodeName);
                    }
                    if (hashMap == null) {
                        hashMap = new HashMap();
                    }
                    writeValueToImplicitCollection(obj2, hashMap, obj, new FieldLocation(str, cls5));
                }
                hierarchicalStreamReader.moveUp();
            } else {
                StringBuffer h = b2.h("Cannot convert type ");
                h.append(obj2.getClass().getName());
                h.append(" to type ");
                h.append(cls.getName());
                throw new ConversionException(h.toString());
            }
        }
        if (hashMap != null) {
            for (Map.Entry entry : hashMap.entrySet()) {
                Object value = entry.getValue();
                if (value instanceof ArraysList) {
                    Object physicalArray = ((ArraysList) value).toPhysicalArray();
                    FieldLocation fieldLocation = (FieldLocation) entry.getKey();
                    Field fieldOrNull2 = this.reflectionProvider.getFieldOrNull(fieldLocation.definedIn, fieldLocation.fieldName);
                    this.reflectionProvider.writeField(obj, fieldLocation.fieldName, physicalArray, fieldOrNull2 != null ? fieldOrNull2.getDeclaringClass() : null);
                }
            }
        }
        return obj;
    }

    @Override // com.thoughtworks.xstream.core.Caching
    public void flushCache() {
        this.serializationMethodInvoker.flushCache();
    }

    public Object instantiateNewInstance(HierarchicalStreamReader hierarchicalStreamReader, UnmarshallingContext unmarshallingContext) {
        String str;
        String aliasForSystemAttribute = this.mapper.aliasForSystemAttribute("resolves-to");
        if (aliasForSystemAttribute == null) {
            str = null;
        } else {
            str = hierarchicalStreamReader.getAttribute(aliasForSystemAttribute);
        }
        Object currentObject = unmarshallingContext.currentObject();
        if (currentObject != null) {
            return currentObject;
        }
        if (str != null) {
            return this.reflectionProvider.newInstance(this.mapper.realClass(str));
        }
        return this.reflectionProvider.newInstance(unmarshallingContext.getRequiredType());
    }

    @Override // com.thoughtworks.xstream.converters.Converter
    public void marshal(Object obj, HierarchicalStreamWriter hierarchicalStreamWriter, MarshallingContext marshallingContext) {
        Object callWriteReplace = this.serializationMembers.callWriteReplace(obj);
        if (callWriteReplace != obj && (marshallingContext instanceof ReferencingMarshallingContext)) {
            ((ReferencingMarshallingContext) marshallingContext).replace(obj, callWriteReplace);
        }
        if (callWriteReplace.getClass() != obj.getClass()) {
            String aliasForSystemAttribute = this.mapper.aliasForSystemAttribute("resolves-to");
            if (aliasForSystemAttribute != null) {
                hierarchicalStreamWriter.addAttribute(aliasForSystemAttribute, this.mapper.serializedClass(callWriteReplace.getClass()));
            }
            marshallingContext.convertAnother(callWriteReplace);
            return;
        }
        doMarshal(callWriteReplace, hierarchicalStreamWriter, marshallingContext);
    }

    public void marshallField(MarshallingContext marshallingContext, Object obj, Field field) {
        marshallingContext.convertAnother(obj, this.mapper.getLocalConverter(field.getDeclaringClass(), field.getName()));
    }

    public Object readResolve() {
        SerializationMethodInvoker serializationMethodInvoker2 = new SerializationMethodInvoker();
        this.serializationMethodInvoker = serializationMethodInvoker2;
        this.serializationMembers = serializationMethodInvoker2.serializationMembers;
        return this;
    }

    public boolean shouldUnmarshalField(Field field) {
        return !Modifier.isTransient(field.getModifiers()) || shouldUnmarshalTransientFields();
    }

    public boolean shouldUnmarshalTransientFields() {
        return false;
    }

    @Override // com.thoughtworks.xstream.converters.Converter
    public Object unmarshal(HierarchicalStreamReader hierarchicalStreamReader, UnmarshallingContext unmarshallingContext) {
        return this.serializationMembers.callReadResolve(doUnmarshal(instantiateNewInstance(hierarchicalStreamReader, unmarshallingContext), hierarchicalStreamReader, unmarshallingContext));
    }

    public Object unmarshallField(UnmarshallingContext unmarshallingContext, Object obj, Class cls, Field field) {
        return unmarshallingContext.convertAnother(obj, cls, this.mapper.getLocalConverter(field.getDeclaringClass(), field.getName()));
    }
}
