package com.thoughtworks.xstream.core.util;

import com.thoughtworks.xstream.converters.basic.AbstractSingleValueConverter;
import java.time.Instant;
import java.time.OffsetDateTime;
import java.time.ZoneId;
import java.time.ZoneOffset;
import java.time.format.DateTimeFormatter;
import java.time.format.DateTimeFormatterBuilder;
import java.time.temporal.ChronoField;
import java.util.Calendar;
import java.util.GregorianCalendar;

public class ISO8601JavaTimeConverter extends AbstractSingleValueConverter {
    private static final DateTimeFormatter BASIC_DATE_TIME = new DateTimeFormatterBuilder().appendPattern("yyyyMMdd'T'HHmmss").appendFraction(ChronoField.MILLI_OF_SECOND, 0, 3, true).appendOffsetId().toFormatter();
    private static final DateTimeFormatter BASIC_ORDINAL_DATE = new DateTimeFormatterBuilder().appendPattern("yyyyDDD").toFormatter();
    private static final DateTimeFormatter BASIC_ORDINAL_DATE_TIME = new DateTimeFormatterBuilder().appendPattern("yyyyDDD'T'HHmmss").appendFraction(ChronoField.MILLI_OF_SECOND, 0, 3, true).appendOffsetId().toFormatter();
    private static final DateTimeFormatter BASIC_TIME = new DateTimeFormatterBuilder().appendPattern("HHmmss").appendFraction(ChronoField.MILLI_OF_SECOND, 0, 3, true).appendOffsetId().toFormatter();
    private static final DateTimeFormatter BASIC_TTIME = new DateTimeFormatterBuilder().appendPattern("'T'HHmmss").appendFraction(ChronoField.MILLI_OF_SECOND, 0, 3, true).appendOffsetId().toFormatter();
    private static final DateTimeFormatter BASIC_WEEK_DATE = new DateTimeFormatterBuilder().appendPattern("YYYY'W'wwe").toFormatter();
    private static final DateTimeFormatter BASIC_WEEK_DATE_TIME = new DateTimeFormatterBuilder().appendPattern("YYYY'W'wwe'T'HHmmss").appendFraction(ChronoField.MILLI_OF_SECOND, 0, 3, true).appendOffsetId().toFormatter();
    private static final DateTimeFormatter ISO_TTIME = new DateTimeFormatterBuilder().appendPattern("'T'HH:mm:ss").appendFraction(ChronoField.MILLI_OF_SECOND, 0, 3, true).appendOffsetId().toFormatter();
    private static final DateTimeFormatter ISO_WEEK_DATE_TIME = new DateTimeFormatterBuilder().appendPattern("YYYY-'W'ww-e'T'HH:mm:ss").appendFraction(ChronoField.MILLI_OF_SECOND, 0, 3, true).appendOffsetId().toFormatter();
    private static final DateTimeFormatter STD_DATE_HOUR = new DateTimeFormatterBuilder().appendPattern("yyyy-MM-dd'T'HH").toFormatter();
    private static final DateTimeFormatter STD_DATE_TIME = new DateTimeFormatterBuilder().appendPattern("yyyy-MM-dd'T'HH:mm:ss").appendFraction(ChronoField.NANO_OF_SECOND, 3, 9, true).appendOffsetId().toFormatter();
    private static final DateTimeFormatter STD_HOUR = new DateTimeFormatterBuilder().appendPattern("HH").toFormatter();
    private static final DateTimeFormatter STD_ORDINAL_DATE_TIME = new DateTimeFormatterBuilder().appendPattern("yyyy-DDD'T'HH:mm:ss").appendFraction(ChronoField.MILLI_OF_SECOND, 0, 3, true).appendOffsetId().toFormatter();
    private static final DateTimeFormatter STD_YEAR_WEEK = new DateTimeFormatterBuilder().appendPattern("YYYY-'W'ww").parseDefaulting(ChronoField.ALIGNED_DAY_OF_WEEK_IN_YEAR, 1).toFormatter();

    @Override // com.thoughtworks.xstream.converters.ConverterMatcher, com.thoughtworks.xstream.converters.basic.AbstractSingleValueConverter
    public boolean canConvert(Class cls) {
        return false;
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:0:0x0000 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:3:0x0011 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:6:0x0022 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:9:0x0033 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:12:0x004a */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:20:0x007a */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:23:0x0093 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:26:0x00b2 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:29:0x00d1 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:32:0x00f0 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:35:0x011f */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:38:0x014e */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:41:0x015f */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:44:0x0172 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:47:0x0185 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:50:0x019c */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:53:0x01b7 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:56:0x01de */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:59:0x01f5 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:67:0x022e */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:70:0x0243 */
    /* JADX DEBUG: Multi-variable search result rejected for r7v0, resolved type: java.lang.String */
    /* JADX DEBUG: Multi-variable search result rejected for r7v23, resolved type: java.lang.String */
    /* JADX DEBUG: Multi-variable search result rejected for r2v5, resolved type: java.time.format.DateTimeFormatter */
    /* JADX DEBUG: Multi-variable search result rejected for r2v10, resolved type: java.time.format.DateTimeFormatter */
    /* JADX DEBUG: Multi-variable search result rejected for r2v24, resolved type: java.time.format.DateTimeFormatter */
    /* JADX DEBUG: Multi-variable search result rejected for r2v48, resolved type: java.time.format.DateTimeFormatter */
    /* JADX DEBUG: Multi-variable search result rejected for r2v53, resolved type: java.time.format.DateTimeFormatter */
    /* JADX DEBUG: Multi-variable search result rejected for r2v58, resolved type: java.time.format.DateTimeFormatter */
    /* JADX DEBUG: Multi-variable search result rejected for r0v15, resolved type: java.time.format.DateTimeFormatter */
    /* JADX DEBUG: Multi-variable search result rejected for r0v19, resolved type: java.time.format.DateTimeFormatter */
    /* JADX DEBUG: Multi-variable search result rejected for r0v23, resolved type: java.time.format.DateTimeFormatter */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r7v1, types: [java.lang.CharSequence] */
    /* JADX WARN: Type inference failed for: r7v2, types: [java.lang.CharSequence] */
    /* JADX WARN: Type inference failed for: r7v3, types: [java.lang.CharSequence] */
    /* JADX WARN: Type inference failed for: r7v4, types: [java.lang.CharSequence] */
    /* JADX WARN: Type inference failed for: r7v5, types: [java.lang.CharSequence] */
    /* JADX WARN: Type inference failed for: r7v7, types: [java.lang.CharSequence] */
    /* JADX WARN: Type inference failed for: r7v8, types: [java.lang.CharSequence] */
    /* JADX WARN: Type inference failed for: r7v9, types: [java.lang.CharSequence] */
    /* JADX WARN: Type inference failed for: r7v10, types: [java.lang.CharSequence] */
    /* JADX WARN: Type inference failed for: r7v11, types: [java.lang.CharSequence] */
    /* JADX WARN: Type inference failed for: r7v12, types: [java.lang.CharSequence] */
    /* JADX WARN: Type inference failed for: r7v13, types: [java.lang.CharSequence] */
    /* JADX WARN: Type inference failed for: r7v14, types: [java.lang.CharSequence] */
    /* JADX WARN: Type inference failed for: r7v15, types: [java.lang.CharSequence] */
    /* JADX WARN: Type inference failed for: r7v16, types: [java.lang.CharSequence] */
    /* JADX WARN: Type inference failed for: r7v17, types: [java.lang.CharSequence] */
    /* JADX WARN: Type inference failed for: r7v18, types: [java.lang.CharSequence] */
    /* JADX WARN: Type inference failed for: r7v19, types: [java.lang.CharSequence] */
    /* JADX WARN: Type inference failed for: r7v20, types: [java.lang.CharSequence] */
    /* JADX WARN: Type inference failed for: r7v22, types: [java.lang.CharSequence] */
    /* JADX WARN: Type inference failed for: r7v26, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r7v27, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r7v29, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r7v30, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r7v31, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r7v32, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r7v33, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r7v34, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r7v35, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r7v36, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r7v37, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r7v38, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r7v39, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r7v40, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r7v41, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r7v42, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r7v44, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r7v45, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r7v46, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r7v47, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARN: Type inference failed for: r7v48, types: [java.util.GregorianCalendar, java.lang.Object] */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:12|13|14) */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:23|24|25) */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:26|27|28) */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:29|30|31) */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:32|33|34) */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:35|36|37) */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:38|39|40) */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:3|4|5) */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:41|42|43) */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:44|45|46) */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:47|48|49) */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:50|51|52) */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:53|54|55) */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:56|57|58) */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:59|60|61) */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:62|63|64) */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:6|7|8) */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:70|71|72) */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:73|74|75) */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:9|10|11) */
    /* JADX WARNING: Code restructure failed: missing block: B:10:?, code lost:
        r7 = java.util.GregorianCalendar.from(((java.time.OffsetDateTime) com.thoughtworks.xstream.core.util.ISO8601JavaTimeConverter.BASIC_DATE_TIME.parse((java.lang.CharSequence) r7, androidx.base.kz.a)).atZoneSameInstant(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:11:0x0049, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:13:?, code lost:
        r7 = java.util.GregorianCalendar.from(((java.time.OffsetDateTime) com.thoughtworks.xstream.core.util.ISO8601JavaTimeConverter.STD_ORDINAL_DATE_TIME.parse((java.lang.CharSequence) r7, androidx.base.kz.a)).atZoneSameInstant(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:14:0x0060, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x0077, code lost:
        return java.util.GregorianCalendar.from(((java.time.OffsetDateTime) com.thoughtworks.xstream.core.util.ISO8601JavaTimeConverter.BASIC_ORDINAL_DATE_TIME.parse((java.lang.CharSequence) r7, androidx.base.kz.a)).atZoneSameInstant(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:?, code lost:
        r7 = java.util.GregorianCalendar.from(java.time.OffsetTime.parse(r7).atDate(java.time.LocalDate.ofEpochDay(0)).atZoneSameInstant(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:22:0x0092, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:24:?, code lost:
        r7 = java.util.GregorianCalendar.from(((java.time.OffsetTime) com.thoughtworks.xstream.core.util.ISO8601JavaTimeConverter.BASIC_TIME.parse((java.lang.CharSequence) r7, androidx.base.jz.a)).atDate(java.time.LocalDate.ofEpochDay(0)).atZoneSameInstant(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:25:0x00b1, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:27:?, code lost:
        r7 = java.util.GregorianCalendar.from(((java.time.OffsetTime) com.thoughtworks.xstream.core.util.ISO8601JavaTimeConverter.ISO_TTIME.parse((java.lang.CharSequence) r7, androidx.base.jz.a)).atDate(java.time.LocalDate.ofEpochDay(0)).atZoneSameInstant(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:28:0x00d0, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:30:?, code lost:
        r7 = java.util.GregorianCalendar.from(((java.time.OffsetTime) com.thoughtworks.xstream.core.util.ISO8601JavaTimeConverter.BASIC_TTIME.parse((java.lang.CharSequence) r7, androidx.base.jz.a)).atDate(java.time.LocalDate.ofEpochDay(0)).atZoneSameInstant(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:31:0x00ef, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:33:?, code lost:
        r2 = com.thoughtworks.xstream.core.util.ISO8601JavaTimeConverter.ISO_WEEK_DATE_TIME.withLocale(java.util.Locale.getDefault()).parse(r7);
        r7 = java.util.GregorianCalendar.from(java.time.OffsetTime.from(r2).atDate(java.time.Year.from(r2).atMonthDay(java.time.MonthDay.from(r2))).atZoneSameInstant(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:34:0x011e, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:36:?, code lost:
        r2 = com.thoughtworks.xstream.core.util.ISO8601JavaTimeConverter.BASIC_WEEK_DATE_TIME.withLocale(java.util.Locale.getDefault()).parse(r7);
        r7 = java.util.GregorianCalendar.from(java.time.OffsetTime.from(r2).atDate(java.time.Year.from(r2).atMonthDay(java.time.MonthDay.from(r2))).atZoneSameInstant(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:37:0x014d, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:39:?, code lost:
        r7 = java.util.GregorianCalendar.from(java.time.LocalDate.parse(r7).atStartOfDay(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:40:0x015e, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:42:?, code lost:
        r7 = java.util.GregorianCalendar.from(java.time.LocalDate.parse(r7, java.time.format.DateTimeFormatter.BASIC_ISO_DATE).atStartOfDay(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:43:0x0171, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:45:?, code lost:
        r7 = java.util.GregorianCalendar.from(java.time.LocalDate.parse(r7, java.time.format.DateTimeFormatter.ISO_ORDINAL_DATE).atStartOfDay(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:46:0x0184, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:48:?, code lost:
        r7 = java.util.GregorianCalendar.from(((java.time.LocalDate) com.thoughtworks.xstream.core.util.ISO8601JavaTimeConverter.BASIC_ORDINAL_DATE.parse((java.lang.CharSequence) r7, androidx.base.nz.a)).atStartOfDay(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:49:0x019b, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:4:?, code lost:
        r7 = java.util.GregorianCalendar.from(java.time.LocalDateTime.parse(r7).atZone(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:51:?, code lost:
        r7 = java.util.GregorianCalendar.from(java.time.LocalDate.parse(r7, java.time.format.DateTimeFormatter.ISO_WEEK_DATE.withLocale(java.util.Locale.getDefault())).atStartOfDay(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:52:0x01b6, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:54:?, code lost:
        r2 = com.thoughtworks.xstream.core.util.ISO8601JavaTimeConverter.BASIC_WEEK_DATE.withLocale(java.util.Locale.getDefault()).parse(r7);
        r7 = java.util.GregorianCalendar.from(java.time.Year.from(r2).atMonthDay(java.time.MonthDay.from(r2)).atStartOfDay(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:55:0x01dd, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:57:?, code lost:
        r7 = java.util.GregorianCalendar.from(((java.time.LocalDateTime) com.thoughtworks.xstream.core.util.ISO8601JavaTimeConverter.STD_DATE_HOUR.parse((java.lang.CharSequence) r7, androidx.base.mz.a)).atZone(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:58:0x01f4, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:5:0x0021, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:60:?, code lost:
        r7 = java.util.GregorianCalendar.from(((java.time.LocalTime) com.thoughtworks.xstream.core.util.ISO8601JavaTimeConverter.STD_HOUR.parse((java.lang.CharSequence) r7, androidx.base.lz.a)).atDate(java.time.LocalDate.ofEpochDay(0)).atZone(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:61:0x0213, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:64:0x022c, code lost:
        return java.util.GregorianCalendar.from(java.time.LocalTime.parse(r7).atDate(java.time.LocalDate.ofEpochDay(0)).atZone(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:68:?, code lost:
        r7 = java.util.GregorianCalendar.from(java.time.YearMonth.parse(r7).atDay(1).atStartOfDay(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:69:0x0242, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:71:?, code lost:
        r7 = java.util.GregorianCalendar.from(java.time.Year.parse(r7).atDay(1).atStartOfDay(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:72:0x0257, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:74:?, code lost:
        r0 = com.thoughtworks.xstream.core.util.ISO8601JavaTimeConverter.STD_YEAR_WEEK.withLocale(java.util.Locale.getDefault()).parse(r7);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:75:0x029c, code lost:
        return java.util.GregorianCalendar.from(java.time.LocalDateTime.from(r0).with(java.time.temporal.WeekFields.ISO.weekOfYear(), (long) r0.get(java.time.temporal.WeekFields.ISO.weekBasedYear())).with(java.time.temporal.WeekFields.ISO.weekOfWeekBasedYear(), (long) r0.get(java.time.temporal.IsoFields.WEEK_OF_WEEK_BASED_YEAR)).atZone(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:76:0x029d, code lost:
        r0 = new com.thoughtworks.xstream.converters.ConversionException("Cannot parse date");
        r0.add("date", r7);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:78:0x02a9, code lost:
        throw r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:7:?, code lost:
        r7 = java.util.GregorianCalendar.from(java.time.Instant.parse(r7).atZone(java.time.ZoneId.systemDefault()));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:8:0x0032, code lost:
        return r7;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:12:0x004a */
    /* JADX WARNING: Missing exception handler attribute for start block: B:15:0x0061 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:23:0x0093 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:26:0x00b2 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:29:0x00d1 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:32:0x00f0 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:35:0x011f */
    /* JADX WARNING: Missing exception handler attribute for start block: B:38:0x014e */
    /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0011 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:41:0x015f */
    /* JADX WARNING: Missing exception handler attribute for start block: B:44:0x0172 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:47:0x0185 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:50:0x019c */
    /* JADX WARNING: Missing exception handler attribute for start block: B:53:0x01b7 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:56:0x01de */
    /* JADX WARNING: Missing exception handler attribute for start block: B:59:0x01f5 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:62:0x0214 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:6:0x0022 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:70:0x0243 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:73:0x0258 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:9:0x0033 */
    @Override // com.thoughtworks.xstream.converters.basic.AbstractSingleValueConverter, com.thoughtworks.xstream.converters.SingleValueConverter
    public Object fromString(String str) {
        str = GregorianCalendar.from(OffsetDateTime.parse(str).atZoneSameInstant(ZoneId.systemDefault()));
        return str;
    }

    @Override // com.thoughtworks.xstream.converters.basic.AbstractSingleValueConverter, com.thoughtworks.xstream.converters.SingleValueConverter
    public String toString(Object obj) {
        Calendar calendar = (Calendar) obj;
        return STD_DATE_TIME.format(OffsetDateTime.ofInstant(Instant.ofEpochMilli(calendar.getTimeInMillis()), ZoneOffset.ofTotalSeconds(calendar.getTimeZone().getOffset(calendar.getTimeInMillis()) / 1000)));
    }
}
