package com.thoughtworks.xstream.io.json;

import androidx.base.b2;
import com.google.android.exoplayer2.extractor.ts.TsExtractor;
import com.thoughtworks.xstream.converters.ConversionException;
import com.thoughtworks.xstream.core.util.FastStack;
import com.thoughtworks.xstream.io.AbstractWriter;
import com.thoughtworks.xstream.io.naming.NameCoder;
import com.thoughtworks.xstream.io.naming.NoNameCoder;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

public abstract class AbstractJsonWriter extends AbstractWriter {
    public static final int DROP_ROOT_MODE = 1;
    public static final int EXPLICIT_MODE = 4;
    public static final int IEEE_754_MODE = 8;
    private static final Set NUMBER_TYPES;
    private static final int STATE_END_ATTRIBUTES = 32;
    private static final int STATE_END_ELEMENTS = 256;
    private static final int STATE_END_OBJECT = 2;
    private static final int STATE_NEXT_ATTRIBUTE = 16;
    private static final int STATE_NEXT_ELEMENT = 128;
    private static final int STATE_ROOT = 1;
    private static final int STATE_SET_VALUE = 512;
    private static final int STATE_START_ATTRIBUTES = 8;
    private static final int STATE_START_ELEMENTS = 64;
    private static final int STATE_START_OBJECT = 4;
    public static final int STRICT_MODE = 2;
    public static /* synthetic */ Class class$com$thoughtworks$xstream$mapper$Mapper$Null;
    public static /* synthetic */ Class class$java$io$Externalizable;
    public static /* synthetic */ Class class$java$lang$Boolean;
    public static /* synthetic */ Class class$java$lang$Byte;
    public static /* synthetic */ Class class$java$lang$Character;
    public static /* synthetic */ Class class$java$lang$Double;
    public static /* synthetic */ Class class$java$lang$Float;
    public static /* synthetic */ Class class$java$lang$Integer;
    public static /* synthetic */ Class class$java$lang$Long;
    public static /* synthetic */ Class class$java$lang$Short;
    public static /* synthetic */ Class class$java$math$BigDecimal;
    public static /* synthetic */ Class class$java$math$BigInteger;
    public static /* synthetic */ Class class$java$util$Collection;
    public static /* synthetic */ Class class$java$util$Map;
    public static /* synthetic */ Class class$java$util$Map$Entry;
    private int expectedStates;
    private int mode;
    private FastStack stack;

    public static class IllegalWriterStateException extends IllegalStateException {
        /* JADX WARNING: Illegal instructions before constructor call */
        public IllegalWriterStateException(int i, int i2, String str) {
            super(r0.toString());
            String str2;
            StringBuffer h = b2.h("Cannot turn from state ");
            h.append(getState(i));
            h.append(" into state ");
            h.append(getState(i2));
            if (str == null) {
                str2 = "";
            } else {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append(" for property ");
                stringBuffer.append(str);
                str2 = stringBuffer.toString();
            }
            h.append(str2);
        }

        private static String getState(int i) {
            if (i == 1) {
                return "ROOT";
            }
            if (i == 2) {
                return "END_OBJECT";
            }
            if (i == 4) {
                return "START_OBJECT";
            }
            if (i == 8) {
                return "START_ATTRIBUTES";
            }
            if (i == 16) {
                return "NEXT_ATTRIBUTE";
            }
            if (i == 32) {
                return "END_ATTRIBUTES";
            }
            if (i == 64) {
                return "START_ELEMENTS";
            }
            if (i == 128) {
                return "NEXT_ELEMENT";
            }
            if (i == 256) {
                return "END_ELEMENTS";
            }
            if (i == 512) {
                return "SET_VALUE";
            }
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("Unknown state provided: ");
            stringBuffer.append(i);
            stringBuffer.append(", cannot create message for IllegalWriterStateException");
            throw new IllegalArgumentException(stringBuffer.toString());
        }
    }

    public static class StackElement {
        public int status;
        public final Class type;

        public StackElement(Class cls, int i) {
            this.type = cls;
            this.status = i;
        }
    }

    public static class Type {
        public static Type BOOLEAN = new Type();
        public static Type NULL = new Type();
        public static Type NUMBER = new Type();
        public static Type STRING = new Type();
    }

    static {
        Class[] clsArr = new Class[14];
        clsArr[0] = Byte.TYPE;
        Class cls = class$java$lang$Byte;
        if (cls == null) {
            cls = class$("java.lang.Byte");
            class$java$lang$Byte = cls;
        }
        clsArr[1] = cls;
        clsArr[2] = Short.TYPE;
        Class cls2 = class$java$lang$Short;
        if (cls2 == null) {
            cls2 = class$("java.lang.Short");
            class$java$lang$Short = cls2;
        }
        clsArr[3] = cls2;
        clsArr[4] = Integer.TYPE;
        Class cls3 = class$java$lang$Integer;
        if (cls3 == null) {
            cls3 = class$("java.lang.Integer");
            class$java$lang$Integer = cls3;
        }
        clsArr[5] = cls3;
        clsArr[6] = Long.TYPE;
        Class cls4 = class$java$lang$Long;
        if (cls4 == null) {
            cls4 = class$("java.lang.Long");
            class$java$lang$Long = cls4;
        }
        clsArr[7] = cls4;
        clsArr[8] = Float.TYPE;
        Class cls5 = class$java$lang$Float;
        if (cls5 == null) {
            cls5 = class$("java.lang.Float");
            class$java$lang$Float = cls5;
        }
        clsArr[9] = cls5;
        clsArr[10] = Double.TYPE;
        Class cls6 = class$java$lang$Double;
        if (cls6 == null) {
            cls6 = class$("java.lang.Double");
            class$java$lang$Double = cls6;
        }
        clsArr[11] = cls6;
        Class cls7 = class$java$math$BigInteger;
        if (cls7 == null) {
            cls7 = class$("java.math.BigInteger");
            class$java$math$BigInteger = cls7;
        }
        clsArr[12] = cls7;
        Class cls8 = class$java$math$BigDecimal;
        if (cls8 == null) {
            cls8 = class$("java.math.BigDecimal");
            class$java$math$BigDecimal = cls8;
        }
        clsArr[13] = cls8;
        NUMBER_TYPES = new HashSet(Arrays.asList(clsArr));
    }

    public AbstractJsonWriter() {
        this(new NoNameCoder());
    }

    public static /* synthetic */ Class class$(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e) {
            throw b2.n(e);
        }
    }

    private void handleCheckedStateTransition(int i, String str, String str2) {
        StackElement stackElement = (StackElement) this.stack.peek();
        if ((this.expectedStates & i) != 0) {
            stackElement.status = handleStateTransition(stackElement.status, i, str, str2);
            return;
        }
        throw new IllegalWriterStateException(stackElement.status, i, str);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:110:0x0166, code lost:
        if (r6 == r0) goto L_0x0168;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:179:0x0237, code lost:
        if ((r17.mode & 4) != 0) goto L_0x023b;
     */
    private int handleStateTransition(int i, int i2, String str, String str2) {
        String str3;
        int i3;
        int size = this.stack.size();
        Class cls = ((StackElement) this.stack.peek()).type;
        boolean z = false;
        boolean z2 = size > 1 && isArray(cls);
        if (size > 1 && isArray(((StackElement) this.stack.get(size - 2)).type)) {
            z = true;
        }
        if (i != 1) {
            if (i != 2) {
                if (i != 4) {
                    String str4 = "";
                    if (i != 8) {
                        if (i != 16) {
                            if (i != 32) {
                                if (i != 64) {
                                    if (i != 128) {
                                        if (i != 256) {
                                            if (i != 512) {
                                                throw new IllegalWriterStateException(i, i2, str);
                                            } else if (i2 == 1) {
                                                handleStateTransition(handleStateTransition(handleStateTransition(i, 256, null, null), 2, null, null), 1, null, null);
                                                return i2;
                                            } else if (i2 == 128) {
                                                handleStateTransition(handleStateTransition(i, 256, null, null), 2, null, null);
                                                return i2;
                                            } else if (i2 == 256) {
                                                if ((this.mode & 4) == 0 && z2) {
                                                    endArray();
                                                }
                                                return i2;
                                            } else {
                                                throw new IllegalWriterStateException(i, i2, str);
                                            }
                                        } else if (i2 == 2) {
                                            if ((this.mode & 4) != 0) {
                                                endArray();
                                                endArray();
                                                endObject();
                                            }
                                            return i2;
                                        } else {
                                            throw new IllegalWriterStateException(i, i2, str);
                                        }
                                    } else if (i2 != 1) {
                                        if (i2 != 2) {
                                            if (i2 == 4) {
                                                nextElement();
                                                if (!z && (this.mode & 4) == 0) {
                                                    addLabel(encodeNode(str));
                                                    if ((this.mode & 4) == 0 && z2) {
                                                        startArray();
                                                    }
                                                    return i2;
                                                }
                                            } else if (i2 != 128) {
                                                if (i2 == 256) {
                                                    if ((this.mode & 4) == 0 && z2) {
                                                        endArray();
                                                    }
                                                    return i2;
                                                }
                                                throw new IllegalWriterStateException(i, i2, str);
                                            }
                                        }
                                        handleStateTransition(handleStateTransition(i, 256, null, null), 2, null, null);
                                        if ((this.mode & 4) == 0 && !z2) {
                                            endObject();
                                        }
                                        return i2;
                                    } else {
                                        handleStateTransition(handleStateTransition(i, 2, null, null), 1, null, null);
                                        return i2;
                                    }
                                }
                                if (i2 == 4) {
                                    int i4 = this.mode;
                                    if ((i4 & 1) == 0 || size > 2) {
                                        if (!z || (i4 & 4) != 0) {
                                            if (!str4.equals(str2)) {
                                                startObject();
                                            }
                                            addLabel(encodeNode(str));
                                        }
                                        i3 = 4;
                                        if ((this.mode & 4) != 0) {
                                            startArray();
                                        }
                                    } else {
                                        i3 = 4;
                                    }
                                    if ((this.mode & i3) == 0 && z2) {
                                        startArray();
                                    }
                                    return i2;
                                } else if (i2 == 128 || i2 == 256) {
                                    if ((this.mode & 4) == 0) {
                                        if (z2) {
                                            endArray();
                                        } else {
                                            endObject();
                                        }
                                    }
                                    return i2;
                                } else if (i2 == 512) {
                                    int i5 = this.mode;
                                    if ((i5 & 2) == 0 || size != 2) {
                                        if (str2 == null) {
                                            Class cls2 = class$com$thoughtworks$xstream$mapper$Mapper$Null;
                                            if (cls2 == null) {
                                                cls2 = class$("com.thoughtworks.xstream.mapper.Mapper$Null");
                                                class$com$thoughtworks$xstream$mapper$Mapper$Null = cls2;
                                            }
                                            if (cls == cls2) {
                                                addValue("null", Type.NULL);
                                            } else if ((this.mode & 4) == 0 && !z2) {
                                                startObject();
                                                endObject();
                                            }
                                        } else {
                                            if ((i5 & 8) != 0) {
                                                if (cls != Long.TYPE) {
                                                    Class cls3 = class$java$lang$Long;
                                                    if (cls3 == null) {
                                                        cls3 = class$("java.lang.Long");
                                                        class$java$lang$Long = cls3;
                                                    }
                                                }
                                                long parseLong = Long.parseLong(str2);
                                                if (parseLong > 9007199254740992L || parseLong < -9007199254740992L) {
                                                    addValue(str2, Type.STRING);
                                                } else {
                                                    addValue(str2, getType(cls));
                                                }
                                            }
                                            addValue(str2, getType(cls));
                                        }
                                        return i2;
                                    }
                                    throw new ConversionException("Single value cannot be root element");
                                } else {
                                    throw new IllegalWriterStateException(i, i2, str);
                                }
                            } else {
                                if (i2 == 2) {
                                    handleStateTransition(handleStateTransition(64, 256, null, null), 2, null, null);
                                } else if (i2 != 64) {
                                    throw new IllegalWriterStateException(i, i2, str);
                                } else if ((this.mode & 4) == 0) {
                                    nextElement();
                                }
                                return i2;
                            }
                        }
                    } else if (i2 == 16) {
                        if (str != null) {
                            StringBuffer stringBuffer = new StringBuffer();
                            if ((this.mode & 4) == 0) {
                                str4 = "@";
                            }
                            stringBuffer.append(str4);
                            stringBuffer.append(str);
                            String stringBuffer2 = stringBuffer.toString();
                            startObject();
                            addLabel(encodeAttribute(stringBuffer2));
                            addValue(str2, Type.STRING);
                        }
                        return i2;
                    }
                    if (i2 != 1) {
                        if (i2 != 4) {
                            if (i2 == 16) {
                                int i6 = z2 ? 4 : 4;
                                nextElement();
                                StringBuffer stringBuffer3 = new StringBuffer();
                                if ((i6 & this.mode) == 0) {
                                    str4 = "@";
                                }
                                stringBuffer3.append(str4);
                                stringBuffer3.append(str);
                                addLabel(encodeAttribute(stringBuffer3.toString()));
                                addValue(str2, Type.STRING);
                                return i2;
                            } else if (i2 == 32) {
                                if ((this.mode & 4) != 0) {
                                    if (i == 16) {
                                        endObject();
                                    }
                                    endArray();
                                    nextElement();
                                    startArray();
                                }
                                return i2;
                            } else if (i2 == 128) {
                                handleStateTransition(handleStateTransition(i, 32, null, null), 2, null, null);
                                return i2;
                            } else if (i2 != 512) {
                                throw new IllegalWriterStateException(i, i2, str);
                            }
                        }
                        int handleStateTransition = handleStateTransition(handleStateTransition(i, 32, null, null), 64, null, null);
                        if (i2 == 2) {
                            handleStateTransition(handleStateTransition(handleStateTransition, 512, null, null), 2, null, null);
                        } else if (i2 == 4) {
                            handleStateTransition(handleStateTransition, 4, str, (this.mode & 4) == 0 ? str4 : null);
                        } else if (i2 == 512) {
                            if ((this.mode & 4) == 0) {
                                addLabel(encodeNode("$"));
                            }
                            handleStateTransition(handleStateTransition, 512, null, str2);
                            if ((this.mode & 4) == 0) {
                                endObject();
                            }
                        }
                        return i2;
                    }
                    handleStateTransition(handleStateTransition(handleStateTransition(i, 32, null, null), 2, null, null), 1, null, null);
                    return i2;
                }
                if (!(i2 == 1 || i2 == 4)) {
                    if (i2 == 8) {
                        if ((this.mode & 4) != 0) {
                            startArray();
                        }
                        return i2;
                    } else if (i2 != 16) {
                        if (!(i2 == 128 || i2 == 512)) {
                            throw new IllegalWriterStateException(i, i2, str);
                        }
                    } else if ((this.mode & 4) == 0 && z2) {
                        return 4;
                    } else {
                        handleStateTransition(handleStateTransition(i, 8, null, null), 16, str, str2);
                        return i2;
                    }
                }
                if (!z || (this.mode & 4) != 0) {
                    str3 = null;
                    handleStateTransition(handleStateTransition(i, 8, null, null), 32, null, null);
                } else {
                    str3 = null;
                }
                if (i2 != 1) {
                    if (i2 == 4) {
                        handleStateTransition(64, 4, str, str3);
                    } else if (i2 != 128) {
                        if (i2 == 512) {
                            handleStateTransition(64, 512, str3, str2);
                        }
                    }
                    return i2;
                }
                handleStateTransition(handleStateTransition(64, 512, str3, str3), i2, str3, str3);
                return i2;
            } else if (i2 == 1) {
                int i7 = this.mode;
                if (((i7 & 1) == 0 || size > 2) && (i7 & 4) == 0) {
                    endObject();
                }
                return i2;
            } else if (i2 == 4) {
                handleStateTransition(handleStateTransition(i, 128, null, null), 4, str, null);
                return i2;
            } else if (i2 == 128) {
                nextElement();
                return i2;
            } else {
                throw new IllegalWriterStateException(i, i2, str);
            }
        } else if (i2 == 4) {
            handleStateTransition(64, 4, str, null);
            return i2;
        } else {
            throw new IllegalWriterStateException(i, i2, str);
        }
    }

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamWriter
    public void addAttribute(String str, String str2) {
        handleCheckedStateTransition(16, str, str2);
        this.expectedStates = 661;
    }

    public abstract void addLabel(String str);

    public abstract void addValue(String str, Type type);

    public abstract void endArray();

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamWriter
    public void endNode() {
        int size = this.stack.size();
        int i = size > 2 ? 128 : 1;
        handleCheckedStateTransition(i, null, null);
        this.stack.pop();
        ((StackElement) this.stack.peek()).status = i;
        this.expectedStates = 4;
        if (size > 2) {
            this.expectedStates = 4 | TsExtractor.TS_STREAM_TYPE_AC3;
        }
    }

    public abstract void endObject();

    public Type getType(Class cls) {
        Class cls2 = class$com$thoughtworks$xstream$mapper$Mapper$Null;
        if (cls2 == null) {
            cls2 = class$("com.thoughtworks.xstream.mapper.Mapper$Null");
            class$com$thoughtworks$xstream$mapper$Mapper$Null = cls2;
        }
        if (cls == cls2) {
            return Type.NULL;
        }
        Class cls3 = class$java$lang$Boolean;
        if (cls3 == null) {
            cls3 = class$("java.lang.Boolean");
            class$java$lang$Boolean = cls3;
        }
        if (cls == cls3 || cls == Boolean.TYPE) {
            return Type.BOOLEAN;
        }
        return NUMBER_TYPES.contains(cls) ? Type.NUMBER : Type.STRING;
    }

    public boolean isArray(Class cls) {
        if (cls != null) {
            if (!cls.isArray()) {
                Class cls2 = class$java$util$Collection;
                if (cls2 == null) {
                    cls2 = class$("java.util.Collection");
                    class$java$util$Collection = cls2;
                }
                if (!cls2.isAssignableFrom(cls)) {
                    Class cls3 = class$java$io$Externalizable;
                    if (cls3 == null) {
                        cls3 = class$("java.io.Externalizable");
                        class$java$io$Externalizable = cls3;
                    }
                    if (!cls3.isAssignableFrom(cls)) {
                        Class cls4 = class$java$util$Map;
                        if (cls4 == null) {
                            cls4 = class$("java.util.Map");
                            class$java$util$Map = cls4;
                        }
                        if (!cls4.isAssignableFrom(cls)) {
                            Class cls5 = class$java$util$Map$Entry;
                            if (cls5 == null) {
                                cls5 = class$("java.util.Map$Entry");
                                class$java$util$Map$Entry = cls5;
                            }
                            if (cls5.isAssignableFrom(cls)) {
                                return true;
                            }
                        }
                    }
                }
            }
            return true;
        }
        return false;
    }

    public abstract void nextElement();

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamWriter
    public void setValue(String str) {
        Class cls = ((StackElement) this.stack.peek()).type;
        Class cls2 = class$java$lang$Character;
        if (cls2 == null) {
            cls2 = class$("java.lang.Character");
            class$java$lang$Character = cls2;
        }
        if ((cls == cls2 || cls == Character.TYPE) && "".equals(str)) {
            str = "\u0000";
        }
        handleCheckedStateTransition(512, null, str);
        this.expectedStates = TsExtractor.TS_STREAM_TYPE_AC3;
    }

    public abstract void startArray();

    @Override // com.thoughtworks.xstream.io.AbstractWriter, com.thoughtworks.xstream.io.ExtendedHierarchicalStreamWriter
    public void startNode(String str, Class cls) {
        if (str != null) {
            FastStack fastStack = this.stack;
            fastStack.push(new StackElement(cls, ((StackElement) fastStack.peek()).status));
            handleCheckedStateTransition(4, str, null);
            this.expectedStates = 661;
            return;
        }
        throw new NullPointerException("name");
    }

    public abstract void startObject();

    public AbstractJsonWriter(int i) {
        this(i, new NoNameCoder());
    }

    public AbstractJsonWriter(NameCoder nameCoder) {
        this(0, nameCoder);
    }

    public AbstractJsonWriter(int i, NameCoder nameCoder) {
        super(nameCoder);
        FastStack fastStack = new FastStack(16);
        this.stack = fastStack;
        this.mode = (i & 4) > 0 ? 4 : i;
        fastStack.push(new StackElement(null, 1));
        this.expectedStates = 4;
    }

    @Override // com.thoughtworks.xstream.io.HierarchicalStreamWriter
    public void startNode(String str) {
        startNode(str, null);
    }
}
