package okio;

import androidx.base.b;
import androidx.base.b2;
import androidx.base.ew;
import androidx.base.f00;
import androidx.base.g00;
import androidx.base.p00;
import androidx.base.sz;
import androidx.base.xz;
import androidx.exifinterface.media.ExifInterface;
import java.io.EOFException;
import java.io.InputStream;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.OutputStream;
import java.io.Serializable;
import java.lang.reflect.Field;
import java.nio.ByteBuffer;
import java.nio.charset.Charset;
import java.security.InvalidKeyException;
import java.security.MessageDigest;
import java.util.Arrays;
import javax.crypto.Mac;
import javax.crypto.spec.SecretKeySpec;
import okio.internal.ByteStringKt;
import org.xwalk.core.XWalkAppVersion;

public class ByteString implements Serializable, Comparable<ByteString> {
    public static final Companion Companion = new Companion(null);
    public static final ByteString EMPTY = new ByteString(new byte[0]);
    private static final long serialVersionUID = 1;
    private final byte[] data;
    private transient int hashCode;
    private transient String utf8;

    public static final class Companion {
        private Companion() {
        }

        public static /* synthetic */ ByteString encodeString$default(Companion companion, String str, Charset charset, int i, Object obj) {
            if ((i & 1) != 0) {
                charset = p00.a;
            }
            return companion.encodeString(str, charset);
        }

        public static /* synthetic */ ByteString of$default(Companion companion, byte[] bArr, int i, int i2, int i3, Object obj) {
            if ((i3 & 1) != 0) {
                i = 0;
            }
            if ((i3 & 2) != 0) {
                i2 = bArr.length;
            }
            return companion.of(bArr, i, i2);
        }

        /* renamed from: -deprecated_decodeBase64  reason: not valid java name */
        public final ByteString m5deprecated_decodeBase64(String str) {
            if (str != null) {
                return decodeBase64(str);
            }
            g00.f("string");
            throw null;
        }

        /* renamed from: -deprecated_decodeHex  reason: not valid java name */
        public final ByteString m6deprecated_decodeHex(String str) {
            if (str != null) {
                return decodeHex(str);
            }
            g00.f("string");
            throw null;
        }

        /* renamed from: -deprecated_encodeString  reason: not valid java name */
        public final ByteString m7deprecated_encodeString(String str, Charset charset) {
            if (str == null) {
                g00.f("string");
                throw null;
            } else if (charset != null) {
                return encodeString(str, charset);
            } else {
                g00.f("charset");
                throw null;
            }
        }

        /* renamed from: -deprecated_encodeUtf8  reason: not valid java name */
        public final ByteString m8deprecated_encodeUtf8(String str) {
            if (str != null) {
                return encodeUtf8(str);
            }
            g00.f("string");
            throw null;
        }

        /* renamed from: -deprecated_of  reason: not valid java name */
        public final ByteString m9deprecated_of(ByteBuffer byteBuffer) {
            if (byteBuffer != null) {
                return of(byteBuffer);
            }
            g00.f("buffer");
            throw null;
        }

        /* renamed from: -deprecated_read  reason: not valid java name */
        public final ByteString m11deprecated_read(InputStream inputStream, int i) {
            if (inputStream != null) {
                return read(inputStream, i);
            }
            g00.f("inputstream");
            throw null;
        }

        public final ByteString decodeBase64(String str) {
            if (str != null) {
                byte[] decodeBase64ToArray = Base64.decodeBase64ToArray(str);
                if (decodeBase64ToArray != null) {
                    return new ByteString(decodeBase64ToArray);
                }
                return null;
            }
            g00.f("$this$decodeBase64");
            throw null;
        }

        public final ByteString decodeHex(String str) {
            if (str != null) {
                if (str.length() % 2 == 0) {
                    int length = str.length() / 2;
                    byte[] bArr = new byte[length];
                    for (int i = 0; i < length; i++) {
                        int i2 = i * 2;
                        bArr[i] = (byte) (ByteStringKt.access$decodeHexDigit(str.charAt(i2 + 1)) + (ByteStringKt.access$decodeHexDigit(str.charAt(i2)) << 4));
                    }
                    return new ByteString(bArr);
                }
                throw new IllegalArgumentException(b2.c("Unexpected hex string: ", str).toString());
            }
            g00.f("$this$decodeHex");
            throw null;
        }

        public final ByteString encodeString(String str, Charset charset) {
            if (str == null) {
                g00.f("$this$encode");
                throw null;
            } else if (charset != null) {
                byte[] bytes = str.getBytes(charset);
                g00.b(bytes, "(this as java.lang.String).getBytes(charset)");
                return new ByteString(bytes);
            } else {
                g00.f("charset");
                throw null;
            }
        }

        public final ByteString encodeUtf8(String str) {
            if (str != null) {
                ByteString byteString = new ByteString(Platform.asUtf8ToByteArray(str));
                byteString.setUtf8$okio(str);
                return byteString;
            }
            g00.f("$this$encodeUtf8");
            throw null;
        }

        public final ByteString of(ByteBuffer byteBuffer) {
            if (byteBuffer != null) {
                byte[] bArr = new byte[byteBuffer.remaining()];
                byteBuffer.get(bArr);
                return new ByteString(bArr);
            }
            g00.f("$this$toByteString");
            throw null;
        }

        public final ByteString read(InputStream inputStream, int i) {
            if (inputStream != null) {
                int i2 = 0;
                if (i >= 0) {
                    byte[] bArr = new byte[i];
                    while (i2 < i) {
                        int read = inputStream.read(bArr, i2, i - i2);
                        if (read != -1) {
                            i2 += read;
                        } else {
                            throw new EOFException();
                        }
                    }
                    return new ByteString(bArr);
                }
                throw new IllegalArgumentException(b2.t("byteCount < 0: ", i).toString());
            }
            g00.f("$this$readByteString");
            throw null;
        }

        public /* synthetic */ Companion(f00 f00) {
            this();
        }

        /* renamed from: -deprecated_of  reason: not valid java name */
        public final ByteString m10deprecated_of(byte[] bArr, int i, int i2) {
            if (bArr != null) {
                return of(bArr, i, i2);
            }
            g00.f("array");
            throw null;
        }

        public final ByteString of(byte... bArr) {
            if (bArr != null) {
                byte[] copyOf = Arrays.copyOf(bArr, bArr.length);
                g00.b(copyOf, "java.util.Arrays.copyOf(this, size)");
                return new ByteString(copyOf);
            }
            g00.f("data");
            throw null;
        }

        public final ByteString of(byte[] bArr, int i, int i2) {
            if (bArr != null) {
                Util.checkOffsetAndCount((long) bArr.length, (long) i, (long) i2);
                return new ByteString(xz.c(bArr, i, i2 + i));
            }
            g00.f("$this$toByteString");
            throw null;
        }
    }

    public ByteString(byte[] bArr) {
        if (bArr != null) {
            this.data = bArr;
        } else {
            g00.f("data");
            throw null;
        }
    }

    public static final ByteString decodeBase64(String str) {
        return Companion.decodeBase64(str);
    }

    public static final ByteString decodeHex(String str) {
        return Companion.decodeHex(str);
    }

    public static final ByteString encodeString(String str, Charset charset) {
        return Companion.encodeString(str, charset);
    }

    public static final ByteString encodeUtf8(String str) {
        return Companion.encodeUtf8(str);
    }

    public static /* synthetic */ int indexOf$default(ByteString byteString, ByteString byteString2, int i, int i2, Object obj) {
        if (obj == null) {
            if ((i2 & 2) != 0) {
                i = 0;
            }
            return byteString.indexOf(byteString2, i);
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: indexOf");
    }

    public static /* synthetic */ int indexOf$default(ByteString byteString, byte[] bArr, int i, int i2, Object obj) {
        if (obj == null) {
            if ((i2 & 2) != 0) {
                i = 0;
            }
            return byteString.indexOf(bArr, i);
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: indexOf");
    }

    public static /* synthetic */ int lastIndexOf$default(ByteString byteString, ByteString byteString2, int i, int i2, Object obj) {
        if (obj == null) {
            if ((i2 & 2) != 0) {
                i = byteString.size();
            }
            return byteString.lastIndexOf(byteString2, i);
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: lastIndexOf");
    }

    public static /* synthetic */ int lastIndexOf$default(ByteString byteString, byte[] bArr, int i, int i2, Object obj) {
        if (obj == null) {
            if ((i2 & 2) != 0) {
                i = byteString.size();
            }
            return byteString.lastIndexOf(bArr, i);
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: lastIndexOf");
    }

    public static final ByteString of(ByteBuffer byteBuffer) {
        return Companion.of(byteBuffer);
    }

    public static final ByteString of(byte... bArr) {
        return Companion.of(bArr);
    }

    public static final ByteString of(byte[] bArr, int i, int i2) {
        return Companion.of(bArr, i, i2);
    }

    public static final ByteString read(InputStream inputStream, int i) {
        return Companion.read(inputStream, i);
    }

    private final void readObject(ObjectInputStream objectInputStream) {
        ByteString read = Companion.read(objectInputStream, objectInputStream.readInt());
        Field declaredField = ByteString.class.getDeclaredField("data");
        g00.b(declaredField, "field");
        declaredField.setAccessible(true);
        declaredField.set(this, read.data);
    }

    public static /* synthetic */ ByteString substring$default(ByteString byteString, int i, int i2, int i3, Object obj) {
        if (obj == null) {
            if ((i3 & 1) != 0) {
                i = 0;
            }
            if ((i3 & 2) != 0) {
                i2 = byteString.size();
            }
            return byteString.substring(i, i2);
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: substring");
    }

    private final void writeObject(ObjectOutputStream objectOutputStream) {
        objectOutputStream.writeInt(this.data.length);
        objectOutputStream.write(this.data);
    }

    /* renamed from: -deprecated_getByte  reason: not valid java name */
    public final byte m3deprecated_getByte(int i) {
        return getByte(i);
    }

    /* renamed from: -deprecated_size  reason: not valid java name */
    public final int m4deprecated_size() {
        return size();
    }

    public ByteBuffer asByteBuffer() {
        ByteBuffer asReadOnlyBuffer = ByteBuffer.wrap(this.data).asReadOnlyBuffer();
        g00.b(asReadOnlyBuffer, "ByteBuffer.wrap(data).asReadOnlyBuffer()");
        return asReadOnlyBuffer;
    }

    public String base64() {
        return Base64.encodeBase64$default(getData$okio(), null, 1, null);
    }

    public String base64Url() {
        return Base64.encodeBase64(getData$okio(), Base64.getBASE64_URL_SAFE());
    }

    public ByteString digest$okio(String str) {
        if (str != null) {
            byte[] digest = MessageDigest.getInstance(str).digest(this.data);
            g00.b(digest, "MessageDigest.getInstance(algorithm).digest(data)");
            return new ByteString(digest);
        }
        g00.f("algorithm");
        throw null;
    }

    public final boolean endsWith(ByteString byteString) {
        if (byteString != null) {
            return rangeEquals(size() - byteString.size(), byteString, 0, byteString.size());
        }
        g00.f("suffix");
        throw null;
    }

    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        if (obj instanceof ByteString) {
            ByteString byteString = (ByteString) obj;
            return byteString.size() == getData$okio().length && byteString.rangeEquals(0, getData$okio(), 0, getData$okio().length);
        }
    }

    public final byte getByte(int i) {
        return internalGet$okio(i);
    }

    public final byte[] getData$okio() {
        return this.data;
    }

    public final int getHashCode$okio() {
        return this.hashCode;
    }

    public int getSize$okio() {
        return getData$okio().length;
    }

    public final String getUtf8$okio() {
        return this.utf8;
    }

    public int hashCode() {
        int hashCode$okio = getHashCode$okio();
        if (hashCode$okio != 0) {
            return hashCode$okio;
        }
        int hashCode2 = Arrays.hashCode(getData$okio());
        setHashCode$okio(hashCode2);
        return hashCode2;
    }

    public String hex() {
        char[] cArr = new char[(getData$okio().length * 2)];
        byte[] data$okio = getData$okio();
        int i = 0;
        for (byte b : data$okio) {
            int i2 = i + 1;
            cArr[i] = ByteStringKt.getHEX_DIGIT_CHARS()[(b >> 4) & 15];
            i = i2 + 1;
            cArr[i2] = ByteStringKt.getHEX_DIGIT_CHARS()[b & 15];
        }
        return new String(cArr);
    }

    public ByteString hmac$okio(String str, ByteString byteString) {
        if (str == null) {
            g00.f("algorithm");
            throw null;
        } else if (byteString != null) {
            try {
                Mac instance = Mac.getInstance(str);
                instance.init(new SecretKeySpec(byteString.toByteArray(), str));
                byte[] doFinal = instance.doFinal(this.data);
                g00.b(doFinal, "mac.doFinal(data)");
                return new ByteString(doFinal);
            } catch (InvalidKeyException e) {
                throw new IllegalArgumentException(e);
            }
        } else {
            g00.f(ew.KEY);
            throw null;
        }
    }

    public ByteString hmacSha1(ByteString byteString) {
        if (byteString != null) {
            return hmac$okio("HmacSHA1", byteString);
        }
        g00.f(ew.KEY);
        throw null;
    }

    public ByteString hmacSha256(ByteString byteString) {
        if (byteString != null) {
            return hmac$okio("HmacSHA256", byteString);
        }
        g00.f(ew.KEY);
        throw null;
    }

    public ByteString hmacSha512(ByteString byteString) {
        if (byteString != null) {
            return hmac$okio("HmacSHA512", byteString);
        }
        g00.f(ew.KEY);
        throw null;
    }

    public final int indexOf(ByteString byteString) {
        return indexOf$default(this, byteString, 0, 2, (Object) null);
    }

    public final int indexOf(ByteString byteString, int i) {
        if (byteString != null) {
            return indexOf(byteString.internalArray$okio(), i);
        }
        g00.f("other");
        throw null;
    }

    public int indexOf(byte[] bArr) {
        return indexOf$default(this, bArr, 0, 2, (Object) null);
    }

    public byte[] internalArray$okio() {
        return getData$okio();
    }

    public byte internalGet$okio(int i) {
        return getData$okio()[i];
    }

    public final int lastIndexOf(ByteString byteString) {
        return lastIndexOf$default(this, byteString, 0, 2, (Object) null);
    }

    public final int lastIndexOf(ByteString byteString, int i) {
        if (byteString != null) {
            return lastIndexOf(byteString.internalArray$okio(), i);
        }
        g00.f("other");
        throw null;
    }

    public int lastIndexOf(byte[] bArr) {
        return lastIndexOf$default(this, bArr, 0, 2, (Object) null);
    }

    public ByteString md5() {
        return digest$okio("MD5");
    }

    public boolean rangeEquals(int i, ByteString byteString, int i2, int i3) {
        if (byteString != null) {
            return byteString.rangeEquals(i2, getData$okio(), i, i3);
        }
        g00.f("other");
        throw null;
    }

    public final void setHashCode$okio(int i) {
        this.hashCode = i;
    }

    public final void setUtf8$okio(String str) {
        this.utf8 = str;
    }

    public ByteString sha1() {
        return digest$okio("SHA-1");
    }

    public ByteString sha256() {
        return digest$okio(XWalkAppVersion.XWALK_APK_HASH_ALGORITHM);
    }

    public ByteString sha512() {
        return digest$okio("SHA-512");
    }

    public final int size() {
        return getSize$okio();
    }

    public final boolean startsWith(ByteString byteString) {
        if (byteString != null) {
            return rangeEquals(0, byteString, 0, byteString.size());
        }
        g00.f("prefix");
        throw null;
    }

    public String string(Charset charset) {
        if (charset != null) {
            return new String(this.data, charset);
        }
        g00.f("charset");
        throw null;
    }

    public ByteString substring() {
        return substring$default(this, 0, 0, 3, null);
    }

    public ByteString substring(int i) {
        return substring$default(this, i, 0, 2, null);
    }

    public ByteString substring(int i, int i2) {
        boolean z = true;
        if (i >= 0) {
            if (i2 <= getData$okio().length) {
                if (i2 - i < 0) {
                    z = false;
                }
                if (z) {
                    return (i == 0 && i2 == getData$okio().length) ? this : new ByteString(xz.c(getData$okio(), i, i2));
                }
                throw new IllegalArgumentException("endIndex < beginIndex".toString());
            }
            StringBuilder j = b2.j("endIndex > length(");
            j.append(getData$okio().length);
            j.append(')');
            throw new IllegalArgumentException(j.toString().toString());
        }
        throw new IllegalArgumentException("beginIndex < 0".toString());
    }

    public ByteString toAsciiLowercase() {
        byte b;
        for (int i = 0; i < getData$okio().length; i++) {
            byte b2 = getData$okio()[i];
            byte b3 = (byte) 65;
            if (b2 >= b3 && b2 <= (b = (byte) 90)) {
                byte[] data$okio = getData$okio();
                byte[] copyOf = Arrays.copyOf(data$okio, data$okio.length);
                g00.b(copyOf, "java.util.Arrays.copyOf(this, size)");
                copyOf[i] = (byte) (b2 + 32);
                for (int i2 = i + 1; i2 < copyOf.length; i2++) {
                    byte b4 = copyOf[i2];
                    if (b4 >= b3 && b4 <= b) {
                        copyOf[i2] = (byte) (b4 + 32);
                    }
                }
                return new ByteString(copyOf);
            }
        }
        return this;
    }

    public ByteString toAsciiUppercase() {
        byte b;
        for (int i = 0; i < getData$okio().length; i++) {
            byte b2 = getData$okio()[i];
            byte b3 = (byte) 97;
            if (b2 >= b3 && b2 <= (b = (byte) 122)) {
                byte[] data$okio = getData$okio();
                byte[] copyOf = Arrays.copyOf(data$okio, data$okio.length);
                g00.b(copyOf, "java.util.Arrays.copyOf(this, size)");
                copyOf[i] = (byte) (b2 - 32);
                for (int i2 = i + 1; i2 < copyOf.length; i2++) {
                    byte b4 = copyOf[i2];
                    if (b4 >= b3 && b4 <= b) {
                        copyOf[i2] = (byte) (b4 - 32);
                    }
                }
                return new ByteString(copyOf);
            }
        }
        return this;
    }

    public byte[] toByteArray() {
        byte[] data$okio = getData$okio();
        byte[] copyOf = Arrays.copyOf(data$okio, data$okio.length);
        g00.b(copyOf, "java.util.Arrays.copyOf(this, size)");
        return copyOf;
    }

    public String toString() {
        ByteString byteString;
        boolean z = true;
        if (getData$okio().length == 0) {
            return "[size=0]";
        }
        int access$codePointIndexToCharIndex = ByteStringKt.access$codePointIndexToCharIndex(getData$okio(), 64);
        if (access$codePointIndexToCharIndex != -1) {
            String utf82 = utf8();
            if (utf82 != null) {
                String substring = utf82.substring(0, access$codePointIndexToCharIndex);
                g00.b(substring, "(this as java.lang.Strin…ing(startIndex, endIndex)");
                String e0 = b.e0(b.e0(b.e0(substring, "\\", "\\\\", false, 4), "\n", "\\n", false, 4), "\r", "\\r", false, 4);
                if (access$codePointIndexToCharIndex < utf82.length()) {
                    StringBuilder j = b2.j("[size=");
                    j.append(getData$okio().length);
                    j.append(" text=");
                    j.append(e0);
                    j.append("…]");
                    return j.toString();
                }
                return "[text=" + e0 + ']';
            }
            throw new sz("null cannot be cast to non-null type java.lang.String");
        } else if (getData$okio().length <= 64) {
            StringBuilder j2 = b2.j("[hex=");
            j2.append(hex());
            j2.append(']');
            return j2.toString();
        } else {
            StringBuilder j3 = b2.j("[size=");
            j3.append(getData$okio().length);
            j3.append(" hex=");
            if (64 > getData$okio().length) {
                z = false;
            }
            if (z) {
                if (64 == getData$okio().length) {
                    byteString = this;
                } else {
                    byteString = new ByteString(xz.c(getData$okio(), 0, 64));
                }
                j3.append(byteString.hex());
                j3.append("…]");
                return j3.toString();
            }
            StringBuilder j4 = b2.j("endIndex > length(");
            j4.append(getData$okio().length);
            j4.append(')');
            throw new IllegalArgumentException(j4.toString().toString());
        }
    }

    public String utf8() {
        String utf8$okio = getUtf8$okio();
        if (utf8$okio != null) {
            return utf8$okio;
        }
        String utf8String = Platform.toUtf8String(internalArray$okio());
        setUtf8$okio(utf8String);
        return utf8String;
    }

    public void write(OutputStream outputStream) {
        if (outputStream != null) {
            outputStream.write(this.data);
        } else {
            g00.f("out");
            throw null;
        }
    }

    public void write$okio(Buffer buffer, int i, int i2) {
        if (buffer != null) {
            ByteStringKt.commonWrite(this, buffer, i, i2);
        } else {
            g00.f("buffer");
            throw null;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:10:0x002d A[RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:11:0x002f A[ORIG_RETURN, RETURN, SYNTHETIC] */
    public int compareTo(ByteString byteString) {
        if (byteString != null) {
            int size = size();
            int size2 = byteString.size();
            int min = Math.min(size, size2);
            for (int i = 0; i < min; i++) {
                int i2 = getByte(i) & ExifInterface.MARKER;
                int i3 = byteString.getByte(i) & ExifInterface.MARKER;
                if (i2 != i3) {
                    return i2 < i3 ? -1 : 1;
                }
            }
            if (size == size2) {
                return 0;
            }
            if (size < size2) {
            }
        } else {
            g00.f("other");
            throw null;
        }
    }

    public final boolean endsWith(byte[] bArr) {
        if (bArr != null) {
            return rangeEquals(size() - bArr.length, bArr, 0, bArr.length);
        }
        g00.f("suffix");
        throw null;
    }

    public int indexOf(byte[] bArr, int i) {
        if (bArr != null) {
            int length = getData$okio().length - bArr.length;
            int max = Math.max(i, 0);
            if (max <= length) {
                while (!Util.arrayRangeEquals(getData$okio(), max, bArr, 0, bArr.length)) {
                    if (max != length) {
                        max++;
                    }
                }
                return max;
            }
            return -1;
        }
        g00.f("other");
        throw null;
    }

    public int lastIndexOf(byte[] bArr, int i) {
        if (bArr != null) {
            for (int min = Math.min(i, getData$okio().length - bArr.length); min >= 0; min--) {
                if (Util.arrayRangeEquals(getData$okio(), min, bArr, 0, bArr.length)) {
                    return min;
                }
            }
            return -1;
        }
        g00.f("other");
        throw null;
    }

    public boolean rangeEquals(int i, byte[] bArr, int i2, int i3) {
        if (bArr != null) {
            return i >= 0 && i <= getData$okio().length - i3 && i2 >= 0 && i2 <= bArr.length - i3 && Util.arrayRangeEquals(getData$okio(), i, bArr, i2, i3);
        }
        g00.f("other");
        throw null;
    }

    public final boolean startsWith(byte[] bArr) {
        if (bArr != null) {
            return rangeEquals(0, bArr, 0, bArr.length);
        }
        g00.f("prefix");
        throw null;
    }
}
