package okio;

import androidx.base.b2;
import androidx.base.g00;
import java.util.zip.CRC32;
import java.util.zip.Deflater;

public final class GzipSink implements Sink {
    private boolean closed;
    private final CRC32 crc;
    private final Deflater deflater;
    private final DeflaterSink deflaterSink;
    private final RealBufferedSink sink;

    public GzipSink(Sink sink2) {
        if (sink2 != null) {
            RealBufferedSink realBufferedSink = new RealBufferedSink(sink2);
            this.sink = realBufferedSink;
            Deflater deflater2 = new Deflater(-1, true);
            this.deflater = deflater2;
            this.deflaterSink = new DeflaterSink((BufferedSink) realBufferedSink, deflater2);
            this.crc = new CRC32();
            Buffer buffer = realBufferedSink.bufferField;
            buffer.writeShort(8075);
            buffer.writeByte(8);
            buffer.writeByte(0);
            buffer.writeInt(0);
            buffer.writeByte(0);
            buffer.writeByte(0);
            return;
        }
        g00.f("sink");
        throw null;
    }

    private final void updateCrc(Buffer buffer, long j) {
        Segment segment = buffer.head;
        if (segment != null) {
            while (j > 0) {
                int min = (int) Math.min(j, (long) (segment.limit - segment.pos));
                this.crc.update(segment.data, segment.pos, min);
                j -= (long) min;
                segment = segment.next;
                if (segment == null) {
                    g00.e();
                    throw null;
                }
            }
            return;
        }
        g00.e();
        throw null;
    }

    private final void writeFooter() {
        this.sink.writeIntLe((int) this.crc.getValue());
        this.sink.writeIntLe((int) this.deflater.getBytesRead());
    }

    /* renamed from: -deprecated_deflater  reason: not valid java name */
    public final Deflater m15deprecated_deflater() {
        return this.deflater;
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable, okio.Sink
    public void close() {
        if (!this.closed) {
            Throwable th = null;
            try {
                this.deflaterSink.finishDeflate$okio();
                writeFooter();
            } catch (Throwable th2) {
                th = th2;
            }
            try {
                this.deflater.end();
            } catch (Throwable th3) {
                if (th == null) {
                    th = th3;
                }
            }
            try {
                this.sink.close();
            } catch (Throwable th4) {
                if (th == null) {
                    th = th4;
                }
            }
            this.closed = true;
            if (th != null) {
                throw th;
            }
        }
    }

    public final Deflater deflater() {
        return this.deflater;
    }

    @Override // okio.Sink, java.io.Flushable
    public void flush() {
        this.deflaterSink.flush();
    }

    @Override // okio.Sink
    public Timeout timeout() {
        return this.sink.timeout();
    }

    @Override // okio.Sink
    public void write(Buffer buffer, long j) {
        if (buffer != null) {
            if (!(j >= 0)) {
                throw new IllegalArgumentException(b2.v("byteCount < 0: ", j).toString());
            } else if (j != 0) {
                updateCrc(buffer, j);
                this.deflaterSink.write(buffer, j);
            }
        } else {
            g00.f("source");
            throw null;
        }
    }
}
