package okio;

import androidx.base.ew;
import androidx.base.f00;
import androidx.base.g00;
import java.security.InvalidKeyException;
import java.security.MessageDigest;
import javax.crypto.Mac;
import javax.crypto.spec.SecretKeySpec;
import org.xwalk.core.XWalkAppVersion;

public final class HashingSink extends ForwardingSink {
    public static final Companion Companion = new Companion(null);
    private final Mac mac;
    private final MessageDigest messageDigest;

    public static final class Companion {
        private Companion() {
        }

        public final HashingSink hmacSha1(Sink sink, ByteString byteString) {
            if (sink == null) {
                g00.f("sink");
                throw null;
            } else if (byteString != null) {
                return new HashingSink(sink, byteString, "HmacSHA1");
            } else {
                g00.f(ew.KEY);
                throw null;
            }
        }

        public final HashingSink hmacSha256(Sink sink, ByteString byteString) {
            if (sink == null) {
                g00.f("sink");
                throw null;
            } else if (byteString != null) {
                return new HashingSink(sink, byteString, "HmacSHA256");
            } else {
                g00.f(ew.KEY);
                throw null;
            }
        }

        public final HashingSink hmacSha512(Sink sink, ByteString byteString) {
            if (sink == null) {
                g00.f("sink");
                throw null;
            } else if (byteString != null) {
                return new HashingSink(sink, byteString, "HmacSHA512");
            } else {
                g00.f(ew.KEY);
                throw null;
            }
        }

        public final HashingSink md5(Sink sink) {
            if (sink != null) {
                return new HashingSink(sink, "MD5");
            }
            g00.f("sink");
            throw null;
        }

        public final HashingSink sha1(Sink sink) {
            if (sink != null) {
                return new HashingSink(sink, "SHA-1");
            }
            g00.f("sink");
            throw null;
        }

        public final HashingSink sha256(Sink sink) {
            if (sink != null) {
                return new HashingSink(sink, XWalkAppVersion.XWALK_APK_HASH_ALGORITHM);
            }
            g00.f("sink");
            throw null;
        }

        public final HashingSink sha512(Sink sink) {
            if (sink != null) {
                return new HashingSink(sink, "SHA-512");
            }
            g00.f("sink");
            throw null;
        }

        public /* synthetic */ Companion(f00 f00) {
            this();
        }
    }

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public HashingSink(Sink sink, String str) {
        super(sink);
        if (sink == null) {
            g00.f("sink");
            throw null;
        } else if (str != null) {
            this.messageDigest = MessageDigest.getInstance(str);
            this.mac = null;
        } else {
            g00.f("algorithm");
            throw null;
        }
    }

    public static final HashingSink hmacSha1(Sink sink, ByteString byteString) {
        return Companion.hmacSha1(sink, byteString);
    }

    public static final HashingSink hmacSha256(Sink sink, ByteString byteString) {
        return Companion.hmacSha256(sink, byteString);
    }

    public static final HashingSink hmacSha512(Sink sink, ByteString byteString) {
        return Companion.hmacSha512(sink, byteString);
    }

    public static final HashingSink md5(Sink sink) {
        return Companion.md5(sink);
    }

    public static final HashingSink sha1(Sink sink) {
        return Companion.sha1(sink);
    }

    public static final HashingSink sha256(Sink sink) {
        return Companion.sha256(sink);
    }

    public static final HashingSink sha512(Sink sink) {
        return Companion.sha512(sink);
    }

    /* renamed from: -deprecated_hash  reason: not valid java name */
    public final ByteString m16deprecated_hash() {
        return hash();
    }

    public final ByteString hash() {
        byte[] bArr;
        MessageDigest messageDigest2 = this.messageDigest;
        if (messageDigest2 != null) {
            bArr = messageDigest2.digest();
        } else {
            Mac mac2 = this.mac;
            if (mac2 != null) {
                bArr = mac2.doFinal();
            } else {
                g00.e();
                throw null;
            }
        }
        g00.b(bArr, "result");
        return new ByteString(bArr);
    }

    @Override // okio.ForwardingSink, okio.Sink
    public void write(Buffer buffer, long j) {
        if (buffer != null) {
            Util.checkOffsetAndCount(buffer.size(), 0, j);
            long j2 = 0;
            Segment segment = buffer.head;
            if (segment != null) {
                while (j2 < j) {
                    int min = (int) Math.min(j - j2, (long) (segment.limit - segment.pos));
                    MessageDigest messageDigest2 = this.messageDigest;
                    if (messageDigest2 != null) {
                        messageDigest2.update(segment.data, segment.pos, min);
                    } else {
                        Mac mac2 = this.mac;
                        if (mac2 != null) {
                            mac2.update(segment.data, segment.pos, min);
                        } else {
                            g00.e();
                            throw null;
                        }
                    }
                    j2 += (long) min;
                    segment = segment.next;
                    if (segment == null) {
                        g00.e();
                        throw null;
                    }
                }
                super.write(buffer, j);
                return;
            }
            g00.e();
            throw null;
        }
        g00.f("source");
        throw null;
    }

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public HashingSink(Sink sink, ByteString byteString, String str) {
        super(sink);
        if (sink == null) {
            g00.f("sink");
            throw null;
        } else if (byteString == null) {
            g00.f(ew.KEY);
            throw null;
        } else if (str != null) {
            try {
                Mac instance = Mac.getInstance(str);
                instance.init(new SecretKeySpec(byteString.toByteArray(), str));
                this.mac = instance;
                this.messageDigest = null;
            } catch (InvalidKeyException e) {
                throw new IllegalArgumentException(e);
            }
        } else {
            g00.f("algorithm");
            throw null;
        }
    }
}
