package okio;

import androidx.base.ew;
import androidx.base.f00;
import androidx.base.g00;
import java.security.InvalidKeyException;
import java.security.MessageDigest;
import javax.crypto.Mac;
import javax.crypto.spec.SecretKeySpec;
import org.xwalk.core.XWalkAppVersion;

public final class HashingSource extends ForwardingSource {
    public static final Companion Companion = new Companion(null);
    private final Mac mac;
    private final MessageDigest messageDigest;

    public static final class Companion {
        private Companion() {
        }

        public final HashingSource hmacSha1(Source source, ByteString byteString) {
            if (source == null) {
                g00.f("source");
                throw null;
            } else if (byteString != null) {
                return new HashingSource(source, byteString, "HmacSHA1");
            } else {
                g00.f(ew.KEY);
                throw null;
            }
        }

        public final HashingSource hmacSha256(Source source, ByteString byteString) {
            if (source == null) {
                g00.f("source");
                throw null;
            } else if (byteString != null) {
                return new HashingSource(source, byteString, "HmacSHA256");
            } else {
                g00.f(ew.KEY);
                throw null;
            }
        }

        public final HashingSource hmacSha512(Source source, ByteString byteString) {
            if (source == null) {
                g00.f("source");
                throw null;
            } else if (byteString != null) {
                return new HashingSource(source, byteString, "HmacSHA512");
            } else {
                g00.f(ew.KEY);
                throw null;
            }
        }

        public final HashingSource md5(Source source) {
            if (source != null) {
                return new HashingSource(source, "MD5");
            }
            g00.f("source");
            throw null;
        }

        public final HashingSource sha1(Source source) {
            if (source != null) {
                return new HashingSource(source, "SHA-1");
            }
            g00.f("source");
            throw null;
        }

        public final HashingSource sha256(Source source) {
            if (source != null) {
                return new HashingSource(source, XWalkAppVersion.XWALK_APK_HASH_ALGORITHM);
            }
            g00.f("source");
            throw null;
        }

        public final HashingSource sha512(Source source) {
            if (source != null) {
                return new HashingSource(source, "SHA-512");
            }
            g00.f("source");
            throw null;
        }

        public /* synthetic */ Companion(f00 f00) {
            this();
        }
    }

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public HashingSource(Source source, String str) {
        super(source);
        if (source == null) {
            g00.f("source");
            throw null;
        } else if (str != null) {
            this.messageDigest = MessageDigest.getInstance(str);
            this.mac = null;
        } else {
            g00.f("algorithm");
            throw null;
        }
    }

    public static final HashingSource hmacSha1(Source source, ByteString byteString) {
        return Companion.hmacSha1(source, byteString);
    }

    public static final HashingSource hmacSha256(Source source, ByteString byteString) {
        return Companion.hmacSha256(source, byteString);
    }

    public static final HashingSource hmacSha512(Source source, ByteString byteString) {
        return Companion.hmacSha512(source, byteString);
    }

    public static final HashingSource md5(Source source) {
        return Companion.md5(source);
    }

    public static final HashingSource sha1(Source source) {
        return Companion.sha1(source);
    }

    public static final HashingSource sha256(Source source) {
        return Companion.sha256(source);
    }

    public static final HashingSource sha512(Source source) {
        return Companion.sha512(source);
    }

    /* renamed from: -deprecated_hash  reason: not valid java name */
    public final ByteString m17deprecated_hash() {
        return hash();
    }

    public final ByteString hash() {
        byte[] bArr;
        MessageDigest messageDigest2 = this.messageDigest;
        if (messageDigest2 != null) {
            bArr = messageDigest2.digest();
        } else {
            Mac mac2 = this.mac;
            if (mac2 != null) {
                bArr = mac2.doFinal();
            } else {
                g00.e();
                throw null;
            }
        }
        g00.b(bArr, "result");
        return new ByteString(bArr);
    }

    @Override // okio.Source, okio.ForwardingSource
    public long read(Buffer buffer, long j) {
        if (buffer != null) {
            long read = super.read(buffer, j);
            if (read != -1) {
                long size = buffer.size() - read;
                long size2 = buffer.size();
                Segment segment = buffer.head;
                if (segment != null) {
                    while (size2 > size) {
                        segment = segment.prev;
                        if (segment != null) {
                            size2 -= (long) (segment.limit - segment.pos);
                        } else {
                            g00.e();
                            throw null;
                        }
                    }
                    while (size2 < buffer.size()) {
                        int i = (int) ((((long) segment.pos) + size) - size2);
                        MessageDigest messageDigest2 = this.messageDigest;
                        if (messageDigest2 != null) {
                            messageDigest2.update(segment.data, i, segment.limit - i);
                        } else {
                            Mac mac2 = this.mac;
                            if (mac2 != null) {
                                mac2.update(segment.data, i, segment.limit - i);
                            } else {
                                g00.e();
                                throw null;
                            }
                        }
                        size2 += (long) (segment.limit - segment.pos);
                        segment = segment.next;
                        if (segment != null) {
                            size = size2;
                        } else {
                            g00.e();
                            throw null;
                        }
                    }
                } else {
                    g00.e();
                    throw null;
                }
            }
            return read;
        }
        g00.f("sink");
        throw null;
    }

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public HashingSource(Source source, ByteString byteString, String str) {
        super(source);
        if (source == null) {
            g00.f("source");
            throw null;
        } else if (byteString == null) {
            g00.f(ew.KEY);
            throw null;
        } else if (str != null) {
            try {
                Mac instance = Mac.getInstance(str);
                instance.init(new SecretKeySpec(byteString.toByteArray(), str));
                this.mac = instance;
                this.messageDigest = null;
            } catch (InvalidKeyException e) {
                throw new IllegalArgumentException(e);
            }
        } else {
            g00.f("algorithm");
            throw null;
        }
    }
}
