package okio;

import androidx.base.b2;
import androidx.base.ew;
import androidx.base.g00;
import androidx.base.sz;
import androidx.base.xz;
import java.io.OutputStream;
import java.nio.ByteBuffer;
import java.nio.charset.Charset;
import java.security.InvalidKeyException;
import java.security.MessageDigest;
import javax.crypto.Mac;
import javax.crypto.spec.SecretKeySpec;
import okio.internal.SegmentedByteStringKt;

public final class SegmentedByteString extends ByteString {
    private final transient int[] directory;
    private final transient byte[][] segments;

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public SegmentedByteString(byte[][] bArr, int[] iArr) {
        super(ByteString.EMPTY.getData$okio());
        if (bArr == null) {
            g00.f("segments");
            throw null;
        } else if (iArr != null) {
            this.segments = bArr;
            this.directory = iArr;
        } else {
            g00.f("directory");
            throw null;
        }
    }

    private final ByteString toByteString() {
        return new ByteString(toByteArray());
    }

    private final Object writeReplace() {
        ByteString byteString = toByteString();
        if (byteString != null) {
            return byteString;
        }
        throw new sz("null cannot be cast to non-null type java.lang.Object");
    }

    @Override // okio.ByteString
    public ByteBuffer asByteBuffer() {
        ByteBuffer asReadOnlyBuffer = ByteBuffer.wrap(toByteArray()).asReadOnlyBuffer();
        g00.b(asReadOnlyBuffer, "ByteBuffer.wrap(toByteArray()).asReadOnlyBuffer()");
        return asReadOnlyBuffer;
    }

    @Override // okio.ByteString
    public String base64() {
        return toByteString().base64();
    }

    @Override // okio.ByteString
    public String base64Url() {
        return toByteString().base64Url();
    }

    @Override // okio.ByteString
    public ByteString digest$okio(String str) {
        if (str != null) {
            MessageDigest instance = MessageDigest.getInstance(str);
            int length = getSegments$okio().length;
            int i = 0;
            int i2 = 0;
            while (i < length) {
                int i3 = getDirectory$okio()[length + i];
                int i4 = getDirectory$okio()[i];
                instance.update(getSegments$okio()[i], i3, i4 - i2);
                i++;
                i2 = i4;
            }
            byte[] digest = instance.digest();
            g00.b(digest, "digest.digest()");
            return new ByteString(digest);
        }
        g00.f("algorithm");
        throw null;
    }

    @Override // okio.ByteString
    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        if (obj instanceof ByteString) {
            ByteString byteString = (ByteString) obj;
            return byteString.size() == size() && rangeEquals(0, byteString, 0, size());
        }
    }

    public final int[] getDirectory$okio() {
        return this.directory;
    }

    public final byte[][] getSegments$okio() {
        return this.segments;
    }

    @Override // okio.ByteString
    public int getSize$okio() {
        return getDirectory$okio()[getSegments$okio().length - 1];
    }

    @Override // okio.ByteString
    public int hashCode() {
        int hashCode$okio = getHashCode$okio();
        if (hashCode$okio != 0) {
            return hashCode$okio;
        }
        int length = getSegments$okio().length;
        int i = 0;
        int i2 = 1;
        int i3 = 0;
        while (i < length) {
            int i4 = getDirectory$okio()[length + i];
            int i5 = getDirectory$okio()[i];
            byte[] bArr = getSegments$okio()[i];
            int i6 = (i5 - i3) + i4;
            while (i4 < i6) {
                i2 = (i2 * 31) + bArr[i4];
                i4++;
            }
            i++;
            i3 = i5;
        }
        setHashCode$okio(i2);
        return i2;
    }

    @Override // okio.ByteString
    public String hex() {
        return toByteString().hex();
    }

    @Override // okio.ByteString
    public ByteString hmac$okio(String str, ByteString byteString) {
        if (str == null) {
            g00.f("algorithm");
            throw null;
        } else if (byteString != null) {
            try {
                Mac instance = Mac.getInstance(str);
                instance.init(new SecretKeySpec(byteString.toByteArray(), str));
                int length = getSegments$okio().length;
                int i = 0;
                int i2 = 0;
                while (i < length) {
                    int i3 = getDirectory$okio()[length + i];
                    int i4 = getDirectory$okio()[i];
                    instance.update(getSegments$okio()[i], i3, i4 - i2);
                    i++;
                    i2 = i4;
                }
                byte[] doFinal = instance.doFinal();
                g00.b(doFinal, "mac.doFinal()");
                return new ByteString(doFinal);
            } catch (InvalidKeyException e) {
                throw new IllegalArgumentException(e);
            }
        } else {
            g00.f(ew.KEY);
            throw null;
        }
    }

    @Override // okio.ByteString
    public int indexOf(byte[] bArr, int i) {
        if (bArr != null) {
            return toByteString().indexOf(bArr, i);
        }
        g00.f("other");
        throw null;
    }

    @Override // okio.ByteString
    public byte[] internalArray$okio() {
        return toByteArray();
    }

    @Override // okio.ByteString
    public byte internalGet$okio(int i) {
        int i2;
        Util.checkOffsetAndCount((long) getDirectory$okio()[getSegments$okio().length - 1], (long) i, 1);
        int segment = SegmentedByteStringKt.segment(this, i);
        if (segment == 0) {
            i2 = 0;
        } else {
            i2 = getDirectory$okio()[segment - 1];
        }
        return getSegments$okio()[segment][(i - i2) + getDirectory$okio()[getSegments$okio().length + segment]];
    }

    @Override // okio.ByteString
    public int lastIndexOf(byte[] bArr, int i) {
        if (bArr != null) {
            return toByteString().lastIndexOf(bArr, i);
        }
        g00.f("other");
        throw null;
    }

    @Override // okio.ByteString
    public boolean rangeEquals(int i, ByteString byteString, int i2, int i3) {
        int i4;
        if (byteString == null) {
            g00.f("other");
            throw null;
        } else if (i < 0 || i > size() - i3) {
            return false;
        } else {
            int i5 = i3 + i;
            int segment = SegmentedByteStringKt.segment(this, i);
            while (i < i5) {
                if (segment == 0) {
                    i4 = 0;
                } else {
                    i4 = getDirectory$okio()[segment - 1];
                }
                int i6 = getDirectory$okio()[getSegments$okio().length + segment];
                int min = Math.min(i5, (getDirectory$okio()[segment] - i4) + i4) - i;
                if (!byteString.rangeEquals(i2, getSegments$okio()[segment], (i - i4) + i6, min)) {
                    return false;
                }
                i2 += min;
                i += min;
                segment++;
            }
            return true;
        }
    }

    @Override // okio.ByteString
    public String string(Charset charset) {
        if (charset != null) {
            return toByteString().string(charset);
        }
        g00.f("charset");
        throw null;
    }

    @Override // okio.ByteString
    public ByteString substring(int i, int i2) {
        int i3 = 0;
        if (i >= 0) {
            if (i2 <= size()) {
                int i4 = i2 - i;
                if (!(i4 >= 0)) {
                    throw new IllegalArgumentException(("endIndex=" + i2 + " < beginIndex=" + i).toString());
                } else if (i == 0 && i2 == size()) {
                    return this;
                } else {
                    if (i == i2) {
                        return ByteString.EMPTY;
                    }
                    int segment = SegmentedByteStringKt.segment(this, i);
                    int segment2 = SegmentedByteStringKt.segment(this, i2 - 1);
                    byte[][] bArr = (byte[][]) xz.d(getSegments$okio(), segment, segment2 + 1);
                    int[] iArr = new int[(bArr.length * 2)];
                    if (segment <= segment2) {
                        int i5 = 0;
                        int i6 = segment;
                        while (true) {
                            iArr[i5] = Math.min(getDirectory$okio()[i6] - i, i4);
                            int i7 = i5 + 1;
                            iArr[i5 + bArr.length] = getDirectory$okio()[getSegments$okio().length + i6];
                            if (i6 == segment2) {
                                break;
                            }
                            i6++;
                            i5 = i7;
                        }
                    }
                    if (segment != 0) {
                        i3 = getDirectory$okio()[segment - 1];
                    }
                    int length = bArr.length;
                    iArr[length] = (i - i3) + iArr[length];
                    return new SegmentedByteString(bArr, iArr);
                }
            } else {
                StringBuilder k = b2.k("endIndex=", i2, " > length(");
                k.append(size());
                k.append(')');
                throw new IllegalArgumentException(k.toString().toString());
            }
        } else {
            throw new IllegalArgumentException(b2.u("beginIndex=", i, " < 0").toString());
        }
    }

    @Override // okio.ByteString
    public ByteString toAsciiLowercase() {
        return toByteString().toAsciiLowercase();
    }

    @Override // okio.ByteString
    public ByteString toAsciiUppercase() {
        return toByteString().toAsciiUppercase();
    }

    @Override // okio.ByteString
    public byte[] toByteArray() {
        byte[] bArr = new byte[size()];
        int length = getSegments$okio().length;
        int i = 0;
        int i2 = 0;
        int i3 = 0;
        while (i < length) {
            int i4 = getDirectory$okio()[length + i];
            int i5 = getDirectory$okio()[i];
            int i6 = i5 - i2;
            xz.a(getSegments$okio()[i], bArr, i3, i4, i4 + i6);
            i3 += i6;
            i++;
            i2 = i5;
        }
        return bArr;
    }

    @Override // okio.ByteString
    public String toString() {
        return toByteString().toString();
    }

    @Override // okio.ByteString
    public void write(OutputStream outputStream) {
        if (outputStream != null) {
            int length = getSegments$okio().length;
            int i = 0;
            int i2 = 0;
            while (i < length) {
                int i3 = getDirectory$okio()[length + i];
                int i4 = getDirectory$okio()[i];
                outputStream.write(getSegments$okio()[i], i3, i4 - i2);
                i++;
                i2 = i4;
            }
            return;
        }
        g00.f("out");
        throw null;
    }

    @Override // okio.ByteString
    public void write$okio(Buffer buffer, int i, int i2) {
        int i3;
        if (buffer != null) {
            int i4 = i2 + i;
            int segment = SegmentedByteStringKt.segment(this, i);
            while (i < i4) {
                if (segment == 0) {
                    i3 = 0;
                } else {
                    i3 = getDirectory$okio()[segment - 1];
                }
                int i5 = getDirectory$okio()[getSegments$okio().length + segment];
                int min = Math.min(i4, (getDirectory$okio()[segment] - i3) + i3) - i;
                int i6 = (i - i3) + i5;
                Segment segment2 = new Segment(getSegments$okio()[segment], i6, i6 + min, true, false);
                Segment segment3 = buffer.head;
                if (segment3 == null) {
                    segment2.prev = segment2;
                    segment2.next = segment2;
                    buffer.head = segment2;
                } else if (segment3 != null) {
                    Segment segment4 = segment3.prev;
                    if (segment4 != null) {
                        segment4.push(segment2);
                    } else {
                        g00.e();
                        throw null;
                    }
                } else {
                    g00.e();
                    throw null;
                }
                i += min;
                segment++;
            }
            buffer.setSize$okio(buffer.size() + ((long) size()));
            return;
        }
        g00.f("buffer");
        throw null;
    }

    @Override // okio.ByteString
    public boolean rangeEquals(int i, byte[] bArr, int i2, int i3) {
        int i4;
        if (bArr == null) {
            g00.f("other");
            throw null;
        } else if (i < 0 || i > size() - i3 || i2 < 0 || i2 > bArr.length - i3) {
            return false;
        } else {
            int i5 = i3 + i;
            int segment = SegmentedByteStringKt.segment(this, i);
            while (i < i5) {
                if (segment == 0) {
                    i4 = 0;
                } else {
                    i4 = getDirectory$okio()[segment - 1];
                }
                int i6 = getDirectory$okio()[getSegments$okio().length + segment];
                int min = Math.min(i5, (getDirectory$okio()[segment] - i4) + i4) - i;
                if (!Util.arrayRangeEquals(getSegments$okio()[segment], (i - i4) + i6, bArr, i2, min)) {
                    return false;
                }
                i2 += min;
                i += min;
                segment++;
            }
            return true;
        }
    }
}
