package org.chromium.base;

import android.os.Handler;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

public class Promise<T> {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final int FULFILLED = 1;
    private static final int REJECTED = 2;
    private static final int UNFULFILLED = 0;
    private final List<Callback<T>> mFulfillCallbacks = new LinkedList();
    private final Handler mHandler = new Handler();
    private final List<Callback<Exception>> mRejectCallbacks = new LinkedList();
    private Exception mRejectReason;
    private T mResult;
    private int mState = 0;
    private final Thread mThread = Thread.currentThread();
    private boolean mThrowingRejectionHandler;

    public interface AsyncFunction<A, R> {
        Promise<R> apply(A a);
    }

    public interface Function<A, R> {
        R apply(A a);
    }

    public static class UnhandledRejectionException extends RuntimeException {
        public UnhandledRejectionException(String str, Throwable th) {
            super(str, th);
        }
    }

    private void checkThread() {
    }

    /* JADX DEBUG: Multi-variable search result rejected for r3v0, resolved type: org.chromium.base.Callback<java.lang.Exception> */
    /* JADX WARN: Multi-variable type inference failed */
    private void exceptInner(Callback<Exception> callback) {
        int i = this.mState;
        if (i == 2) {
            postCallbackToLooper(callback, this.mRejectReason);
        } else if (i == 0) {
            this.mRejectCallbacks.add(callback);
        }
    }

    public static <T> Promise<T> fulfilled(T t) {
        Promise<T> promise = new Promise<>();
        promise.fulfill(t);
        return promise;
    }

    private <S> void postCallbackToLooper(final Callback<S> callback, final S s) {
        this.mHandler.post(new Runnable() {
            /* class org.chromium.base.Promise.AnonymousClass5 */

            /* JADX DEBUG: Multi-variable search result rejected for r0v0, resolved type: org.chromium.base.Callback */
            /* JADX WARN: Multi-variable type inference failed */
            public void run() {
                callback.onResult(s);
            }
        });
    }

    /* access modifiers changed from: private */
    public static <T> Callback<Exception> rejectPromiseCallback(Promise<T> promise) {
        return new Callback<Exception>(promise) {
            /* class org.chromium.base.Promise.AnonymousClass6 */
            public final /* synthetic */ Promise val$promise;

            {
                this.val$promise = r1;
            }

            public void onResult(Exception exc) {
                this.val$promise.reject(exc);
            }
        };
    }

    /* JADX DEBUG: Multi-variable search result rejected for r3v0, resolved type: org.chromium.base.Callback<T> */
    /* JADX WARN: Multi-variable type inference failed */
    private void thenInner(Callback<T> callback) {
        int i = this.mState;
        if (i == 1) {
            postCallbackToLooper(callback, this.mResult);
        } else if (i == 0) {
            this.mFulfillCallbacks.add(callback);
        }
    }

    public void except(Callback<Exception> callback) {
        checkThread();
        exceptInner(callback);
    }

    /* JADX DEBUG: Type inference failed for r1v2. Raw type applied. Possible types: org.chromium.base.Callback<T>, org.chromium.base.Callback<S> */
    public void fulfill(T t) {
        checkThread();
        this.mState = 1;
        this.mResult = t;
        Iterator<Callback<T>> it = this.mFulfillCallbacks.iterator();
        while (it.hasNext()) {
            postCallbackToLooper((Callback<T>) it.next(), t);
        }
        this.mFulfillCallbacks.clear();
    }

    public Callback<T> fulfillmentCallback() {
        return new Callback<T>() {
            /* class org.chromium.base.Promise.AnonymousClass2 */

            @Override // org.chromium.base.Callback
            public void onResult(T t) {
                Promise.this.fulfill(t);
            }
        };
    }

    public boolean isFulfilled() {
        checkThread();
        return this.mState == 1;
    }

    public boolean isRejected() {
        checkThread();
        return this.mState == 2;
    }

    public void reject(Exception exc) {
        checkThread();
        this.mState = 2;
        this.mRejectReason = exc;
        Iterator<Callback<Exception>> it = this.mRejectCallbacks.iterator();
        while (it.hasNext()) {
            postCallbackToLooper((Callback<S>) it.next(), exc);
        }
        this.mRejectCallbacks.clear();
    }

    public void then(Callback<T> callback) {
        checkThread();
        if (this.mThrowingRejectionHandler) {
            thenInner(callback);
            return;
        }
        then(callback, new Callback<Exception>() {
            /* class org.chromium.base.Promise.AnonymousClass1 */

            public void onResult(Exception exc) {
                throw new UnhandledRejectionException("Promise was rejected without a rejection handler.", exc);
            }
        });
        this.mThrowingRejectionHandler = true;
    }

    public void reject() {
        reject(null);
    }

    public void then(Callback<T> callback, Callback<Exception> callback2) {
        checkThread();
        thenInner(callback);
        exceptInner(callback2);
    }

    public <R> Promise<R> then(final Function<T, R> function) {
        checkThread();
        final Promise<R> promise = new Promise<>();
        thenInner(new Callback<T>() {
            /* class org.chromium.base.Promise.AnonymousClass3 */

            /* JADX DEBUG: Multi-variable search result rejected for r0v1, resolved type: org.chromium.base.Promise */
            /* JADX WARN: Multi-variable type inference failed */
            @Override // org.chromium.base.Callback
            public void onResult(T t) {
                try {
                    promise.fulfill(function.apply(t));
                } catch (Exception e) {
                    promise.reject(e);
                }
            }
        });
        exceptInner(rejectPromiseCallback(promise));
        return promise;
    }

    public <R> Promise<R> then(final AsyncFunction<T, R> asyncFunction) {
        checkThread();
        final Promise<R> promise = new Promise<>();
        thenInner(new Callback<T>() {
            /* class org.chromium.base.Promise.AnonymousClass4 */

            @Override // org.chromium.base.Callback
            public void onResult(T t) {
                try {
                    asyncFunction.apply(t).then(new Callback<R>() {
                        /* class org.chromium.base.Promise.AnonymousClass4.AnonymousClass1 */

                        @Override // org.chromium.base.Callback
                        public void onResult(R r) {
                            promise.fulfill(r);
                        }
                    }, Promise.rejectPromiseCallback(promise));
                } catch (Exception e) {
                    promise.reject(e);
                }
            }
        });
        exceptInner(rejectPromiseCallback(promise));
        return promise;
    }
}
