package org.chromium.media;

import android.content.Context;
import android.media.MediaPlayer;
import android.net.Uri;
import android.os.AsyncTask;
import android.os.Build;
import android.os.ParcelFileDescriptor;
import android.text.TextUtils;
import android.util.Base64InputStream;
import android.view.Surface;
import androidx.base.b2;
import androidx.base.bx;
import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.HashMap;
import org.chromium.base.Log;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;

@JNINamespace("media")
public class MediaPlayerBridge {
    private static final String TAG = "MediaPlayerBridge";
    private static ResourceLoadingFilter sResourceLoadFilter;
    private LoadDataUriTask mLoadDataUriTask;
    private long mNativeMediaPlayerBridge;
    private MediaPlayer mPlayer;

    public static class AllowedOperations {
        private final boolean mCanPause;
        private final boolean mCanSeekBackward;
        private final boolean mCanSeekForward;

        public AllowedOperations(boolean z, boolean z2, boolean z3) {
            this.mCanPause = z;
            this.mCanSeekForward = z2;
            this.mCanSeekBackward = z3;
        }

        @CalledByNative("AllowedOperations")
        private boolean canPause() {
            return this.mCanPause;
        }

        @CalledByNative("AllowedOperations")
        private boolean canSeekBackward() {
            return this.mCanSeekBackward;
        }

        @CalledByNative("AllowedOperations")
        private boolean canSeekForward() {
            return this.mCanSeekForward;
        }
    }

    public class LoadDataUriTask extends AsyncTask<Void, Void, Boolean> {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        private final Context mContext;
        private final String mData;
        private File mTempFile;

        public LoadDataUriTask(Context context, String str) {
            this.mData = str;
            this.mContext = context;
        }

        private void deleteFile() {
            File file = this.mTempFile;
            if (file != null && !file.delete()) {
                StringBuilder j = b2.j("Failed to delete temporary file: ");
                j.append(this.mTempFile);
                Log.e(MediaPlayerBridge.TAG, j.toString(), new Object[0]);
            }
        }

        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:18:0x0044 */
        /* JADX WARNING: Removed duplicated region for block: B:21:0x0048 A[SYNTHETIC, Splitter:B:21:0x0048] */
        /* JADX WARNING: Removed duplicated region for block: B:26:0x004e A[SYNTHETIC, Splitter:B:26:0x004e] */
        public Boolean doInBackground(Void... voidArr) {
            Throwable th;
            FileOutputStream fileOutputStream = null;
            this.mTempFile = File.createTempFile("decoded", "mediadata");
            FileOutputStream fileOutputStream2 = new FileOutputStream(this.mTempFile);
            try {
                Base64InputStream base64InputStream = new Base64InputStream(new ByteArrayInputStream(this.mData.getBytes()), 0);
                byte[] bArr = new byte[1024];
                while (true) {
                    int read = base64InputStream.read(bArr);
                    if (read == -1) {
                        break;
                    }
                    fileOutputStream2.write(bArr, 0, read);
                }
                base64InputStream.close();
                Boolean bool = Boolean.TRUE;
                try {
                    fileOutputStream2.close();
                } catch (IOException unused) {
                }
                return bool;
            } catch (IOException unused2) {
                fileOutputStream = fileOutputStream2;
                try {
                    Boolean bool2 = Boolean.FALSE;
                    if (fileOutputStream != null) {
                        try {
                            fileOutputStream.close();
                        } catch (IOException unused3) {
                        }
                    }
                    return bool2;
                } catch (Throwable th2) {
                    fileOutputStream2 = fileOutputStream;
                    th = th2;
                    if (fileOutputStream2 != null) {
                    }
                    throw th;
                }
            } catch (Throwable th3) {
                th = th3;
                if (fileOutputStream2 != null) {
                    try {
                        fileOutputStream2.close();
                    } catch (IOException unused4) {
                    }
                }
                throw th;
            }
        }

        public void onPostExecute(Boolean bool) {
            if (isCancelled()) {
                deleteFile();
                return;
            }
            try {
                MediaPlayerBridge.this.getLocalPlayer().setDataSource(this.mContext, Uri.fromFile(this.mTempFile));
            } catch (IOException unused) {
                bool = Boolean.FALSE;
            }
            deleteFile();
            MediaPlayerBridge mediaPlayerBridge = MediaPlayerBridge.this;
            mediaPlayerBridge.nativeOnDidSetDataUriDataSource(mediaPlayerBridge.mNativeMediaPlayerBridge, bool.booleanValue());
        }
    }

    public static class ResourceLoadingFilter {
        public boolean shouldOverrideResourceLoading(MediaPlayer mediaPlayer, Context context, Uri uri) {
            return false;
        }
    }

    public MediaPlayerBridge(long j) {
        this.mNativeMediaPlayerBridge = j;
    }

    @CalledByNative
    private static MediaPlayerBridge create(long j) {
        return new MediaPlayerBridge(j);
    }

    private boolean hasTrack(int i) {
        try {
            MediaPlayer.TrackInfo[] trackInfo = getLocalPlayer().getTrackInfo();
            if (trackInfo.length == 0) {
                return true;
            }
            for (MediaPlayer.TrackInfo trackInfo2 : trackInfo) {
                if (i == trackInfo2.getTrackType() || trackInfo2.getTrackType() == 0) {
                    return true;
                }
            }
            return false;
        } catch (RuntimeException unused) {
            return true;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native void nativeOnDidSetDataUriDataSource(long j, boolean z);

    public static void setResourceLoadingFilter(ResourceLoadingFilter resourceLoadingFilter) {
        sResourceLoadFilter = resourceLoadingFilter;
    }

    @CalledByNative
    public void destroy() {
        LoadDataUriTask loadDataUriTask = this.mLoadDataUriTask;
        if (loadDataUriTask != null) {
            loadDataUriTask.cancel(true);
            this.mLoadDataUriTask = null;
        }
        this.mNativeMediaPlayerBridge = 0;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:21:0x00fb, code lost:
        if (((java.lang.Boolean) r6.invoke(r1, java.lang.Integer.valueOf(r4))).booleanValue() != false) goto L_0x00fd;
     */
    /* JADX WARNING: Removed duplicated region for block: B:13:0x00bd A[Catch:{ NoSuchMethodException -> 0x010f, InvocationTargetException -> 0x010d, IllegalAccessException -> 0x010b, NoSuchFieldException -> 0x0109 }] */
    /* JADX WARNING: Removed duplicated region for block: B:20:0x00e9 A[Catch:{ NoSuchMethodException -> 0x0107, InvocationTargetException -> 0x0105, IllegalAccessException -> 0x0103, NoSuchFieldException -> 0x0101 }] */
    @CalledByNative
    public AllowedOperations getAllowedOperations() {
        boolean z;
        boolean z2;
        NoSuchMethodException e;
        InvocationTargetException e2;
        IllegalAccessException e3;
        NoSuchFieldException e4;
        MediaPlayer localPlayer = getLocalPlayer();
        boolean z3 = false;
        boolean z4 = true;
        try {
            Class<?> cls = localPlayer.getClass();
            Class<?> cls2 = Boolean.TYPE;
            Method declaredMethod = cls.getDeclaredMethod("getMetadata", cls2, cls2);
            declaredMethod.setAccessible(true);
            Boolean bool = Boolean.FALSE;
            Object invoke = declaredMethod.invoke(localPlayer, bool, bool);
            if (invoke != null) {
                Class<?> cls3 = invoke.getClass();
                Class<?> cls4 = Integer.TYPE;
                Method declaredMethod2 = cls3.getDeclaredMethod("has", cls4);
                Method declaredMethod3 = cls3.getDeclaredMethod("getBoolean", cls4);
                int intValue = ((Integer) cls3.getField("PAUSE_AVAILABLE").get(null)).intValue();
                int intValue2 = ((Integer) cls3.getField("SEEK_FORWARD_AVAILABLE").get(null)).intValue();
                int intValue3 = ((Integer) cls3.getField("SEEK_BACKWARD_AVAILABLE").get(null)).intValue();
                declaredMethod2.setAccessible(true);
                declaredMethod3.setAccessible(true);
                if (((Boolean) declaredMethod2.invoke(invoke, Integer.valueOf(intValue))).booleanValue()) {
                    if (!((Boolean) declaredMethod3.invoke(invoke, Integer.valueOf(intValue))).booleanValue()) {
                        z2 = false;
                        if (((Boolean) declaredMethod2.invoke(invoke, Integer.valueOf(intValue2))).booleanValue()) {
                            if (!((Boolean) declaredMethod3.invoke(invoke, Integer.valueOf(intValue2))).booleanValue()) {
                                z = false;
                                if (((Boolean) declaredMethod2.invoke(invoke, Integer.valueOf(intValue3))).booleanValue()) {
                                }
                                z3 = true;
                                z4 = z2;
                            }
                        }
                        z = true;
                        if (((Boolean) declaredMethod2.invoke(invoke, Integer.valueOf(intValue3))).booleanValue()) {
                        }
                        z3 = true;
                        z4 = z2;
                    }
                }
                z2 = true;
                try {
                    if (((Boolean) declaredMethod2.invoke(invoke, Integer.valueOf(intValue2))).booleanValue()) {
                    }
                    z = true;
                } catch (NoSuchMethodException e5) {
                    e = e5;
                    z = true;
                    Log.e(TAG, "Cannot find getMetadata() method: " + e, new Object[0]);
                    z4 = z2;
                    z3 = true;
                    return new AllowedOperations(z4, z, z3);
                } catch (InvocationTargetException e6) {
                    e2 = e6;
                    z = true;
                    Log.e(TAG, "Cannot invoke MediaPlayer.getMetadata() method: " + e2, new Object[0]);
                    z4 = z2;
                    z3 = true;
                    return new AllowedOperations(z4, z, z3);
                } catch (IllegalAccessException e7) {
                    e3 = e7;
                    z = true;
                    Log.e(TAG, "Cannot access metadata: " + e3, new Object[0]);
                    z4 = z2;
                    z3 = true;
                    return new AllowedOperations(z4, z, z3);
                } catch (NoSuchFieldException e8) {
                    e4 = e8;
                    z = true;
                    Log.e(TAG, "Cannot find matching fields in Metadata class: " + e4, new Object[0]);
                    z4 = z2;
                    z3 = true;
                    return new AllowedOperations(z4, z, z3);
                }
                try {
                    if (((Boolean) declaredMethod2.invoke(invoke, Integer.valueOf(intValue3))).booleanValue()) {
                    }
                    z3 = true;
                    z4 = z2;
                } catch (NoSuchMethodException e9) {
                    e = e9;
                    Log.e(TAG, "Cannot find getMetadata() method: " + e, new Object[0]);
                    z4 = z2;
                    z3 = true;
                    return new AllowedOperations(z4, z, z3);
                } catch (InvocationTargetException e10) {
                    e2 = e10;
                    Log.e(TAG, "Cannot invoke MediaPlayer.getMetadata() method: " + e2, new Object[0]);
                    z4 = z2;
                    z3 = true;
                    return new AllowedOperations(z4, z, z3);
                } catch (IllegalAccessException e11) {
                    e3 = e11;
                    Log.e(TAG, "Cannot access metadata: " + e3, new Object[0]);
                    z4 = z2;
                    z3 = true;
                    return new AllowedOperations(z4, z, z3);
                } catch (NoSuchFieldException e12) {
                    e4 = e12;
                    Log.e(TAG, "Cannot find matching fields in Metadata class: " + e4, new Object[0]);
                    z4 = z2;
                    z3 = true;
                    return new AllowedOperations(z4, z, z3);
                }
            } else {
                z3 = true;
                z = true;
            }
        } catch (NoSuchMethodException e13) {
            e = e13;
            z2 = true;
            z = true;
            Log.e(TAG, "Cannot find getMetadata() method: " + e, new Object[0]);
            z4 = z2;
            z3 = true;
            return new AllowedOperations(z4, z, z3);
        } catch (InvocationTargetException e14) {
            e2 = e14;
            z2 = true;
            z = true;
            Log.e(TAG, "Cannot invoke MediaPlayer.getMetadata() method: " + e2, new Object[0]);
            z4 = z2;
            z3 = true;
            return new AllowedOperations(z4, z, z3);
        } catch (IllegalAccessException e15) {
            e3 = e15;
            z2 = true;
            z = true;
            Log.e(TAG, "Cannot access metadata: " + e3, new Object[0]);
            z4 = z2;
            z3 = true;
            return new AllowedOperations(z4, z, z3);
        } catch (NoSuchFieldException e16) {
            e4 = e16;
            z2 = true;
            z = true;
            Log.e(TAG, "Cannot find matching fields in Metadata class: " + e4, new Object[0]);
            z4 = z2;
            z3 = true;
            return new AllowedOperations(z4, z, z3);
        }
        return new AllowedOperations(z4, z, z3);
    }

    @CalledByNative
    public int getCurrentPosition() {
        return getLocalPlayer().getCurrentPosition();
    }

    @CalledByNative
    public int getDuration() {
        return getLocalPlayer().getDuration();
    }

    public MediaPlayer getLocalPlayer() {
        if (this.mPlayer == null) {
            this.mPlayer = new MediaPlayer();
        }
        return this.mPlayer;
    }

    @CalledByNative
    public int getVideoHeight() {
        return getLocalPlayer().getVideoHeight();
    }

    @CalledByNative
    public int getVideoWidth() {
        return getLocalPlayer().getVideoWidth();
    }

    @CalledByNative
    public boolean hasAudio() {
        return hasTrack(2);
    }

    @CalledByNative
    public boolean hasVideo() {
        return hasTrack(1);
    }

    @CalledByNative
    public boolean isPlaying() {
        return getLocalPlayer().isPlaying();
    }

    @CalledByNative
    public void pause() {
        getLocalPlayer().pause();
    }

    @CalledByNative
    public boolean prepareAsync() {
        try {
            getLocalPlayer().prepareAsync();
            return true;
        } catch (IllegalStateException e) {
            Log.e(TAG, "Unable to prepare MediaPlayer.", e);
            return false;
        } catch (Exception e2) {
            Log.e(TAG, "Unable to prepare MediaPlayer.", e2);
            return false;
        }
    }

    @CalledByNative
    public void release() {
        getLocalPlayer().release();
    }

    @CalledByNative
    public void seekTo(int i) {
        getLocalPlayer().seekTo(i);
    }

    @CalledByNative
    public boolean setDataSource(Context context, String str, String str2, String str3, boolean z) {
        Uri parse = Uri.parse(str);
        HashMap hashMap = new HashMap();
        if (z) {
            hashMap.put("x-hide-urls-from-log", "true");
        }
        if (!TextUtils.isEmpty(str2)) {
            hashMap.put(bx.HEAD_KEY_COOKIE, str2);
        }
        if (!TextUtils.isEmpty(str3)) {
            hashMap.put(bx.HEAD_KEY_USER_AGENT, str3);
        }
        if (Build.VERSION.SDK_INT > 19) {
            hashMap.put("allow-cross-domain-redirect", "false");
        }
        try {
            ResourceLoadingFilter resourceLoadingFilter = sResourceLoadFilter;
            if (resourceLoadingFilter != null && resourceLoadingFilter.shouldOverrideResourceLoading(getLocalPlayer(), context, parse)) {
                return true;
            }
            getLocalPlayer().setDataSource(context, parse, hashMap);
            return true;
        } catch (Exception unused) {
            return false;
        }
    }

    @CalledByNative
    public boolean setDataSourceFromFd(int i, long j, long j2) {
        try {
            ParcelFileDescriptor adoptFd = ParcelFileDescriptor.adoptFd(i);
            getLocalPlayer().setDataSource(adoptFd.getFileDescriptor(), j, j2);
            adoptFd.close();
            return true;
        } catch (IOException e) {
            Log.e(TAG, "Failed to set data source from file descriptor: " + e, new Object[0]);
            return false;
        }
    }

    @CalledByNative
    public boolean setDataUriDataSource(Context context, String str) {
        int indexOf;
        LoadDataUriTask loadDataUriTask = this.mLoadDataUriTask;
        if (loadDataUriTask != null) {
            loadDataUriTask.cancel(true);
            this.mLoadDataUriTask = null;
        }
        if (!str.startsWith("data:") || (indexOf = str.indexOf(44)) == -1) {
            return false;
        }
        String substring = str.substring(0, indexOf);
        String substring2 = str.substring(indexOf + 1);
        String[] split = substring.substring(5).split(";");
        if (split.length != 2 || !"base64".equals(split[1])) {
            return false;
        }
        LoadDataUriTask loadDataUriTask2 = new LoadDataUriTask(context, substring2);
        this.mLoadDataUriTask = loadDataUriTask2;
        loadDataUriTask2.executeOnExecutor(AsyncTask.THREAD_POOL_EXECUTOR, new Void[0]);
        return true;
    }

    public void setOnBufferingUpdateListener(MediaPlayer.OnBufferingUpdateListener onBufferingUpdateListener) {
        getLocalPlayer().setOnBufferingUpdateListener(onBufferingUpdateListener);
    }

    public void setOnCompletionListener(MediaPlayer.OnCompletionListener onCompletionListener) {
        getLocalPlayer().setOnCompletionListener(onCompletionListener);
    }

    public void setOnErrorListener(MediaPlayer.OnErrorListener onErrorListener) {
        getLocalPlayer().setOnErrorListener(onErrorListener);
    }

    public void setOnPreparedListener(MediaPlayer.OnPreparedListener onPreparedListener) {
        getLocalPlayer().setOnPreparedListener(onPreparedListener);
    }

    public void setOnSeekCompleteListener(MediaPlayer.OnSeekCompleteListener onSeekCompleteListener) {
        getLocalPlayer().setOnSeekCompleteListener(onSeekCompleteListener);
    }

    public void setOnVideoSizeChangedListener(MediaPlayer.OnVideoSizeChangedListener onVideoSizeChangedListener) {
        getLocalPlayer().setOnVideoSizeChangedListener(onVideoSizeChangedListener);
    }

    @CalledByNative
    public void setSurface(Surface surface) {
        getLocalPlayer().setSurface(surface);
    }

    @CalledByNative
    public void setVolume(double d) {
        float f = (float) d;
        getLocalPlayer().setVolume(f, f);
    }

    @CalledByNative
    public void start() {
        getLocalPlayer().start();
    }

    public MediaPlayerBridge() {
    }
}
