package org.chromium.media;

import android.annotation.TargetApi;
import android.content.Context;
import android.graphics.Rect;
import android.hardware.camera2.CameraAccessException;
import android.hardware.camera2.CameraCaptureSession;
import android.hardware.camera2.CameraCharacteristics;
import android.hardware.camera2.CameraDevice;
import android.hardware.camera2.CameraManager;
import android.hardware.camera2.CaptureRequest;
import android.hardware.camera2.params.StreamConfigurationMap;
import android.media.Image;
import android.media.ImageReader;
import android.os.Handler;
import android.os.HandlerThread;
import android.util.Size;
import androidx.base.b2;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import org.chromium.base.Log;
import org.chromium.base.annotations.JNINamespace;

@JNINamespace("media")
@TargetApi(21)
public class VideoCaptureCamera2 extends VideoCapture {
    private static final String TAG = "VideoCapture";
    private static final double kNanoSecondsToFps = 1.0E-9d;
    private CameraDevice mCameraDevice;
    private CameraState mCameraState = CameraState.STOPPED;
    private final Object mCameraStateLock = new Object();
    private byte[] mCapturedData;
    private CaptureRequest mPreviewRequest;
    private CameraCaptureSession mPreviewSession;

    public enum CameraState {
        OPENING,
        CONFIGURING,
        STARTED,
        STOPPED
    }

    public class CrImageReaderListener implements ImageReader.OnImageAvailableListener {
        private CrImageReaderListener() {
        }

        /* JADX WARNING: Code restructure failed: missing block: B:24:0x00d1, code lost:
            r9 = move-exception;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:26:?, code lost:
            r1.close();
         */
        /* JADX WARNING: Code restructure failed: missing block: B:27:0x00d5, code lost:
            throw r9;
         */
        public void onImageAvailable(ImageReader imageReader) {
            try {
                Image acquireLatestImage = imageReader.acquireLatestImage();
                if (acquireLatestImage == null) {
                    if (acquireLatestImage != null) {
                        acquireLatestImage.close();
                    }
                } else if (acquireLatestImage.getFormat() != 35 || acquireLatestImage.getPlanes().length != 3) {
                    VideoCaptureCamera2 videoCaptureCamera2 = VideoCaptureCamera2.this;
                    long j = videoCaptureCamera2.mNativeVideoCaptureDeviceAndroid;
                    videoCaptureCamera2.nativeOnError(j, "Unexpected image format: " + acquireLatestImage.getFormat() + " or #planes: " + acquireLatestImage.getPlanes().length);
                    throw new IllegalStateException();
                } else if (imageReader.getWidth() == acquireLatestImage.getWidth() && imageReader.getHeight() == acquireLatestImage.getHeight()) {
                    VideoCaptureCamera2.readImageIntoBuffer(acquireLatestImage, VideoCaptureCamera2.this.mCapturedData);
                    VideoCaptureCamera2 videoCaptureCamera22 = VideoCaptureCamera2.this;
                    videoCaptureCamera22.nativeOnFrameAvailable(videoCaptureCamera22.mNativeVideoCaptureDeviceAndroid, videoCaptureCamera22.mCapturedData, VideoCaptureCamera2.this.mCapturedData.length, VideoCaptureCamera2.this.getCameraRotation());
                    acquireLatestImage.close();
                } else {
                    VideoCaptureCamera2 videoCaptureCamera23 = VideoCaptureCamera2.this;
                    long j2 = videoCaptureCamera23.mNativeVideoCaptureDeviceAndroid;
                    videoCaptureCamera23.nativeOnError(j2, "ImageReader size (" + imageReader.getWidth() + "x" + imageReader.getHeight() + ") did not match Image size (" + acquireLatestImage.getWidth() + "x" + acquireLatestImage.getHeight() + ")");
                    throw new IllegalStateException();
                }
            } catch (IllegalStateException e) {
                Log.e(VideoCaptureCamera2.TAG, "acquireLatestImage():", e);
            }
        }
    }

    public class CrPhotoReaderListener implements ImageReader.OnImageAvailableListener {
        private final long mCallbackId;

        public CrPhotoReaderListener(long j) {
            this.mCallbackId = j;
        }

        /* JADX DEBUG: Failed to insert an additional move for type inference into block B:1:0x0002 */
        /* JADX DEBUG: Multi-variable search result rejected for r4v0, resolved type: android.media.Image */
        /* JADX DEBUG: Multi-variable search result rejected for r4v1, resolved type: android.media.Image */
        /* JADX WARN: Multi-variable type inference failed */
        /* JADX WARN: Type inference failed for: r4v5, types: [byte[]] */
        /* JADX WARNING: Code restructure failed: missing block: B:5:?, code lost:
            r4 = r4.getPlanes()[0].getBuffer();
            r1 = new byte[r4.remaining()];
            r4.get(r1);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:7:?, code lost:
            return r1;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:8:?, code lost:
            return r1;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:4:0x0011 */
        private byte[] readCapturedData(Image image) {
            byte[] bArr = null;
            image = image.getPlanes()[0].getBuffer().array();
            return image;
        }

        /* JADX WARNING: Code restructure failed: missing block: B:20:0x0066, code lost:
            r0 = move-exception;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:21:0x0067, code lost:
            if (r10 != null) goto L_0x0069;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:23:?, code lost:
            r10.close();
         */
        /* JADX WARNING: Code restructure failed: missing block: B:24:0x006c, code lost:
            throw r0;
         */
        public void onImageAvailable(ImageReader imageReader) {
            StringBuilder j = b2.j("CrPhotoReaderListener.mCallbackId ");
            j.append(this.mCallbackId);
            Log.d(VideoCaptureCamera2.TAG, j.toString());
            try {
                Image acquireLatestImage = imageReader.acquireLatestImage();
                if (acquireLatestImage == null) {
                    throw new IllegalStateException();
                } else if (acquireLatestImage.getFormat() == 256) {
                    byte[] readCapturedData = readCapturedData(acquireLatestImage);
                    VideoCaptureCamera2 videoCaptureCamera2 = VideoCaptureCamera2.this;
                    videoCaptureCamera2.nativeOnPhotoTaken(videoCaptureCamera2.mNativeVideoCaptureDeviceAndroid, this.mCallbackId, readCapturedData);
                    acquireLatestImage.close();
                    if (!VideoCaptureCamera2.this.createPreviewObjects()) {
                        VideoCaptureCamera2 videoCaptureCamera22 = VideoCaptureCamera2.this;
                        videoCaptureCamera22.nativeOnError(videoCaptureCamera22.mNativeVideoCaptureDeviceAndroid, "Error restarting preview");
                    }
                } else {
                    Log.e(VideoCaptureCamera2.TAG, "Unexpected image format: %d", Integer.valueOf(acquireLatestImage.getFormat()));
                    throw new IllegalStateException();
                }
            } catch (IllegalStateException unused) {
                VideoCaptureCamera2.this.notifyTakePhotoError(this.mCallbackId);
            }
        }
    }

    public class CrPhotoSessionListener extends CameraCaptureSession.StateCallback {
        private final long mCallbackId;
        private final CaptureRequest mPhotoRequest;

        public CrPhotoSessionListener(CaptureRequest captureRequest, long j) {
            this.mPhotoRequest = captureRequest;
            this.mCallbackId = j;
        }

        public void onConfigureFailed(CameraCaptureSession cameraCaptureSession) {
            Log.e(VideoCaptureCamera2.TAG, "failed configuring capture session", new Object[0]);
            VideoCaptureCamera2.this.notifyTakePhotoError(this.mCallbackId);
        }

        public void onConfigured(CameraCaptureSession cameraCaptureSession) {
            Log.d(VideoCaptureCamera2.TAG, "onConfigured");
            try {
                cameraCaptureSession.capture(this.mPhotoRequest, null, null);
            } catch (CameraAccessException unused) {
                Log.e(VideoCaptureCamera2.TAG, "capture() error", new Object[0]);
                VideoCaptureCamera2.this.notifyTakePhotoError(this.mCallbackId);
            }
        }
    }

    public class CrPreviewSessionListener extends CameraCaptureSession.StateCallback {
        private final CaptureRequest mPreviewRequest;

        public CrPreviewSessionListener(CaptureRequest captureRequest) {
            this.mPreviewRequest = captureRequest;
        }

        public void onConfigureFailed(CameraCaptureSession cameraCaptureSession) {
            VideoCaptureCamera2.this.changeCameraStateAndNotify(CameraState.STOPPED);
            VideoCaptureCamera2 videoCaptureCamera2 = VideoCaptureCamera2.this;
            videoCaptureCamera2.nativeOnError(videoCaptureCamera2.mNativeVideoCaptureDeviceAndroid, "Camera session configuration error");
        }

        public void onConfigured(CameraCaptureSession cameraCaptureSession) {
            Log.d(VideoCaptureCamera2.TAG, "onConfigured");
            VideoCaptureCamera2.this.mPreviewSession = cameraCaptureSession;
            try {
                VideoCaptureCamera2.this.mPreviewSession.setRepeatingRequest(this.mPreviewRequest, null, null);
                VideoCaptureCamera2.this.changeCameraStateAndNotify(CameraState.STARTED);
            } catch (CameraAccessException | IllegalArgumentException | SecurityException e) {
                Log.e(VideoCaptureCamera2.TAG, "setRepeatingRequest: ", e);
            }
        }
    }

    public class CrStateListener extends CameraDevice.StateCallback {
        private CrStateListener() {
        }

        public void onDisconnected(CameraDevice cameraDevice) {
            cameraDevice.close();
            VideoCaptureCamera2.this.mCameraDevice = null;
            VideoCaptureCamera2.this.changeCameraStateAndNotify(CameraState.STOPPED);
        }

        public void onError(CameraDevice cameraDevice, int i) {
            cameraDevice.close();
            VideoCaptureCamera2.this.mCameraDevice = null;
            VideoCaptureCamera2.this.changeCameraStateAndNotify(CameraState.STOPPED);
            VideoCaptureCamera2 videoCaptureCamera2 = VideoCaptureCamera2.this;
            long j = videoCaptureCamera2.mNativeVideoCaptureDeviceAndroid;
            StringBuilder j2 = b2.j("Camera device error ");
            j2.append(Integer.toString(i));
            videoCaptureCamera2.nativeOnError(j, j2.toString());
        }

        public void onOpened(CameraDevice cameraDevice) {
            VideoCaptureCamera2.this.mCameraDevice = cameraDevice;
            VideoCaptureCamera2.this.changeCameraStateAndNotify(CameraState.CONFIGURING);
            if (!VideoCaptureCamera2.this.createPreviewObjects()) {
                VideoCaptureCamera2.this.changeCameraStateAndNotify(CameraState.STOPPED);
                VideoCaptureCamera2 videoCaptureCamera2 = VideoCaptureCamera2.this;
                videoCaptureCamera2.nativeOnError(videoCaptureCamera2.mNativeVideoCaptureDeviceAndroid, "Error configuring camera");
            }
        }
    }

    public VideoCaptureCamera2(Context context, int i, long j) {
        super(context, i, j);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void changeCameraStateAndNotify(CameraState cameraState) {
        synchronized (this.mCameraStateLock) {
            this.mCameraState = cameraState;
            this.mCameraStateLock.notifyAll();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean createPreviewObjects() {
        Log.d(TAG, "createPreviewObjects");
        if (this.mCameraDevice == null) {
            return false;
        }
        ImageReader newInstance = ImageReader.newInstance(this.mCaptureFormat.getWidth(), this.mCaptureFormat.getHeight(), this.mCaptureFormat.getPixelFormat(), 2);
        HandlerThread handlerThread = new HandlerThread("CameraPreview");
        handlerThread.start();
        newInstance.setOnImageAvailableListener(new CrImageReaderListener(), new Handler(handlerThread.getLooper()));
        try {
            CaptureRequest.Builder createCaptureRequest = this.mCameraDevice.createCaptureRequest(1);
            if (createCaptureRequest == null) {
                Log.e(TAG, "previewRequestBuilder error", new Object[0]);
                return false;
            }
            createCaptureRequest.addTarget(newInstance.getSurface());
            createCaptureRequest.set(CaptureRequest.CONTROL_MODE, 1);
            createCaptureRequest.set(CaptureRequest.NOISE_REDUCTION_MODE, 1);
            createCaptureRequest.set(CaptureRequest.EDGE_MODE, 1);
            createCaptureRequest.set(CaptureRequest.CONTROL_VIDEO_STABILIZATION_MODE, 1);
            ArrayList arrayList = new ArrayList(1);
            arrayList.add(newInstance.getSurface());
            this.mPreviewRequest = createCaptureRequest.build();
            try {
                this.mCameraDevice.createCaptureSession(arrayList, new CrPreviewSessionListener(this.mPreviewRequest), null);
                return true;
            } catch (CameraAccessException | IllegalArgumentException | SecurityException e) {
                Log.e(TAG, "createCaptureSession: ", e);
                return false;
            }
        } catch (CameraAccessException | IllegalArgumentException | SecurityException e2) {
            Log.e(TAG, "createCaptureRequest: ", e2);
            return false;
        }
    }

    private static CameraCharacteristics getCameraCharacteristics(Context context, int i) {
        try {
            return ((CameraManager) context.getSystemService("camera")).getCameraCharacteristics(Integer.toString(i));
        } catch (CameraAccessException e) {
            Log.e(TAG, "getCameraCharacteristics: ", e);
            return null;
        }
    }

    public static int getCaptureApiType(int i, Context context) {
        CameraCharacteristics cameraCharacteristics = getCameraCharacteristics(context, i);
        if (cameraCharacteristics == null) {
            return 5;
        }
        int intValue = ((Integer) cameraCharacteristics.get(CameraCharacteristics.INFO_SUPPORTED_HARDWARE_LEVEL)).intValue();
        if (intValue != 0) {
            return intValue != 1 ? 1 : 2;
        }
        return 3;
    }

    public static VideoCaptureFormat[] getDeviceSupportedFormats(Context context, int i) {
        boolean z;
        CameraCharacteristics cameraCharacteristics = getCameraCharacteristics(context, i);
        if (cameraCharacteristics == null) {
            return null;
        }
        int[] iArr = (int[]) cameraCharacteristics.get(CameraCharacteristics.REQUEST_AVAILABLE_CAPABILITIES);
        int length = iArr.length;
        int i2 = 0;
        while (true) {
            z = true;
            if (i2 >= length) {
                z = false;
                break;
            } else if (iArr[i2] == 1) {
                break;
            } else {
                i2++;
            }
        }
        ArrayList arrayList = new ArrayList();
        StreamConfigurationMap streamConfigurationMap = (StreamConfigurationMap) cameraCharacteristics.get(CameraCharacteristics.SCALER_STREAM_CONFIGURATION_MAP);
        int[] outputFormats = streamConfigurationMap.getOutputFormats();
        for (int i3 : outputFormats) {
            Size[] outputSizes = streamConfigurationMap.getOutputSizes(i3);
            if (outputSizes != null) {
                for (Size size : outputSizes) {
                    double d = 0.0d;
                    if (z) {
                        long outputMinFrameDuration = streamConfigurationMap.getOutputMinFrameDuration(i3, size);
                        if (outputMinFrameDuration != 0) {
                            double d2 = (double) outputMinFrameDuration;
                            Double.isNaN(d2);
                            d = d2 * 9.999999999999999E8d;
                        }
                    }
                    arrayList.add(new VideoCaptureFormat(size.getWidth(), size.getHeight(), (int) d, 0));
                }
            }
        }
        return (VideoCaptureFormat[]) arrayList.toArray(new VideoCaptureFormat[arrayList.size()]);
    }

    public static String getName(int i, Context context) {
        CameraCharacteristics cameraCharacteristics = getCameraCharacteristics(context, i);
        if (cameraCharacteristics == null) {
            return null;
        }
        int intValue = ((Integer) cameraCharacteristics.get(CameraCharacteristics.LENS_FACING)).intValue();
        StringBuilder k = b2.k("camera2 ", i, ", facing ");
        k.append(intValue == 0 ? "front" : "back");
        return k.toString();
    }

    public static int getNumberOfCameras(Context context) {
        try {
            return ((CameraManager) context.getSystemService("camera")).getCameraIdList().length;
        } catch (CameraAccessException | SecurityException e) {
            Log.e(TAG, "getNumberOfCameras: getCameraIdList(): ", e);
            return 0;
        }
    }

    public static boolean isLegacyDevice(Context context, int i) {
        CameraCharacteristics cameraCharacteristics = getCameraCharacteristics(context, i);
        return cameraCharacteristics != null && ((Integer) cameraCharacteristics.get(CameraCharacteristics.INFO_SUPPORTED_HARDWARE_LEVEL)).intValue() == 2;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void notifyTakePhotoError(long j) {
        nativeOnPhotoTaken(this.mNativeVideoCaptureDeviceAndroid, j, new byte[0]);
    }

    /* access modifiers changed from: private */
    public static void readImageIntoBuffer(Image image, byte[] bArr) {
        int i;
        int i2;
        int width = image.getWidth();
        int height = image.getHeight();
        Image.Plane[] planes = image.getPlanes();
        int i3 = 0;
        for (int i4 = 0; i4 < planes.length; i4++) {
            ByteBuffer buffer = planes[i4].getBuffer();
            int rowStride = planes[i4].getRowStride();
            int pixelStride = planes[i4].getPixelStride();
            if (i4 == 0) {
                i = width;
            } else {
                i = width / 2;
            }
            if (i4 == 0) {
                i2 = height;
            } else {
                i2 = height / 2;
            }
            if (pixelStride == 1 && rowStride == i) {
                int i5 = i * i2;
                buffer.get(bArr, i3, i5);
                i3 = i5 + i3;
            } else {
                byte[] bArr2 = new byte[rowStride];
                for (int i6 = 0; i6 < i2 - 1; i6++) {
                    buffer.get(bArr2, 0, rowStride);
                    int i7 = 0;
                    while (i7 < i) {
                        bArr[i3] = bArr2[i7 * pixelStride];
                        i7++;
                        i3++;
                    }
                }
                buffer.get(bArr2, 0, Math.min(rowStride, buffer.remaining()));
                int i8 = 0;
                while (i8 < i) {
                    bArr[i3] = bArr2[i8 * pixelStride];
                    i8++;
                    i3++;
                }
            }
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:10:0x003a, code lost:
        if (r1 != null) goto L_0x003d;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:11:0x003c, code lost:
        return false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:12:0x003d, code lost:
        r4 = null;
        r5 = r1.length;
        r7 = 0;
        r8 = Integer.MAX_VALUE;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:13:0x0046, code lost:
        if (r7 >= r5) goto L_0x0064;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:14:0x0048, code lost:
        r9 = r1[r7];
        r11 = java.lang.Math.abs(r9.getHeight() - r14) + java.lang.Math.abs(r9.getWidth() - r13);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:15:0x005d, code lost:
        if (r11 >= r8) goto L_0x0061;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x005f, code lost:
        r4 = r9;
        r8 = r11;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x0061, code lost:
        r7 = r7 + 1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:0x0064, code lost:
        if (r8 != Integer.MAX_VALUE) goto L_0x0070;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x0066, code lost:
        org.chromium.base.Log.e(org.chromium.media.VideoCaptureCamera2.TAG, "No supported resolutions.", new java.lang.Object[0]);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x006f, code lost:
        return false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x0070, code lost:
        org.chromium.base.Log.d(org.chromium.media.VideoCaptureCamera2.TAG, "allocate: matched (%d x %d)", java.lang.Integer.valueOf(r4.getWidth()), java.lang.Integer.valueOf(r4.getHeight()));
        r13 = new org.chromium.media.VideoCaptureFormat(r4.getWidth(), r4.getHeight(), r15, 35);
        r12.mCaptureFormat = r13;
        r12.mCapturedData = new byte[((android.graphics.ImageFormat.getBitsPerPixel(r13.mPixelFormat) * (r13.mWidth * r13.mHeight)) / 8)];
        r12.mCameraNativeOrientation = ((java.lang.Integer) r0.get(android.hardware.camera2.CameraCharacteristics.SENSOR_ORIENTATION)).intValue();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:22:0x00c5, code lost:
        if (((java.lang.Integer) r0.get(android.hardware.camera2.CameraCharacteristics.LENS_FACING)).intValue() != 1) goto L_0x00c8;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:23:0x00c7, code lost:
        r3 = true;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:24:0x00c8, code lost:
        r12.mInvertDeviceOrientationReadings = r3;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:25:0x00ca, code lost:
        return true;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:9:0x0024, code lost:
        r0 = getCameraCharacteristics(r12.mContext, r12.mId);
        r1 = ((android.hardware.camera2.params.StreamConfigurationMap) r0.get(android.hardware.camera2.CameraCharacteristics.SCALER_STREAM_CONFIGURATION_MAP)).getOutputSizes(35);
     */
    @Override // org.chromium.media.VideoCapture
    public boolean allocate(int i, int i2, int i3) {
        Log.d(TAG, "allocate: requested (%d x %d) @%dfps", Integer.valueOf(i), Integer.valueOf(i2), Integer.valueOf(i3));
        synchronized (this.mCameraStateLock) {
            CameraState cameraState = this.mCameraState;
            boolean z = false;
            if (cameraState != CameraState.OPENING) {
                if (cameraState == CameraState.CONFIGURING) {
                }
            }
            Log.e(TAG, "allocate() invoked while Camera is busy opening/configuring.", new Object[0]);
            return false;
        }
    }

    @Override // org.chromium.media.VideoCapture
    public void deallocate() {
        Log.d(TAG, "deallocate");
    }

    @Override // org.chromium.media.VideoCapture
    public PhotoCapabilities getPhotoCapabilities() {
        CameraCharacteristics cameraCharacteristics = getCameraCharacteristics(this.mContext, this.mId);
        return new PhotoCapabilities(Math.round(((Float) cameraCharacteristics.get(CameraCharacteristics.SCALER_AVAILABLE_MAX_DIGITAL_ZOOM)).floatValue() * 100.0f), 100, (((Rect) this.mPreviewRequest.get(CaptureRequest.SCALER_CROP_REGION)).width() * 100) / ((Rect) cameraCharacteristics.get(CameraCharacteristics.SENSOR_INFO_ACTIVE_ARRAY_SIZE)).width());
    }

    @Override // org.chromium.media.VideoCapture
    public boolean startCapture() {
        Log.d(TAG, "startCapture");
        changeCameraStateAndNotify(CameraState.OPENING);
        CameraManager cameraManager = (CameraManager) this.mContext.getSystemService("camera");
        Handler handler = new Handler(this.mContext.getMainLooper());
        try {
            cameraManager.openCamera(Integer.toString(this.mId), new CrStateListener(), handler);
            return true;
        } catch (CameraAccessException | IllegalArgumentException | SecurityException e) {
            Log.e(TAG, "allocate: manager.openCamera: ", e);
            return false;
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:17:?, code lost:
        r6.mPreviewSession.abortCaptures();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:0x0035, code lost:
        r0 = r6.mCameraDevice;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x0037, code lost:
        if (r0 != null) goto L_0x003a;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x0039, code lost:
        return false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x003a, code lost:
        r0.close();
        changeCameraStateAndNotify(r2);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:22:0x0040, code lost:
        return true;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:23:0x0041, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:24:0x0044, code lost:
        org.chromium.base.Log.e(org.chromium.media.VideoCaptureCamera2.TAG, "abortCaptures: ", r0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:25:0x004f, code lost:
        return false;
     */
    @Override // org.chromium.media.VideoCapture
    public boolean stopCapture() {
        CameraState cameraState;
        Log.d(TAG, "stopCapture");
        synchronized (this.mCameraStateLock) {
            while (true) {
                cameraState = this.mCameraState;
                if (cameraState == CameraState.STARTED || cameraState == CameraState.STOPPED) {
                    CameraState cameraState2 = CameraState.STOPPED;
                } else {
                    try {
                        this.mCameraStateLock.wait();
                    } catch (InterruptedException e) {
                        Log.e(TAG, "CaptureStartedEvent: ", e);
                    }
                }
            }
            CameraState cameraState22 = CameraState.STOPPED;
            if (cameraState == cameraState22) {
                return true;
            }
        }
    }

    @Override // org.chromium.media.VideoCapture
    public boolean takePhoto(long j) {
        Log.d(TAG, "takePhoto " + j);
        if (this.mCameraDevice != null && this.mCameraState == CameraState.STARTED) {
            ImageReader newInstance = ImageReader.newInstance(this.mCaptureFormat.getWidth(), this.mCaptureFormat.getHeight(), 256, 1);
            HandlerThread handlerThread = new HandlerThread("CameraPicture");
            handlerThread.start();
            Handler handler = new Handler(handlerThread.getLooper());
            newInstance.setOnImageAvailableListener(new CrPhotoReaderListener(j), handler);
            ArrayList arrayList = new ArrayList(1);
            arrayList.add(newInstance.getSurface());
            try {
                CaptureRequest.Builder createCaptureRequest = this.mCameraDevice.createCaptureRequest(2);
                if (createCaptureRequest == null) {
                    Log.e(TAG, "photoRequestBuilder error", new Object[0]);
                    return false;
                }
                createCaptureRequest.addTarget(newInstance.getSurface());
                createCaptureRequest.set(CaptureRequest.JPEG_ORIENTATION, Integer.valueOf(getCameraRotation()));
                try {
                    this.mCameraDevice.createCaptureSession(arrayList, new CrPhotoSessionListener(createCaptureRequest.build(), j), handler);
                    return true;
                } catch (CameraAccessException | IllegalArgumentException | SecurityException e) {
                    Log.e(TAG, "createCaptureSession: " + e, new Object[0]);
                    return false;
                }
            } catch (CameraAccessException unused) {
                Log.e(TAG, "mCameraDevice.createCaptureRequest() error", new Object[0]);
            }
        }
        return false;
    }
}
