package org.chromium.media;

import android.content.Context;
import android.media.MediaCodec;
import android.media.MediaCrypto;
import android.media.MediaExtractor;
import android.media.MediaFormat;
import android.os.ParcelFileDescriptor;
import android.view.Surface;
import java.io.File;
import java.nio.ByteBuffer;
import org.chromium.base.Log;
import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;
import tv.danmaku.ijk.media.player.misc.IMediaFormat;

@JNINamespace("media")
public class WebAudioMediaCodecBridge {
    private static final String TAG = "cr.media";
    public static final long TIMEOUT_MICROSECONDS = 500;

    @CalledByNative
    private static String createTempFile(Context context) {
        return File.createTempFile("webaudio", ".dat", context.getCacheDir()).getAbsolutePath();
    }

    /* JADX WARNING: Removed duplicated region for block: B:28:0x005e  */
    /* JADX WARNING: Removed duplicated region for block: B:43:0x008b  */
    /* JADX WARNING: Removed duplicated region for block: B:81:0x012f  */
    /* JADX WARNING: Removed duplicated region for block: B:92:0x0179  */
    @CalledByNative
    private static boolean decodeAudioFile(Context context, long j, int i, long j2) {
        long j3;
        MediaCodec createDecoderByType;
        boolean z;
        ParcelFileDescriptor parcelFileDescriptor;
        boolean z2;
        boolean z3;
        MediaCodec.BufferInfo bufferInfo;
        int dequeueOutputBuffer;
        ByteBuffer[] byteBufferArr;
        int i2;
        long j4;
        int i3;
        boolean z4;
        if (j2 < 0 || j2 > 2147483647L) {
            return false;
        }
        MediaExtractor mediaExtractor = new MediaExtractor();
        ParcelFileDescriptor adoptFd = ParcelFileDescriptor.adoptFd(i);
        try {
            mediaExtractor.setDataSource(adoptFd.getFileDescriptor(), 0, j2);
            if (mediaExtractor.getTrackCount() <= 0) {
                adoptFd.detachFd();
                return false;
            }
            MediaFormat trackFormat = mediaExtractor.getTrackFormat(0);
            try {
                int integer = trackFormat.getInteger("channel-count");
                try {
                    int integer2 = trackFormat.getInteger("sample-rate");
                    try {
                        String string = trackFormat.getString(IMediaFormat.KEY_MIME);
                        if (trackFormat.containsKey("durationUs")) {
                            try {
                                j3 = trackFormat.getLong("durationUs");
                            } catch (Exception unused) {
                                Log.d(TAG, "Cannot get duration");
                            }
                            if (j3 > 2147483647L) {
                                j3 = 0;
                            }
                            Log.d(TAG, "Initial: Tracks: %d Format: %s", Integer.valueOf(mediaExtractor.getTrackCount()), trackFormat);
                            createDecoderByType = MediaCodec.createDecoderByType(string);
                            try {
                                createDecoderByType.configure(trackFormat, (Surface) null, (MediaCrypto) null, 0);
                                try {
                                    createDecoderByType.start();
                                    try {
                                        ByteBuffer[] inputBuffers = createDecoderByType.getInputBuffers();
                                        try {
                                            ByteBuffer[] outputBuffers = createDecoderByType.getOutputBuffers();
                                            mediaExtractor.selectTrack(0);
                                            int i4 = integer;
                                            z = false;
                                            boolean z5 = false;
                                            boolean z6 = false;
                                            while (!z) {
                                                if (!z5) {
                                                    try {
                                                        int dequeueInputBuffer = createDecoderByType.dequeueInputBuffer(500);
                                                        if (dequeueInputBuffer >= 0) {
                                                            try {
                                                                int readSampleData = mediaExtractor.readSampleData(inputBuffers[dequeueInputBuffer], 0);
                                                                if (readSampleData < 0) {
                                                                    z4 = true;
                                                                    i3 = 0;
                                                                    j4 = 0;
                                                                } else {
                                                                    i3 = readSampleData;
                                                                    z4 = z5;
                                                                    j4 = mediaExtractor.getSampleTime();
                                                                }
                                                                try {
                                                                    createDecoderByType.queueInputBuffer(dequeueInputBuffer, 0, i3, j4, z4 ? 4 : 0);
                                                                    if (!z4) {
                                                                        mediaExtractor.advance();
                                                                    }
                                                                    z3 = z4;
                                                                    bufferInfo = new MediaCodec.BufferInfo();
                                                                    parcelFileDescriptor = adoptFd;
                                                                    dequeueOutputBuffer = createDecoderByType.dequeueOutputBuffer(bufferInfo, 500);
                                                                    if (dequeueOutputBuffer < 0) {
                                                                        ByteBuffer byteBuffer = outputBuffers[dequeueOutputBuffer];
                                                                        if (!z6) {
                                                                            Log.d(TAG, "Final:  Rate: %d Channels: %d Mime: %s Duration: %d microsec", Integer.valueOf(integer2), Integer.valueOf(integer), string, Long.valueOf(j3));
                                                                            nativeInitializeDestination(j, integer, integer2, j3);
                                                                            z6 = true;
                                                                        }
                                                                        byteBufferArr = inputBuffers;
                                                                        if (z6 && (i2 = bufferInfo.size) > 0) {
                                                                            nativeOnChunkDecoded(j, byteBuffer, i2, integer, i4);
                                                                        }
                                                                        byteBuffer.clear();
                                                                        createDecoderByType.releaseOutputBuffer(dequeueOutputBuffer, false);
                                                                        if ((bufferInfo.flags & 4) != 0) {
                                                                            z = true;
                                                                        }
                                                                    } else {
                                                                        byteBufferArr = inputBuffers;
                                                                        if (dequeueOutputBuffer == -3) {
                                                                            outputBuffers = createDecoderByType.getOutputBuffers();
                                                                        } else if (dequeueOutputBuffer == -2) {
                                                                            MediaFormat outputFormat = createDecoderByType.getOutputFormat();
                                                                            i4 = outputFormat.getInteger("channel-count");
                                                                            integer2 = outputFormat.getInteger("sample-rate");
                                                                            Log.d(TAG, "output format changed to " + outputFormat);
                                                                        }
                                                                    }
                                                                    adoptFd = parcelFileDescriptor;
                                                                    z5 = z3;
                                                                    mediaExtractor = mediaExtractor;
                                                                    inputBuffers = byteBufferArr;
                                                                } catch (Exception e) {
                                                                    Object[] objArr = new Object[5];
                                                                    objArr[0] = Integer.valueOf(dequeueInputBuffer);
                                                                    objArr[1] = Integer.valueOf(i3);
                                                                    objArr[2] = Long.valueOf(j4);
                                                                    objArr[3] = Integer.valueOf(z4 ? 4 : 0);
                                                                    objArr[4] = e;
                                                                    Log.w(TAG, "queueInputBuffer(%d, 0, %d, %d, %d) failed.", objArr);
                                                                    parcelFileDescriptor = adoptFd;
                                                                    z2 = false;
                                                                    parcelFileDescriptor.detachFd();
                                                                    createDecoderByType.stop();
                                                                    createDecoderByType.release();
                                                                    return z2;
                                                                }
                                                            } catch (Exception unused2) {
                                                                z2 = false;
                                                                Log.w(TAG, "readSampleData failed.", new Object[0]);
                                                                parcelFileDescriptor = adoptFd;
                                                            }
                                                        }
                                                    } catch (Exception e2) {
                                                        Log.w(TAG, "dequeueInputBuffer(%d) failed.", 500L, e2);
                                                        parcelFileDescriptor = adoptFd;
                                                        z2 = false;
                                                        parcelFileDescriptor.detachFd();
                                                        createDecoderByType.stop();
                                                        createDecoderByType.release();
                                                        return z2;
                                                    }
                                                }
                                                z3 = z5;
                                                bufferInfo = new MediaCodec.BufferInfo();
                                                parcelFileDescriptor = adoptFd;
                                                try {
                                                    dequeueOutputBuffer = createDecoderByType.dequeueOutputBuffer(bufferInfo, 500);
                                                    if (dequeueOutputBuffer < 0) {
                                                    }
                                                    adoptFd = parcelFileDescriptor;
                                                    z5 = z3;
                                                    mediaExtractor = mediaExtractor;
                                                    inputBuffers = byteBufferArr;
                                                } catch (Exception e3) {
                                                    Log.w(TAG, "dequeueOutputBuffer(%s, %d) failed", bufferInfo, 500L);
                                                    e3.printStackTrace();
                                                    z2 = false;
                                                    parcelFileDescriptor.detachFd();
                                                    createDecoderByType.stop();
                                                    createDecoderByType.release();
                                                    return z2;
                                                }
                                            }
                                            parcelFileDescriptor = adoptFd;
                                            z2 = true;
                                            parcelFileDescriptor.detachFd();
                                            createDecoderByType.stop();
                                            createDecoderByType.release();
                                            return z2;
                                        } catch (Exception e4) {
                                            Log.w(TAG, "getOutputBuffers() failed", e4);
                                            adoptFd.detachFd();
                                            return false;
                                        }
                                    } catch (Exception e5) {
                                        Log.w(TAG, "getInputBuffers() failed", e5);
                                        adoptFd.detachFd();
                                        return false;
                                    }
                                } catch (Exception e6) {
                                    Log.w(TAG, "Unable to start()", e6);
                                    adoptFd.detachFd();
                                    return false;
                                }
                            } catch (Exception e7) {
                                Log.w(TAG, "Unable to configure codec for format " + trackFormat, e7);
                                adoptFd.detachFd();
                                return false;
                            }
                        }
                        j3 = 0;
                        if (j3 > 2147483647L) {
                        }
                        Log.d(TAG, "Initial: Tracks: %d Format: %s", Integer.valueOf(mediaExtractor.getTrackCount()), trackFormat);
                        try {
                            createDecoderByType = MediaCodec.createDecoderByType(string);
                            createDecoderByType.configure(trackFormat, (Surface) null, (MediaCrypto) null, 0);
                            createDecoderByType.start();
                            ByteBuffer[] inputBuffers2 = createDecoderByType.getInputBuffers();
                            ByteBuffer[] outputBuffers2 = createDecoderByType.getOutputBuffers();
                            mediaExtractor.selectTrack(0);
                            int i42 = integer;
                            z = false;
                            boolean z52 = false;
                            boolean z62 = false;
                            while (!z) {
                            }
                            parcelFileDescriptor = adoptFd;
                            z2 = true;
                            parcelFileDescriptor.detachFd();
                            createDecoderByType.stop();
                            createDecoderByType.release();
                            return z2;
                        } catch (Exception unused3) {
                            Log.w(TAG, "Failed to create MediaCodec for mime type: %s", string);
                            adoptFd.detachFd();
                            return false;
                        }
                    } catch (Exception unused4) {
                        Log.w(TAG, "Unable to determine type of encoding used by the file", new Object[0]);
                        adoptFd.detachFd();
                        return false;
                    }
                } catch (Exception unused5) {
                    Log.w(TAG, "Unable to determine sample rate", new Object[0]);
                    adoptFd.detachFd();
                    return false;
                }
            } catch (Exception unused6) {
                Log.w(TAG, "Unable to determine number of channels", new Object[0]);
                adoptFd.detachFd();
                return false;
            }
        } catch (Exception e8) {
            e8.printStackTrace();
            adoptFd.detachFd();
            return false;
        }
    }

    private static native void nativeInitializeDestination(long j, int i, int i2, long j2);

    private static native void nativeOnChunkDecoded(long j, ByteBuffer byteBuffer, int i, int i2, int i3);
}
