package org.xwalk.core;

import android.content.Context;
import android.content.SharedPreferences;
import android.content.pm.PackageManager;
import android.os.Build;
import android.util.Log;
import androidx.base.b2;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.URI;
import java.net.URISyntaxException;

public class XWalkEnvironment {
    private static final String META_XWALK_APK_URL = "xwalk_apk_url";
    private static final String META_XWALK_DOWNLOAD_MODE = "xwalk_download_mode";
    private static final String META_XWALK_DOWNLOAD_MODE_UPDATE = "xwalk_download_mode_update";
    private static final String META_XWALK_ENABLE_DOWNLOAD_MODE = "xwalk_enable_download_mode";
    private static final String META_XWALK_VERIFY = "xwalk_verify";
    private static final String OPTIMIZED_DEX_DIR = "dex";
    private static final String PACKAGE_RE = "[a-z]+\\.[a-z0-9]+\\.[a-z0-9]+.*";
    private static final String PRIVATE_DATA_DIRECTORY_SUFFIX = "xwalkcore";
    private static final String TAG = "XWalkLib";
    private static final String XWALK_CORE_EXTRACTED_DIR = "extracted_xwalkcore";
    private static Context sApplicationContext;
    private static String sApplicationName;
    private static String sDeviceAbi;
    private static Boolean sIsDownloadMode;
    private static Boolean sIsDownloadModeUpdate;
    private static Boolean sIsXWalkVerify;
    private static String sRuntimeAbi;
    private static String sXWalkApkUrl;

    public static Context getApplicationContext() {
        return sApplicationContext;
    }

    private static String getApplicationMetaData(String str) {
        try {
            return sApplicationContext.getPackageManager().getApplicationInfo(sApplicationContext.getPackageName(), 128).metaData.get(str).toString();
        } catch (PackageManager.NameNotFoundException | NullPointerException unused) {
            return null;
        }
    }

    public static String getApplicationName() {
        if (sApplicationName == null) {
            try {
                PackageManager packageManager = sApplicationContext.getPackageManager();
                sApplicationName = (String) packageManager.getApplicationLabel(packageManager.getApplicationInfo(sApplicationContext.getPackageName(), 0));
            } catch (PackageManager.NameNotFoundException unused) {
            }
            String str = sApplicationName;
            if (str == null || str.isEmpty() || sApplicationName.matches(PACKAGE_RE)) {
                sApplicationName = "this application";
            }
            StringBuilder j = b2.j("Crosswalk application name: ");
            j.append(sApplicationName);
            Log.d(TAG, j.toString());
        }
        return sApplicationName;
    }

    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:4:0x0010 */
    public static String getDeviceAbi() {
        if (sDeviceAbi == null) {
            sDeviceAbi = Build.SUPPORTED_ABIS[0].toLowerCase();
            try {
                InputStreamReader inputStreamReader = new InputStreamReader(Runtime.getRuntime().exec("getprop ro.product.cpu.abi").getInputStream());
                BufferedReader bufferedReader = new BufferedReader(inputStreamReader);
                sDeviceAbi = bufferedReader.readLine().toLowerCase();
                bufferedReader.close();
                inputStreamReader.close();
                StringBuilder j = b2.j("Device ABI: ");
                j.append(sDeviceAbi);
                Log.d(TAG, j.toString());
            } catch (IOException unused) {
                throw new RuntimeException("Can not detect device's ABI");
            }
        }
        return sDeviceAbi;
    }

    public static String getExtractedCoreDir() {
        return sApplicationContext.getDir(XWALK_CORE_EXTRACTED_DIR, 0).getAbsolutePath();
    }

    public static String getOptimizedDexDir() {
        return sApplicationContext.getDir(OPTIMIZED_DEX_DIR, 0).getAbsolutePath();
    }

    public static String getPrivateDataDir() {
        return sApplicationContext.getDir(PRIVATE_DATA_DIRECTORY_SUFFIX, 0).getAbsolutePath();
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Code restructure failed: missing block: B:75:0x0122, code lost:
        if (r6.equals("armv7l") == false) goto L_0x0124;
     */
    /* JADX WARNING: Removed duplicated region for block: B:92:0x0159  */
    /* JADX WARNING: Removed duplicated region for block: B:95:0x0162  */
    public static String getRuntimeAbi() {
        char c;
        if (sRuntimeAbi == null) {
            char c2 = 0;
            try {
                if (Build.VERSION.SDK_INT < 21) {
                    String lowerCase = Build.CPU_ABI.toLowerCase();
                    switch (lowerCase.hashCode()) {
                        case -806050265:
                            if (lowerCase.equals("x86_64")) {
                                c = 4;
                                break;
                            }
                            c = 65535;
                            break;
                        case -738963905:
                            if (lowerCase.equals("armeabi")) {
                                c = 0;
                                break;
                            }
                            c = 65535;
                            break;
                        case 117110:
                            if (lowerCase.equals("x86")) {
                                c = 3;
                                break;
                            }
                            c = 65535;
                            break;
                        case 145444210:
                            if (lowerCase.equals("armeabi-v7a")) {
                                c = 1;
                                break;
                            }
                            c = 65535;
                            break;
                        case 1431565292:
                            if (lowerCase.equals("arm64-v8a")) {
                                c = 2;
                                break;
                            }
                            c = 65535;
                            break;
                        default:
                            c = 65535;
                            break;
                    }
                    if (c == 0 || c == 1) {
                        sRuntimeAbi = "armeabi-v7a";
                        if (!sRuntimeAbi.equals("armeabi-v7a")) {
                            if (isIaDevice()) {
                                sRuntimeAbi = "x86";
                            }
                        } else if (sRuntimeAbi.equals("arm64-v8a") && isIaDevice()) {
                            sRuntimeAbi = "x86_64";
                        }
                        StringBuilder j = b2.j("Runtime ABI: ");
                        j.append(sRuntimeAbi);
                        Log.d(TAG, j.toString());
                    } else {
                        if (c == 2) {
                            sRuntimeAbi = "arm64-v8a";
                        } else if (c == 3) {
                            sRuntimeAbi = "x86";
                        } else if (c == 4) {
                            sRuntimeAbi = "x86_64";
                        } else {
                            throw new RuntimeException("Unexpected CPU_ABI: " + lowerCase);
                        }
                        if (!sRuntimeAbi.equals("armeabi-v7a")) {
                        }
                        StringBuilder j2 = b2.j("Runtime ABI: ");
                        j2.append(sRuntimeAbi);
                        Log.d(TAG, j2.toString());
                    }
                } else {
                    throw new NoSuchFieldError();
                }
            } catch (NoSuchFieldError unused) {
                String lowerCase2 = System.getProperty("os.arch").toLowerCase();
                lowerCase2.hashCode();
                switch (lowerCase2.hashCode()) {
                    case -1409295825:
                        break;
                    case -1221096139:
                        if (lowerCase2.equals("aarch64")) {
                            c2 = 1;
                            break;
                        }
                        c2 = 65535;
                        break;
                    case -806050265:
                        if (lowerCase2.equals("x86_64")) {
                            c2 = 2;
                            break;
                        }
                        c2 = 65535;
                        break;
                    case -738963905:
                        if (lowerCase2.equals("armeabi")) {
                            c2 = 3;
                            break;
                        }
                        c2 = 65535;
                        break;
                    case 117046:
                        if (lowerCase2.equals("x64")) {
                            c2 = 4;
                            break;
                        }
                        c2 = 65535;
                        break;
                    case 117110:
                        if (lowerCase2.equals("x86")) {
                            c2 = 5;
                            break;
                        }
                        c2 = 65535;
                        break;
                    case 3178856:
                        if (lowerCase2.equals("i386")) {
                            c2 = 6;
                            break;
                        }
                        c2 = 65535;
                        break;
                    case 3181739:
                        if (lowerCase2.equals("i686")) {
                            c2 = 7;
                            break;
                        }
                        c2 = 65535;
                        break;
                    case 3222903:
                        if (lowerCase2.equals("ia32")) {
                            c2 = '\b';
                            break;
                        }
                        c2 = 65535;
                        break;
                    case 93084186:
                        if (lowerCase2.equals("arm64")) {
                            c2 = '\t';
                            break;
                        }
                        c2 = 65535;
                        break;
                    case 93086174:
                        if (lowerCase2.equals("armv8")) {
                            c2 = '\n';
                            break;
                        }
                        c2 = 65535;
                        break;
                    case 145444210:
                        if (lowerCase2.equals("armeabi-v7a")) {
                            c2 = 11;
                            break;
                        }
                        c2 = 65535;
                        break;
                    default:
                        c2 = 65535;
                        break;
                }
                switch (c2) {
                    case 0:
                    case 3:
                    case 11:
                        sRuntimeAbi = "armeabi-v7a";
                        break;
                    case 1:
                    case '\t':
                    case '\n':
                        if (!is64bitDevice()) {
                            sRuntimeAbi = "armeabi-v7a";
                            break;
                        } else {
                            sRuntimeAbi = "arm64-v8a";
                            break;
                        }
                    case 2:
                    case 4:
                        if (!is64bitDevice()) {
                            sRuntimeAbi = "x86";
                            break;
                        } else {
                            sRuntimeAbi = "x86_64";
                            break;
                        }
                    case 5:
                    case 6:
                    case 7:
                    case '\b':
                        sRuntimeAbi = "x86";
                        break;
                    default:
                        throw new RuntimeException(b2.c("Unexpected os.arch: ", lowerCase2));
                }
            }
        }
        return sRuntimeAbi;
    }

    public static SharedPreferences getSharedPreferences() {
        return sApplicationContext.getSharedPreferences("libxwalkcore", 0);
    }

    public static String getXWalkApkUrl() {
        if (sXWalkApkUrl == null) {
            String applicationMetaData = getApplicationMetaData(META_XWALK_APK_URL);
            if (applicationMetaData == null) {
                sXWalkApkUrl = "";
            } else {
                StringBuilder j = b2.j("arch=");
                j.append(getRuntimeAbi());
                String sb = j.toString();
                try {
                    URI uri = new URI(applicationMetaData);
                    String query = uri.getQuery();
                    if (query != null) {
                        sb = query + "&" + sb;
                    }
                    sXWalkApkUrl = new URI(uri.getScheme(), uri.getAuthority(), uri.getPath(), sb, uri.getFragment()).toString();
                } catch (URISyntaxException e) {
                    throw new RuntimeException("Invalid xwalk_apk_url", e);
                }
            }
            StringBuilder j2 = b2.j("Crosswalk APK download URL: ");
            j2.append(sXWalkApkUrl);
            Log.d(TAG, j2.toString());
        }
        return sXWalkApkUrl;
    }

    public static void init(Context context) {
        sApplicationContext = context.getApplicationContext();
    }

    public static boolean is64bitApp() {
        String runtimeAbi = getRuntimeAbi();
        return runtimeAbi.equals("arm64-v8a") || runtimeAbi.equals("x86_64");
    }

    public static boolean is64bitDevice() {
        String deviceAbi = getDeviceAbi();
        return deviceAbi.equals("arm64-v8a") || deviceAbi.equals("x86_64");
    }

    public static boolean isDownloadMode() {
        if (sIsDownloadMode == null) {
            String applicationMetaData = getApplicationMetaData(META_XWALK_DOWNLOAD_MODE);
            if (applicationMetaData == null) {
                applicationMetaData = getApplicationMetaData(META_XWALK_ENABLE_DOWNLOAD_MODE);
            }
            sIsDownloadMode = Boolean.valueOf(applicationMetaData != null && (applicationMetaData.equalsIgnoreCase("enable") || applicationMetaData.equalsIgnoreCase("true")));
            StringBuilder j = b2.j("Crosswalk download mode: ");
            j.append(sIsDownloadMode);
            Log.d(TAG, j.toString());
        }
        return sIsDownloadMode.booleanValue();
    }

    public static boolean isDownloadModeUpdate() {
        if (sIsDownloadModeUpdate == null) {
            String applicationMetaData = getApplicationMetaData(META_XWALK_DOWNLOAD_MODE_UPDATE);
            sIsDownloadModeUpdate = Boolean.valueOf(applicationMetaData != null && (applicationMetaData.equalsIgnoreCase("enable") || applicationMetaData.equalsIgnoreCase("true")));
            StringBuilder j = b2.j("Crosswalk download mode update: ");
            j.append(sIsDownloadModeUpdate);
            Log.d(TAG, j.toString());
        }
        return sIsDownloadModeUpdate.booleanValue();
    }

    public static boolean isIaDevice() {
        String deviceAbi = getDeviceAbi();
        return deviceAbi.equals("x86") || deviceAbi.equals("x86_64");
    }

    public static boolean isXWalkVerify() {
        if (sIsXWalkVerify == null) {
            String applicationMetaData = getApplicationMetaData(META_XWALK_VERIFY);
            sIsXWalkVerify = Boolean.valueOf(applicationMetaData == null || (!applicationMetaData.equalsIgnoreCase("disable") && !applicationMetaData.equalsIgnoreCase("false")));
            StringBuilder j = b2.j("Crosswalk verify: ");
            j.append(sIsXWalkVerify);
            Log.d(TAG, j.toString());
        }
        return sIsXWalkVerify.booleanValue();
    }

    public static void setXWalkApkUrl(String str) {
        sXWalkApkUrl = str;
        StringBuilder j = b2.j("Crosswalk APK download URL: ");
        j.append(sXWalkApkUrl);
        Log.d(TAG, j.toString());
    }
}
