package org.xwalk.core.extension;

import androidx.base.b2;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.util.Iterator;
import java.util.Map;
import org.xwalk.core.extension.ReflectionHelper;

public class JsStubGenerator {
    public static final String MSG_TO_CLASS = "postMessageToClass";
    public static final String MSG_TO_EXTENSION = "postMessageToExtension";
    public static final String MSG_TO_OBJECT = "postMessageToObject";
    public static String TAG = "JsStubGenerator";
    public String jsHeader = "var v8tools = requireNative(\"v8tools\");\nvar jsStubModule = requireNative(\"jsStub\");\njsStubModule.init(extension, v8tools);\nvar jsStub = jsStubModule.jsStub;\nvar helper = jsStub.createRootStub(exports);\n";
    public ReflectionHelper reflection;

    /* renamed from: org.xwalk.core.extension.JsStubGenerator$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$org$xwalk$core$extension$ReflectionHelper$MemberType;

        /* JADX WARNING: Can't wrap try/catch for region: R(6:0|1|2|3|4|(3:5|6|8)) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0011 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x001c */
        static {
            ReflectionHelper.MemberType.values();
            int[] iArr = new int[3];
            $SwitchMap$org$xwalk$core$extension$ReflectionHelper$MemberType = iArr;
            iArr[ReflectionHelper.MemberType.JS_PROPERTY.ordinal()] = 1;
            $SwitchMap$org$xwalk$core$extension$ReflectionHelper$MemberType[ReflectionHelper.MemberType.JS_METHOD.ordinal()] = 2;
            try {
                $SwitchMap$org$xwalk$core$extension$ReflectionHelper$MemberType[ReflectionHelper.MemberType.JS_CONSTRUCTOR.ordinal()] = 3;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    public JsStubGenerator(ReflectionHelper reflectionHelper) {
        this.reflection = reflectionHelper;
    }

    public String[] classGenerator(ReflectionHelper reflectionHelper) {
        String str;
        String str2;
        String str3;
        if (reflectionHelper.getEventList() != null) {
            String generateEventTarget = generateEventTarget(reflectionHelper);
            str = b2.c("", generateEventTarget);
            str2 = b2.c("", generateEventTarget);
        } else {
            str2 = "";
            str = str2;
        }
        Map<String, ReflectionHelper.MemberInfo> members = reflectionHelper.getMembers();
        for (String str4 : members.keySet()) {
            ReflectionHelper.MemberInfo memberInfo = members.get(str4);
            String str5 = memberInfo.isStatic ? MSG_TO_CLASS : MSG_TO_OBJECT;
            int ordinal = memberInfo.type.ordinal();
            if (ordinal == 0) {
                str3 = generateMethod(str5, memberInfo, true);
            } else if (ordinal != 1) {
                str3 = "";
            } else {
                str3 = generateProperty(str5, memberInfo);
            }
            if (memberInfo.isStatic) {
                str2 = b2.c(str2, str3);
            } else {
                str = b2.c(str, str3);
            }
        }
        return new String[]{str, str2};
    }

    public String destroyBindingObject(ReflectionHelper reflectionHelper) {
        Iterator<String> it = reflectionHelper.getMembers().keySet().iterator();
        String str = "exports.destroy = function() {\n";
        while (it.hasNext()) {
            str = str + "delete exports[\"" + it.next() + "\"];\n";
        }
        return b2.c(b2.c(b2.c(b2.c(str, "helper.destroy();\n"), "delete exports[\"__stubHelper\"];\n"), "delete exports[\"destroy\"];\n"), "};");
    }

    public String generate() {
        ReflectionHelper.MemberInfo entryPoint = this.reflection.getEntryPoint();
        String generateEntryPoint = entryPoint != null ? generateEntryPoint(entryPoint) : "";
        if (generateEntryPoint.length() <= 0) {
            generateEntryPoint = this.jsHeader;
        }
        if (this.reflection.getEventList() != null) {
            StringBuilder j = b2.j(generateEntryPoint);
            j.append(generateEventTarget(this.reflection));
            generateEntryPoint = j.toString();
        }
        Map<String, ReflectionHelper.MemberInfo> members = this.reflection.getMembers();
        for (String str : members.keySet()) {
            ReflectionHelper.MemberInfo memberInfo = members.get(str);
            if (!memberInfo.isEntryPoint) {
                int ordinal = memberInfo.type.ordinal();
                if (ordinal == 0) {
                    StringBuilder j2 = b2.j(generateEntryPoint);
                    j2.append(generateMethod(MSG_TO_EXTENSION, memberInfo, true));
                    generateEntryPoint = j2.toString();
                } else if (ordinal == 1) {
                    StringBuilder j3 = b2.j(generateEntryPoint);
                    j3.append(generateProperty(MSG_TO_EXTENSION, memberInfo));
                    generateEntryPoint = j3.toString();
                } else if (ordinal == 2) {
                    StringBuilder j4 = b2.j(generateEntryPoint);
                    j4.append(generateConstructor(memberInfo, true));
                    generateEntryPoint = j4.toString();
                }
            }
        }
        return b2.c(generateEntryPoint, "\n");
    }

    public String generateConstructor(ReflectionHelper.MemberInfo memberInfo, boolean z) {
        String str;
        String str2 = memberInfo.jsName;
        String prototypeName = getPrototypeName(str2);
        String argString = getArgString((Method) memberInfo.accesser, false);
        ReflectionHelper constructorReflection = this.reflection.getConstructorReflection(str2);
        String[] classGenerator = classGenerator(constructorReflection);
        String format = String.format("function %s(exports, helper){\n%s\n%s\n}\n", prototypeName, classGenerator[0], destroyBindingObject(constructorReflection));
        String format2 = String.format("function %s(%s) {\nvar newObject = this;\nvar objectId =\nNumber(helper.invokeNative(\"%s\", \"+%s\", [%s], true));\nif (!objectId) throw \"Error to create instance for constructor:%s.\";\nvar objectHelper = jsStub.getHelper(newObject, helper);\nobjectHelper.objectId = objectId;\nobjectHelper.constructorJsName = \"%s\";\nobjectHelper.registerLifecycleTracker();%s(newObject, objectHelper);\nhelper.addBindingObject(objectId, newObject);}\nhelper.constructors[\"%s\"] = %s;\n", str2, argString, MSG_TO_EXTENSION, str2, argString, str2, str2, prototypeName, str2, str2);
        String format3 = String.format("(function(exports, helper){\n  helper.constructorJsName = \"%s\";\n%s\n})(%s, jsStub.getHelper(%s, helper));\n", str2, classGenerator[1], str2, str2);
        if (z) {
            str = String.format("exports[\"%s\"] = %s;\n", str2, str2);
        } else {
            str = "";
        }
        return format + format2 + format3 + str;
    }

    public String generateEntryPoint(ReflectionHelper.MemberInfo memberInfo) {
        ReflectionHelper.MemberType memberType = memberInfo.type;
        if (memberType == ReflectionHelper.MemberType.JS_PROPERTY) {
            String simpleName = ((Field) memberInfo.accesser).getType().getSimpleName();
            return this.jsHeader + String.format("%s(exports, helper);\n", getPrototypeName(simpleName));
        } else if (memberType == ReflectionHelper.MemberType.JS_METHOD) {
            return String.format("exports = %s;\n %s\n %s", getInternalName(memberInfo.jsName), this.jsHeader, generateMethod(MSG_TO_EXTENSION, memberInfo, false));
        } else if (memberType != ReflectionHelper.MemberType.JS_CONSTRUCTOR) {
            return "";
        } else {
            return String.format("exports = %s;\n %s\n %s", memberInfo.jsName, this.jsHeader, generateConstructor(memberInfo, false));
        }
    }

    public String generateEventTarget(ReflectionHelper reflectionHelper) {
        String[] eventList = reflectionHelper.getEventList();
        if (eventList == null || eventList.length == 0) {
            return "";
        }
        String str = "jsStub.makeEventTarget(exports);\n";
        for (String str2 : eventList) {
            str = str + "helper.addEvent(\"" + str2 + "\");\n";
        }
        return str;
    }

    public String generateMethod(String str, ReflectionHelper.MemberInfo memberInfo, boolean z) {
        if (memberInfo.withPromise) {
            return generatePromiseMethod(str, memberInfo);
        }
        String str2 = memberInfo.jsName;
        Method method = (Method) memberInfo.accesser;
        String internalName = getInternalName(str2);
        method.getParameterAnnotations();
        String argString = getArgString(method, memberInfo.withPromise);
        boolean z2 = !method.getReturnType().equals(Void.TYPE);
        StringBuilder j = b2.j("function %s(%s) {\n");
        j.append(z2 ? "  return " : "  ");
        j.append("helper.invokeNative(\"%s\", \"%s\", [%s], %b);\n");
        j.append("};\n");
        return b2.c(String.format(j.toString(), internalName, argString, str, str2, argString, Boolean.valueOf(z2)), z ? String.format("exports[\"%s\"] = %s;\n", str2, internalName) : "");
    }

    public String generatePromiseMethod(String str, ReflectionHelper.MemberInfo memberInfo) {
        String str2 = memberInfo.jsName;
        String str3 = "null";
        String str4 = memberInfo.wrapArgs.length() > 0 ? memberInfo.wrapArgs : str3;
        if (memberInfo.wrapReturns.length() > 0) {
            str3 = memberInfo.wrapReturns;
        }
        return String.format("jsStub.addMethodWithPromise(\"%s\", exports, \"%s\", %s, %s);\n", str, str2, str4, str3);
    }

    public String generateProperty(String str, ReflectionHelper.MemberInfo memberInfo) {
        return String.format("jsStub.defineProperty(\"%s\", exports, \"%s\", %b);\n", str, memberInfo.jsName, Boolean.valueOf(memberInfo.isWritable));
    }

    public String getArgString(Method method, boolean z) {
        String str = "";
        if (method == null) {
            return str;
        }
        Class<?>[] parameterTypes = method.getParameterTypes();
        method.getParameterAnnotations();
        int length = parameterTypes.length;
        if (z) {
            length--;
        }
        for (int i = 0; i < length; i++) {
            Class<?> cls = parameterTypes[i];
            StringBuilder k = b2.k("arg", i, "_");
            k.append(cls.getSimpleName());
            String sb = k.toString();
            if (str.length() > 0) {
                str = b2.c(str, ", ");
            }
            str = b2.c(str, sb);
        }
        return str;
    }

    public String getInternalName(String str) {
        return b2.c("__", str);
    }

    public String getPrototypeName(String str) {
        return b2.d("__", str, "_prototype");
    }
}
